<?php
/**
 * Advanced Footer Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Advanced_Footer_Configs' ) ) {

	/**
	 * Register Advanced Footer Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Advanced_Footer_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Advanced Footer Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_config = array(
				/**
				 * Option: Footer Widgets Layout
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[footer-adv]',
					'default'           => adaptive_get_option( 'footer-adv' ),
					'type'              => 'control',
					'priority'          => 0,
					'control'           => 'ast-radio-image',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_choices' ),
					'title'             => __( '样式', 'adaptive-addon' ),
					'section'           => 'section-footer-adv',
					'choices'           => array(
						'disabled' => array(
							'label' => __( '禁用', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'disabled', false ) : '',
						),
						'layout-1' => array(
							'label' => __( '布局1', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'footer-adv-layout-1', false ) : '',
						),
						'layout-2' => array(
							'label' => __( '布局2', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'footer-adv-layout-2', false ) : '',
						),
						'layout-3' => array(
							'label' => __( '布局3', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'footer-adv-layout-3', false ) : '',
						),
						'layout-4' => array(
							'label' => __( '布局4', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'footer-layout-4', false ) : '',
						),
						'layout-5' => array(
							'label' => __( '布局5', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'footer-adv-layout-5', false ) : '',
						),
						'layout-6' => array(
							'label' => __( '布局6', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'footer-adv-layout-6', false ) : '',
						),
						'layout-7' => array(
							'label' => __( '布局7', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'footer-adv-layout-7', false ) : '',
						),
					),
				),

				/**
				 * Option: Footer Widgets Width
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[footer-adv-layout-width]',
					'default'  => adaptive_get_option( 'footer-adv-layout-width' ),
					'type'     => 'control',
					'priority' => 1,
					'control'  => 'ast-select',
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'section'  => 'section-footer-adv',
					'title'    => __( '宽度', 'adaptive-addon' ),
					'choices'  => array(
						'full'    => __( '全宽度', 'adaptive-addon' ),
						'content' => __( '内容宽度', 'adaptive-addon' ),
					),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[footer-adv]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
					'divider'  => array( 'ast_class' => 'ast-top-divider' ),
				),

				/**
				 * Footer Widgets Padding
				 *
				 * @since 1.2.0 Updated to support responsive spacing param
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[footer-adv-area-padding]',
					'default'           => adaptive_get_option( 'footer-adv-area-padding' ),
					'type'              => 'control',
					'transport'         => 'postMessage',
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority'          => 2,
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'section'           => 'section-footer-adv',
					'title'             => __( '内距', 'adaptive-addon' ),
					'linked_choices'    => true,
					'unit_choices'      => array( 'px', 'em', '%' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
					'context'           => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[footer-adv]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
				),
			);

			return array_merge( $configurations, $_config );
		}

	}
}

new Adaptive_Advanced_Footer_Configs();
