<?php
/**
 * Advanced Footer Typography Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Advanced_Footer_Typo_Configs' ) ) {

	/**
	 * Register Advanced Footer Typography Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Advanced_Footer_Typo_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Advanced Footer Typography Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_config = array(

				/**
				 * Option: Footer Widget Title Typography Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[footer-widget-title-typography-group]',
					'default'   => adaptive_get_option( 'footer-widget-title-typography-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '小工具标题字体', 'adaptive-addon' ),
					'section'   => 'section-footer-adv',
					'transport' => 'postMessage',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority'  => 48,
					'context'   => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[footer-adv]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
				),

				array(
					'name'      => 'footer-adv-wgt-title-font-family',
					'default'   => adaptive_get_option( 'footer-adv-wgt-title-font-family' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[footer-widget-title-typography-group]',
					'section'   => 'section-footer-adv',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[footer-adv-wgt-title-font-weight]',
				),

				array(
					'name'        => 'footer-adv-wgt-title-font-size',
					'default'     => adaptive_get_option( 'footer-adv-wgt-title-font-size' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[footer-widget-title-typography-group]',
					'section'     => 'section-footer-adv',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'control'     => 'ast-responsive',
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				array(
					'name'              => 'footer-adv-wgt-title-font-weight',
					'default'           => adaptive_get_option( 'footer-adv-wgt-title-font-weight' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-widget-title-typography-group]',
					'section'           => 'section-footer-adv',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'footer-adv-wgt-title-font-family',
				),

				array(
					'name'    => 'footer-adv-wgt-title-text-transform',
					'default' => adaptive_get_option( 'footer-adv-wgt-title-text-transform' ),
					'type'    => 'sub-control',
					'parent'  => ADAPTIVE_THEME_SETTINGS . '[footer-widget-title-typography-group]',
					'section' => 'section-footer-adv',
					'title'   => __( '文本转换', 'adaptive-addon' ),
					'control' => 'ast-select',
					'choices' => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				array(
					'name'              => 'footer-adv-wgt-title-line-height',
					'default'           => adaptive_get_option( 'footer-adv-wgt-title-line-height' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-widget-title-typography-group]',
					'section'           => 'section-footer-adv',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'title'             => __( '行高', 'adaptive-addon' ),
					'control'           => 'ast-slider',
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

				/**
				 * Option: Footer Widget Content Typography Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[footer-widget-content-typography-group]',
					'default'   => adaptive_get_option( 'footer-widget-content-typography-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '小工具内容字体', 'adaptive-addon' ),
					'section'   => 'section-footer-adv',
					'transport' => 'postMessage',
					'priority'  => 48,
					'context'   => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[footer-adv]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
				),

				array(
					'name'      => 'footer-adv-wgt-content-font-family',
					'default'   => adaptive_get_option( 'footer-adv-wgt-content-font-family' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[footer-widget-content-typography-group]',
					'section'   => 'section-footer-adv',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[footer-adv-wgt-content-font-weight]',
				),

				array(
					'name'        => 'footer-adv-wgt-content-font-size',
					'default'     => adaptive_get_option( 'footer-adv-wgt-content-font-size' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[footer-widget-content-typography-group]',
					'section'     => 'section-footer-adv',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'control'     => 'ast-responsive',
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				array(
					'name'              => 'footer-adv-wgt-content-font-weight',
					'default'           => adaptive_get_option( 'footer-adv-wgt-content-font-weight' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-widget-content-typography-group]',
					'section'           => 'section-footer-adv',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'footer-adv-wgt-content-font-family',
				),

				array(
					'name'    => 'footer-adv-wgt-content-text-transform',
					'default' => adaptive_get_option( 'footer-adv-wgt-content-text-transform' ),
					'type'    => 'sub-control',
					'parent'  => ADAPTIVE_THEME_SETTINGS . '[footer-widget-content-typography-group]',
					'section' => 'section-footer-adv',
					'title'   => __( '文本转换', 'adaptive-addon' ),
					'control' => 'ast-select',
					'choices' => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				array(
					'name'              => 'footer-adv-wgt-content-line-height',
					'default'           => adaptive_get_option( 'footer-adv-wgt-content-line-height' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-widget-content-typography-group]',
					'section'           => 'section-footer-adv',
					'title'             => __( '行高', 'adaptive-addon' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'control'           => 'ast-slider',
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

			);

			return array_merge( $configurations, $_config );
		}

	}
}

new Adaptive_Advanced_Footer_Typo_Configs();



