<?php
/**
 * Advanced Headers - Loader.
 *
 * @package Adaptive Addon
 * @since 1.0.0
 */

if ( ! class_exists( 'Adaptive_Ext_Advanced_Headers_Loader' ) ) {

	/**
	 * Adaptive Advanced Headers Initialization
	 *
	 * @since 1.0.0
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Ext_Advanced_Headers_Loader { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Member Variable
		 *
		 * @var instance
		 */
		private static $instance;

		/**
		 * Member Variable
		 *
		 * @var $_action
		 */
		public static $_action = 'advanced-headers'; // phpcs:ignore PSR2.Classes.PropertyDeclaration.Underscore

		/**
		 *  Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 *  Constructor
		 */
		public function __construct() {

			add_action( 'init', array( $this, 'advanced_headers_post_type' ) );
			add_action( 'admin_menu', array( $this, 'register_admin_menu' ), 100 );
			add_filter( 'postbox_classes_adaptive_adv_header_adaptive_advanced_headers_settings', array( $this, 'add_class_to_metabox' ) );

			add_filter( 'post_updated_messages', array( $this, 'custom_post_type_post_update_messages' ) );

			if ( is_admin() ) {
				add_action( 'manage_adaptive_adv_header_posts_custom_column', array( $this, 'column_content' ), 10, 2 );
				// Filters.
				add_filter( 'manage_adaptive_adv_header_posts_columns', array( $this, 'column_headings' ) );
			}

			// Actions.
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );

			self::load_files();
		}


		/**
		 * Add Custom Class to setting meta box
		 *
		 * @param array $classes Array of meta box classes.
		 * @return array $classes updated body classes.
		 */
		public function add_class_to_metabox( $classes ) {
			$classes[] = 'adaptive-advanced-headers-meta-box-wrap';
				return $classes;
		}

		/**
		 * Loads classes and includes.
		 *
		 * @since 1.0.0
		 * @access private
		 * @return void
		 */
		private static function load_files() {
			// Classes.
			include_once ADAPTIVE_ADDON_EXT_ADVANCED_HEADERS_DIR . 'classes/class-adaptive-ext-advanced-headers-data.php';
			// Load Adaptive Breadcrumbs.
			include_once ADAPTIVE_ADDON_EXT_ADVANCED_HEADERS_DIR . 'classes/adaptive-breadcrumbs.php';
		}


		/**
		 * Return Advanced Headers layout options.
		 *
		 * @param  string $option     Option key.
		 * @param  string $default    Option default value.
		 * @param  string $deprecated Option default value.
		 * @return string                  Return option value.
		 */
		public static function adaptive_advanced_headers_layout_option( $option, $default = '', $deprecated = '' ) {

			if ( '' != $deprecated ) {
				$default = $deprecated;
			}

			$advanced_headers_options = self::get_advanced_headers_layout();
			if ( ! $advanced_headers_options ) {
				return false;
			}
			$value = ( isset( $advanced_headers_options[ $option ] ) && '' !== $advanced_headers_options[ $option ] ) ? $advanced_headers_options[ $option ] : $default;

			return $value;
		}

		/**
		 * Return Advanced Headers design options.
		 *
		 * @param  string $option     Option key.
		 * @param  string $default    Option default value.
		 * @param  string $deprecated Option default value.
		 * @return string                  Return option value.
		 */
		public static function adaptive_advanced_headers_design_option( $option, $default = '', $deprecated = '' ) {

			if ( '' != $deprecated ) {
				$default = $deprecated;
			}

			$advanced_headers_options = self::get_advanced_headers_design();

			$value = ( isset( $advanced_headers_options[ $option ] ) && '' !== $advanced_headers_options[ $option ] ) ? $advanced_headers_options[ $option ] : $default;

			return $value;
		}

		/**
		 * Render Advanced Headers Setting page
		 */
		public static function get_advanced_headers_layout() {

			$ids = Adaptive_Ext_Advanced_Headers_Data::get_current_page_header_ids();

			if ( false == $ids ) {
				return false;
			}

			$settings = get_post_meta( $ids, 'ast-advanced-headers-layout', true );

			return $settings;
		}

		/**
		 * Render Advanced Headers Setting page
		 */
		public static function get_advanced_headers_design() {

			$ids = Adaptive_Ext_Advanced_Headers_Data::get_current_page_header_ids();

			if ( false == $ids ) {
				return false;
			}

			$settings = get_post_meta( $ids, 'ast-advanced-headers-design', true );

			return $settings;
		}

		/**
		 * Create Adaptive Advanced Headers custom post type
		 */
		public function advanced_headers_post_type() {

			$labels = array(
				'name'          => esc_html_x( '页面页眉', 'advanced-header general name', 'adaptive-addon' ),
				'singular_name' => esc_html_x( '页眉', 'advanced-header singular name', 'adaptive-addon' ),
				'search_items'  => esc_html__( '搜索页眉', 'adaptive-addon' ),
				'all_items'     => esc_html__( '所有的页眉', 'adaptive-addon' ),
				'edit_item'     => esc_html__( '编辑标题', 'adaptive-addon' ),
				'add_new'       => esc_html__( '新增可重用区块', 'adaptive-addon' ),
				'update_item'   => esc_html__( '更新标题', 'adaptive-addon' ),
				'add_new_item'  => esc_html__( '新增可重用区块', 'adaptive-addon' ),
				'new_item_name' => esc_html__( '新标题名称', 'adaptive-addon' ),
			);

			$args = array(
				'labels'              => $labels,
				'show_in_menu'        => false,
				'public'              => false,
				'show_ui'             => true,
				'query_var'           => true,
				'can_export'          => true,
				'show_in_menu'        => false,
				'show_in_admin_bar'   => true,
				'exclude_from_search' => true,
				'supports'            => apply_filters( 'adaptive_advanced_headers_supports', array( 'title' ) ),
			);

			register_post_type( 'adaptive_adv_header', apply_filters( 'adaptive_advanced_headers_post_type_args', $args ) );
		}

		/**
		 * Register the admin menu for Page Headers
		 *
		 * @since  1.2.1
		 *         Moved the menu under Appearance -> Page Headers
		 */
		public function register_admin_menu() {

			$page_header_capability = apply_filters( 'adaptive_page_header_capability', 'edit_theme_options' );

			add_submenu_page(
				'themes.php',
				__( '页面页眉', 'adaptive-addon' ),
				__( '页面页眉', 'adaptive-addon' ),
				$page_header_capability,
				'edit.php?post_type=adaptive_adv_header'
			);
		}

		/**
		 * Enqueues scripts and styles for the theme layout
		 * post type on the GeChiUI admin edit post screen.
		 *
		 * @since 1.0.0
		 * @return void
		 */
		public function admin_enqueue_scripts() {

			global $pagenow;
			global $post;

			$screen = get_current_screen();

			if ( ( 'post-new.php' == $pagenow || 'post.php' == $pagenow ) && 'adaptive_adv_header' == $screen->post_type ) {
				$rtl = '';
				if ( is_rtl() ) {
					$rtl = '-rtl';
				}
				// Styles.
				gc_enqueue_media();

				/**
				 * Localize gc-color-picker & gcColorPickerL10n.
				 *
				 * This is only needed in GeChiUI version >= 5.5 because gcColorPickerL10n has been removed.
				 *
				 * @see https://github.com/GeChiUI/GeChiUI/commit/7e7b70cd1ae5772229abb769d0823411112c748b
				 *
				 * This is should be removed once the issue is fixed from gc-color-picker-alpha repo.
				 * @see https://github.com/kallookoo/gc-color-picker-alpha/issues/35
				 *
				 * @since 2.6.3
				 */
				global $gc_version;

				if ( version_compare( $gc_version, '5.4.99', '>=' ) ) {
					gc_localize_script(
						'gc-color-picker',
						'gcColorPickerL10n',
						array(
							'clear'            => __( '不排序', 'adaptive-addon' ),
							'clearAriaLabel'   => __( '清除颜色', 'adaptive-addon' ),
							'defaultString'    => __( '默认', 'adaptive-addon' ),
							'defaultAriaLabel' => __( '选择默认的颜色', 'adaptive-addon' ),
							'pick'             => __( '选择颜色', 'adaptive-addon' ),
							'defaultLabel'     => __( '色彩明度', 'adaptive-addon' ),
						)
					);
				}

				// Scripts.
				if ( SCRIPT_DEBUG ) {

					gc_enqueue_style( 'adaptive-advanced-headers-admin-edit', ADAPTIVE_ADDON_EXT_ADVANCED_HEADERS_URL . 'assets/css/unminified/adaptive-advanced-headers-admin-edit' . $rtl . '.css', array( 'gc-color-picker' ), ADAPTIVE_EXT_VER );

					gc_enqueue_script( 'adaptive-advanced-headers-admin', ADAPTIVE_ADDON_EXT_ADVANCED_HEADERS_URL . 'assets/js/unminified/adaptive-advanced-headers-admin.js', array( 'jquery', 'gc-color-picker', 'adaptive-color-alpha', 'jquery-ui-tooltip' ), ADAPTIVE_EXT_VER, false );

				} else {
					gc_enqueue_style( 'adaptive-advanced-headers-admin-edit', ADAPTIVE_ADDON_EXT_ADVANCED_HEADERS_URL . 'assets/css/minified/adaptive-advanced-headers-admin-edit' . $rtl . '.min.css', array( 'gc-color-picker' ), ADAPTIVE_EXT_VER );

					gc_enqueue_script( 'adaptive-advanced-headers-admin', ADAPTIVE_ADDON_EXT_ADVANCED_HEADERS_URL . 'assets/js/minified/adaptive-advanced-headers-admin.min.js', array( 'jquery', 'gc-color-picker', 'adaptive-color-alpha', 'jquery-ui-tooltip' ), ADAPTIVE_EXT_VER, false );
				}
			}
		}

		/**
		 * Add Update messages for any custom post type
		 *
		 * @param array $messages Array of default messages.
		 */
		public function custom_post_type_post_update_messages( $messages ) {

			$custom_post_type = get_post_type( get_the_ID() );

			if ( 'adaptive_adv_header' == $custom_post_type ) {

				$obj                           = get_post_type_object( $custom_post_type );
				$singular_name                 = $obj->labels->singular_name;
				$messages[ $custom_post_type ] = array(
					0  => '', // Unused. Messages start at index 1.
					/* translators: %s: singular custom post type name */
					1  => sprintf( __( '%s 更新。', 'adaptive-addon' ), $singular_name ),
					/* translators: %s: singular custom post type name */
					2  => sprintf( __( '自定义更新%s。', 'adaptive-addon' ), $singular_name ),
					/* translators: %s: singular custom post type name */
					3  => sprintf( __( '自定义删除%s。', 'adaptive-addon' ), $singular_name ),
					/* translators: %s: singular custom post type name */
					4  => sprintf( __( '%s 更新。', 'adaptive-addon' ), $singular_name ),
					/* translators: %1$s: singular custom post type name ,%2$s: date and time of the revision */
					5  => isset( $_GET['revision'] ) ? sprintf( __( '%1$s从%2$s恢复到修订版本', 'adaptive-addon' ), $singular_name, gc_post_revision_title( (int) $_GET['revision'], false ) ) : false, // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
					/* translators: %s: singular custom post type name */
					6  => sprintf( __( '% s发布。', 'adaptive-addon' ), $singular_name ),
					/* translators: %s: singular custom post type name */
					7  => sprintf( __( '%s保存。', 'adaptive-addon' ), $singular_name ),
					/* translators: %s: singular custom post type name */
					8  => sprintf( __( '%s提交。', 'adaptive-addon' ), $singular_name ),
					/* translators: %s: singular custom post type name */
					9  => sprintf( __( '%s安排。', 'adaptive-addon' ), $singular_name ),
					/* translators: %s: singular custom post type name */
					10 => sprintf( __( '% s更新草稿。', 'adaptive-addon' ), $singular_name ),
				);
			}

			return $messages;
		}

		/**
		 * Adds or removes list table column headings.
		 *
		 * @param array $columns Array of columns.
		 * @return array
		 */
		public static function column_headings( $columns ) {

			unset( $columns['date'] );

			$columns['advanced_headers_display_rules'] = __( '显示规则', 'adaptive-addon' );
			$columns['date']                           = __( '时间', 'adaptive-addon' );

			return $columns;
		}

		/**
		 * Adds the custom list table column content.
		 *
		 * @since 1.0
		 * @param array $column Name of column.
		 * @param int   $post_id Post id.
		 * @return void
		 */
		public function column_content( $column, $post_id ) {

			if ( 'advanced_headers_display_rules' == $column ) {

				$locations = get_post_meta( $post_id, 'ast-advanced-headers-location', true );
				if ( ! empty( $locations ) ) {
					echo '<div class="ast-advanced-headers-location-wrap" style="margin-bottom: 5px;">';
					echo '<strong>Display: </strong>';
					$this->column_display_location_rules( $locations );
					echo '</div>';
				}

				$locations = get_post_meta( $post_id, 'ast-advanced-headers-exclusion', true );
				if ( ! empty( $locations ) ) {
					echo '<div class="ast-advanced-headers-exclusion-wrap" style="margin-bottom: 5px;">';
					echo '<strong>Exclusion: </strong>';
					$this->column_display_location_rules( $locations );
					echo '</div>';
				}

				$users = get_post_meta( $post_id, 'ast-advanced-headers-users', true );
				if ( isset( $users ) && is_array( $users ) ) {
					if ( isset( $users[0] ) && ! empty( $users[0] ) ) {
						$user_label = array();
						foreach ( $users as $user ) {
							$user_label[] = Adaptive_Target_Rules_Fields::get_user_by_key( $user );
						}
						echo '<div class="ast-advanced-headers-users-wrap">';
						echo '<strong>Users: </strong>';
						echo esc_html( join( ', ', $user_label ) );
						echo '</div>';
					}
				}
			}
		}

		/**
		 * Get Markup of Location rules for Display rule column.
		 *
		 * @param array $locations Array of locations.
		 * @return void
		 */
		public function column_display_location_rules( $locations ) {

			$location_label = array();
			$index          = array_search( 'specifics', $locations['rule'] );
			if ( false !== $index && ! empty( $index ) ) {
				unset( $locations['rule'][ $index ] );
			}

			if ( isset( $locations['rule'] ) && is_array( $locations['rule'] ) ) {
				foreach ( $locations['rule'] as $location ) {
					$location_label[] = Adaptive_Target_Rules_Fields::get_location_by_key( $location );
				}
			}
			if ( isset( $locations['specific'] ) && is_array( $locations['specific'] ) ) {
				foreach ( $locations['specific'] as $location ) {
					$location_label[] = Adaptive_Target_Rules_Fields::get_location_by_key( $location );
				}
			}

			echo esc_html( join( ', ', $location_label ) );
		}

	}
}

/**
 *  Kicking this off by calling 'get_instance()' method
 */
Adaptive_Ext_Advanced_Headers_Loader::get_instance();
