<?php
/**
 * Adaptive Advanced Hooks Bar Post Meta Box
 *
 * @package   Adaptive Pro
 */

/**
 * Meta Boxes setup
 */
if ( ! class_exists( 'Adaptive_Ext_Advanced_Hooks_Meta' ) ) {

	/**
	 * Meta Boxes setup
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Ext_Advanced_Hooks_Meta { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Instance
		 *
		 * @var $instance
		 */
		private static $instance;

		/**
		 * Meta Option
		 *
		 * @var $meta_option
		 */
		private static $meta_option;

		/**
		 * Theme Layouts hooks.
		 *
		 * @var $layouts
		 */
		public static $layouts = array();

		/**
		 * Theme Action hooks.
		 *
		 * @var $hooks
		 */
		public static $hooks = array();

		/**
		 * Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}

			/**
			 * Filter for the 'Layouts' in Custom Layouts selection.
			 *
			 * @since 1.5.0
			 */
			$layouts = array(
				'header'   => array(
					'title' => __( '表头', 'adaptive-addon' ),
				),
				'footer'   => array(
					'title' => __( '注脚', 'adaptive-addon' ),
				),
				'404-page' => array(
					'title' => __( '404页', 'adaptive-addon' ),
				),
				'hooks'    => array(
					'title' => __( 'Hooks', 'adaptive-addon' ),
				),
				'content'  => array(
					'title' => __( '内页小工具内容', 'adaptive-addon' ),
				),
			);

			/**
			 * Filter for the 'Hooks' in Custom Layouts selection.
			 *
			 * @since 1.5.0
			 */
			$hooks = array(
				'head'    => array(
					'title' => __( '头部', 'adaptive-addon' ),
					'hooks' => array(
						'adaptive_html_before' => array(
							'title'       => 'html_before',
							'description' => __( 'adaptive_html_before - 在打开 <html> 标记之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_head_top'    => array(
							'title'       => 'head_top',
							'description' => __( 'adaptive_head_top - 将您的内容或代码段添加到 <head> 标记顶部的操作。', 'adaptive-addon' ),
						),
						'adaptive_head_bottom' => array(
							'title'       => 'head_bottom',
							'description' => __( 'adaptive_head_bottom - 在 <head> 标记底部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'gc_head'           => array(
							'title'       => 'gc_head',
							'description' => __( 'gc_head - 在 <head> 标记底部添加自定义样式，脚本和元的操作。', 'adaptive-addon' ),
						),
					),
				),
				'header'  => array(
					'title' => __( '表头', 'adaptive-addon' ),
					'hooks' => array(
						'adaptive_body_top'               => array(
							'title'       => 'body_top',
							'description' => __( 'adaptive_body_top - 将您的内容或代码段添加到 <body> 标记顶部的操作。', 'adaptive-addon' ),
						),
						'adaptive_header_before'          => array(
							'title'       => 'header_before',
							'description' => __( 'adaptive_header_before - 在开始 <header> 标记之前添加内容或代码段的操作.', 'adaptive-addon' ),
						),
						'adaptive_masthead_top'           => array(
							'title'       => 'masthead_top',
							'description' => __( 'adaptive_masthead_top -添加内容或代码片段的操作  的顶部 <header> 标签.', 'adaptive-addon' ),
						),
						'adaptive_main_header_bar_top'    => array(
							'title'       => 'main_header_bar_top',
							'description' => __( 'adaptive_main_header_bar_top—在主标题顶部添加内容或代码片段的操作。', 'adaptive-addon' ),
						),
						'adaptive_masthead_content'       => array(
							'title'       => 'masthead_content',
							'description' => __( 'adaptive_masthead_content—添加内容或片段的操作<header> 标签.', 'adaptive-addon' ),
						),
						'adaptive_masthead_toggle_buttons_before' => array(
							'title'       => 'masthead_toggle_buttons_before',
							'description' => __( 'adaptive_masthead_toggle_buttons_before -在响应式菜单切换按钮之前添加内容或代码片段的操作。', 'adaptive-addon' ),
						),
						'adaptive_masthead_toggle_buttons_after' => array(
							'title'       => 'masthead_toggle_buttons_after',
							'description' => __( 'adaptive_masthead_toggle_buttons_after -在响应式菜单切换按钮之后添加内容或代码片段的操作。', 'adaptive-addon' ),
						),
						'adaptive_main_header_bar_bottom' => array(
							'title'       => 'main_header_bar_bottom',
							'description' => __( 'adaptive_main_header_bar_bottom—在主标题底部之后添加内容或代码片段的操作。', 'adaptive-addon' ),
						),
						'adaptive_masthead_bottom'        => array(
							'title'       => 'masthead_bottom',
							'description' => __( 'adaptive_masthead_bottom -添加内容或代码片段的操作  底部的<header> 标签.', 'adaptive-addon' ),
						),
						'adaptive_header_after'           => array(
							'title'       => 'header_after',
							'description' => __( 'adaptive_header_after -在结束后添加内容或代码片段的操作 <header> 标签.', 'adaptive-addon' ),
						),
					),
				),
				'content' => array(
					'title' => __( '内容', 'adaptive-addon' ),
					'hooks' => array(
						'adaptive_content_before'             => array(
							'title'       => 'content_before',
							'description' => __( 'adaptive_content_before - 在主要内容之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_content_top'                => array(
							'title'       => 'content_top',
							'description' => __( 'adaptive_content_top - 在主要内容之上添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_primary_content_top'        => array(
							'title'       => 'primary_content_top',
							'description' => __( 'adaptive_primary_content_top - 将您的内容或代码段添加到主要内容之上的操作。', 'adaptive-addon' ),
						),
						'adaptive_content_loop'               => array(
							'title'       => 'content_loop',
							'description' => __( 'adaptive_content_loop - 在主内容循环顶部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_template_parts_content_none' => array(
							'title'       => 'template_parts_content_none',
							'description' => __( 'stra_template_parts_content_none - 将您的内容或代码段添加到主要内容之上的操作。', 'adaptive-addon' ),
						),
						'adaptive_content_while_before'       => array(
							'title'       => 'content_while_before',
							'description' => __( 'adaptive_content_while_before - 在循环开始之前添加内容或代码段的操作.', 'adaptive-addon' ),
						),
						'adaptive_template_parts_content_top' => array(
							'title'       => 'template_parts_content_top',
							'description' => __( 'adaptive_template_parts_content_top - 在主模板内容顶部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_template_parts_content'     => array(
							'title'       => 'template_parts_content',
							'description' => __( 'adaptive_template_parts_content - 在主模板内容顶部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_entry_before'               => array(
							'title'       => 'entry_before',
							'description' => __( 'adaptive_entry_before - 在 <article> 标记之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_entry_top'                  => array(
							'title'       => 'entry_top',
							'description' => __( 'adaptive_entry_top - 将您的内容或代码段添加到 <article> 标记顶部的操作。', 'adaptive-addon' ),
						),
						'adaptive_single_header_before'       => array(
							'title'       => 'single_header_before',
							'description' => __( 'adaptive_single_header_before - 在单个帖子标题之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_single_header_top'          => array(
							'title'       => 'single_header_top',
							'description' => __( 'adaptive_single_header_top - 将您的内容或代码段添加到单个帖子标题顶部的操作。', 'adaptive-addon' ),
						),
						'adaptive_single_post_title_after'    => array(
							'title'       => 'single_post_title_after',
							'description' => __( 'adaptive_single_post_title_after - 单一文章文章标题后添加内容的操作', 'adaptive-addon' ),
						),
						'adaptive_single_header_bottom'       => array(
							'title'       => 'single_header_bottom',
							'description' => __( 'adaptive_single_header_bottom - 将您的内容或代码段添加到单个帖子标题底部的操作。', 'adaptive-addon' ),
						),
						'adaptive_single_header_after'        => array(
							'title'       => 'single_header_after',
							'description' => __( 'adaptive_single_header_after - 单个帖子标题后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_entry_content_before'       => array(
							'title'       => 'entry_content_before',
							'description' => __( 'adaptive_entry_content_before - 在发布内容之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_entry_content_after'        => array(
							'title'       => 'entry_content_after',
							'description' => __( 'adaptive_entry_content_after - 在发布内容后添加内容或代码段的操作', 'adaptive-addon' ),
						),
						'adaptive_entry_bottom'               => array(
							'title'       => 'entry_bottom',
							'description' => __( 'adaptive_entry_bottom - 在 <article> 标记底部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_entry_after'                => array(
							'title'       => 'entry_after',
							'description' => __( 'adaptive_entry_after - 关闭 <article> 标记后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_template_parts_content_bottom' => array(
							'title'       => 'template_parts_content_bottom',
							'description' => __( 'adaptive_template_parts_content_bottom-结束 <article> 标记后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_primary_content_bottom'     => array(
							'title'       => 'primary_content_bottom',
							'description' => __( 'adaptive_primary_content_bottom - 在主要内容底部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_content_while_after'        => array(
							'title'       => 'content_while_after',
							'description' => __( 'adaptive_content_while_after - 在循环结束后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_content_bottom'             => array(
							'title'       => 'content_bottom',
							'description' => __( 'adaptive_content_bottom - 在主要内容底部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_content_after'              => array(
							'title'       => 'content_after',
							'description' => __( 'adaptive_content_after - 在主要内容之后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
					),
				),
				'comment' => array(
					'title' => __( '评论', 'adaptive-addon' ),
					'hooks' => array(
						'adaptive_comments_before' => array(
							'title'       => 'comments_before',
							'description' => __( 'adaptive_comments_before - 在开始评论开始之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_comments_after'  => array(
							'title'       => 'comments_after',
							'description' => __( 'adaptive_comments_after - 关闭评论包装后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
					),
				),
				'sidebar' => array(
					'title' => __( '边栏', 'adaptive-addon' ),
					'hooks' => array(
						'adaptive_sidebars_before' => array(
							'title'       => 'sidebars_before',
							'description' => __( 'adaptive_sidebars_before - 在打开侧边栏包装器之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_sidebars_after'  => array(
							'title'       => 'sidebars_after',
							'description' => __( 'adaptive_sidebars_after - 关闭侧边栏包装后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
					),
				),
				'footer'  => array(
					'title' => __( '注脚', 'adaptive-addon' ),
					'hooks' => array(
						'adaptive_footer_before'         => array(
							'title'       => 'footer_before',
							'description' => __( 'adaptive_footer_before - 在打开 <footer> 标记之前添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_footer_content_top'    => array(
							'title'       => 'footer_content_top',
							'description' => __( 'adaptive_footer_content_top - 在标记顶部添加内容或代码段 <footer> 的操作。</footer>。', 'adaptive-addon' ),
						),
						'adaptive_footer_inside_container_top' => array(
							'title'       => 'footer_inside_container_top',
							'description' => __( 'adaptive_footer_inside_container_top - 将内容或代码段添加到页脚容器顶部的操作。', 'adaptive-addon' ),
						),
						'adaptive_footer_inside_container_bottom' => array(
							'title'       => 'footer_inside_container_bottom',
							'description' => __( 'adaptive_footer_inside_container_bottom - 在页脚容器底部添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_footer_content_bottom' => array(
							'title'       => 'footer_content_bottom',
							'description' => __( 'adaptive_footer_content_bottom - 在标记底部添加内容或代码段 <footer> 的操作。</footer>。', 'adaptive-addon' ),
						),
						'adaptive_footer_after'          => array(
							'title'       => 'footer_after',
							'description' => __( 'adaptive_footer_after - 关闭 <footer> 标记后添加内容或代码段的操作。', 'adaptive-addon' ),
						),
						'adaptive_body_bottom'           => array(
							'title'       => 'body_bottom',
							'description' => __( 'adaptive_body_bottom - 将您的内容或代码段添加到 <body> 标记底部的操作。', 'adaptive-addon' ),
						),
						'gc_footer'                   => array(
							'title'       => 'gc_footer',
							'description' => __( 'gc_footer - 在文档末尾添加内容或代码段的操作。', 'adaptive-addon' ),
						),
					),
				),
			);

			// If plugin - 'WooCommerce'.
			if ( class_exists( 'WooCommerce' ) ) {
				$hooks['woo-global'] = array(
					'title' => __( '在线商城- 全局', 'adaptive-addon' ),
					'hooks' => array(
						'woocommerce_before_main_content'  => array(
							'title'       => 'before_main_content',
							'description' => __( '将您的内容添加到WooCommerce的主要内容之前。', 'adaptive-addon' ),
						),
						'woocommerce_after_main_content'   => array(
							'title'       => 'after_main_content',
							'description' => __( '将您的内容添加到WooCommerce的主要内容之后。', 'adaptive-addon' ),
						),
						'woocommerce_sidebar'              => array(
							'title'       => 'sidebar',
							'description' => __( '添加您的内容在WooCommerce侧边栏。', 'adaptive-addon' ),
						),
						'woocommerce_breadcrumb'           => array(
							'title'       => 'breadcrumb',
							'description' => __( '添加您的内容在WooCommerce面包屑。', 'adaptive-addon' ),
						),
						'woocommerce_before_template_part' => array(
							'title'       => 'before_template_part',
							'description' => __( '在WooCommerce模板部分之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_template_part'  => array(
							'title'       => 'after_template_part',
							'description' => __( '在WooCommerce模板部分之后添加您的内容。', 'adaptive-addon' ),
						),
					),
				);

				$hooks['woo-shop'] = array(
					'title' => __( '在线商城- 商店', 'adaptive-addon' ),
					'hooks' => array(
						'woocommerce_archive_description'  => array(
							'title'       => 'archive_description',
							'description' => __( '在archive_description操作上添加内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_shop_loop'     => array(
							'title'       => 'before_shop_loop',
							'description' => __( '在WooCommerce商店循环之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_shop_loop_item_title' => array(
							'title'       => 'before_shop_loop_item_title',
							'description' => __( '在WooCommerce商店循环项目之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_shop_loop_item_title' => array(
							'title'       => 'after_shop_loop_item_title',
							'description' => __( '在WooCommerce商店循环项目之后添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_category_before'   => array(
							'title'       => 'woo_shop_category_before',
							'description' => __( '在WooCommerce商店类别之前添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_category_after'    => array(
							'title'       => 'woo_shop_category_after',
							'description' => __( '在WooCommerce商店类别之后添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_title_before'      => array(
							'title'       => 'woo_shop_title_before',
							'description' => __( '在WooCommerce商店标题之前添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_title_after'       => array(
							'title'       => 'woo_shop_title_after',
							'description' => __( '将您的内容添加到WooCommerce商店标题之后。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_rating_before'     => array(
							'title'       => 'woo_shop_rating_before',
							'description' => __( '在WooCommerce商店评级之前添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_rating_after'      => array(
							'title'       => 'woo_shop_rating_after',
							'description' => __( '在WooCommerce商店评级之后添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_price_before'      => array(
							'title'       => 'woo_shop_price_before',
							'description' => __( '在WooCommerce商店价格之前添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_price_after'       => array(
							'title'       => 'woo_shop_price_after',
							'description' => __( '在WooCommerce商店价格之后添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_add_to_cart_before' => array(
							'title'       => 'woo_shop_add_to_cart_before',
							'description' => __( '在WooCommerce商店购物车前添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_shop_add_to_cart_after' => array(
							'title'       => 'woo_shop_add_to_cart_after',
							'description' => __( '在WooCommerce商店购物车后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_shop_loop'      => array(
							'title'       => 'after_shop_loop',
							'description' => __( '在WooCommerce商店循环之后添加您的内容。', 'adaptive-addon' ),
						),
					),
				);

				$hooks['woo-product'] = array(
					'title' => __( '在线商城- 产品', 'adaptive-addon' ),
					'hooks' => array(
						'woocommerce_before_single_product' => array(
							'title'       => 'before_single_product',
							'description' => __( '在WooCommerce单一产品之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_single_product_summary' => array(
							'title'       => 'before_single_product_summary',
							'description' => __( '在WooCommerce单一产品摘要之前添加您的内容。', 'adaptive-addon' ),
						),

						'woocommerce_single_product_summary' => array(
							'title'       => 'single_product_summary',
							'description' => __( '添加您的内容在WooCommerce单一产品摘要。', 'adaptive-addon' ),
						),
						'woocommerce_after_single_product_summary' => array(
							'title'       => 'after_single_product_summary',
							'description' => __( '在WooCommerce单一产品摘要之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_simple_add_to_cart'   => array(
							'title'       => 'simple_add_to_cart',
							'description' => __( '添加您的内容在简单的添加到购物车。', 'adaptive-addon' ),
						),
						'woocommerce_before_add_to_cart_form' => array(
							'title'       => 'before_add_to_cart_form',
							'description' => __( '在WooCommerce添加到购物车表单之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_add_to_cart_button' => array(
							'title'       => 'before_add_to_cart_button',
							'description' => __( '在WooCommerce添加到购物车按钮之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_add_to_cart_quantity' => array(
							'title'       => 'before_add_to_cart_quantity',
							'description' => __( '在WooCommerce添加到购物车数量之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_add_to_cart_quantity' => array(
							'title'       => 'after_add_to_cart_quantity',
							'description' => __( '在WooCommerce添加到购物车数量之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_add_to_cart_button' => array(
							'title'       => 'after_add_to_cart_button',
							'description' => __( '在WooCommerce添加到购物车按钮之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_add_to_cart_form' => array(
							'title'       => 'after_add_to_cart_form',
							'description' => __( '在WooCommerce添加到购物车表单之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_product_meta_start'   => array(
							'title'       => 'product_meta_start',
							'description' => __( '添加您的内容在WooCommerce产品meta开始前。', 'adaptive-addon' ),
						),
						'woocommerce_product_meta_end'     => array(
							'title'       => 'product_meta_end',
							'description' => __( '添加您的内容在WooCommerce产品meta结束之后。', 'adaptive-addon' ),
						),
						'woocommerce_share'                => array(
							'title'       => 'share',
							'description' => __( '将您的内容添加到共享操作。', 'adaptive-addon' ),
						),
						'woocommerce_after_single_product' => array(
							'title'       => 'after_single_product',
							'description' => __( '在WooCommerce单产品之后添加您的内容。', 'adaptive-addon' ),
						),
					),
				);

				$hooks['woo-cart'] = array(
					'title' => __( '在线商城- 购物车', 'adaptive-addon' ),
					'hooks' => array(
						'woocommerce_check_cart_items'     => array(
							'title'       => 'check_cart_items',
							'description' => __( '在检查购物车条目添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_reset'           => array(
							'title'       => 'cart_reset',
							'description' => __( '在购物车重置添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_updated'         => array(
							'title'       => 'cart_updated',
							'description' => __( '在购物车更新添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_is_empty'        => array(
							'title'       => 'cart_is_empty',
							'description' => __( '在检查购物车是空的处添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_calculate_totals' => array(
							'title'       => 'before_calculate_totals',
							'description' => __( '在WooCommerce计算总额之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_calculate_fees'  => array(
							'title'       => 'cart_calculate_fees',
							'description' => __( '在购物车计算费用添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_calculate_totals' => array(
							'title'       => 'after_calculate_totals',
							'description' => __( '在WooCommerce计算总数后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_cart'          => array(
							'title'       => 'before_cart',
							'description' => __( '在WooCommerce购物车前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_cart_table'    => array(
							'title'       => 'before_cart_table',
							'description' => __( '在WooCommerce购物车表单之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_cart_contents' => array(
							'title'       => 'before_cart_contents',
							'description' => __( '在WooCommerce购物车内容之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_contents'        => array(
							'title'       => 'cart_contents',
							'description' => __( '在购物车内容上添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_cart_contents'  => array(
							'title'       => 'after_cart_contents',
							'description' => __( '在WooCommerce购物车内容之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_coupon'          => array(
							'title'       => 'cart_coupon',
							'description' => __( '在购物车优惠券添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_actions'         => array(
							'title'       => 'cart_actions',
							'description' => __( '在购物车操作中添加内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_cart_table'     => array(
							'title'       => 'after_cart_table',
							'description' => __( '将您的内容添加到WooCommerce购物车表单之后。', 'adaptive-addon' ),
						),
						'woocommerce_cart_collaterals'     => array(
							'title'       => 'cart_collaterals',
							'description' => __( '添加您的内容在购物车担保。', 'adaptive-addon' ),
						),
						'woocommerce_before_cart_totals'   => array(
							'title'       => 'before_cart_totals',
							'description' => __( '在WooCommerce购物车总数之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_totals_before_order_total' => array(
							'title'       => 'cart_totals_before_order_total',
							'description' => __( '在WooCommerce订单总数之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_cart_totals_after_order_total' => array(
							'title'       => 'cart_totals_after_order_total',
							'description' => __( '将您的内容添加到WooCommerce订单总额之后。', 'adaptive-addon' ),
						),
						'woocommerce_proceed_to_checkout'  => array(
							'title'       => 'proceed_to_checkout',
							'description' => __( '在proceed to checkout操作中添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_cart_totals'    => array(
							'title'       => 'after_cart_totals',
							'description' => __( '将您的内容添加到WooCommerce购物车总数之后。', 'adaptive-addon' ),
						),
						'woocommerce_after_cart'           => array(
							'title'       => 'after_cart',
							'description' => __( '在WooCommerce购物车后添加您的内容。', 'adaptive-addon' ),
						),
					),
				);

				$hooks['woo-checkout'] = array(
					'title' => __( '在线商城-付款', 'adaptive-addon' ),
					'hooks' => array(
						'woocommerce_before_checkout_form' => array(
							'title'       => 'before_checkout_form',
							'description' => __( '在WooCommerce结帐表格之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_checkout_before_customer_details' => array(
							'title'       => 'checkout_before_customer_details',
							'description' => __( '在WooCommerce客户详细信息之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_checkout_after_customer_details' => array(
							'title'       => 'checkout_after_customer_details',
							'description' => __( '在WooCommerce客户信息之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_checkout_billing'     => array(
							'title'       => 'checkout_billing',
							'description' => __( '将您的内容添加到结帐账单上。', 'adaptive-addon' ),
						),
						'woocommerce_before_checkout_billing_form' => array(
							'title'       => 'before_checkout_billing_form',
							'description' => __( '在WooCommerce付款表格之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_checkout_billing_form' => array(
							'title'       => 'after_checkout_billing_form',
							'description' => __( '在WooCommerce付款表格之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_before_order_notes'   => array(
							'title'       => 'before_order_notes',
							'description' => __( '在WooCommerce订单备注前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_order_notes'    => array(
							'title'       => 'after_order_notes',
							'description' => __( '在WooCommerce订单备注之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_checkout_shipping'    => array(
							'title'       => 'checkout_shipping',
							'description' => __( '在付款运输操作中添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_checkout_before_order_review' => array(
							'title'       => 'checkout_before_order_review',
							'description' => __( '在WooCommerce付款订单审核前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_checkout_order_review' => array(
							'title'       => 'checkout_order_review',
							'description' => __( '将您的内容添加到checkout order review操作中。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_before_cart_contents' => array(
							'title'       => 'review_order_before_cart_contents',
							'description' => __( '在WooCommerce审核订单购物车内容之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_after_cart_contents' => array(
							'title'       => 'review_order_after_cart_contents',
							'description' => __( '在WooCommerce审核订单购物车内容之后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_before_order_total' => array(
							'title'       => 'review_order_before_order_total',
							'description' => __( '在WooCommerce审核订单总额之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_after_order_total' => array(
							'title'       => 'review_order_after_order_total',
							'description' => __( '在WooCommerce审核订单总额后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_before_payment' => array(
							'title'       => 'review_order_before_payment',
							'description' => __( '在WooCommerce订单付款之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_before_submit' => array(
							'title'       => 'review_order_before_submit',
							'description' => __( '在WooCommerce订单提交之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_after_submit' => array(
							'title'       => 'review_order_after_submit',
							'description' => __( '在WooCommerce订单提交后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_review_order_after_payment' => array(
							'title'       => 'review_order_after_payment',
							'description' => __( '在WooCommerce订单付款后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_checkout_after_order_review' => array(
							'title'       => 'checkout_after_order_review',
							'description' => __( '在WooCommerce审核订单后添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_checkout_form'  => array(
							'title'       => 'after_checkout_form',
							'description' => __( '在WooCommerce结帐表格后添加你的内容。', 'adaptive-addon' ),
						),
					),
				);

				$hooks['woo-distraction-checkout'] = array(
					'title' => __( '在线商城-免打扰结帐', 'adaptive-addon' ),
					'hooks' => array(
						'adaptive_woo_checkout_masthead_top' => array(
							'title'       => 'woo_checkout_masthead_top',
							'description' => __( '在线商城checkout的报头顶部添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_checkout_main_header_bar_top' => array(
							'title'       => 'adaptive_woo_checkout_main_header_bar_top',
							'description' => __( '将你的内容添加到在线商城checkout的主标题栏顶部。', 'adaptive-addon' ),
						),
						'adaptive_woo_checkout_main_header_bar_bottom' => array(
							'title'       => 'adaptive_woo_checkout_main_header_bar_bottom',
							'description' => __( '将你的内容添加到WooCommerce的付款主标题栏底部。', 'adaptive-addon' ),
						),
						'adaptive_woo_checkout_masthead_bottom' => array(
							'title'       => 'woo_checkout_masthead_bottom',
							'description' => __( '将您的内容添加到在线商城checkout报头底部。', 'adaptive-addon' ),
						),
						'adaptive_woo_checkout_footer_content_top' => array(
							'title'       => 'woo_checkout_footer_content_top',
							'description' => __( '在线商城checkout页脚内容顶部添加您的内容。', 'adaptive-addon' ),
						),
						'adaptive_woo_checkout_footer_content_bottom' => array(
							'title'       => 'woo_checkout_footer_content_bottom',
							'description' => __( '在线商城checkout页脚内容底部添加您的内容。', 'adaptive-addon' ),
						),
					),
				);

				$hooks['woo-account'] = array(
					'title' => __( 'WooCommerce——帐户', 'adaptive-addon' ),
					'hooks' => array(
						'woocommerce_before_account_navigation' => array(
							'title'       => 'before_account_navigation',
							'description' => __( '在WooCommerce帐户导航之前添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_account_navigation' => array(
							'title'       => 'account_navigation',
							'description' => __( '在WooCommerce帐户导航中添加您的内容。', 'adaptive-addon' ),
						),
						'woocommerce_after_account_navigation' => array(
							'title'       => 'after_account_navigation',
							'description' => __( '在WooCommerce帐户导航之后添加您的内容。', 'adaptive-addon' ),
						),
					),
				);
			}

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				unset( $hooks['header']['hooks']['adaptive_main_header_bar_top'] );
				unset( $hooks['header']['hooks']['adaptive_masthead_content'] );
				unset( $hooks['header']['hooks']['adaptive_masthead_toggle_buttons_after'] );
				unset( $hooks['header']['hooks']['adaptive_masthead_toggle_buttons_before'] );
				unset( $hooks['header']['hooks']['adaptive_main_header_bar_bottom'] );
				unset( $hooks['footer']['hooks']['adaptive_footer_content_top'] );
				unset( $hooks['footer']['hooks']['adaptive_footer_inside_container_top'] );
				unset( $hooks['footer']['hooks']['adaptive_footer_inside_container_bottom'] );
				unset( $hooks['footer']['hooks']['adaptive_footer_content_bottom'] );

				/**
				 * Above Header
				 */

				$insert_above_bar_before = array(
					'adaptive_header_above_container_before' => array(
						'title'       => 'header_above_container_before',
						'description' => __( 'adaptive_header_above_container_before - 将内容或代码段添加到页眉上方容器之前的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_header_above_container_after' at position 3.
				$above_offset_before      = 3;
				$mast_head_before         = array_slice( $hooks['header']['hooks'], 0, $above_offset_before, true ) + $insert_above_bar_before + array_slice( $hooks['header']['hooks'], $above_offset_before, null, true );
				$hooks['header']['hooks'] = $mast_head_before;

				$insert_above_bar_after = array(
					'adaptive_header_above_container_after' => array(
						'title'       => 'header_above_container_after',
						'description' => __( 'adaptive_header_above_container_after 将内容或代码段添加到页眉上方容器之后的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_header_above_container_after' at position 4.
				$above_offset_after       = 4;
				$mast_head_after          = array_slice( $hooks['header']['hooks'], 0, $above_offset_after, true ) + $insert_above_bar_after + array_slice( $hooks['header']['hooks'], $above_offset_after, null, true );
				$hooks['header']['hooks'] = $mast_head_after;

				/**
				 * Primary Header
				 */

				$insert_main_bar_before = array(
					'adaptive_header_primary_container_before' => array(
						'title'       => 'header_primary_container_before',
						'description' => __( 'adaptive_header_primary_container_before - 将内容或代码段添加到主页眉容器之前的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_header_primary_container_after' at position 5.
				$offset_before            = 5;
				$mast_head_before         = array_slice( $hooks['header']['hooks'], 0, $offset_before, true ) + $insert_main_bar_before + array_slice( $hooks['header']['hooks'], $offset_before, null, true );
				$hooks['header']['hooks'] = $mast_head_before;

				$insert_main_bar_after = array(
					'adaptive_header_primary_container_after' => array(
						'title'       => 'header_primary_container_after',
						'description' => __( 'adaptive_header_primary_container_after - 将内容或代码段添加到主页眉容器之后的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_header_primary_container_after' at position 6.
				$offset_after             = 6;
				$mast_head_after          = array_slice( $hooks['header']['hooks'], 0, $offset_after, true ) + $insert_main_bar_after + array_slice( $hooks['header']['hooks'], $offset_after, null, true );
				$hooks['header']['hooks'] = $mast_head_after;

				/**
				 * Below Header
				 */

				$insert_below_bar_before = array(
					'adaptive_header_below_container_before' => array(
						'title'       => 'header_below_container_before',
						'description' => __( 'adaptive_header_below_container_before - 将内容或代码段添加到页眉下方容器之前的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'header_below_container_before' at position 7.
				$below_offset_before      = 7;
				$mast_head_before         = array_slice( $hooks['header']['hooks'], 0, $below_offset_before, true ) + $insert_below_bar_before + array_slice( $hooks['header']['hooks'], $below_offset_before, null, true );
				$hooks['header']['hooks'] = $mast_head_before;

				$insert_below_bar_after = array(
					'adaptive_header_below_container_after' => array(
						'title'       => 'header_below_container_after',
						'description' => __( 'adaptive_header_below_container_after - 将内容或代码段添加到页眉下方容器之后的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_header_below_container_after' at position 8.
				$below_offset_after       = 8;
				$mast_head_after          = array_slice( $hooks['header']['hooks'], 0, $below_offset_after, true ) + $insert_below_bar_after + array_slice( $hooks['header']['hooks'], $below_offset_after, null, true );
				$hooks['header']['hooks'] = $mast_head_after;

				/**
				 * Above Footer
				 */

				$insert_above_footer_before = array(
					'adaptive_footer_above_container_before' => array(
						'title'       => 'footer_above_container_before',
						'description' => __( 'adaptive_footer_above_container_before - 将内容或代码段添加到页脚下方容器之前的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_footer_above_container_before' at position 2.
				$offset_above_footer_before = 2;
				$mast_footer_before         = array_slice( $hooks['footer']['hooks'], 0, $offset_above_footer_before, true ) + $insert_above_footer_before + array_slice( $hooks['footer']['hooks'], $offset_above_footer_before, null, true );
				$hooks['footer']['hooks']   = $mast_footer_before;

				$insert_above_footer_after = array(
					'adaptive_footer_above_container_after' => array(
						'title'       => 'footer_above_container_after',
						'description' => __( 'adaptive_footer_above_container_after - 将内容或代码段添加到页脚下方容器之后的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_footer_above_container_after' at position 3.
				$offset_above_footer_after = 3;
				$mast_footer_after         = array_slice( $hooks['footer']['hooks'], 0, $offset_above_footer_after, true ) + $insert_above_footer_after + array_slice( $hooks['footer']['hooks'], $offset_above_footer_after, null, true );
				$hooks['footer']['hooks']  = $mast_footer_after;

				/**
				 * Footer
				 */

				$insert_main_footer_before = array(
					'adaptive_footer_primary_container_before' => array(
						'title'       => 'footer_primary_container_before',
						'description' => __( 'adaptive_footer_primary_container_before - 将内容或代码段添加到主页脚容器之前的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_footer_primary_container_before' at position 4.
				$offset_footer_before     = 4;
				$mast_footer_before       = array_slice( $hooks['footer']['hooks'], 0, $offset_footer_before, true ) +
				$insert_main_footer_before +
				array_slice( $hooks['footer']['hooks'], $offset_footer_before, null, true );
				$hooks['footer']['hooks'] = $mast_footer_before;

				$insert_main_footer_after = array(
					'adaptive_footer_primary_container_after' => array(
						'title'       => 'footer_primary_container_after',
						'description' => __( 'adaptive_footer_primary_container_after - 将内容或代码段添加到主页脚容器之后的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_footer_primary_container_after' at position 5.
				$offset_footer_after      = 5;
				$mast_footer_after        = array_slice( $hooks['footer']['hooks'], 0, $offset_footer_after, true ) + $insert_main_footer_after + array_slice( $hooks['footer']['hooks'], $offset_footer_after, null, true );
				$hooks['footer']['hooks'] = $mast_footer_after;

				/**
				 * Below Footer
				 */

				$insert_below_footer_before = array(
					'adaptive_footer_below_container_before' => array(
						'title'       => 'footer_below_container_before',
						'description' => __( 'adaptive_footer_below_container_before - 将内容或代码段添加到页脚下方容器之前的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_footer_below_container_before' at position 6.
				$offset_below_footer_before = 6;
				$mast_footer_before         = array_slice( $hooks['footer']['hooks'], 0, $offset_below_footer_before, true ) + $insert_below_footer_before + array_slice( $hooks['footer']['hooks'], $offset_below_footer_before, null, true );
				$hooks['footer']['hooks']   = $mast_footer_before;

				$insert_below_footer_after = array(
					'adaptive_footer_below_container_after' => array(
						'title'       => 'footer_below_container_after',
						'description' => __( 'adaptive_footer_below_container_after - 将内容或代码段添加到页脚下方容器之后的操作。', 'adaptive-addon' ),
					),
				);

				// Add new array 'adaptive_footer_below_container_after' at position 7.
				$offset_below_footer_after = 7;
				$mast_footer_after         = array_slice( $hooks['footer']['hooks'], 0, $offset_below_footer_after, true ) + $insert_below_footer_after + array_slice( $hooks['footer']['hooks'], $offset_below_footer_after, null, true );
				$hooks['footer']['hooks']  = $mast_footer_after;
			}

			self::$layouts = apply_filters( 'adaptive_custom_layouts_layout', $layouts );
			self::$hooks   = apply_filters( 'adaptive_custom_layouts_hooks', $hooks );

			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {

			add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
			add_action( 'admin_head', array( $this, 'menu_highlight' ) );
			add_action( 'admin_body_class', array( $this, 'admin_body_class' ) );
			add_action( 'load-post.php', array( $this, 'init_metabox' ) );
			add_action( 'load-post-new.php', array( $this, 'init_metabox' ) );
			add_filter( 'adaptive_addon_location_rule_post_types', array( $this, 'location_rule_post_types' ) );
		}

		/**
		 * Enqueue admin Scripts and Styles.
		 *
		 * @since  1.0.3
		 */
		public function admin_scripts() {

			global $post;
			global $pagenow;

			$screen = get_current_screen();

			if ( ( 'post-new.php' == $pagenow || 'post.php' == $pagenow ) && ADAPTIVE_ADVANCED_HOOKS_POST_TYPE == $screen->post_type && ( isset( $_GET['code_editor'] ) || ( isset( $post->ID ) && 'code_editor' == get_post_meta( $post->ID, 'editor_type', true ) ) ) ) {  // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended

				if ( ! function_exists( 'gc_enqueue_code_editor' ) || isset( $_GET['gechiui_editor'] ) ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
					return;
				}

				$settings = gc_enqueue_code_editor(
					array(
						'type'       => 'application/x-httpd-php',
						'codemirror' => array(
							'indentUnit' => 2,
							'tabSize'    => 2,
						),
					)
				);

				gc_add_inline_script(
					'code-editor',
					sprintf(
						'jQuery( function() { gc.codeEditor.initialize( "ast-advanced-hook-php-code", %s ); } );',
						gc_json_encode( $settings )
					)
				);
			}
		}


		/**
		 * Filter location rule post types to skip current post type.
		 *
		 * @param array $post_types Array of all public post types.
		 * @return array
		 */
		public function location_rule_post_types( $post_types ) {
			global $pagenow;

			$screen = get_current_screen();

			if ( ( 'post-new.php' == $pagenow || 'post.php' == $pagenow ) && ADAPTIVE_ADVANCED_HOOKS_POST_TYPE == $screen->post_type && isset( $post_types[ ADAPTIVE_ADVANCED_HOOKS_POST_TYPE ] ) ) {
				unset( $post_types[ ADAPTIVE_ADVANCED_HOOKS_POST_TYPE ] );
			}
			return $post_types;
		}

		/**
		 * Init Metabox
		 */
		public function init_metabox() {
			global $gc_version;
			add_action( 'add_meta_boxes', array( $this, 'setup_meta_box' ) );
			add_action( 'edit_form_after_title', array( $this, 'enable_php_markup' ), 1, 1 );
			add_action( 'admin_footer', array( $this, 'add_navigation_button' ), 1, 1 );
			add_action( 'edit_form_after_editor', array( $this, 'php_editor_markup' ), 10, 1 );

			if ( isset( $_POST['ast-advanced-hook-layout'] ) ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Missing
				add_action( 'save_post', array( $this, 'save_meta_box' ) );
			}

			/**
			 * Set metabox options
			 *
			 * @see https://php.net/manual/en/filter.filters.sanitize.php
			 */
			self::$meta_option = apply_filters(
				'adaptive_advanced_hooks_meta_box_options',
				array(
					'ast-advanced-hook-location'  => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-exclusion' => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-layout'    => array(
						'default'  => '',
						'sanitize' => 'FILTER_DEFAULT',
					),

					'ast-advanced-hook-action'    => array(
						'default'  => '',
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-priority'  => array(
						'default'  => '',
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-with-php'  => array(
						'default'  => '',
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-php-code'  => array(
						'default'  => '<!-- Add your snippet here. -->',
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-users'     => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-padding'   => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-header'    => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-footer'    => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-404-page'                => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-hook-content'   => array(
						'default'  => array(),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-display-device' => array(
						'default'  => array( 'desktop', 'tablet', 'mobile' ),
						'sanitize' => 'FILTER_DEFAULT',
					),
					'ast-advanced-time-duration'  => array(
						'default'  => array(
							'enabled'  => '',
							'start-dt' => '',
							'end-dt'   => '',
						),
						'sanitize' => 'FILTER_DEFAULT',
					),
				)
			);

		}

		/**
		 * Filter admin body class
		 *
		 * @since 1.0.0
		 *
		 * @param string $classes List of Admin Classes.
		 * @return string
		 */
		public function admin_body_class( $classes ) {

			global $pagenow;
			global $post;

			$screen = get_current_screen();

			if ( ( 'post-new.php' == $pagenow || 'post.php' == $pagenow ) && ADAPTIVE_ADVANCED_HOOKS_POST_TYPE == $screen->post_type ) {
				$with_php = get_post_meta( $post->ID, 'editor_type', true );
				if ( 'code_editor' === $with_php ) {
					$classes = ' adaptive-php-snippt-enabled';
				}
			}
			return $classes;
		}

		/**
		 * Keep the Adaptive menu open when editing the advanced headers.
		 * Highlights the wanted admin (sub-) menu items for the CPT.
		 *
		 * @since  1.0.0
		 */
		public function menu_highlight() {
			global $parent_file, $submenu_file, $post_type;
			if ( ADAPTIVE_ADVANCED_HOOKS_POST_TYPE == $post_type ) :
				$parent_file  = 'themes.php'; // phpcs:ignore GeChiUI.GC.GlobalVariablesOverride.Prohibited
				$submenu_file = 'edit.php?post_type=' . ADAPTIVE_ADVANCED_HOOKS_POST_TYPE; // phpcs:ignore GeChiUI.GC.GlobalVariablesOverride.Prohibited

				/* Same display rule assign notice */
				$option = array(
					'layout'    => 'ast-advanced-hook-layout',
					'location'  => 'ast-advanced-hook-location',
					'exclusion' => 'ast-advanced-hook-exclusion',
					'users'     => 'ast-advanced-hook-users',
				);

				self::hook_same_display_on_notice( ADAPTIVE_ADVANCED_HOOKS_POST_TYPE, $option );
			endif;
		}

		/**
		 * Same display_on notice.
		 *
		 * @since  1.0.0
		 * @param  int   $post_type Post Type.
		 * @param  array $option meta option name.
		 */
		public static function hook_same_display_on_notice( $post_type, $option ) {
			global $gcdb;
			global $post;

			$all_rules        = array();
			$already_set_rule = array();

			$layout   = isset( $option['layout'] ) ? $option['layout'] : '';
			$location = isset( $option['location'] ) ? $option['location'] : '';

			$all_headers = $gcdb->get_results(
				$gcdb->prepare(
					"SELECT p.ID, p.post_title, pm.meta_value FROM {$gcdb->postmeta} as pm
				INNER JOIN {$gcdb->posts} as p ON pm.post_id = p.ID
				WHERE pm.meta_key = %s
				AND p.post_type = %s
				AND p.post_status = 'publish'",
					$location,
					$post_type
				)
			);

			foreach ( $all_headers as $header ) {

				$layout_data = get_post_meta( $header->ID, $layout, true );

				if ( 'hooks' === $layout_data ) {
					continue;
				};

				$location_rules = unserialize( $header->meta_value ); // phpcs:ignore GeChiUI.PHP.DiscouragedPHPFunctions.serialize_unserialize

				if ( is_array( $location_rules ) && isset( $location_rules['rule'] ) ) {

					foreach ( $location_rules['rule'] as $key => $rule ) {

						if ( ! isset( $all_rules[ $rule ] ) ) {
							$all_rules[ $rule ] = array();
						}

						if ( 'specifics' == $rule && isset( $location_rules['specific'] ) && is_array( $location_rules['specific'] ) ) {

							foreach ( $location_rules['specific'] as $s_index => $s_value ) {

								$all_rules[ $rule ][ $s_value ][ $header->ID ] = array(
									'ID'     => $header->ID,
									'name'   => $header->post_title,
									'layout' => $layout_data,
								);
							}
						} else {
							$all_rules[ $rule ][ $header->ID ] = array(
								'ID'     => $header->ID,
								'name'   => $header->post_title,
								'layout' => $layout_data,
							);
						}
					}
				}
			}

			if ( empty( $post ) ) {
				return;
			}
			$current_post_data   = get_post_meta( $post->ID, $location, true );
			$current_post_layout = get_post_meta( $post->ID, $layout, true );

			if ( is_array( $current_post_data ) && isset( $current_post_data['rule'] ) ) {

				foreach ( $current_post_data['rule'] as $c_key => $c_rule ) {

					if ( ! isset( $all_rules[ $c_rule ] ) ) {
						continue;
					}

					if ( 'specifics' === $c_rule ) {

						foreach ( $current_post_data['specific'] as $s_index => $s_id ) {
							if ( ! isset( $all_rules[ $c_rule ][ $s_id ] ) ) {
								continue;
							}

							foreach ( $all_rules[ $c_rule ][ $s_id ] as $p_id => $data ) {

								if ( $p_id == $post->ID ) {
									continue;
								}

								if ( '0' !== $data['layout'] && $current_post_layout === $data['layout'] ) {

									$already_set_rule[] = $data['name'];
								}
							}
						}
					} else {

						foreach ( $all_rules[ $c_rule ] as $p_id => $data ) {

							if ( $p_id == $post->ID ) {
								continue;
							}

							if ( '0' !== $data['layout'] && $current_post_layout === $data['layout'] ) {
								$already_set_rule[] = $data['name'];
							}
						}
					}
				}
			}

			if ( ! empty( $already_set_rule ) ) {
				add_action(
					'admin_notices',
					function() use ( $already_set_rule, $current_post_layout ) {

						$rule_set_titles = '<strong>' . implode( ',', $already_set_rule ) . '</strong>';
						$layout          = '<strong>' . ucfirst( $current_post_layout ) . '</strong>';

						/* translators: %s layout. */
						$notice = sprintf( __( '为相同的显示规则选择另一个%s布局。', 'adaptive-addon' ), $layout );

						echo '<div class="error">';
						echo '<p>' . $notice . '</p>'; // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
						echo '</div>';

					}
				);
			}
		}
		/**
		 *  Setup Metabox
		 */
		public function setup_meta_box() {

			// Get all posts.
			$post_types = get_post_types();

			if ( ADAPTIVE_ADVANCED_HOOKS_POST_TYPE == get_post_type() ) {
				// Enable for all posts.
				foreach ( $post_types as $type ) {

					if ( 'attachment' !== $type ) {
						add_meta_box(
							'advanced-hook-settings',                // Id.
							__( '自定义布局设置', 'adaptive-addon' ), // Title.
							array( $this, 'markup_meta_box' ),      // Callback.
							$type,                                  // Post_type.
							'normal',                               // Context.
							'high',                                 // Priority.
							array(
								'__back_compat_meta_box' => true,
							)
						);

						// Show notice metabox only for block based Custom Layout post.
						$screen = get_current_screen();
						if ( true === $screen->is_block_editor() ) {
							add_meta_box(
								'advanced-hook-notice',                // Id.
								__( '自定义布局设置', 'adaptive-addon' ), // Title.
								array( $this, 'meta_box_notice' ),      // Callback.
								$type,                                  // Post_type.
								'normal',                               // Context.
								'low'                                   // Priority.
							);
						}
					}
				}
			}
		}

		/**
		 * Add navigatory button to GC-Gutenberg editor.
		 *
		 * @since 2.5.0
		 * @param object $post Post Object.
		 */
		public function add_navigation_button( $post ) {

			if ( ! $post ) {
				global $post;
			}

			if ( isset( $_GET['gechiui_editor'] ) ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
				update_post_meta( $post->ID, 'editor_type', 'gechiui_editor' );
			} elseif ( isset( $_GET['code_editor'] ) ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
				update_post_meta( $post->ID, 'editor_type', 'code_editor' );
			}

			global $pagenow;
			$screen = get_current_screen();

			$editor_type = get_post_meta( $post->ID, 'editor_type', true );

			if ( 'code_editor' === $editor_type ) {
				return;
			}

			if ( ( 'post-new.php' === $pagenow ) && ADAPTIVE_ADVANCED_HOOKS_POST_TYPE === $screen->post_type ) {
				$editor_type = 'gechiui_editor';
			}

			$start_wrapper = '<script id="adaptive-editor-button-switch-mode" type="text/html" >';
			$end_wrapper   = '</script>';
			$label         = __( '开启代码编辑器', 'adaptive-addon' );
			$icon          = 'dashicons-editor-code';

			echo $start_wrapper; // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
			?>
				<div class="ast-advanced-hook-enable-php-wrapper">
					<button type="button" class="ast-advanced-hook-enable-php-btn button button-primary button-large" data-editor-type="<?php echo esc_attr( $editor_type ); ?>" data-label="<?php echo esc_attr( $label ); ?>" >
						<i class="dashicons <?php echo esc_attr( $icon ); ?>"></i>
						<span class="ast-btn-title"><?php echo esc_html( $label ); ?></span>
					</button>
				</div>
			<?php
			echo $end_wrapper; // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
		}

		/**
		 * Markup for checkbox for execute php snippet.
		 *
		 * @since 1.0.0
		 * @param object $post Post Object.
		 */
		public function enable_php_markup( $post ) {

			if ( ! $post ) {
				global $post;
			}

			$editor_type = get_post_meta( $post->ID, 'editor_type', true );

			if ( ADAPTIVE_ADVANCED_HOOKS_POST_TYPE == $post->post_type ) {

				gc_nonce_field( basename( __FILE__ ), ADAPTIVE_ADVANCED_HOOKS_POST_TYPE );
				$stored = get_post_meta( $post->ID );

				// Set stored and override defaults.
				foreach ( $stored as $key => $value ) {
					self::$meta_option[ $key ]['default'] = ( isset( $stored[ $key ][0] ) ) ? $stored[ $key ][0] : '';
				}

				// Get defaults.
				$meta = self::get_meta_option();

				/**
				 * Get options.
				 */
				$with_php      = ( isset( $meta['ast-advanced-hook-with-php']['default'] ) ) ? $meta['ast-advanced-hook-with-php']['default'] : '';
				$editor_type   = ( isset( $meta['editor_type']['default'] ) ) ? $meta['editor_type']['default'] : 'gechiui_editor';
				$enable_label  = __( '开启代码编辑器', 'adaptive-addon' );
				$disable_label = __( '启用 GeChiUI 编辑器', 'adaptive-addon' );

				global $pagenow;
				$icon  = 'dashicons-editor-code';
				$label = $enable_label;

				if ( ( 'post-new.php' === $pagenow && isset( $_GET['code_editor'] ) ) || isset( $_GET['code_editor'] ) || 'enabled' === $with_php ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
					$editor_type = 'code_editor';
					$icon        = 'dashicons-edit';
					$label       = $disable_label;
				}

				if ( isset( $_GET['gechiui_editor'] ) || 'gechiui_editor' === $editor_type ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
					$editor_type = 'gechiui_editor';
					$icon        = 'dashicons-editor-code';
					$label       = $enable_label;
				}

				?>
					<div class="ast-advanced-hook-enable-php-wrapper">
						<button type="button" class="ast-advanced-hook-enable-php-btn button button-primary button-large" data-enable-text="<?php echo esc_attr( $enable_label ); ?>" data-editor-type="<?php echo esc_attr( $editor_type ); ?>" data-disable-text="<?php echo esc_attr( $disable_label ); ?>" >
							<i class="dashicons <?php echo esc_attr( $icon ); ?>"></i>
							<span class="ast-btn-title"><?php echo esc_html( $label ); ?></span>
							<input type="hidden" class="ast-advanced-hook-with-php" name="ast-advanced-hook-with-php" value="<?php echo esc_attr( $with_php ); ?>" />
						</button>
					</div>
				<?php
			}
		}

		/**
		 * Markup PHP snippt editor.
		 *
		 * @since 1.0.0
		 * @param object $post Post Object.
		 */
		public function php_editor_markup( $post ) {

			// Get all posts.
			$post_type = get_post_type();

			if ( ADAPTIVE_ADVANCED_HOOKS_POST_TYPE == $post_type ) {

				gc_nonce_field( basename( __FILE__ ), ADAPTIVE_ADVANCED_HOOKS_POST_TYPE );
				$stored = get_post_meta( $post->ID );

				// Set stored and override defaults.
				foreach ( $stored as $key => $value ) {
					self::$meta_option[ $key ]['default'] = ( isset( $stored[ $key ][0] ) ) ? $stored[ $key ][0] : '';
				}

				// Get defaults.
				$meta = self::get_meta_option();

				/**
				 * Get options
				 */
				$content = ( isset( $meta['ast-advanced-hook-php-code']['default'] ) ) ? $meta['ast-advanced-hook-php-code']['default'] : "<?php\n	// Add your snippet here.\n?>";
				?>
				<div class="gc-editor-container adaptive-php-editor-container">
					<textarea id="ast-advanced-hook-php-code" name="ast-advanced-hook-php-code" class="gc-editor-area ast-advanced-hook-php-content"><?php echo esc_textarea( $content ); ?></textarea>
				</div>
				<?php
			}
		}

		/**
		 * Get metabox options
		 */
		public static function get_meta_option() {
			return self::$meta_option;
		}

		/**
		 * Metabox Markup
		 *
		 * @param  object $post Post object.
		 * @return void
		 */
		public function markup_meta_box( $post ) {

			gc_nonce_field( basename( __FILE__ ), ADAPTIVE_ADVANCED_HOOKS_POST_TYPE );
			$stored = get_post_meta( $post->ID );

			$advanced_hooks_meta = array( 'ast-advanced-time-duration', 'ast-advanced-display-device', 'ast-advanced-hook-location', 'ast-advanced-hook-exclusion', 'ast-advanced-hook-users', 'ast-advanced-hook-padding', 'ast-advanced-hook-header', 'ast-advanced-hook-footer', 'ast-404-page', 'ast-advanced-hook-content' );

			// Set stored and override defaults.
			foreach ( $stored as $key => $value ) {
				if ( in_array( $key, $advanced_hooks_meta ) ) {
					self::$meta_option[ $key ]['default'] = ( isset( $stored[ $key ][0] ) ) ? maybe_unserialize( $stored[ $key ][0] ) : '';
				} else {
					self::$meta_option[ $key ]['default'] = ( isset( $stored[ $key ][0] ) ) ? $stored[ $key ][0] : '';
				}
			}

			// Get defaults.
			$meta = self::get_meta_option();

			/**
			 * Get options
			 */
			$display_locations = ( isset( $meta['ast-advanced-hook-location']['default'] ) ) ? $meta['ast-advanced-hook-location']['default'] : '';
			$exclude_locations = ( isset( $meta['ast-advanced-hook-exclusion']['default'] ) ) ? $meta['ast-advanced-hook-exclusion']['default'] : '';
			$layout            = ( isset( $meta['ast-advanced-hook-layout']['default'] ) ) ? $meta['ast-advanced-hook-layout']['default'] : '';
			$action            = ( isset( $meta['ast-advanced-hook-action']['default'] ) ) ? $meta['ast-advanced-hook-action']['default'] : '';
			$priority          = ( isset( $meta['ast-advanced-hook-priority']['default'] ) ) ? $meta['ast-advanced-hook-priority']['default'] : '';
			$user_roles        = ( isset( $meta['ast-advanced-hook-users']['default'] ) ) ? $meta['ast-advanced-hook-users']['default'] : '';
			$padding           = ( isset( $meta['ast-advanced-hook-padding']['default'] ) ) ? $meta['ast-advanced-hook-padding']['default'] : array();
			$header            = ( isset( $meta['ast-advanced-hook-header']['default'] ) ) ? $meta['ast-advanced-hook-header']['default'] : array();
			$footer            = ( isset( $meta['ast-advanced-hook-footer']['default'] ) ) ? $meta['ast-advanced-hook-footer']['default'] : array();
			$layout_404        = ( isset( $meta['ast-404-page']['default'] ) ) ? $meta['ast-404-page']['default'] : array();
			$content           = ( isset( $meta['ast-advanced-hook-content']['default'] ) ) ? $meta['ast-advanced-hook-content']['default'] : array();
			$display_devices   = ( isset( $meta['ast-advanced-display-device']['default'] ) ) ? $meta['ast-advanced-display-device']['default'] : array();
			$time_duration     = ( isset( $meta['ast-advanced-time-duration']['default'] ) ) ? $meta['ast-advanced-time-duration']['default'] : array();

			$ast_advanced_hooks = array(
				'include-locations' => $display_locations,
				'exclude-locations' => $exclude_locations,
				'layout'            => $layout,
				'action'            => $action,
				'priority'          => $priority,
				'user_roles'        => $user_roles,
				'padding'           => $padding,
				'header'            => $header,
				'footer'            => $footer,
				'layout-404'        => $layout_404,
				'content'           => $content,
				'display-devices'   => $display_devices,
				'time-duration'     => $time_duration,
			);
			do_action( 'adaptive_advanced_hooks_settings_markup_before', $meta );
			$this->page_header_tab( $ast_advanced_hooks );
			do_action( 'adaptive_advanced_hooks_settings_markup_after', $meta );
		}

		/**
		 * Display notice for Existing users for Custom layout settings improvements.
		 *
		 * @param  object $post Post object.
		 * @return void
		 */
		public function meta_box_notice( $post ) {
			$link = '<a href="https://gcadaptive.com/docs/custom-layouts-pro/" target="blank"> Click here </a>';
			/* translators: %s: blog link */
			echo sprintf( esc_html__( '\"自定布局设置\"移至边栏。通过单击右上角的Adaptive图标访问设置。有关详细信息，%s。', 'adaptive-addon' ), $link ); // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
		}

		/**
		 * Metabox Save
		 *
		 * @param  number $post_id Post ID.
		 * @return void
		 */
		public function save_meta_box( $post_id ) {

			// Checks save status.
			$is_autosave = gc_is_post_autosave( $post_id );
			$is_revision = gc_is_post_revision( $post_id );

			$is_valid_nonce = ( isset( $_POST[ ADAPTIVE_ADVANCED_HOOKS_POST_TYPE ] ) && gc_verify_nonce( $_POST[ ADAPTIVE_ADVANCED_HOOKS_POST_TYPE ], basename( __FILE__ ) ) ) ? true : false;

			// Exits script depending on save status.
			if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
				return;
			}

			$editor_type = get_post_meta( $post_id, 'editor_type', true );
			update_post_meta( $post_id, 'editor_type', 'gechiui_editor' );

			if ( strpos( $_POST['_gc_http_referer'], 'code_editor' ) !== false || 'code_editor' === $editor_type ) {
				update_post_meta( $post_id, 'editor_type', 'code_editor' );
			}

			/**
			 * Get meta options
			 */
			$post_meta = self::get_meta_option();
			foreach ( $post_meta as $key => $data ) {
				if ( in_array( $key, array( 'ast-advanced-hook-users', 'ast-advanced-hook-padding' ) ) ) {
					$index = array_search( '', $_POST[ $key ] );
					if ( false !== $index ) {
						unset( $_POST[ $key ][ $index ] );
					}
					$meta_value = array_map( 'esc_attr', $_POST[ $key ] );
				} elseif ( in_array( $key, array( 'ast-advanced-time-duration', 'ast-advanced-display-device', 'ast-advanced-hook-header', 'ast-advanced-hook-footer', 'ast-404-page', 'ast-advanced-hook-content' ) ) ) {
					$meta_value = isset( $_POST[ $key ] ) ? array_map( 'esc_attr', $_POST[ $key ] ) : array();
				} elseif ( in_array( $key, array( 'ast-advanced-hook-location', 'ast-advanced-hook-exclusion' ) ) ) {
					$meta_value = Adaptive_Target_Rules_Fields::get_format_rule_value( $_POST, $key );
				} else {
					// Sanitize values.
					$sanitize_filter = ( isset( $data['sanitize'] ) ) ? $data['sanitize'] : 'FILTER_DEFAULT';

					switch ( $sanitize_filter ) {

						case 'FILTER_SANITIZE_STRING':
							$meta_value = filter_input( INPUT_POST, $key, FILTER_SANITIZE_STRING );
							break;

						case 'FILTER_SANITIZE_URL':
							$meta_value = filter_input( INPUT_POST, $key, FILTER_SANITIZE_URL );
							break;

						case 'FILTER_SANITIZE_NUMBER_INT':
							$meta_value = filter_input( INPUT_POST, $key, FILTER_SANITIZE_NUMBER_INT );
							break;

						default:
							$meta_value = filter_input( INPUT_POST, $key, FILTER_DEFAULT );
							break;
					}
				}

				// Store values.
				if ( '' != $meta_value ) {
					update_post_meta( $post_id, $key, $meta_value );
				} else {
					if ( 'ast-advanced-hook-php-code' !== $key ) {
						delete_post_meta( $post_id, $key );
					}
				}
			}

			// Correct the target rules for 404-page layout.
			$this->target_rules_404_layout();
		}

		/**
		 * Force target rules for 404 page layout.
		 *
		 * 404 Page layout will always the target rules of special-404.
		 *
		 * @since  1.2.1
		 * @return null
		 */
		private function target_rules_404_layout() {
			$layout = get_post_meta( get_the_ID(), 'ast-advanced-hook-layout', true );

			// bail if current layout is not 404 Page.
			if ( '404-page' !== $layout ) {
				return;
			}

			$target_rule_404 = array(
				'rule'     => array(
					0 => 'special-404',
				),
				'specific' => array(),
			);

			update_post_meta( get_the_ID(), 'ast-advanced-hook-location', $target_rule_404 );
		}


		/**
		 * Get the timezone string as selected in gc general setting.
		 *
		 * @return false|mixed|string|void
		 */
		public static function get_gc_timezone_string() {

			$current_offset = get_option( 'gmt_offset' );
			$tzstring       = get_option( 'timezone_string' );

			if ( false !== strpos( $tzstring, 'Etc/GMT' ) ) {
				$tzstring = '';
			}

			if ( empty( $tzstring ) ) {
				if ( 0 == $current_offset ) {
					$tzstring = 'UTC+0';
				} elseif ( $current_offset < 0 ) {
					$tzstring = 'UTC' . $current_offset;
				} else {
					$tzstring = 'UTC+' . $current_offset;
				}
			}

			return $tzstring;
		}

		/**
		 * Page Header Tabs
		 *
		 * @param  array $options Post meta.
		 */
		public function page_header_tab( $options ) {
			// Load Target Rule assets.
			Adaptive_Target_Rules_Fields::get_instance()->admin_styles();

			$include_locations = $options['include-locations'];
			$exclude_locations = $options['exclude-locations'];
			$users             = $options['user_roles'];
			$padding           = $options['padding'];
			$header            = $options['header'];
			$footer            = $options['footer'];
			$content           = $options['content'];
			$layout_404        = $options['layout-404'];
			$display_devices   = $options['display-devices'];
			$time_duration     = $options['time-duration'];

			$padding_top           = isset( $padding['top'] ) ? $padding['top'] : '';
			$padding_bottom        = isset( $padding['bottom'] ) ? $padding['bottom'] : '';
			$header_sticky         = isset( $header['sticky'] ) ? $header['sticky'] : '';
			$header_shrink         = isset( $header['shrink'] ) ? $header['shrink'] : '';
			$header_on_devices     = isset( $header['sticky-header-on-devices'] ) ? $header['sticky-header-on-devices'] : '';
			$footer_sticky         = isset( $footer['sticky'] ) ? $footer['sticky'] : '';
			$footer_on_devices     = isset( $footer['sticky-footer-on-devices'] ) ? $footer['sticky-footer-on-devices'] : '';
			$disable_header        = isset( $layout_404['disable_header'] ) ? $layout_404['disable_header'] : '';
			$disable_footer        = isset( $layout_404['disable_footer'] ) ? $layout_404['disable_footer'] : '';
			$content_location      = isset( $content['location'] ) ? $content['location'] : '';
			$after_blocks_number   = isset( $content['after_block_number'] ) ? $content['after_block_number'] : '';
			$before_heading_number = isset( $content['before_heading_number'] ) ? $content['before_heading_number'] : '';
			?>
			<table class="ast-advanced-hook-table widefat">

				<tr class="ast-advanced-hook-row">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '样式', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
						<select id="ast-advanced-hook-layout" name="ast-advanced-hook-layout" style="width: 50%;" >
							<option value="0"><?php printf( '&mdash; %s &mdash;', esc_html__( '选择', 'adaptive-addon' ) ); ?></option>
							<?php if ( is_array( self::$layouts ) && ! empty( self::$layouts ) ) : ?>
								<?php foreach ( self::$layouts as $key => $layout ) : ?>

									<option <?php selected( $key, $options['layout'] ); ?> value="<?php echo esc_attr( $key ); ?>" ><?php echo esc_html( $layout['title'] ); ?></option>

								<?php endforeach; ?>
							<?php endif; ?>
						</select>
						<p class="ast-inside-content-notice"><?php esc_html_e( '此选项将只适用于与块编辑器创建的帖子/页面。', 'adaptive-addon' ); ?></p>
					</td>
				</tr>

				<!-- 404 Layout -->
				<tr class="ast-advanced-hook-row ast-404-layout-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '禁用主页眉', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
					<input type="checkbox" name="ast-404-page[disable_header]"
								value="enabled" <?php checked( $disable_header, 'enabled' ); ?> />
					</td>
				</tr>

				<tr class="ast-advanced-hook-row ast-404-layout-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '禁用页脚栏', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
					<input type="checkbox" name="ast-404-page[disable_footer]"
								value="enabled" <?php checked( $disable_footer, 'enabled' ); ?> />
					</td>
				</tr>

				<tr class="ast-advanced-hook-row ast-layout-content-location-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '文章/页面位置', 'adaptive-addon' ); ?></label>
						<i class="ast-advanced-hook-heading-help dashicons dashicons-editor-help" title="<?php echo esc_attr__( '布局将插入在一个选定的位置上的页面/帖子在块编辑器。', 'adaptive-addon' ); ?>"></i>
					</td>
					<td class="ast-advanced-hook-row-content">
					<select id="ast-advanced-hook-content-location" name="ast-advanced-hook-content[location]" style="width: 50%;" >
						<option value="<?php echo esc_attr( 'after_blocks' ); ?>" <?php selected( 'after_blocks', $content_location, true ); ?> ><?php esc_html_e( '经过一定数量的块', 'adaptive-addon' ); ?></option>
						<option value="<?php echo esc_attr( 'before_headings' ); ?>" <?php selected( 'before_headings', $content_location, true ); ?>><?php esc_html_e( '在一定数量的标题块之前', 'adaptive-addon' ); ?></option>
					</select>
					</td>
				</tr>
				<tr class="ast-advanced-hook-row ast-layout-content-after-blocks">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '块号等级', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
						<span class="ast-advanced-hook-inline-label"><?php esc_attr_e( '添加布局之后', 'adaptive-addon' ); ?></span>
						<input type="number" class="ast-inside-content-number-field" name="ast-advanced-hook-content[after_block_number]"  min="1" oninput="validity.valid||(value='');" value="<?php echo esc_attr( $after_blocks_number ); ?>" >
						<span class="ast-advanced-hook-inline-label"><?php esc_attr_e( '区块', 'adaptive-addon' ); ?></span>
						<p class="ast-inside-content-blocks-notice"><?php esc_attr_e( '布局后将插入选定数量的块。示例-如果你设置为3，布局将在前3块之后添加。', 'adaptive-addon' ); ?></p>
					</td>
				</tr>
				<tr class="ast-advanced-hook-row ast-layout-content-before-heading">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '标题块编号', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
						<span class="ast-advanced-hook-inline-label"><?php esc_attr_e( '添加内容之前', 'adaptive-addon' ); ?></span>
						<input type="number" class="ast-inside-content-number-field" name="ast-advanced-hook-content[before_heading_number]"  min="1" oninput="validity.valid||(value='');" value="<?php echo esc_attr( $before_heading_number ); ?>" >
						<span class="ast-advanced-hook-inline-label"><?php esc_attr_e( '标题块', 'adaptive-addon' ); ?></span>
						<p class="ast-inside-content-heading-notice"><?php esc_attr_e( '布局前将插入选定数量的标题块。示例-如果你设置为3，布局将添加在第3页标题块之前。', 'adaptive-addon' ); ?></p>
					</td>
				</tr>

				<!-- Header Layout -->
				<!-- Sticky Header -->
				<tr class="ast-advanced-hook-row ast-layout-header-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '固定', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
					<input type="checkbox" name="ast-advanced-hook-header[sticky]"
								value="enabled" <?php checked( $header_sticky, 'enabled' ); ?> />
					</td>
				</tr>
				<!-- Shrink Header -->
				<tr class="ast-advanced-hook-row ast-layout-header-sticky-required ast-layout-header-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '收缩', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
					<input type="checkbox" name="ast-advanced-hook-header[shrink]"
							value="enabled" <?php checked( $header_shrink, 'enabled' ); ?> />
					</td>
				</tr>
				<!-- Display On -->
				<tr class="ast-advanced-hook-row ast-layout-header-sticky-required ast-layout-header-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '固定在', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">

						<select name="ast-advanced-hook-header[sticky-header-on-devices]" style="width:50%;">
							<option value="desktop"><?php esc_html_e( '桌面端', 'adaptive-addon' ); ?></option>
							<option value="mobile" <?php selected( $header_on_devices, 'mobile' ); ?> > <?php esc_html_e( '手机号', 'adaptive-addon' ); ?></option>
							<option value="both" <?php selected( $header_on_devices, 'both' ); ?> > <?php esc_html_e( '桌面端+移动端', 'adaptive-addon' ); ?></option>
						</select>
					</td>
				</tr>

				<!-- Footer Layout -->
				<!-- Sticky Footer -->
				<tr class="ast-advanced-hook-row ast-layout-footer-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '固定', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
					<input type="checkbox" name="ast-advanced-hook-footer[sticky]"
								value="enabled" <?php checked( $footer_sticky, 'enabled' ); ?> />
					</td>
				</tr>
				<!-- Display On -->
				<tr class="ast-advanced-hook-row ast-layout-footer-sticky-required ast-layout-footer-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '固定在', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">

						<select name="ast-advanced-hook-footer[sticky-footer-on-devices]" style="width:50%;">
							<option value="desktop"><?php esc_html_e( '桌面端', 'adaptive-addon' ); ?></option>
							<option value="mobile" <?php selected( $footer_on_devices, 'mobile' ); ?> > <?php esc_html_e( '手机号', 'adaptive-addon' ); ?></option>
							<option value="both" <?php selected( $footer_on_devices, 'both' ); ?> > <?php esc_html_e( '桌面端+移动端', 'adaptive-addon' ); ?></option>
						</select>
					</td>
				</tr>


				<tr class="ast-advanced-hook-row ast-layout-hooks-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '操作', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
						<?php
						$description = '';
						?>
						<select id="ast-advanced-hook-action" name="ast-advanced-hook-action" style="width: 50%;" >
							<option value="0"><?php printf( '&mdash; %s &mdash;', esc_html__( '选择', 'adaptive-addon' ) ); ?></option>
							<?php if ( is_array( self::$hooks ) && ! empty( self::$hooks ) ) : ?>
								<?php foreach ( self::$hooks as $hook_cat ) : ?>
								<optgroup label="<?php echo esc_attr( $hook_cat['title'] ); ?>" >
									<?php if ( is_array( $hook_cat['hooks'] ) && ! empty( $hook_cat['hooks'] ) ) : ?>
										<?php foreach ( $hook_cat['hooks'] as $key => $hook ) : ?>
											<?php
											if ( $key == $options['action'] && isset( $hook['description'] ) ) {
												$description = $hook['description'];
											}
											$hook_description = isset( $hook['description'] ) ? $hook['description'] : '';
											?>
										<option <?php selected( $key, $options['action'] ); ?> value="<?php echo esc_attr( $key ); ?>" data-desc="<?php echo esc_attr( $hook_description ); ?>"><?php echo esc_html( $hook['title'] ); ?></option>
									<?php endforeach; ?>
									<?php endif; ?>
								</optgroup>
							<?php endforeach; ?>
							<?php endif; ?>
						</select>
						<p class="description ast-advanced-hook-action-desc <?php echo ( '' == $description ) ? 'ast-no-desc' : ''; ?>"><?php echo esc_html( $description ); ?></p>
					</td>
				</tr>
				<tr class="ast-advanced-hook-row ast-layout-hooks-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '优先级', 'adaptive-addon' ); ?></label>
					</td>
					<td class="ast-advanced-hook-row-content">
					<input type="number" name="ast-advanced-hook-priority" value="<?php echo esc_attr( $options['priority'] ); ?>" placeholder="10" style="width: 50%;"/>
					</td>
				</tr>
				<tr class="ast-advanced-hook-row ast-layout-hooks-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '间距', 'adaptive-addon' ); ?></label>
						<i class="ast-advanced-hook-heading-help dashicons dashicons-editor-help" title="<?php esc_attr_e( '间距可以给定任何正数，有或没有单位，如“5”。或“;5 px\"。默认单位是“px\";', 'adaptive-addon' ); ?>"></i>
					</td>
					<td class="ast-advanced-hook-row-content">
						<div class="ast-advanced-hook-padding-top-wrap">
							<input type="text" id="ast-advanced-hook-padding-top" class="ast-advanced-hook-padding ast-advanced-hook-padding-top" name="ast-advanced-hook-padding[top]" value="<?php echo esc_attr( $padding_top ); ?>" placeholder="0" style="width: 35%;"/>
							<label for="ast-advanced-hook-padding-top"><?php esc_html_e( '顶间距', 'adaptive-addon' ); ?></label>
						</div>
						<div class="ast-advanced-hook-padding-bottom-wrap" >
							<input type="text" id="ast-advanced-hook-padding-bottom" class="ast-advanced-hook-padding ast-advanced-hook-padding-bottom" name="ast-advanced-hook-padding[bottom]" value="<?php echo esc_attr( $padding_bottom ); ?>" placeholder="0" style="width: 35%;"/>
							<label for="ast-advanced-hook-padding-bottom"><?php esc_html_e( '底间距', 'adaptive-addon' ); ?></label>
						</div>
					</td>
				</tr>

				<tr class="ast-advanced-hook-row ast-target-rules-display ast-layout-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '显示在', 'adaptive-addon' ); ?></label>
						<i class="ast-advanced-hook-heading-help dashicons dashicons-editor-help" title="<?php echo esc_attr__( '添加自定义布局应该出现的位置。', 'adaptive-addon' ); ?>"></i>
					</td>
					<td class="ast-advanced-hook-row-content">
					<?php
						Adaptive_Target_Rules_Fields::target_rule_settings_field(
							'ast-advanced-hook-location',
							array(
								'title'          => __( '显示规则', 'adaptive-addon' ),
								'value'          => '[{"type":"basic-global","specific":null}]',
								'tags'           => 'site,enable,target,pages',
								'rule_type'      => 'display',
								'add_rule_label' => __( '添加显示规则', 'adaptive-addon' ),
							),
							$include_locations
						);
					?>
					</td>
				</tr>
				<tr class="ast-advanced-hook-row ast-target-rules-exclude ast-layout-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '不显示', 'adaptive-addon' ); ?></label>
						<i class="ast-advanced-hook-heading-help dashicons dashicons-editor-help" title="<?php echo esc_attr__( '此自定义布局将不会出现在这些位置。', 'adaptive-addon' ); ?>"></i>
					</td>
					<td class="ast-advanced-hook-row-content">
					<?php
						Adaptive_Target_Rules_Fields::target_rule_settings_field(
							'ast-advanced-hook-exclusion',
							array(
								'title'          => __( '排除在', 'adaptive-addon' ),
								'value'          => '[]',
								'tags'           => 'site,enable,target,pages',
								'add_rule_label' => __( '添加排除规则', 'adaptive-addon' ),
								'rule_type'      => 'exclude',
							),
							$exclude_locations
						);
					?>
					</td>
				</tr>
				<tr class="ast-advanced-hook-row ast-target-rules-user ast-layout-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '用户角色', 'adaptive-addon' ); ?></label>
						<i class="ast-advanced-hook-heading-help dashicons dashicons-editor-help" title="<?php echo esc_attr__( '根据用户角色定位此自定义布局。', 'adaptive-addon' ); ?>"></i>
					</td>
					<td class="ast-advanced-hook-row-content">
					<?php
						Adaptive_Target_Rules_Fields::target_user_role_settings_field(
							'ast-advanced-hook-users',
							array(
								'title'          => __( '用户', 'adaptive-addon' ),
								'value'          => '[]',
								'tags'           => 'site,enable,target,pages',
								'add_rule_label' => __( '添加用户规则', 'adaptive-addon' ),
							),
							$users
						);
					?>
					</td>
				</tr>

				<tr class="ast-advanced-hook-row ast-target-responsive-display ast-layout-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '响应可见性', 'adaptive-addon' ); ?></label>
						<i class="ast-advanced-hook-heading-help dashicons dashicons-editor-help" title="<?php echo esc_attr__( '选择设备以选择此自定义布局应显示的位置。', 'adaptive-addon' ); ?>"></i>
					</td>
					<td class="ast-advanced-hook-row-content">
						<ul class="ast-advanced-device-display-wrap">
							<li>
								<label>
									<input type="checkbox" name="ast-advanced-display-device[]" value="desktop" <?php echo in_array( 'desktop', $display_devices, true ) ? 'checked="checked"' : ''; ?> />
									<?php esc_html_e( '桌面端', 'adaptive-addon' ); ?>
								</label>
							</li>
							<li>
								<label>
									<input type="checkbox" name="ast-advanced-display-device[]" value="tablet" <?php echo in_array( 'tablet', $display_devices, true ) ? 'checked="checked"' : ''; ?> />
									<?php esc_html_e( '平板', 'adaptive-addon' ); ?>
								</label>
							</li>
							<li>
								<label>
									<input type="checkbox" name="ast-advanced-display-device[]" value="mobile" <?php echo in_array( 'mobile', $display_devices, true ) ? 'checked="checked"' : ''; ?> />
									<?php esc_html_e( '手机号', 'adaptive-addon' ); ?>
								</label>
							</li>
						</ul>
					</td>
				</tr>

				<tr class="ast-advanced-hook-row ast-target-time-duration-display ast-layout-required">
					<td class="ast-advanced-hook-row-heading">
						<label><?php esc_html_e( '时间期限', 'adaptive-addon' ); ?></label>
						<i class="ast-advanced-hook-heading-help dashicons dashicons-editor-help" title="<?php echo esc_attr__( '选择应显示此自定义布局的时间持续时间。', 'adaptive-addon' ); ?>"></i>
					</td>
					<td class="ast-advanced-hook-row-content">
						<ul class="ast-advanced-time-duration-wrap">
							<li>
								<label>
									<input type="checkbox" id="ast-advanced-time-duration-enabled" name="ast-advanced-time-duration[enabled]" value="enabled" <?php checked( isset( $time_duration['enabled'] ) ? $time_duration['enabled'] : '', 'enabled' ); ?> />
									<?php esc_html_e( '启用', 'adaptive-addon' ); ?>
								</label>
							</li>
							<li class="ast-advanced-time-duration-enabled">
								<label for="ast-advanced-time-duration-start-dt"> <?php esc_attr_e( '开始日期/时间', 'adaptive-addon' ); ?>:
								<input placeholder="<?php esc_attr_e( '单击以选择日期', 'adaptive-addon' ); ?>" class="ast-advanced-date-time-input" type="text" id="ast-advanced-time-duration-start-dt" name="ast-advanced-time-duration[start-dt]"  value="<?php echo isset( $time_duration['start-dt'] ) ? esc_attr( $time_duration['start-dt'] ) : ''; ?>" readonly />
								</label>
							</li>
							<li class="ast-advanced-time-duration-enabled">
								<label for="ast-advanced-time-duration-end-dt"> <?php esc_attr_e( '结束日期/时间', 'adaptive-addon' ); ?>:
								<input placeholder="<?php esc_attr_e( '单击以选择日期', 'adaptive-addon' ); ?>" class="ast-advanced-date-time-input" type="text" id="ast-advanced-time-duration-end-dt" name="ast-advanced-time-duration[end-dt]" value="<?php echo isset( $time_duration['end-dt'] ) ? esc_attr( $time_duration['end-dt'] ) : ''; ?>" readonly />
								</label>
							</li>
							<li class="ast-advanced-time-duration-enabled" >
								<label> <?php esc_html_e( '时区：', 'adaptive-addon' ); ?> </label>
								<a target="_blank" href="<?php echo esc_attr( admin_url( 'options-general.php' ) ); ?>"> <?php echo esc_attr( static::get_gc_timezone_string() ); ?> </a>
							</li>
						</ul>
					</td>
				</tr>

			</table>

			<?php
		}


	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
Adaptive_Ext_Advanced_Hooks_Meta::get_instance();
