<?php
/**
 * Above Header
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.8
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.8
 */
if ( ! class_exists( 'Adaptive_Customizer_Adv_Search_Above_Header' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Adv_Search_Above_Header extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.8
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				// Option: Above Header Section 1 Search Style.
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1-search-box-type]',
					'default'  => adaptive_get_option( 'above-header-section-1-search-box-type' ),
					'section'  => 'section-above-header',
					'priority' => 45,
					'title'    => __( '搜索风格', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'choices'  => array(
						'slide-search' => __( '向上滑', 'adaptive-addon' ),
						'full-screen'  => __( '全屏', 'adaptive-addon' ),
						'header-cover' => __( '页头覆盖', 'adaptive-addon' ),
						'search-box'   => __( '搜索框', 'adaptive-addon' ),
					),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'search',
						),
					),
				),

				// Option: Above Header Section 2 Search Style.
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2-search-box-type]',
					'default'  => adaptive_get_option( 'above-header-section-2-search-box-type' ),
					'section'  => 'section-above-header',
					'priority' => 70,
					'title'    => __( '搜索风格', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'choices'  => array(
						'slide-search' => __( '向上滑', 'adaptive-addon' ),
						'full-screen'  => __( '全屏', 'adaptive-addon' ),
						'header-cover' => __( '页头覆盖', 'adaptive-addon' ),
						'search-box'   => __( '搜索框', 'adaptive-addon' ),
					),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '==',
							'value'    => 'above-header-layout-1',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'search',
						),
					),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Adv_Search_Above_Header();
