<?php
/**
 * Adaptive Theme Customizer Configuration Builder.
 *
 * @package     adaptive-addon
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       3.0.0
 */

// No direct access, please.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Register Builder Customizer Configurations.
 *
 * @since 3.0.0
 */
// @codingStandardsIgnoreStart
class Adaptive_Customizer_Adv_Search_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
	// @codingStandardsIgnoreEnd

	/**
	 * Register Builder Customizer Configurations.
	 *
	 * @param Array                $configurations Adaptive Customizer Configurations.
	 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
	 * @since 3.0.0
	 * @return Array Adaptive Customizer Configurations with updated configurations.
	 */
	public function register_configuration( $configurations, $gc_customize ) {

		$_section = 'section-header-search';

		/**
		 * Option: Pro Search Bar Configs.
		 */
		$_configs = array(
			// Option: Header Search Style.
			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
				'default'   => adaptive_get_option( 'header-search-box-type' ),
				'section'   => $_section,
				'priority'  => 1,
				'title'     => __( '搜索风格', 'adaptive-addon' ),
				'type'      => 'control',
				'control'   => 'ast-select',
				'choices'   => array(
					'slide-search' => __( '滑动搜索', 'adaptive-addon' ),
					'full-screen'  => __( '全屏搜索', 'adaptive-addon' ),
					'header-cover' => __( '页眉覆盖搜索', 'adaptive-addon' ),
					'search-box'   => __( '搜索框', 'adaptive-addon' ),
				),
				'context'   => adaptive_addon_builder_helper()->general_tab,
				'transport' => 'postMessage',
				'partial'   => array(
					'selector'            => '.ast-header-search',
					'container_inclusive' => false,
					'render_callback'     => array( Adaptive_Ext_Adv_Search_Markup::get_instance(), 'get_search_markup' ),
				),
				'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
			),

			/**
			 * Option: search placeholder text.
			 */
			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-search-box-placeholder]',
				'default'   => adaptive_get_option( 'header-search-box-placeholder' ),
				'section'   => $_section,
				'priority'  => 2,
				'title'     => __( '点位符文本', 'adaptive-addon' ),
				'type'      => 'control',
				'control'   => 'text',
				'transport' => 'postMessage',
				'partial'   => array(
					'selector'            => '.ast-header-search',
					'container_inclusive' => false,
					'render_callback'     => array( Adaptive_Ext_Adv_Search_Markup::get_instance(), 'get_search_markup' ),
				),
				'context'   => adaptive_addon_builder_helper()->general_tab,
			),
		);

		return array_merge( $configurations, $_configs );
	}
}

/**
 * Kicking this off by creating object of this class.
 */

new Adaptive_Customizer_Adv_Search_Configs();

