<?php
/**
 * Primary Header
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.8
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.8
 */
if ( ! class_exists( 'Adaptive_Customizer_Adv_Search_Header' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Adv_Search_Header extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.8
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				// Option: Header Search Style.
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section-search-box-type]',
					'default'  => adaptive_get_option( 'header-main-rt-section-search-box-type' ),
					'section'  => 'section-primary-menu',
					'priority' => 20,
					'title'    => __( '搜索风格', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'choices'  => array(
						'slide-search' => __( '滑动搜索', 'adaptive-addon' ),
						'full-screen'  => __( '全屏搜索', 'adaptive-addon' ),
						'header-cover' => __( '页眉覆盖搜索', 'adaptive-addon' ),
						'search-box'   => __( '搜索框', 'adaptive-addon' ),
					),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section]',
							'operator' => '==',
							'value'    => 'search',
						),
					),
					'divider'  => array( 'ast_class' => 'ast-top-divider' ),
				),

			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Adv_Search_Header();
