<?php
/**
 * Blog Pro General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Blog_Pro_Configs' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Blog_Pro_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Display Post Meta
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[blog-meta]',
					'type'              => 'control',
					'control'           => 'ast-sortable',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_multi_choices' ),
					'section'           => 'section-blog',
					'default'           => adaptive_get_option( 'blog-meta' ),
					'priority'          => 50,
					'title'             => __( '其他', 'adaptive-addon' ),
					'choices'           => array(
						'comments'  => __( '评论', 'adaptive-addon' ),
						'category'  => __( '分类', 'adaptive-addon' ),
						'author'    => __( '作者', 'adaptive-addon' ),
						'date'      => __( '发布日期', 'adaptive-addon' ),
						'tag'       => __( '标签', 'adaptive-addon' ),
						'read-time' => __( '读取时间', 'adaptive-addon' ),
					),
					'context'           => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-post-structure]',
							'operator' => 'contains',
							'value'    => 'title-meta',
						),
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Blog Layout
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[blog-layout]',
					'type'              => 'control',
					'control'           => 'ast-radio-image',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_choices' ),
					'section'           => 'section-blog',
					'default'           => adaptive_get_option( 'blog-layout' ),
					'priority'          => 5,
					'title'             => __( '样式', 'adaptive-addon' ),
					'choices'           => array(
						'blog-layout-1' => array(
							'label' => __( '布局1', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'blog-layout-1', false ) : '',
						),
						'blog-layout-2' => array(
							'label' => __( '布局2', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'blog-layout-2', false ) : '',
						),
						'blog-layout-3' => array(
							'label' => __( '布局3', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'blog-layout-3', false ) : '',
						),
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Grid Layout
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-grid]',
					'type'     => 'control',
					'control'  => 'ast-select',
					'section'  => 'section-blog',
					'default'  => adaptive_get_option( 'blog-grid' ),
					'priority' => 10,
					'title'    => __( '网格布局', 'adaptive-addon' ),
					'choices'  => array(
						'1' => __( '1列', 'adaptive-addon' ),
						'2' => __( '2列', 'adaptive-addon' ),
						'3' => __( '3列', 'adaptive-addon' ),
						'4' => __( '4列', 'adaptive-addon' ),
					),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-layout]',
							'operator' => '===',
							'value'    => 'blog-layout-1',
						),
					),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Space Between Post
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[blog-space-bet-posts]',
					'default'   => adaptive_get_option( 'blog-space-bet-posts' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$switch_control,
					'section'   => 'section-blog',
					'title'     => __( '在Posts之间添加空格', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'priority'  => 15,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Masonry Effect
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-masonry]',
					'default'  => adaptive_get_option( 'blog-masonry' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-blog',
					'title'    => __( 'Masonry 布局', 'adaptive-addon' ),
					'priority' => 20,
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-layout]',
							'operator' => '===',
							'value'    => 'blog-layout-1',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-grid]',
							'operator' => '!=',
							'value'    => 1,
						),
					),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: First Post full width
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[first-post-full-width]',
					'default'     => adaptive_get_option( 'first-post-full-width' ),
					'type'        => 'control',
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'section'     => 'section-blog',
					'title'       => __( '强调第一篇文章', 'adaptive-addon' ),
					'description' => __( '如果Masonry布局是启用的，这将不会工作。', 'adaptive-addon' ),
					'priority'    => 25,
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-layout]',
							'operator' => '===',
							'value'    => 'blog-layout-1',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-grid]',
							'operator' => '!=',
							'value'    => 1,
						),
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Disable Date Box
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-date-box]',
					'default'  => adaptive_get_option( 'blog-date-box' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-blog',
					'title'    => __( '启用日期框', 'adaptive-addon' ),
					'priority' => 30,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Date Box Style
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[blog-date-box-style]',
					'default'    => adaptive_get_option( 'blog-date-box-style' ),
					'type'       => 'control',
					'section'    => 'section-blog',
					'title'      => __( '日期框风格', 'adaptive-addon' ),
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'priority'   => 35,
					'choices'    => array(
						'square' => __( '实心方块', 'adaptive-addon' ),
						'circle' => __( '圆圈', 'adaptive-addon' ),
					),
					'context'    => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-date-box]',
							'operator' => '===',
							'value'    => true,
						),
					),
					'responsive' => false,
					'renderAs'   => 'text',
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Remove feature image padding
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[blog-featured-image-padding]',
					'default'     => adaptive_get_option( 'blog-featured-image-padding' ),
					'type'        => 'control',
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'section'     => 'section-blog',
					'title'       => __( '删除特色图像填充', 'adaptive-addon' ),
					'description' => __( '此选项不适用于全宽度布局。', 'adaptive-addon' ),
					'priority'    => 40,
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-layout]',
							'operator' => '===',
							'value'    => 'blog-layout-1',
						),
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Excerpt Count
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[blog-excerpt-count]',
					'default'     => adaptive_get_option( 'blog-excerpt-count' ),
					'type'        => 'control',
					'control'     => 'number',
					'section'     => 'section-blog',
					'priority'    => 80,
					'title'       => __( '摘要数', 'adaptive-addon' ),
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 3000,
					),
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-post-content]',
							'operator' => '===',
							'value'    => 'excerpt',
						),
					),
				),

				/**
				 * Option: Read more text
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-read-more-text]',
					'default'  => adaptive_get_option( 'blog-read-more-text' ),
					'type'     => 'control',
					'section'  => 'section-blog',
					'priority' => 85,
					'title'    => __( '阅读更多的文本', 'adaptive-addon' ),
					'control'  => 'text',
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-post-content]',
							'operator' => '===',
							'value'    => 'excerpt',
						),
					),
				),

				/**
				 * Option: Display read more as button
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-read-more-as-button]',
					'default'  => adaptive_get_option( 'blog-read-more-as-button' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-blog',
					'title'    => __( '显示阅读更多的按钮', 'adaptive-addon' ),
					'priority' => 90,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Post Pagination
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[blog-pagination]',
					'default'    => adaptive_get_option( 'blog-pagination' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => 'section-blog',
					'priority'   => 110,
					'title'      => __( '文章分页', 'adaptive-addon' ),
					'choices'    => array(
						'number'   => __( '显示序列号', 'adaptive-addon' ),
						'infinite' => __( '无限分页', 'adaptive-addon' ),
					),
					'responsive' => false,
					'renderAs'   => 'text',
					'divider'    => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
				),

				/**
				 * Option: Event to Trigger Infinite Loading
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[blog-infinite-scroll-event]',
					'default'     => adaptive_get_option( 'blog-infinite-scroll-event' ),
					'type'        => 'control',
					'control'     => Adaptive_Theme_Extension::$selector_control,
					'section'     => 'section-blog',
					'description' => __( '无法在定制程序中预览无限分页。', 'adaptive-addon' ),
					'priority'    => 112,
					'title'       => __( '事件触发无限加载', 'adaptive-addon' ),
					'choices'     => array(
						'scroll' => __( '滚动', 'adaptive-addon' ),
						'click'  => __( '点此查看本设置相关文档', 'adaptive-addon' ),
					),
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-pagination]',
							'operator' => '===',
							'value'    => 'infinite',
						),
					),
					'responsive'  => false,
					'renderAs'    => 'text',
				),

				/**
				 * Option: Post Pagination Style
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[blog-pagination-style]',
					'default'    => adaptive_get_option( 'blog-pagination-style' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => 'section-blog',
					'priority'   => 115,
					'title'      => __( '文章分页样式', 'adaptive-addon' ),
					'choices'    => array(
						'default' => __( '默认', 'adaptive-addon' ),
						'square'  => __( '实心方块', 'adaptive-addon' ),
						'circle'  => __( '圆圈', 'adaptive-addon' ),
					),
					'context'    => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-pagination]',
							'operator' => '===',
							'value'    => 'number',
						),
					),
					'responsive' => false,
					'renderAs'   => 'text',
				),

				/**
				 * Option: Read more text
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-load-more-text]',
					'default'  => adaptive_get_option( 'blog-load-more-text' ),
					'type'     => 'control',
					'section'  => 'section-blog',
					'priority' => 90,
					'title'    => __( '加载更多的文本', 'adaptive-addon' ),
					'control'  => 'text',
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-pagination]',
							'operator' => '===',
							'value'    => 'infinite',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-infinite-scroll-event]',
							'operator' => '===',
							'value'    => 'click',
						),
					),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Blog_Pro_Configs();
