<?php
/**
 * Blog Pro Single General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Blog_Pro_Single_Configs' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Blog_Pro_Single_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Single Post Meta
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-single-meta]',
					'type'     => 'control',
					'control'  => 'ast-sortable',
					'default'  => adaptive_get_option( 'blog-single-meta' ),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-single-post-structure]',
							'operator' => 'contains',
							'value'    => 'single-title-meta',
						),
					),
					'section'  => 'section-blog-single',
					'priority' => 5,
					'title'    => __( '其他', 'adaptive-addon' ),
					'choices'  => array(
						'comments'  => __( '评论', 'adaptive-addon' ),
						'category'  => __( '分类', 'adaptive-addon' ),
						'author'    => __( '作者', 'adaptive-addon' ),
						'date'      => __( '发布日期', 'adaptive-addon' ),
						'tag'       => __( '标签', 'adaptive-addon' ),
						'read-time' => __( '读取时间', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Author info
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[ast-author-info]',
					'default'  => adaptive_get_option( 'ast-author-info' ),
					'type'     => 'control',
					'section'  => 'section-blog-single',
					'title'    => __( '作者信息', 'adaptive-addon' ),
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'priority' => 9,
					'divider'  => array( 'ast_class' => 'ast-top-divider ast-bottom-divider' ),
				),

				/**
				 * Option: Disable Single Post Navigation
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[ast-single-post-navigation]',
					'default'  => adaptive_get_option( 'ast-single-post-navigation' ),
					'type'     => 'control',
					'section'  => 'section-blog-single',
					'title'    => __( '禁用单页面导航', 'adaptive-addon' ),
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'priority' => 9,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Autoposts
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[ast-auto-prev-post]',
					'default'     => adaptive_get_option( 'ast-auto-prev-post' ),
					'type'        => 'control',
					'section'     => 'section-blog-single',
					'title'       => __( '自动加载以前的文章', 'adaptive-addon' ),
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'description' => __( '自动加载以前的文章不能在自定义程序中预览。', 'adaptive-addon' ),
					'priority'    => 9,
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Remove feature image padding
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[single-featured-image-padding]',
					'default'     => adaptive_get_option( 'single-featured-image-padding' ),
					'type'        => 'control',
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'section'     => 'section-blog-single',
					'title'       => __( '删除特色图像填充', 'adaptive-addon' ),
					'description' => __( '此选项不适用于全宽度布局。', 'adaptive-addon' ),
					'priority'    => 9,
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by creating new instance.
 */
new Adaptive_Customizer_Blog_Pro_Single_Configs();
