<?php
/**
 * Blog Pro General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Colors_Archive' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Colors_Archive extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$content_colors_config_title = __( '内容', 'adaptive-addon' );
			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
				$content_colors_config_title = __( '内容颜色', 'adaptive-addon' );
			}

			$_configs = array(

				/**
				 * Option: Blog / Archive Color Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'default'   => adaptive_get_option( 'blog-content-color-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => $content_colors_config_title,
					'section'   => 'section-blog',
					'transport' => 'postMessage',
					'priority'  => 130,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Divider.
				array(
					'name'     => 'divider-blog-archive',
					'control'  => 'ast-divider',
					'default'  => '',
					'type'     => 'sub-control',
					'parent'   => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'  => 'section-blog',
					'title'    => __( '归档总结盒子', 'adaptive-addon' ),
					'tab'      => __( '标准', 'adaptive-addon' ),
					'priority' => 11,
					'settings' => array(),
					'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Archive Summary Box Background Color.
				array(
					'name'        => 'archive-summary-box-bg-color',
					'default'     => adaptive_get_option( 'archive-summary-box-bg-color' ),
					'tab'         => __( '标准', 'adaptive-addon' ),
					'priority'    => 11,
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'     => 'section-blog',
					'transport'   => 'postMessage',
					'control'     => 'ast-color',
					'title'       => __( '背景颜色', 'adaptive-addon' ),
					'description' => __( '这个背景色在全宽度布局上不起作用。', 'adaptive-addon' ),
					'context'     => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Archive Summary Box Title Color.
				array(
					'type'              => 'sub-control',
					'tab'               => __( '标准', 'adaptive-addon' ),
					'priority'          => 11,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'           => 'section-blog',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'name'              => 'archive-summary-box-title-color',
					'default'           => adaptive_get_option( 'archive-summary-box-title-color' ),
					'title'             => __( '标题颜色', 'adaptive-addon' ),
				),

				// Option: Archive Summary Box Description Color.
				array(
					'type'              => 'sub-control',
					'tab'               => __( '标准', 'adaptive-addon' ),
					'priority'          => 11,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'           => 'section-blog',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'name'              => 'archive-summary-box-text-color',
					'default'           => adaptive_get_option( 'archive-summary-box-text-color' ),
					'title'             => __( '描述颜色', 'adaptive-addon' ),
				),

				// Option: Blog / Archive Post Title Color.
				array(
					'type'              => 'sub-control',
					'tab'               => __( '标准', 'adaptive-addon' ),
					'priority'          => 10,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'           => 'section-blog',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'page-title-color' ),
					'transport'         => 'postMessage',
					'name'              => 'page-title-color',
					'title'             => __( '文章标题的颜色', 'adaptive-addon' ),
				),

				// Option: Post Meta Color.
				array(
					'type'              => 'sub-control',
					'tab'               => __( '标准', 'adaptive-addon' ),
					'priority'          => 10,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'           => 'section-blog',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'post-meta-color' ),
					'transport'         => 'postMessage',
					'name'              => 'post-meta-color',
					'title'             => __( 'Meta颜色', 'adaptive-addon' ),
				),

				// Option: Post Meta Link Color.
				array(
					'type'              => 'sub-control',
					'tab'               => __( '标准', 'adaptive-addon' ),
					'priority'          => 10,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'           => 'section-blog',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'post-meta-link-color' ),
					'transport'         => 'postMessage',
					'name'              => 'post-meta-link-color',
					'title'             => __( 'Meta链接颜色', 'adaptive-addon' ),
				),

				// Option: Post Meta Link Hover Color.
				array(
					'type'              => 'sub-control',
					'tab'               => __( '悬停', 'adaptive-addon' ),
					'priority'          => 12,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-content-color-group]',
					'section'           => 'section-blog',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'post-meta-link-h-color' ),
					'transport'         => 'postMessage',
					'name'              => 'post-meta-link-h-color',
					'title'             => __( 'Meta链接颜色', 'adaptive-addon' ),
				),
			);

			if ( false === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				array_push(
					$_configs,
					/**
					 * Option: Blog Color Section heading
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[blog-color-heading-divider]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => 'section-blog',
						'title'    => __( '颜色和背景', 'adaptive-addon' ),
						'priority' => 125,
						'settings' => array(),
						'context'  => adaptive_addon_builder_helper()->general_tab,
					)
				);
			}

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Colors_Archive();
