<?php
/**
 * Blog Pro General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Colors_Content' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Colors_Content extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_section = version_compare( ADAPTIVE_THEME_VERSION, '3.7.0', '>=' ) ? 'section-colors-background' : 'section-colors-content';

			$_configs = array(

				// Option: Heading 1 <h1> Color.
				array(
					'default'           => adaptive_get_option( 'h1-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'name'              => ADAPTIVE_THEME_SETTINGS . '[h1-color]',
					'title'             => __( '一级标题', 'adaptive-addon' ),
					'section'           => $_section,
				),

				// Option: Heading 2 <h2> Color.
				array(
					'default'           => adaptive_get_option( 'h2-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'name'              => ADAPTIVE_THEME_SETTINGS . '[h2-color]',
					'title'             => __( '二级标题', 'adaptive-addon' ),
					'section'           => $_section,
				),

				// Option: Heading 3 <h3> Color.
				array(
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'name'              => ADAPTIVE_THEME_SETTINGS . '[h3-color]',
					'default'           => adaptive_get_option( 'h3-color' ),
					'title'             => __( '三级标题', 'adaptive-addon' ),
					'section'           => $_section,
				),

				// Option: Heading 4 <h4> Color.
				array(
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'h4-color' ),
					'name'              => ADAPTIVE_THEME_SETTINGS . '[h4-color]',
					'title'             => __( '四级标题', 'adaptive-addon' ),
					'section'           => $_section,
				),

				// Option: Heading 5 <h5> Color.
				array(
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'h5-color' ),
					'transport'         => 'postMessage',
					'name'              => ADAPTIVE_THEME_SETTINGS . '[h5-color]',
					'title'             => __( '五级标题', 'adaptive-addon' ),
					'section'           => $_section,
				),

				// Option: Heading 6 <h6> Color.
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[h6-color]',
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'h6-color' ),
					'title'             => __( '六级标题', 'adaptive-addon' ),
					'section'           => $_section,
				),

			);

			if ( adaptive_addon_has_gcp_typo_preset_compatibility() ) {

				// Option: Content Background Color.
				$content_bg_option = array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[content-bg-obj-responsive]',
					'default'   => adaptive_get_option( 'content-bg-obj-responsive' ),
					'type'      => 'control',
					'control'   => 'ast-responsive-background',
					'label'     => __( '背景', 'adaptive-addon' ),
					'section'   => 'section-colors-content',
					'transport' => 'postMessage',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				);

				array_unshift( $_configs, $content_bg_option );
			}

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Colors_Content();
