<?php
/**
 * Colors Primary Menu Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Colors_Header_Builder' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Colors_Header_Builder extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			/**
			 * Header - Menu - Colors
			 */

			$html_config = array();

			$component_limit = adaptive_addon_builder_helper()->component_limit;
			for ( $index = 1; $index <= $component_limit; $index++ ) {

				$_section = 'section-hb-menu-' . $index;
				$_prefix  = 'menu' . $index;

				$_configs = array(

					// Option Group: Sub Menu Colors.
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-link-colors]',
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '文字 / 链接', 'adaptive-addon' ),
						'section'    => $_section,
						'priority'   => 100,
						'transport'  => 'postMessage',
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'responsive' => true,
						'divider'    => array(
							'ast_class' => 'ast-top-divider',
							'ast_title' => __( '子菜单颜色', 'adaptive-addon' ),
						),
					),

					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-background-colors]',
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '背景', 'adaptive-addon' ),
						'section'    => $_section,
						'priority'   => 100,
						'transport'  => 'postMessage',
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'responsive' => true,
					),

					// Option: Submenu Color.
					array(
						'name'       => 'header-' . $_prefix . '-submenu-color-responsive',
						'default'    => adaptive_get_option( 'header-' . $_prefix . '-submenu-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-link-colors]',
						'type'       => 'sub-control',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'tab'        => __( '标准', 'adaptive-addon' ),
						'section'    => $_section,
						'transport'  => 'postMessage',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 13,
						'context'    => adaptive_addon_builder_helper()->general_tab,
					),

					// Option: Submenu Background Color.
					array(
						'name'       => 'header-' . $_prefix . '-submenu-bg-color-responsive',
						'default'    => adaptive_get_option( 'header-' . $_prefix . '-submenu-bg-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-background-colors]',
						'type'       => 'sub-control',
						'title'      => __( '标准', 'adaptive-addon' ),
						'tab'        => __( '标准', 'adaptive-addon' ),
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'transport'  => 'postMessage',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 15,
						'context'    => adaptive_addon_builder_helper()->general_tab,
					),

					// Option: Submenu Hover Color.
					array(
						'name'       => 'header-' . $_prefix . '-submenu-h-color-responsive',
						'default'    => adaptive_get_option( 'header-' . $_prefix . '-submenu-h-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-link-colors]',
						'type'       => 'sub-control',
						'control'    => 'ast-responsive-color',
						'section'    => $_section,
						'transport'  => 'postMessage',
						'title'      => __( '悬停', 'adaptive-addon' ),
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 25,
						'context'    => adaptive_addon_builder_helper()->general_tab,
					),

					// Option: Submenu Hover Background Color.
					array(
						'name'       => 'header-' . $_prefix . '-submenu-h-bg-color-responsive',
						'default'    => adaptive_get_option( 'header-' . $_prefix . '-submenu-h-bg-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-background-colors]',
						'type'       => 'sub-control',
						'control'    => 'ast-responsive-color',
						'transport'  => 'postMessage',
						'section'    => $_section,
						'title'      => __( '悬停', 'adaptive-addon' ),
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 27,
						'context'    => adaptive_addon_builder_helper()->general_tab,
					),

					// Option: Active Submenu Color.
					array(
						'name'       => 'header-' . $_prefix . '-submenu-a-color-responsive',
						'default'    => adaptive_get_option( 'header-' . $_prefix . '-submenu-a-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-link-colors]',
						'type'       => 'sub-control',
						'control'    => 'ast-responsive-color',
						'transport'  => 'postMessage',
						'section'    => $_section,
						'title'      => __( '已启用', 'adaptive-addon' ),
						'tab'        => __( '已启用', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 37,
						'context'    => adaptive_addon_builder_helper()->general_tab,
					),

					// Option: Active Submenu Background Color.
					array(
						'name'       => 'header-' . $_prefix . '-submenu-a-bg-color-responsive',
						'default'    => adaptive_get_option( 'header-' . $_prefix . '-submenu-a-bg-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-submenu-background-colors]',
						'type'       => 'sub-control',
						'control'    => 'ast-responsive-color',
						'transport'  => 'postMessage',
						'section'    => $_section,
						'title'      => __( '已启用', 'adaptive-addon' ),
						'tab'        => __( '已启用', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 39,
						'context'    => adaptive_addon_builder_helper()->general_tab,
					),
				);

				$html_config[] = $_configs;

				if ( 3 > $index ) {
					$_configs = array(
						// Option Group: Primary Mega Menu Colors.
						array(
							'name'      => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-color-group]',
							'type'      => 'control',
							'transport' => 'postMessage',
							'control'   => 'ast-color-group',
							'title'     => __( '超级菜单标题', 'adaptive-addon' ),
							'section'   => $_section,
							'priority'  => 100,
							'context'   => adaptive_addon_builder_helper()->design_tab,
						),

						// Option: Megamenu Heading Color.
						array(
							'name'              => 'header-' . $_prefix . '-header-megamenu-heading-color',
							'default'           => adaptive_get_option( 'header-' . $_prefix . '-header-megamenu-heading-color' ),
							'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-color-group]',
							'type'              => 'sub-control',
							'control'           => 'ast-color',
							'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
							'section'           => $_section,
							'transport'         => 'postMessage',
							'title'             => __( '标准', 'adaptive-addon' ),
							'context'           => adaptive_addon_builder_helper()->general_tab,
						),

						// Option: Megamenu Heading Hover Color.
						array(
							'name'              => 'header-' . $_prefix . '-header-megamenu-heading-h-color',
							'default'           => adaptive_get_option( 'header-' . $_prefix . '-header-megamenu-heading-h-color' ),
							'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-color-group]',
							'type'              => 'sub-control',
							'control'           => 'ast-color',
							'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
							'section'           => $_section,
							'transport'         => 'postMessage',
							'title'             => __( '悬停', 'adaptive-addon' ),
							'context'           => adaptive_addon_builder_helper()->general_tab,
						),
					);

					$html_config[] = $_configs;
				}
			}

			/**
			 * Footer Copyright Link Colors
			 */

			$html_config[] = array(

				/**
				* Option: Account Colors tab
				*/
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-heading]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'section'  => 'section-header-account',
					'title'    => __( '颜色', 'adaptive-addon' ),
					'priority' => 18,
					'settings' => array(),
					'context'  => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-action]',
								'operator' => '==',
								'value'    => 'login',
							),
						),
					),
				),

				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-link-colors]',
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '链接', 'adaptive-addon' ),
					'section'    => 'section-header-account',
					'transport'  => 'postMessage',
					'priority'   => 19,
					'divider'    => array(
						'ast_title' => __( '菜单颜色', 'adaptive-addon' ),
					),
					'context'    => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
							'operator' => '==',
							'value'    => 'menu',
						),
						adaptive_addon_builder_helper()->design_tab_config,
					),
					'responsive' => false,
				),
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-background-colors]',
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '背景', 'adaptive-addon' ),
					'section'    => 'section-header-account',
					'transport'  => 'postMessage',
					'priority'   => 19,
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'    => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
							'operator' => '==',
							'value'    => 'menu',
						),
						adaptive_addon_builder_helper()->design_tab_config,
					),
					'responsive' => false,
				),

				// Option: Menu Color.
				array(
					'name'      => 'header-account-menu-color',
					'default'   => adaptive_get_option( 'header-account-menu-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-link-colors]',
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'tab'       => __( '标准', 'adaptive-addon' ),
					'section'   => 'section-header-account',
					'title'     => __( '标准', 'adaptive-addon' ),
					'priority'  => 7,
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
							'operator' => '==',
							'value'    => 'menu',
						),
						adaptive_addon_builder_helper()->design_tab_config,
					),
				),

				// Option: Background Color.
				array(
					'name'      => 'header-account-menu-bg-obj',
					'default'   => adaptive_get_option( 'header-account-menu-bg-obj' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-background-colors]',
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'section'   => 'section-header-account',
					'title'     => __( '标准', 'adaptive-addon' ),
					'tab'       => __( '标准', 'adaptive-addon' ),
					'priority'  => 8,
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Menu Hover Color.
				array(
					'name'      => 'header-account-menu-h-color',
					'default'   => adaptive_get_option( 'header-account-menu-h-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-link-colors]',
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'title'     => __( '悬停', 'adaptive-addon' ),
					'tab'       => __( '悬停', 'adaptive-addon' ),
					'section'   => 'section-header-account',
					'priority'  => 19,
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Menu Hover Background Color.
				array(
					'name'      => 'header-account-menu-h-bg-color',
					'default'   => adaptive_get_option( 'header-account-menu-h-bg-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-background-colors]',
					'type'      => 'sub-control',
					'title'     => __( '悬停', 'adaptive-addon' ),
					'tab'       => __( '悬停', 'adaptive-addon' ),
					'section'   => 'section-header-account',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'priority'  => 21,
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Active Menu Color.
				array(
					'name'      => 'header-account-menu-a-color',
					'default'   => adaptive_get_option( 'header-account-menu-a-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-link-colors]',
					'type'      => 'sub-control',
					'section'   => 'section-header-account',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'title'     => __( '已启用', 'adaptive-addon' ),
					'tab'       => __( '已启用', 'adaptive-addon' ),
					'priority'  => 31,
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Active Menu Background Color.
				array(
					'name'      => 'header-account-menu-a-bg-color',
					'default'   => adaptive_get_option( 'header-account-menu-a-bg-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-background-colors]',
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'section'   => 'section-header-account',
					'title'     => __( '已启用', 'adaptive-addon' ),
					'tab'       => __( '已启用', 'adaptive-addon' ),
					'priority'  => 33,
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				// Option Group: Account Popup Color.
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[header-account-popup-colors]',
					'default'   => adaptive_get_option( 'header-account-popup-colors' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '登录弹出窗口', 'adaptive-addon' ),
					'section'   => 'section-header-account',
					'transport' => 'postMessage',
					'priority'  => 20,
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-action]',
							'operator' => '==',
							'value'    => 'login',
						),
						adaptive_addon_builder_helper()->design_tab_config,
					),
				),

				// Option: label Color.
				array(
					'name'              => 'header-account-popup-label-color',
					'default'           => adaptive_get_option( 'header-account-popup-label-color' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-account-popup-colors]',
					'type'              => 'sub-control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'section'           => 'section-header-account',
					'title'             => __( '标签颜色', 'adaptive-addon' ),
					'rgba'              => true,
					'priority'          => 1,
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: input text Color.
				array(
					'name'              => 'header-account-popup-input-text-color',
					'default'           => adaptive_get_option( 'header-account-popup-input-text-color' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-account-popup-colors]',
					'type'              => 'sub-control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'section'           => 'section-header-account',
					'title'             => __( '输入文字颜色', 'adaptive-addon' ),
					'rgba'              => true,
					'priority'          => 2,
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Background Color.
				array(
					'name'              => 'header-account-popup-input-border-color',
					'default'           => adaptive_get_option( 'header-account-popup-input-border-color' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-account-popup-colors]',
					'type'              => 'sub-control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'section'           => 'section-header-account',
					'title'             => __( '输入边框颜色', 'adaptive-addon' ),
					'rgba'              => true,
					'priority'          => 3,
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Background Color.
				array(
					'name'              => 'header-account-popup-button-text-color',
					'default'           => adaptive_get_option( 'header-account-popup-button-text-color' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-account-popup-colors]',
					'type'              => 'sub-control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'section'           => 'section-header-account',
					'title'             => __( '按钮文字颜色', 'adaptive-addon' ),
					'rgba'              => true,
					'priority'          => 4,
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Background Color.
				array(
					'name'              => 'header-account-popup-button-bg-color',
					'default'           => adaptive_get_option( 'header-account-popup-button-bg-color' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-account-popup-colors]',
					'type'              => 'sub-control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'section'           => 'section-header-account',
					'title'             => __( '按钮背景颜色', 'adaptive-addon' ),
					'rgba'              => true,
					'priority'          => 5,
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Popup Background Color.
				array(
					'name'              => 'header-account-popup-bg-color',
					'default'           => adaptive_get_option( 'header-account-popup-bg-color' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-account-popup-colors]',
					'type'              => 'sub-control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'section'           => 'section-header-account',
					'title'             => __( '弹窗背景颜色', 'adaptive-addon' ),
					'rgba'              => true,
					'priority'          => 6,
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Group: Search Border Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[footer-copyright-link-color-group]',
					'default'   => adaptive_get_option( 'footer-copyright-link-color-group' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$group_control,
					'title'     => __( '链接的颜色', 'adaptive-addon' ),
					'section'   => 'section-footer-copyright',
					'transport' => 'postMessage',
					'priority'  => 6,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),

				/**
				 * Option: Footer copyright Link Color.
				 */
				array(
					'name'              => 'footer-copyright-link-color',
					'default'           => adaptive_get_option( 'footer-copyright-link-color' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-copyright-link-color-group]',
					'type'              => 'sub-control',
					'section'           => 'section-footer-copyright',
					'priority'          => 9,
					'transport'         => 'postMessage',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '标准', 'adaptive-addon' ),
					'context'           => adaptive_addon_builder_helper()->design_tab_config,
				),

				/**
				 * Option: Link Hover Color.
				 */
				array(
					'name'              => 'footer-copyright-link-h-color',
					'default'           => adaptive_get_option( 'footer-copyright-link-h-color' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-copyright-link-color-group]',
					'section'           => 'section-footer-copyright',
					'priority'          => 9,
					'transport'         => 'postMessage',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '悬停', 'adaptive-addon' ),
					'context'           => adaptive_addon_builder_helper()->design_tab_config,
				),
			);

			/**
			 * Mobile Menu - Submenu Colors
			 */
			$html_config[] = array(

				// Option Group: Sub Menu Colors.
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-link-colors]',
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '链接', 'adaptive-addon' ),
					'divider'    => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '子菜单颜色', 'adaptive-addon' ),
					),
					'section'    => 'section-header-mobile-menu',
					'priority'   => 100,
					'transport'  => 'postMessage',
					'context'    => adaptive_addon_builder_helper()->design_tab,
					'responsive' => true,
				),

				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-background-colors]',
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '背景', 'adaptive-addon' ),
					'section'    => 'section-header-mobile-menu',
					'priority'   => 100,
					'transport'  => 'postMessage',
					'context'    => adaptive_addon_builder_helper()->design_tab,
					'responsive' => true,
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				// Option: Submenu Color.
				array(
					'name'       => 'header-mobile-menu-submenu-color-responsive',
					'default'    => adaptive_get_option( 'header-mobile-menu-submenu-color-responsive' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-link-colors]',
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'title'      => __( '标准', 'adaptive-addon' ),
					'tab'        => __( '标准', 'adaptive-addon' ),
					'section'    => 'section-header-mobile-menu',
					'transport'  => 'postMessage',
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 13,
					'context'    => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Submenu Background Color.
				array(
					'name'       => 'header-mobile-menu-submenu-bg-color-responsive',
					'default'    => adaptive_get_option( 'header-mobile-menu-submenu-bg-color-responsive' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-background-colors]',
					'type'       => 'sub-control',
					'title'      => __( '标准', 'adaptive-addon' ),
					'tab'        => __( '标准', 'adaptive-addon' ),
					'section'    => 'section-header-mobile-menu',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 15,
					'context'    => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Submenu Hover Color.
				array(
					'name'       => 'header-mobile-menu-submenu-h-color-responsive',
					'default'    => adaptive_get_option( 'header-mobile-menu-submenu-h-color-responsive' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-link-colors]',
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'section'    => 'section-header-mobile-menu',
					'transport'  => 'postMessage',
					'title'      => __( '悬停', 'adaptive-addon' ),
					'tab'        => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 25,
					'context'    => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Submenu Hover Background Color.
				array(
					'name'       => 'header-mobile-menu-submenu-h-bg-color-responsive',
					'default'    => adaptive_get_option( 'header-mobile-menu-submenu-h-bg-color-responsive' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-background-colors]',
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'section'    => 'section-header-mobile-menu',
					'title'      => __( '悬停', 'adaptive-addon' ),
					'tab'        => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 27,
					'context'    => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Active Submenu Color.
				array(
					'name'       => 'header-mobile-menu-submenu-a-color-responsive',
					'default'    => adaptive_get_option( 'header-mobile-menu-submenu-a-color-responsive' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-link-colors]',
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'section'    => 'section-header-mobile-menu',
					'title'      => __( '已启用', 'adaptive-addon' ),
					'tab'        => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 37,
					'context'    => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Active Submenu Background Color.
				array(
					'name'       => 'header-mobile-menu-submenu-a-bg-color-responsive',
					'default'    => adaptive_get_option( 'header-mobile-menu-submenu-a-bg-color-responsive' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-submenu-background-colors]',
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'section'    => 'section-header-mobile-menu',
					'title'      => __( '已启用', 'adaptive-addon' ),
					'tab'        => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 39,
					'context'    => adaptive_addon_builder_helper()->general_tab,
				),
			);

			/**
			 * Langugae Switcher
			 */
			$html_config[] = array(

				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[section-hb-language-switcher-color]',
					'default'   => adaptive_get_option( 'section-hb-language-switcher-color' ),
					'type'      => 'control',
					'section'   => 'section-hb-language-switcher',
					'priority'  => 21,
					'transport' => 'postMessage',
					'control'   => 'ast-color',
					'title'     => __( '颜色', 'adaptive-addon' ),
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-language-switcher-show-name]',
							'operator' => '==',
							'value'    => true,
						),
						adaptive_addon_builder_helper()->design_tab_config,
					),
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				),
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[section-fb-language-switcher-color]',
					'default'   => adaptive_get_option( 'section-fb-language-switcher-color' ),
					'type'      => 'control',
					'section'   => 'section-fb-language-switcher',
					'priority'  => 21,
					'transport' => 'postMessage',
					'control'   => 'ast-color',
					'title'     => __( '颜色', 'adaptive-addon' ),
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[footer-language-switcher-show-name]',
							'operator' => '==',
							'value'    => true,
						),
						adaptive_addon_builder_helper()->design_tab_config,
					),
				),
			);

			$html_config    = call_user_func_array( 'array_merge', $html_config + array( array() ) );
			$configurations = array_merge( $configurations, $html_config );

			return $configurations;
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Colors_Header_Builder();
