<?php
/**
 * Colors Header Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Colors_Header' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Colors_Header extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$title_color_heading = __( '颜色', 'adaptive-addon' );
			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
				$title_color_heading = __( '标题', 'adaptive-addon' );
			}

			$_configs = array();

			/**
			 * We adding this control only to maintain backwards. Remove this condition after 2-3 updates of theme.
			 * Moving Site Title color & Tagline color option into theme.
			 *
			 * @since 3.5.0
			 */
			if ( adaptive_addon_check_theme_3_5_0_version() ) {
				array_push(
					$_configs,
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[site-identity-title-color-group]',
						'default'    => adaptive_get_option( 'site-identity-title-color-group' ),
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => adaptive_addon_builder_helper()->is_header_footer_builder_active ? __( '标题颜色', 'adaptive-addon' ) : __( '颜色', 'adaptive-addon' ),
						'section'    => 'title_tagline',
						'responsive' => false,
						'transport'  => 'postMessage',
						'priority'   => 8,
						'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-title]',
								'operator' => '==',
								'value'    => true,
							),
						) : array(
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-title]',
								'operator' => '==',
								'value'    => true,
							),
						),
					),
					// Option: Site Tagline Color.
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[header-color-site-tagline]',
						'type'      => 'control',
						'control'   => 'ast-color',
						'transport' => 'postMessage',
						'default'   => adaptive_get_option( 'header-color-site-tagline' ),
						'title'     => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? __( '副标题', 'adaptive-addon' ) : __( '颜色', 'adaptive-addon' ),
						'section'   => 'title_tagline',
						'priority'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? 8 : 11,
						'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline]',
								'operator' => '==',
								'value'    => true,
							),
						) : array(
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline]',
								'operator' => '==',
								'value'    => true,
							),
						),
					)
				);

				if ( false === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
					array_push(
						$_configs,
						/**
						 * Option: Color heading
						 */
						array(
							'name'     => ADAPTIVE_THEME_SETTINGS . '[site-identity-colors-heading]',
							'type'     => 'control',
							'control'  => 'ast-heading',
							'section'  => 'title_tagline',
							'title'    => __( '颜色', 'adaptive-addon' ),
							'priority' => 7,
							'settings' => array(),
							'context'  => array(
								'relation' => 'AND',
								adaptive_addon_builder_helper()->design_tab_config,
								array(
									'relation' => 'OR',
									array(
										'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-title]',
										'operator' => '==',
										'value'    => true,
									),
									array(
										'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline]',
										'operator' => '==',
										'value'    => true,
									),
								),
							),
						),
						// Option: Site Title Color.
						array(
							'name'      => 'header-color-site-title',
							'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-identity-title-color-group]',
							'section'   => 'title_tagline',
							'type'      => 'sub-control',
							'control'   => 'ast-color',
							'default'   => adaptive_get_option( 'header-color-site-title' ),
							'transport' => 'postMessage',
							'title'     => __( '标准', 'adaptive-addon' ),
							'context'   => adaptive_addon_builder_helper()->design_tab,
						),
						// Option: Site Title Hover Color.
						array(
							'name'      => 'header-color-h-site-title',
							'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-identity-title-color-group]',
							'section'   => 'title_tagline',
							'type'      => 'sub-control',
							'control'   => 'ast-color',
							'transport' => 'postMessage',
							'default'   => adaptive_get_option( 'header-color-h-site-title' ),
							'title'     => __( '悬停', 'adaptive-addon' ),
							'context'   => adaptive_addon_builder_helper()->design_tab,
						)
					);
				}
			}

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				array_push(
					$_configs,
					/**
					 * Option: Search height
					 */
					array(
						'name'        => ADAPTIVE_THEME_SETTINGS . '[header-search-height]',
						'section'     => 'section-header-search',
						'priority'    => 3,
						'transport'   => 'postMessage',
						'default'     => adaptive_get_option( 'header-search-height' ),
						'title'       => __( '搜索高度', 'adaptive-addon' ),
						'suffix'      => 'px',
						'type'        => 'control',
						'control'     => 'ast-responsive-slider',
						'input_attrs' => array(
							'min'  => 40,
							'step' => 1,
							'max'  => 100,
						),
						'divider'     => array( 'ast_class' => 'ast-top-divider' ),
						'context'     => array(
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'slide-search', 'search-box' ),
							),
						),
					),
					/**
					 * Search Overlay Color
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[header-search-overlay-color]',
						'default'   => adaptive_get_option( 'header-search-overlay-color' ),
						'type'      => 'control',
						'section'   => 'section-header-search',
						'priority'  => 9,
						'transport' => 'postMessage',
						'control'   => 'ast-color',
						'title'     => __( '叠加背景颜色', 'adaptive-addon' ),
						'context'   => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'full-screen', 'header-cover' ),
							),
						),
					),
					/**
					 * Search Overlay Text Color
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[header-search-overlay-text-color]',
						'default'   => adaptive_get_option( 'header-search-overlay-text-color' ),
						'type'      => 'control',
						'section'   => 'section-header-search',
						'priority'  => 9,
						'transport' => 'postMessage',
						'control'   => 'ast-color',
						'title'     => __( '覆盖文本颜色', 'adaptive-addon' ),
						'context'   => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'full-screen', 'header-cover' ),
							),
						),
					),
					array(
						'name'       => 'header-search-icon-h-color',
						'default'    => adaptive_get_option( 'header-search-icon-h-color' ),
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-search-icon-color-parent]',
						'section'    => 'section-header-search',
						'priority'   => 1,
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'title'      => __( '图标悬停颜色', 'adaptive-addon' ),
						'context'    => adaptive_addon_builder_helper()->design_tab,
					),
					/**
					 * Option: Search Color.
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[header-search-bg-color-parent]',
						'default'   => adaptive_get_option( 'header-search-bg-color-parent' ),
						'type'      => 'control',
						'control'   => 'ast-color-group',
						'title'     => __( '盒子背景', 'adaptive-addon' ),
						'section'   => 'section-header-search',
						'transport' => 'postMessage',
						'priority'  => 9,
						'context'   => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'slide-search', 'search-box' ),
							),
						),
						'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					),
					/**
					 * Search Box Background Color
					 */
					array(
						'name'      => 'header-search-box-background-color',
						'default'   => adaptive_get_option( 'header-search-box-background-color' ),
						'type'      => 'sub-control',
						'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-search-bg-color-parent]',
						'section'   => 'section-header-search',
						'priority'  => 1,
						'transport' => 'postMessage',
						'control'   => 'ast-color',
						'title'     => __( '标准', 'adaptive-addon' ),
						'context'   => adaptive_addon_builder_helper()->design_tab,
					),
					/**
					 * Search Box Background hover Color
					 */
					array(
						'name'      => 'header-search-box-background-h-color',
						'default'   => adaptive_get_option( 'header-search-box-background-h-color' ),
						'type'      => 'sub-control',
						'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-search-bg-color-parent]',
						'section'   => 'section-heade-search',
						'priority'  => 2,
						'transport' => 'postMessage',
						'control'   => 'ast-color',
						'title'     => __( '悬停', 'adaptive-addon' ),
						'context'   => adaptive_addon_builder_helper()->design_tab,
					),
					/**
					 * Option: Search Border Size
					 */
					array(
						'name'           => ADAPTIVE_THEME_SETTINGS . '[header-search-border-size]',
						'default'        => adaptive_get_option( 'header-search-border-size' ),
						'type'           => 'control',
						'section'        => 'section-header-search',
						'control'        => 'ast-border',
						'transport'      => 'postMessage',
						'linked_choices' => true,
						'priority'       => 9,
						'title'          => __( '宽度', 'adaptive-addon' ),
						'context'        => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'slide-search', 'search-box' ),
							),
						),
						'choices'        => array(
							'top'    => __( '顶部', 'adaptive-addon' ),
							'right'  => __( '右', 'adaptive-addon' ),
							'bottom' => __( '底部', 'adaptive-addon' ),
							'left'   => __( '左', 'adaptive-addon' ),
						),
					),
					/**
					 * Group: Search Border Group
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[header-search-border-color-group]',
						'default'   => adaptive_get_option( 'header-search-border-color-group' ),
						'type'      => 'control',
						'control'   => Adaptive_Theme_Extension::$group_control,
						'title'     => __( '边框颜色', 'adaptive-addon' ),
						'section'   => 'section-header-search',
						'transport' => 'postMessage',
						'priority'  => 9,
						'context'   => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'slide-search', 'search-box' ),
							),
						),
					),
					/**
					 * Option: Search Border Color
					 */
					array(
						'name'       => 'header-search-border-color',
						'default'    => adaptive_get_option( 'header-search-border-color' ),
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-search-border-color-group]',
						'section'    => 'section-header-search',
						'control'    => 'ast-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 1,
						'context'    => adaptive_addon_builder_helper()->general_tab,
						'title'      => __( '标准', 'adaptive-addon' ),
					),
					/**
					 * Option: Search Border Hover Color
					 */
					array(
						'name'       => 'header-search-border-h-color',
						'default'    => adaptive_get_option( 'header-search-border-h-color' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-search-border-color-group]',
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'section'    => 'section-header-search',
						'control'    => 'ast-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 2,
						'context'    => adaptive_addon_builder_helper()->general_tab,
						'title'      => __( '悬停', 'adaptive-addon' ),
					),
					/**
					 * Option: Search Border Radius
					 */
					array(
						'name'        => ADAPTIVE_THEME_SETTINGS . '[header-search-border-radius]',
						'default'     => adaptive_get_option( 'header-search-border-radius' ),
						'type'        => 'control',
						'parent'      => ADAPTIVE_THEME_SETTINGS . '[header-search-border-color-group]',
						'section'     => 'section-header-search',
						'control'     => 'ast-slider',
						'transport'   => 'postMessage',
						'priority'    => 9,
						'title'       => __( '边界圆角', 'adaptive-addon' ),
						'suffix'      => 'px',
						'input_attrs' => array(
							'min'  => 0,
							'step' => 1,
							'max'  => 100,
						),
						'context'     => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'slide-search', 'search-box' ),
							),
						),
					),
					/**
					 * Option: Search text/placeholder Color
					 */
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[header-search-text-placeholder-color]',
						'default'    => adaptive_get_option( 'header-search-text-placeholder-color' ),
						'transport'  => 'postMessage',
						'type'       => 'control',
						'section'    => 'section-header-search',
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 8.5,
						'title'      => __( '文本/占位符颜色', 'adaptive-addon' ),
						'context'    => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
								'operator' => 'in',
								'value'    => array( 'slide-search', 'search-box' ),
							),
						),
					)
				);
			}

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Colors_Header();
