<?php
/**
 * Colors Primary Menu Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Colors_Primary_Menu' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Colors_Primary_Menu extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[primary-menu-link-colors]',
					'default'    => adaptive_get_option( 'primary-menu-colors' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '链接文本', 'adaptive-addon' ),
					'section'    => 'section-primary-menu',
					'transport'  => 'postMessage',
					'priority'   => 70,
					'responsive' => true,
					'divider'    => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '菜单颜色', 'adaptive-addon' ),
					),
				),

				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[primary-menu-background-colors]',
					'default'    => adaptive_get_option( 'primary-menu-colors' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '背景', 'adaptive-addon' ),
					'section'    => 'section-primary-menu',
					'transport'  => 'postMessage',
					'priority'   => 70,
					'responsive' => true,
				),

				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-link-colors]',
					'default'    => adaptive_get_option( 'primary-submenu-colors' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '链接文本', 'adaptive-addon' ),
					'section'    => 'section-primary-menu',
					'transport'  => 'postMessage',
					'priority'   => 70,
					'responsive' => true,
					'divider'    => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '子菜单颜色', 'adaptive-addon' ),
					),
				),
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-background-colors]',
					'default'    => adaptive_get_option( 'primary-submenu-colors' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '背景', 'adaptive-addon' ),
					'section'    => 'section-primary-menu',
					'transport'  => 'postMessage',
					'priority'   => 70,
					'responsive' => true,
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				// Option: Primary Menu Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-menu-link-colors]',
					'section'    => 'section-primary-menu',
					'name'       => 'primary-menu-color-responsive',
					'default'    => adaptive_get_option( 'primary-menu-color-responsive' ),
					'title'      => __( '标准', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 7,
				),

				// Option: Menu Background image, color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-background',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-menu-background-colors]',
					'section'    => 'section-primary-menu',
					'default'    => adaptive_get_option( 'primary-menu-bg-obj-responsive' ),
					'name'       => 'primary-menu-bg-obj-responsive',
					'data_attrs' => array( 'name' => 'primary-menu-bg-obj-responsive' ),
					'title'      => __( '标准', 'adaptive-addon' ),
					'priority'   => 9,
				),

				// Option: Submenu Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-link-colors]',
					'section'    => 'section-primary-menu',
					'transport'  => 'postMessage',
					'name'       => 'primary-submenu-color-responsive',
					'default'    => adaptive_get_option( 'primary-submenu-color-responsive' ),
					'title'      => __( '标准', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 13,
				),

				// Option: Submenu Background Color.
				array(
					'type'       => 'sub-control',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-background-colors]',
					'section'    => 'section-primary-menu',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'name'       => 'primary-submenu-bg-color-responsive',
					'default'    => adaptive_get_option( 'primary-submenu-bg-color-responsive' ),
					'title'      => __( '标准', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 15,
				),

				// Option: Menu Hover Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'name'       => 'primary-menu-h-color-responsive',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-menu-link-colors]',
					'section'    => 'section-primary-menu',
					'default'    => adaptive_get_option( 'primary-menu-h-color-responsive' ),
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 19,
				),

				// Option: Menu Hover Background Color.
				array(
					'name'       => 'primary-menu-h-bg-color-responsive',
					'type'       => 'sub-control',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-menu-background-colors]',
					'section'    => 'section-primary-menu',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'default'    => adaptive_get_option( 'primary-menu-h-bg-color-responsive' ),
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 21,
				),

				// Option: Submenu Hover Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-link-colors]',
					'section'    => 'section-primary-menu',
					'transport'  => 'postMessage',
					'name'       => 'primary-submenu-h-color-responsive',
					'default'    => adaptive_get_option( 'primary-submenu-h-color-responsive' ),
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 25,
				),

				// Option: Submenu Hover Background Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-background-colors]',
					'section'    => 'section-primary-menu',
					'name'       => 'primary-submenu-h-bg-color-responsive',
					'default'    => adaptive_get_option( 'primary-submenu-h-bg-color-responsive' ),
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 27,
				),

				// Option: Active Menu Color.
				array(
					'type'       => 'sub-control',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-menu-link-colors]',
					'section'    => 'section-primary-menu',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'name'       => 'primary-menu-a-color-responsive',
					'default'    => adaptive_get_option( 'primary-menu-a-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 31,
				),

				// Option: Active Menu Background Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'name'       => 'primary-menu-a-bg-color-responsive',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-menu-background-colors]',
					'section'    => 'section-primary-menu',
					'default'    => adaptive_get_option( 'primary-menu-a-bg-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 33,
				),

				// Option: Active Submenu Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-link-colors]',
					'section'    => 'section-primary-menu',
					'name'       => 'primary-submenu-a-color-responsive',
					'default'    => adaptive_get_option( 'primary-submenu-a-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 37,
				),

				// Option: Active Submenu Background Color.
				array(
					'type'       => 'sub-control',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[primary-submenu-background-colors]',
					'section'    => 'section-primary-menu',
					'name'       => 'primary-submenu-a-bg-color-responsive',
					'default'    => adaptive_get_option( 'primary-submenu-a-bg-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'priority'   => 39,
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Colors_Primary_Menu();
