<?php
/**
 * Colors Sidebar Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Colors_Sidebar' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Colors_Sidebar extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				// Option: Sidebar Background.
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sidebar-bg-obj]',
					'type'      => 'control',
					'control'   => 'ast-background',
					'priority'  => 23,
					'section'   => 'section-sidebars',
					'transport' => 'postMessage',
					'default'   => adaptive_get_option( 'sidebar-bg-obj' ),
					'title'     => __( '背景', 'adaptive-addon' ),
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
					adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: SideBar Content Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-link-group]',
					'default'   => adaptive_get_option( 'sidebar-content-group' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$group_control,
					'title'     => __( '内容链接', 'adaptive-addon' ),
					'section'   => 'section-sidebars',
					'transport' => 'postMessage',
					'priority'  => 24,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Widget Title Color.
				array(
					'type'              => 'control',
					'priority'          => 23,
					'section'           => 'section-sidebars',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'sidebar-widget-title-color' ),
					'transport'         => 'postMessage',
					'name'              => ADAPTIVE_THEME_SETTINGS . '[sidebar-widget-title-color]',
					'title'             => __( '内容标题', 'adaptive-addon' ),
					'context'           => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Text Color.
				array(
					'type'              => 'control',
					'priority'          => 23,
					'section'           => 'section-sidebars',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'sidebar-text-color' ),
					'transport'         => 'postMessage',
					'name'              => ADAPTIVE_THEME_SETTINGS . '[sidebar-text-color]',
					'title'             => __( '内容文本', 'adaptive-addon' ),
					'context'           => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Link Color.
				array(
					'type'     => 'sub-control',
					'priority' => 10,
					'parent'   => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-link-group]',
					'section'  => 'section-sidebars',
					'control'  => 'ast-color',
					'default'  => adaptive_get_option( 'sidebar-link-color' ),
					'name'     => 'sidebar-link-color',
					'title'    => __( '标准', 'adaptive-addon' ),
					'tab'      => __( '标准', 'adaptive-addon' ),
				),

				// Option: Link Hover Color.
				array(
					'type'              => 'sub-control',
					'priority'          => 11,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-link-group]',
					'section'           => 'section-sidebars',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'sidebar-link-h-color' ),
					'transport'         => 'postMessage',
					'name'              => 'sidebar-link-h-color',
					'title'             => __( '悬停', 'adaptive-addon' ),
					'tab'               => __( '悬停', 'adaptive-addon' ),
				),

			);

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				$_configs[] = array(
					'name'        => 'section-sidebars-ast-context-tabs',
					'section'     => 'section-sidebars',
					'type'        => 'control',
					'control'     => 'ast-builder-header-control',
					'priority'    => 0,
					'description' => '',
				);
			} else {

				$_configs[] = array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[sidebar-color-background-heading-divider]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'section'  => 'section-sidebars',
					'title'    => __( '颜色和背景', 'adaptive-addon' ),
					'priority' => 23,
					'settings' => array(),
					'context'  => adaptive_addon_builder_helper()->general_tab,
				);
			}

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Colors_Sidebar();
