<?php
/**
 * Register customizer panels & sections.
 *
 * @package     Adaptive
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       Adaptive 1.6.10
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Edd_Panels_And_Sections' ) ) {

	/**
	 * Register Easy Digital Downloads Panels and sections Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Edd_Panels_And_Sections extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Easy Digital Downloads Panels and sections Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.10
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Section General
				 */
				array(
					'name'     => 'section-edd-general',
					'title'    => __( '常规', 'adaptive-addon' ),
					'type'     => 'section',
					'section'  => 'section-edd-group',
					'priority' => 5,
				),

				/**
				 * Section Checkout Page
				 */
				array(
					'name'     => 'section-edd-checkout-page',
					'priority' => 25,
					'title'    => __( '结算页面', 'adaptive-addon' ),
					'type'     => 'section',
					'section'  => 'section-edd-group',
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Edd_Panels_And_Sections();





