<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.6.10
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Edd_Checkout_Configs' ) ) {

	/**
	 * Register Easy Digital Downloads Checkout Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Edd_Checkout_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Easy Digital Downloads Checkout Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.10
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Display Coupon on Checkout Page
				 */
				array(
					'name'    => ADAPTIVE_THEME_SETTINGS . '[edd-checkout-coupon-display]',
					'default' => adaptive_get_option( 'edd-checkout-coupon-display' ),
					'type'    => 'control',
					'section' => 'section-edd-checkout-page',
					'title'   => __( '显示应用优惠券字段', 'adaptive-addon' ),
					'control' => Adaptive_Theme_Extension::$switch_control,
					'divider' => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/*
				 * Option: Distraction free Checkout.
				 */
				array(
					'name'    => ADAPTIVE_THEME_SETTINGS . '[edd-distraction-free-checkout]',
					'default' => adaptive_get_option( 'edd-distraction-free-checkout' ),
					'type'    => 'control',
					'section' => 'section-edd-checkout-page',
					'title'   => __( '免打扰结帐', 'adaptive-addon' ),
					'control' => Adaptive_Theme_Extension::$switch_control,
					'divider' => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Checkout Content Width
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[edd-checkout-content-width]',
					'default'   => adaptive_get_option( 'edd-checkout-content-width' ),
					'type'      => 'control',
					'control'   => 'ast-select',
					'section'   => 'section-edd-checkout-page',
					'transport' => 'postMessage',
					'title'     => __( '付款形式宽度', 'adaptive-addon' ),
					'choices'   => array(
						'default' => __( '默认', 'adaptive-addon' ),
						'custom'  => __( '自定义', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Enter Width
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[edd-checkout-content-max-width]',
					'default'     => adaptive_get_option( 'edd-checkout-content-max-width' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-checkout-content-width]',
							'operator' => '==',
							'value'    => 'custom',
						),
					),
					'section'     => 'section-edd-checkout-page',
					'title'       => __( '自定义宽度', 'adaptive-addon' ),
					'suffix'      => 'px',
					'input_attrs' => array(
						'min'  => 768,
						'step' => 1,
						'max'  => 1920,
					),
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Edd_Checkout_Configs();





