<?php
/**
 * Easy Digital Downloads General Options for our theme.
 *
 * @package     Adaptive
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       Adaptive 1.6.10
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Edd_General_Configs' ) ) {

	/**
	 * Register Easy Digital Downloads General Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Edd_General_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Easy Digital Downloads General Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.10
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_section = ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? 'section-header-edd-cart' : 'section-edd-general';

			$context = ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab;

			$cart_outline_width_context = ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? adaptive_addon_builder_helper()->design_tab_config : adaptive_addon_builder_helper()->general_tab_config;

			$_configs = array(

				/**
				 * Option: Header Cart Icon
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon]',
					'default'  => adaptive_get_option( 'edd-header-cart-icon' ),
					'type'     => 'control',
					'section'  => $_section,
					'title'    => __( '图标', 'adaptive-addon' ),
					'control'  => 'select',
					'priority' => 35,
					'choices'  => array(
						'default' => __( '默认', 'adaptive-addon' ),
						'cart'    => __( '购物车', 'adaptive-addon' ),
						'bag'     => __( '包包', 'adaptive-addon' ),
						'basket'  => __( '篮子', 'adaptive-addon' ),
					),
					'context'  => adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: Cart Count color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-product-count-color]',
					'default'           => adaptive_get_option( 'edd-header-cart-product-count-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'title'             => __( '计数颜色', 'adaptive-addon' ),
					'context'           => array(
						Adaptive_Builder_Helper::$design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon]',
							'operator' => '!=',
							'value'    => 'default',
						),
					),
					'section'           => $_section,
					'priority'          => 45,
				),

				/**
				 * Option: Border Width
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-border-width]',
					'default'     => adaptive_get_option( 'edd-header-cart-border-width' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'section'     => $_section,
					'context'     => array(
						$cart_outline_width_context,
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-style]',
							'operator' => '==',
							'value'    => 'outline',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon]',
							'operator' => '!=',
							'value'    => 'default',
						),
					),
					'title'       => __( '边框宽度', 'adaptive-addon' ),
					'suffix'      => 'px',
					'control'     => 'ast-slider',
					'priority'    => 46,
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 20,
					),
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			$_configs = array(
				/**
				 * Option: Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-divider]',
					'section'  => $_section,
					'title'    => __( '页眉购物车图标', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-heading',
					'priority' => 30,
					'settings' => array(),
					'context'  => adaptive_addon_builder_helper()->general_tab,
				),
				/**
				 * Option: Icon Style
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-style]',
					'default'   => adaptive_get_option( 'edd-header-cart-icon-style' ),
					'type'      => 'control',
					'transport' => 'postMessage',
					'section'   => $_section,
					'title'     => __( '样式', 'adaptive-addon' ),
					'control'   => 'select',
					'priority'  => 40,
					'choices'   => array(
						'none'    => __( '无', 'adaptive-addon' ),
						'outline' => __( '轮廓', 'adaptive-addon' ),
						'fill'    => __( '填充', 'adaptive-addon' ),
					),
					'context'   => $context,
				),
				/**
				 * Option: Background color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-color]',
					'default'           => adaptive_get_option( 'edd-header-cart-icon-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '颜色', 'adaptive-addon' ),
					'transport'         => 'postMessage',
					'section'           => $_section,
					'priority'          => 45,
					'context'           => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-style]',
							'operator' => '!=',
							'value'    => 'none',
						),
						adaptive_addon_builder_helper()->design_tab,
					),
				),

				/**
				 * Option: Background color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-color]',
					'default'           => adaptive_get_option( 'edd-header-cart-icon-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '颜色', 'adaptive-addon' ),
					'transport'         => 'postMessage',
					'section'           => $_section,
					'priority'          => 45,
					'context'           => array(
						$context,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-style]',
							'operator' => '!=',
							'value'    => 'none',
						),
					),
				),

				/**
				 * Option: Border Radius
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-radius]',
					'default'     => adaptive_get_option( 'edd-header-cart-icon-radius' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'section'     => $_section,
					'title'       => __( '边界圆角', 'adaptive-addon' ),
					'control'     => 'ast-slider',
					'priority'    => 47,
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 200,
					),
					'suffix'      => 'px',
					'context'     => array(
						$context,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-icon-style]',
							'operator' => '!=',
							'value'    => 'none',
						),
					),
				),

				/**
				 * Option: Header cart total
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-total-display]',
					'default'  => adaptive_get_option( 'edd-header-cart-total-display' ),
					'type'     => 'control',
					'section'  => $_section,
					'title'    => __( '显示购物车总数', 'adaptive-addon' ),
					'priority' => 50,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'context'  => adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: Cart Title
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[edd-header-cart-title-display]',
					'default'  => adaptive_get_option( 'edd-header-cart-title-display' ),
					'type'     => 'control',
					'section'  => $_section,
					'title'    => __( '显示购物车标题', 'adaptive-addon' ),
					'priority' => 55,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'context'  => adaptive_addon_builder_helper()->general_tab,
				),
			);

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
				$_configs = array(
					/**
					 * EDD Cart section
					 */
					array(
						'name'     => $_section,
						'type'     => 'section',
						'priority' => 5,
						'title'    => __( 'EDD 购物车', 'adaptive-addon' ),
						'panel'    => 'panel-header-builder-group',
					),

				);
			}

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Edd_General_Configs();
