<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.6.10
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Edd_Shop_Configs' ) ) {

	/**
	 * Register Easy Digital Downloads Shop Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Edd_Shop_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Easy Digital Downloads Shop Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.10
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Choose Product Style
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-archive-style]',
					'default'           => adaptive_get_option( 'edd-archive-style' ),
					'type'              => 'control',
					'section'           => 'section-edd-archive',
					'title'             => __( '样式', 'adaptive-addon' ),
					'control'           => 'ast-radio-image',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_choices' ),
					'priority'          => 5,
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'choices'           => array(
						'edd-archive-page-grid-style' => array(
							'label' => __( '网格视图', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'edd-archive-page-grid-style', false ) : '',
						),
						'edd-archive-page-list-style' => array(
							'label' => __( '列表视图', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'edd-archive-page-list-style', false ) : '',
						),
					),
				),

				/**
				 * Option: EDD Archive Post override-heading to display notice
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-structure]',
					'type'              => 'control',
					'control'           => 'ast-sortable',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_multi_choices' ),
					'section'           => 'section-edd-archive',
					'default'           => adaptive_get_option( 'edd-archive-product-structure' ),
					'priority'          => 30,
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'title'             => __( '产品结构', 'adaptive-addon' ),
					'description'       => __( '如果将产品样式选择为列表样式，则“图像”选项无法排序', 'adaptive-addon' ),
					'choices'           => array(
						'image'      => __( '图像', 'adaptive-addon' ),
						'title'      => __( '标题', 'adaptive-addon' ),
						'price'      => __( '价格', 'adaptive-addon' ),
						'short_desc' => __( '简要描述', 'adaptive-addon' ),
						'add_cart'   => __( '添加到购物车', 'adaptive-addon' ),
						'category'   => __( '分类', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[edd-archive-box-styling-divider]',
					'section'  => 'section-edd-archive',
					'title'    => __( '产品造型', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-heading',
					'priority' => 75,
					'settings' => array(),
				),

				/**
				 * Option: Content Alignment
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-align]',
					'default'    => adaptive_get_option( 'edd-archive-product-align' ),
					'type'       => 'control',
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
					'transport'  => 'postMessage',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => 'section-edd-archive',
					'priority'   => 80,
					'title'      => __( '内容对齐', 'adaptive-addon' ),
					'choices'    => array(
						'align-left'   => 'align-left',
						'align-center' => 'align-center',
						'align-right'  => 'align-right',
					),
					'responsive' => false,
				),

				/**
				 * Option: Box shadow
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-shadow]',
					'default'     => adaptive_get_option( 'edd-archive-product-shadow' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'title'       => __( '阴影', 'adaptive-addon' ),
					'section'     => 'section-edd-archive',
					'suffix'      => 'px',
					'priority'    => 85,
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 5,
					),
				),

				/**
				 * Option: Box hover shadow
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-shadow-hover]',
					'default'     => adaptive_get_option( 'edd-archive-product-shadow-hover' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'title'       => __( '阴影悬停', 'adaptive-addon' ),
					'section'     => 'section-edd-archive',
					'suffix'      => 'px',
					'priority'    => 90,
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 5,
					),
				),

				/**
				 * Option: Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[edd-archive-button-divider]',
					'section'  => 'section-edd-archive',
					'title'    => __( '按钮', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-heading',
					'priority' => 110,
					'settings' => array(),
				),

				/**
				 * Option: Vertical Padding
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-archive-button-v-padding]',
					'default'           => adaptive_get_option( 'edd-archive-button-v-padding' ),
					'type'              => 'control',
					'transport'         => 'postMessage',
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'section'           => 'section-edd-archive',
					'title'             => __( '垂直填充', 'adaptive-addon' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'control'           => 'ast-slider',
					'suffix'            => 'px',
					'priority'          => 110,
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 1,
						'max'  => 200,
					),
				),

				/**
				 * Option: Horizontal Padding
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-archive-button-h-padding]',
					'default'           => adaptive_get_option( 'edd-archive-button-h-padding' ),
					'type'              => 'control',
					'transport'         => 'postMessage',
					'section'           => 'section-edd-archive',
					'priority'          => 110,
					'title'             => __( '水平填充', 'adaptive-addon' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'control'           => 'ast-slider',
					'suffix'            => 'px',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 1,
						'max'  => 200,
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Display Page Title
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[edd-archive-page-title-display]',
					'default'  => adaptive_get_option( 'edd-archive-page-title-display' ),
					'type'     => 'control',
					'section'  => 'section-edd-archive',
					'title'    => __( '显示页面标题', 'adaptive-addon' ),
					'priority' => 29,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'control'  => Adaptive_Theme_Extension::$switch_control,
				),

				/**
				 * Option: EDD Product Title Typography
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-title-typo]',
					'default'   => adaptive_get_option( 'edd-archive-product-title-typo' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '商品标题字体', 'adaptive-addon' ),
					'section'   => 'section-edd-archive',
					'transport' => 'postMessage',
					'priority'  => 233,
				),

				/**
				 * Option: EDD Product Price Typography
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-price-typo]',
					'default'   => adaptive_get_option( 'edd-archive-product-price-typo' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '商品价格字体', 'adaptive-addon' ),
					'section'   => 'section-edd-archive',
					'transport' => 'postMessage',
					'priority'  => 233,
				),

				/**
				 * Option: EDD Product Content Typography
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-content-typo]',
					'default'   => adaptive_get_option( 'edd-archive-product-content-typo' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '产品内容字体', 'adaptive-addon' ),
					'section'   => 'section-edd-archive',
					'transport' => 'postMessage',
					'context'   => array(
						'relation' => 'AND',
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-structure]',
								'operator' => 'contains',
								'value'    => 'category',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[edd-archive-product-structure]',
								'operator' => 'contains',
								'value'    => 'structure',
							),
						),

					),
					'priority'  => 233,
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Edd_Shop_Configs();
