<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.6.10
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Edd_Shop_Single_Configs' ) ) {

	/**
	 * Register Easy Digital Downloads shop single Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Edd_Shop_Single_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Easy Digital Downloads shop single Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.10
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Enable Ajax add to cart.
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[disable-edd-single-product-add-to-cart]',
					'default'  => adaptive_get_option( 'disable-edd-single-product-add-to-cart' ),
					'type'     => 'control',
					'section'  => 'section-edd-single',
					'title'    => __( '禁用“加入购物车”按钮', 'adaptive-addon' ),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority' => 18,
					'control'  => Adaptive_Theme_Extension::$switch_control,
				),

				/**
				 * Option: EDD Product Title Typography
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[edd-single-product-title-typo]',
					'default'   => adaptive_get_option( 'edd-single-product-title-typo' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '商品标题字体', 'adaptive-addon' ),
					'section'   => 'section-edd-single',
					'transport' => 'postMessage',
					'priority'  => 233,
					'divider'   => array( 'ast_class' => 'ast-top-divider' ),
				),

				/**
				 * Option: EDD Product Content Typography
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[edd-single-product-content-typo]',
					'default'   => adaptive_get_option( 'edd-single-product-content-typo' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '产品内容字体', 'adaptive-addon' ),
					'section'   => 'section-edd-single',
					'transport' => 'postMessage',
					'priority'  => 233,
				),

			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Edd_Shop_Single_Configs();





