<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.6.10
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Edd_Single_Colors_Configs' ) ) {

	/**
	 * Register Easy Digital Downloads Shop Single Color Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Edd_Single_Colors_Configs extends Adaptive_Customizer_Config_Base { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Easy Digital Downloads Shop Single Color Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.10
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Single Product Title Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-single-product-title-color]',
					'section'           => 'section-edd-single',
					'default'           => adaptive_get_option( 'edd-single-product-title-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'title'             => __( '商品标题', 'adaptive-addon' ),
					'priority'          => 231,
				),

				/**
				 * Single Product Content Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-single-product-content-color]',
					'section'           => 'section-edd-single',
					'default'           => adaptive_get_option( 'edd-single-product-content-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'title'             => __( '产品内容', 'adaptive-addon' ),
					'priority'          => 231,
				),

				/**
				 * Single Product Breadcrumb Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[edd-single-product-navigation-color]',
					'section'           => 'section-edd-single',
					'default'           => adaptive_get_option( 'edd-single-product-navigation-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'context'           => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[disable-edd-single-product-nav]',
							'operator' => '!=',
							'value'    => '1',
						),
					),
					'transport'         => 'postMessage',
					'title'             => __( '产品导航', 'adaptive-addon' ),
					'priority'          => 231,
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Edd_Single_Colors_Configs();





