<?php
/**
 * Above Header - Layout Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}


if ( ! class_exists( 'Adaptive_Above_Header_Configs' ) ) {

	/**
	 * Register Header Layout Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Above_Header_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Header Layout Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$sections = apply_filters(
				'adaptive_header_section_elements',
				array(
					''          => __( '无', 'adaptive-addon' ),
					'menu'      => __( '菜单', 'adaptive-addon' ),
					'search'    => __( '搜索', 'adaptive-addon' ),
					'text-html' => __( '文本/HTML', 'adaptive-addon' ),
					'widget'    => __( '小工具', 'adaptive-addon' ),
				),
				'above-header'
			);

			$_config = array(

				/**
				 * Option: Above Header Layout
				 */

				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
					'section'           => 'section-above-header',
					'type'              => 'control',
					'control'           => 'ast-radio-image',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_choices' ),
					'default'           => adaptive_get_option( 'above-header-layout' ),
					'priority'          => 1,
					'title'             => __( '样式', 'adaptive-addon' ),
					'choices'           => array(
						'disabled'              => array(
							'label' => __( '停用', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'disabled', false ) : '',
						),
						'above-header-layout-1' => array(
							'label' => __( '布局1', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'above-header-layout-1', false ) : '',
						),
						'above-header-layout-2' => array(
							'label' => __( '布局2', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'above-header-layout-2', false ) : '',
						),
					),
				),

				/**
				 *  Section: Section
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
					'default'  => adaptive_get_option( 'above-header-section-1' ),
					'type'     => 'control',
					'context'  => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
					'divider'  => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '区域1', 'adaptive-addon' ),
					),
					'control'  => 'ast-select',
					'section'  => 'section-above-header',
					'priority' => 35,
					'choices'  => $sections,
				),

				/**
				 * Option: Text/HTML
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1-html]',
					'section'   => 'section-above-header',
					'type'      => 'control',
					'control'   => 'textarea',
					'transport' => 'postMessage',
					'default'   => adaptive_get_option( 'above-header-section-1-html' ),
					'priority'  => 50,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => array(

						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'text-html',
						),
					),
					'partial'   => array(
						'selector'            => '.ast-above-header-section-1 .user-select  .ast-custom-html',
						'container_inclusive' => false,
						'render_callback'     => 'Adaptive_Customizer_Header_Sections_Partials::_render_above_header_section_1_html',
					),
					'title'     => __( '文本/HTML', 'adaptive-addon' ),
				),

				/**
				 * Option: Section 2
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
					'type'     => 'control',
					'control'  => 'ast-select',
					'section'  => 'section-above-header',
					'priority' => 60,
					'default'  => adaptive_get_option( 'above-header-section-2' ),
					'choices'  => $sections,
					'divider'  => array(
						'ast_class' => 'ast-top-divider ast-bottom-divider',
						'ast_title' => __( '区域2', 'adaptive-addon' ),
					),
					'context'  => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '==',
							'value'    => 'above-header-layout-1',
						),
					),
				),

				/**
				 * Option: Text/HTML
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2-html]',
					'type'      => 'control',
					'control'   => 'textarea',
					'transport' => 'postMessage',
					'section'   => 'section-above-header',
					'default'   => adaptive_get_option( 'above-header-section-2-html' ),
					'priority'  => 75,
					'context'   => array(

						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '==',
							'value'    => 'above-header-layout-1',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'text-html',
						),
					),
					'partial'   => array(
						'selector'            => '.ast-above-header-section-2 .user-select .ast-custom-html',
						'container_inclusive' => false,
						'render_callback'     => 'Adaptive_Customizer_Header_Sections_Partials::_render_above_header_section_2_html',
					),
					'title'     => __( '文本/HTML', 'adaptive-addon' ),
				),

				/**
				 * Option: Above Header Height
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[above-header-height]',
					'section'     => 'section-above-header',
					'priority'    => 84,
					'transport'   => 'postMessage',
					'title'       => __( '高度', 'adaptive-addon' ),
					'default'     => adaptive_get_option( 'above-header-height' ),
					'context'     => array(

						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
					'type'        => 'control',
					'control'     => 'ast-slider',
					'suffix'      => 'px',
					'input_attrs' => array(
						'min'  => 30,
						'step' => 1,
						'max'  => 600,
					),
				),

				/**
				 * Option: Above Header Bottom Border
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[above-header-divider]',
					'section'     => 'section-above-header',
					'priority'    => 85,
					'transport'   => 'postMessage',
					'context'     => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
					'default'     => adaptive_get_option( 'above-header-divider' ),
					'title'       => __( '底部边框宽度', 'adaptive-addon' ),
					'type'        => 'control',
					'suffix'      => 'px',
					'control'     => 'ast-slider',
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 600,
					),
				),

				/**
				 * Option: Above Header Bottom Border Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[above-header-divider-color]',
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'above-header-divider-color' ),
					'context'           => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
					'section'           => 'section-above-header',
					'priority'          => 90,
					'title'             => __( '底部边框颜色', 'adaptive-addon' ),
				),

				/**
				 * Option: Above Header Menu Typography Styling
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-typography-menu-styling]',
					'default'   => adaptive_get_option( 'above-header-typography-menu-styling' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '菜单字体', 'adaptive-addon' ),
					'section'   => 'section-above-header',
					'transport' => 'postMessage',
					'priority'  => 132,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
					'context'   => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),

				/**
				 * Option: Above Header Submenu Typography Styling
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-typography-submenu-styling]',
					'default'   => adaptive_get_option( 'above-header-typography-submenu-styling' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '子菜单的字体', 'adaptive-addon' ),
					'section'   => 'section-above-header',
					'transport' => 'postMessage',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority'  => 132,
					'context'   => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),

				/**
				* Option: Above Header typography Group
				*/
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-content-typography-styling]',
					'default'   => adaptive_get_option( 'above-header-content-typography-styling' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'title'     => __( '内容字体', 'adaptive-addon' ),
					'section'   => 'section-above-header',
					'transport' => 'postMessage',
					'priority'  => 132,
					'context'   => array(
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => 'in',
								'value'    => array( 'search', 'text-html', 'widget' ),
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => 'in',
								'value'    => array( 'search', 'text-html', 'widget' ),
							),
						),
					),
				),

				/**
				 * Option: Above Header Menus Styling
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-menu-colors]',
					'default'   => adaptive_get_option( 'above-header-menu-colors' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '菜单颜色', 'adaptive-addon' ),
					'section'   => 'section-above-header',
					'transport' => 'postMessage',
					'priority'  => 131,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),

				/**
				 * Option: Above Header Menus Styling
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-colors]',
					'default'   => adaptive_get_option( 'above-header-submenu-colors' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '菜单颜色', 'adaptive-addon' ),
					'section'   => 'section-above-header',
					'transport' => 'postMessage',
					'priority'  => 131,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => array(
						'relation' => 'OR',

						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),

				/**
				 * Option: Above Header Content Section Styling
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[above-header-content-section-link-styling]',
					'default'    => adaptive_get_option( 'above-header-content-section-styling' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '链接', 'adaptive-addon' ),
					'section'    => 'section-above-header',
					'transport'  => 'postMessage',
					'priority'   => 131,
					'responsive' => true,
					'context'    => array(
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => 'in',
								'value'    => array( 'search', 'text-html', 'widget' ),
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => 'in',
								'value'    => array( 'search', 'text-html', 'widget' ),
							),
						),
					),
				),

				/**
				 * Option: Above Header Submenu Border Divier
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-border-divider]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'title'    => __( '子菜单', 'adaptive-addon' ),
					'context'  => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'section'  => 'section-above-header',
					'priority' => 95,
					'settings' => array(),
				),

				/**
				 * Option: Submenu Container Animation
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-container-animation]',
					'default'  => adaptive_get_option( 'above-header-submenu-container-animation' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'section'  => 'section-above-header',
					'priority' => 95,
					'title'    => __( '子菜单容器动画', 'adaptive-addon' ),
					'context'  => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'choices'  => array(
						''           => __( '默认', 'adaptive-addon' ),
						'slide-down' => __( '向下滑', 'adaptive-addon' ),
						'slide-up'   => __( '向上滑', 'adaptive-addon' ),
						'fade'       => __( '渐褪', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Submenu Border
				 */
				array(
					'name'           => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-border]',
					'type'           => 'control',
					'control'        => 'ast-border',
					'transport'      => 'postMessage',
					'context'        => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'section'        => 'section-above-header',
					'default'        => adaptive_get_option( 'above-header-submenu-border' ),
					'title'          => __( '容器边框', 'adaptive-addon' ),
					'linked_choices' => true,
					'priority'       => 95,
					'choices'        => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Submenu Border Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-border-color]',
					'type'              => 'control',
					'context'           => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'above-header-submenu-border-color' ),
					'priority'          => 95,
					'transport'         => 'postMessage',
					'section'           => 'section-above-header',
					'title'             => __( '边框颜色', 'adaptive-addon' ),
				),

				/**
				 * Option: Submenu Divider
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-item-border]',
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$switch_control,
					'transport' => 'postMessage',
					'context'   => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'section'   => 'section-above-header',
					'default'   => adaptive_get_option( 'above-header-submenu-item-border' ),
					'title'     => __( '子菜单分隔符', 'adaptive-addon' ),
					'priority'  => 95,
				),

				/**
				 * Option: Submenu Border Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-item-b-color]',
					'type'              => 'control',
					'context'           => array(

						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-submenu-item-border]',
							'operator' => '==',
							'value'    => true,
						),
					),

					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'above-header-submenu-item-b-color' ),
					'priority'          => 95,
					'transport'         => 'postMessage',
					'section'           => 'section-above-header',
					'title'             => __( '分隔线颜色', 'adaptive-addon' ),
				),

				/**
				 * Option: Mobile Menu Label Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-mobile-menu-divider]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'context'  => array(
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '!=',
								'value'    => '',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '!=',
								'value'    => '',
							),
						),

					),
					'section'  => 'section-above-header',
					'title'    => __( '移动端页眉', 'adaptive-addon' ),
					'priority' => 100,
					'settings' => array(),
				),

				/**
				 * Option: Display Above Header on Mobile
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-on-mobile]',
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'  => array(
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '!=',
								'value'    => '',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '!=',
								'value'    => '',
							),
						),

					),
					'default'  => adaptive_get_option( 'above-header-on-mobile' ),
					'section'  => 'section-above-header',
					'title'    => __( '在移动设备上显示', 'adaptive-addon' ),
					'priority' => 101,
				),

				/**
				 * Option: Merged with primary header menu
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[above-header-merge-menu]',
					'default'     => adaptive_get_option( 'above-header-merge-menu' ),
					'type'        => 'control',
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'context'     => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
					'section'     => 'section-above-header',
					'title'       => __( '移动设备上的合并菜单', 'adaptive-addon' ),
					'description' => __( '通过启用此选项，您可以在移动设备中与主菜单合并菜单。', 'adaptive-addon' ),
					'priority'    => 101,
				),

				/**
				 * Option: Swap section on mobile devices
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[above-header-swap-mobile]',
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'context'  => array(

						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '==',
							'value'    => 'above-header-layout-1',
						),
					),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'section'  => 'section-above-header',
					'default'  => adaptive_get_option( 'above-header-swap-mobile' ),
					'title'    => __( '在移动设备上交换部分', 'adaptive-addon' ),
					'priority' => 101,
				),

				/**
				 * Option: Mobile Menu Alignment
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[above-header-menu-align]',
					'default'           => adaptive_get_option( 'above-header-menu-align' ),
					'section'           => 'section-above-header',
					'priority'          => 101,
					'title'             => __( '样式', 'adaptive-addon' ),
					'type'              => 'control',
					'control'           => 'ast-radio-image',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_choices' ),
					'context'           => array(
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '!=',
								'value'    => '',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '!=',
								'value'    => '',
							),
						),

					),
					'choices'           => array(
						'inline' => array(
							'label' => __( '行内', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'menu-inline', false ) : '',
						),
						'stack'  => array(
							'label' => __( '堆叠', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'menu-stack', false ) : '',
						),
					),
				),

				/**
				 * Option: Mobile Menu Label
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[above-header-menu-label]',
					'type'      => 'control',
					'control'   => 'text',
					'context'   => array(
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-on-mobile]',
								'operator' => '==',
								'value'    => true,
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-merge-menu]',
								'operator' => '!=',
								'value'    => true,
							),
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),

					),
					'section'   => 'section-above-header',
					'default'   => adaptive_get_option( 'above-header-menu-label' ),
					'transport' => 'postMessage',
					'priority'  => 101,
					'title'     => __( '菜单标签', 'adaptive-addon' ),
				),
			);

			return array_merge( $configurations, $_config );
		}

	}
}

new Adaptive_Above_Header_Configs();
