<?php
/**
 * Below Header - Colors Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Below_Header_Colors_Bg_Configs' ) ) {

	/**
	 * Register Header Layout Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Below_Header_Colors_Bg_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Header Layout Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Menu Color
				 */
				array(
					'name'       => 'below-header-menu-text-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 6,
					'tab'        => __( '标准', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-link-color-group]',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'default'    => adaptive_get_option( 'below-header-menu-text-color-responsive' ),
					'title'      => __( '标准', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				/**
				 * Option: Menu Background Color
				 */
				array(
					'name'      => 'below-header-menu-bg-obj-responsive',
					'type'      => 'sub-control',
					'section'   => 'section-below-header',
					'priority'  => 7,
					'tab'       => __( '标准', 'adaptive-addon' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[below-header-bg-color-group]',
					'control'   => 'ast-responsive-background',
					'transport' => 'postMessage',
					'default'   => adaptive_get_option( 'below-header-menu-bg-obj-responsive' ),
					'title'     => __( '标准', 'adaptive-addon' ),
				),

				/**
				 * Option: Menu Hover Color
				 */

				array(
					'name'       => 'below-header-menu-text-hover-color-responsive',
					'transport'  => 'postMessage',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 8,
					'tab'        => __( '悬停', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-link-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-menu-text-hover-color-responsive' ),
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				// Check Adaptive_Control_Color is exist in the theme.
				/**
				 * Option: Menu Hover Background Color
				 */
				array(
					'name'       => 'below-header-menu-bg-hover-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 9,
					'tab'        => __( '悬停', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-bg-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-menu-bg-hover-color-responsive' ),
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				/**
				 * Option: Active Menu Color
				 */
				array(
					'name'       => 'below-header-current-menu-text-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 10,
					'tab'        => __( '已启用', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-link-color-group]',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'default'    => adaptive_get_option( 'below-header-current-menu-text-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				// Check Adaptive_Control_Color is exist in the theme.
				/**
				 * Option: Active Menu Background Color
				 */
				array(
					'name'       => 'below-header-current-menu-bg-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 11,
					'tab'        => __( '已启用', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-bg-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-current-menu-bg-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				/**
				 * Option: Submenu Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[below-header-color-bg-dropdown-menu-divider]',
					'type'     => 'control',
					'control'  => 'ast-divider',
					'title'    => __( '页眉子菜单以下', 'adaptive-addon' ),
					'settings' => array(),
				),

				// Check Adaptive_Control_Color is exist in the theme.

				/**
				 * Option: Submenu Color
				 */
				array(
					'name'       => 'below-header-submenu-text-color-responsive',
					'transport'  => 'postMessage',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 9,
					'tab'        => __( '标准', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-submenus-link-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-submenu-text-color-responsive' ),
					'title'      => __( '标准', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				/**
				 * Option: Submenu Background Color
				 */
				array(
					'name'       => 'below-header-submenu-bg-color-responsive',
					'transport'  => 'postMessage',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 9,
					'tab'        => __( '标准', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-submenus-bg-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-submenu-bg-color-responsive' ),
					'title'      => __( '标准', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				/**
				 * Option: Submenu Hover Color
				 */
				array(
					'name'       => 'below-header-submenu-hover-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 10,
					'tab'        => __( '悬停', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-submenus-link-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-submenu-hover-color-responsive' ),
					'transport'  => 'postMessage',
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				// Check Adaptive_Control_Color is exist in the theme.
				/**
				 * Option: Menu Hover Background Color
				 */
				array(
					'name'       => 'below-header-submenu-bg-hover-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 10,
					'tab'        => __( '悬停', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-submenus-bg-color-group]',
					'control'    => 'ast-responsive-color',
					'transport'  => 'postMessage',
					'default'    => adaptive_get_option( 'below-header-submenu-bg-hover-color-responsive' ),
					'title'      => __( '悬停', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				/**
				 * Option: Submenu Active Color
				 */

				array(
					'name'       => 'below-header-submenu-active-color-responsive',
					'transport'  => 'postMessage',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 10,
					'tab'        => __( '已启用', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-submenus-link-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-submenu-active-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				// Check Adaptive_Control_Color is exist in the theme.
				/**
				 * Option: Submenu Active Background Color
				 */
				array(
					'name'       => 'below-header-submenu-active-bg-color-responsive',
					'transport'  => 'postMessage',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'priority'   => 10,
					'tab'        => __( '已启用', 'adaptive-addon' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-submenus-bg-color-group]',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-submenu-active-bg-color-responsive' ),
					'title'      => __( '已启用', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
				),

				/**
				 * Option: Text Color
				 */
				array(
					'name'       => 'below-header-text-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-text-color-responsive' ),
					'transport'  => 'postMessage',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-content-group]',
					'title'      => __( '文本颜色', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'tab'        => __( '标准', 'adaptive-addon' ),
				),

				/**
				 * Option: Link Color
				 */
				array(
					'name'       => 'below-header-link-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-link-color-responsive' ),
					'transport'  => 'postMessage',
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-content-group]',
					'title'      => __( '链接颜色', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'tab'        => __( '标准', 'adaptive-addon' ),
				),

				/**
				 * Option: Link Hover Color
				 */
				array(
					'name'       => 'below-header-link-hover-color-responsive',
					'type'       => 'sub-control',
					'section'    => 'section-below-header',
					'control'    => 'ast-responsive-color',
					'default'    => adaptive_get_option( 'below-header-link-hover-color-responsive' ),
					'parent'     => ADAPTIVE_THEME_SETTINGS . '[below-header-content-group]',
					'transport'  => 'postMessage',
					'title'      => __( '链接颜色', 'adaptive-addon' ),
					'responsive' => true,
					'rgba'       => true,
					'tab'        => __( '悬停', 'adaptive-addon' ),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

new Adaptive_Below_Header_Colors_Bg_Configs();
