<?php
/**
 * Below Header - Typpography Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Below_Header_Typo_Configs' ) ) {

	/**
	 * Register below header Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Below_Header_Typo_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Below Header Typo Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Below Header Menu Font Family
				 */

				array(
					'name'      => 'font-family-below-header-primary-menu',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[below-header-menu-typography-styling]',
					'type'      => 'sub-control',
					'section'   => 'section-below-header',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'default'   => adaptive_get_option( 'font-family-below-header-primary-menu' ),
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-below-header-primary-menu]',
				),

				/**
				 * Option: Below Header Menu Font Size
				 */
				array(
					'name'        => 'font-size-below-header-primary-menu',
					'transport'   => 'postMessage',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[below-header-menu-typography-styling]',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'type'        => 'sub-control',
					'section'     => 'section-below-header',
					'control'     => 'ast-responsive',
					'default'     => adaptive_get_option( 'font-size-below-header-primary-menu' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Below Header Menu Font Weight
				 */
				array(
					'name'              => 'font-weight-below-header-primary-menu',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[below-header-menu-typography-styling]',
					'type'              => 'sub-control',
					'control'           => 'ast-font',
					'section'           => 'section-below-header',
					'font_type'         => 'ast-font-weight',
					'default'           => adaptive_get_option( 'font-weight-below-header-primary-menu' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-below-header-primary-menu',
				),

				/**
				 * Option: Below Header Menu Text Transform
				 */
				array(
					'name'      => 'text-transform-below-header-primary-menu',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[below-header-menu-typography-styling]',
					'type'      => 'sub-control',
					'control'   => 'ast-select',
					'section'   => 'section-below-header',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'default'   => adaptive_get_option( 'text-transform-below-header-primary-menu' ),
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Below Header Submenu Font Family
				 */
				array(
					'name'      => 'font-family-below-header-dropdown-menu',
					'type'      => 'sub-control',
					'control'   => 'ast-font',
					'section'   => 'section-below-header',
					'font_type' => 'ast-font-family',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[below-header-submenu-typography-styling]',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'default'   => adaptive_get_option( 'font-family-below-header-dropdown-menu' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-below-header-dropdown-menu]',
				),

				/**
				 * Option: Below Header Submenu Font Size
				 */
				array(
					'name'        => 'font-size-below-header-dropdown-menu',
					'transport'   => 'postMessage',
					'type'        => 'sub-control',
					'control'     => 'ast-responsive',
					'section'     => 'section-below-header',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[below-header-submenu-typography-styling]',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'default'     => adaptive_get_option( 'font-size-below-header-dropdown-menu' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Below Header Submenu Font Weight
				 */
				array(
					'name'              => 'font-weight-below-header-dropdown-menu',
					'type'              => 'sub-control',
					'control'           => 'ast-font',
					'section'           => 'section-below-header',
					'font_type'         => 'ast-font-weight',
					'default'           => adaptive_get_option( 'font-weight-below-header-dropdown-menu' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[below-header-submenu-typography-styling]',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-below-header-dropdown-menu',
				),

				/**
				 * Option: Below Header Submenu Text Transform
				 */
				array(
					'name'      => 'text-transform-below-header-dropdown-menu',
					'transport' => 'postMessage',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[below-header-submenu-typography-styling]',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'default'   => adaptive_get_option( 'text-transform-below-header-dropdown-menu' ),
					'type'      => 'sub-control',
					'section'   => 'section-below-header',
					'control'   => 'ast-select',
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Below Header Content Font Family
				 */

				array(
					'name'      => 'font-family-below-header-content',
					'default'   => adaptive_get_option( 'font-family-below-header-content' ),
					'type'      => 'sub-control',
					'control'   => 'ast-font',
					'section'   => 'section-below-header',
					'font_type' => 'ast-font-family',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[below-header-content-typography-styling]',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => 'font-weight-below-header-content',
				),

				/**
				 * Option: Below Header Content Font Size
				 */
				array(
					'name'        => 'font-size-below-header-content',
					'type'        => 'sub-control',
					'transport'   => 'postMessage',
					'default'     => adaptive_get_option( 'font-size-below-header-content' ),
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[below-header-content-typography-styling]',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'control'     => 'ast-responsive',
					'section'     => 'section-below-header',
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Below Header Content Font Weight
				 */
				array(
					'name'              => 'font-weight-below-header-content',
					'default'           => adaptive_get_option( 'font-weight-below-header-content' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'control'           => 'ast-font',
					'section'           => 'section-below-header',
					'font_type'         => 'ast-font-weight',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[below-header-content-typography-styling]',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-below-header-content',
				),

				/**
				 * Option: Below Header Content Text Transform
				 */
				array(
					'name'      => 'text-transform-below-header-content',
					'type'      => 'sub-control',
					'control'   => 'ast-select',
					'section'   => 'section-below-header',
					'default'   => adaptive_get_option( 'text-transform-below-header-content' ),
					'transport' => 'postMessage',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[below-header-content-typography-styling]',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

			);

			return array_merge( $configurations, $_configs );
		}
	}
}

new Adaptive_Below_Header_Typo_Configs();


