<?php
/**
 * LearnDash General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Learndash_Color_Configs' ) ) {

	/**
	 * Register Learndash color Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Learndash_Color_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Learndash color Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$active_ld_theme = '';

			if ( is_callable( 'LearnDash_Theme_Register::get_active_theme_key' ) ) {
				$active_ld_theme = LearnDash_Theme_Register::get_active_theme_key();
			}

			if ( 'ld30' !== $active_ld_theme ) {

				$_configs = array(

					/**
					 * Group: Learndash Colors Group
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[learndash-heading-color-group]',
						'default'   => adaptive_get_option( 'learndash-color-group' ),
						'type'      => 'control',
						'control'   => Adaptive_Theme_Extension::$group_control,
						'title'     => __( '标题颜色', 'adaptive-addon' ),
						'section'   => 'section-learndash',
						'transport' => 'postMessage',
						'priority'  => 41,
						'divider'   => array( 'ast_class' => 'ast-top-divider' ),
					),
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[learndash-title-color-group]',
						'default'   => adaptive_get_option( 'learndash-color-group' ),
						'type'      => 'control',
						'control'   => Adaptive_Theme_Extension::$group_control,
						'title'     => __( '标题颜色', 'adaptive-addon' ),
						'section'   => 'section-learndash',
						'transport' => 'postMessage',
						'priority'  => 41,
					),
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[learndash-icon-color-group]',
						'default'   => adaptive_get_option( 'learndash-color-group' ),
						'type'      => 'control',
						'control'   => Adaptive_Theme_Extension::$group_control,
						'title'     => __( '图标颜色', 'adaptive-addon' ),
						'section'   => 'section-learndash',
						'transport' => 'postMessage',
						'priority'  => 41,
					),

					/**
					 * Option: Separator Color
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[learndash-table-title-separator-color]',
						'default'  => adaptive_get_option( 'learndash-table-title-separator-color' ),
						'type'     => 'control',
						'section'  => 'section-learndash',
						'control'  => 'ast-color',
						'title'    => __( '分隔符颜色', 'adaptive-addon' ),
						'priority' => 41,
					),

					/**
					 * Option: Heading Color
					 */
					array(
						'name'     => 'learndash-table-heading-color',
						'default'  => adaptive_get_option( 'learndash-table-heading-color' ),
						'type'     => 'sub-control',
						'section'  => 'section-learndash',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[learndash-heading-color-group]',
						'control'  => 'ast-color',
						'title'    => __( '标准', 'adaptive-addon' ),
						'priority' => 10,
					),

					/**
					 * Option: Heading Background Color
					 */
					array(
						'name'     => 'learndash-table-heading-bg-color',
						'default'  => adaptive_get_option( 'learndash-table-heading-bg-color' ),
						'type'     => 'sub-control',
						'section'  => 'section-learndash',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[learndash-heading-color-group]',
						'control'  => 'ast-color',
						'title'    => __( '背景', 'adaptive-addon' ),
						'priority' => 15,
					),

					/**
					 * Option: Title Color
					 */
					array(
						'name'     => 'learndash-table-title-color',
						'default'  => adaptive_get_option( 'learndash-table-title-color' ),
						'type'     => 'sub-control',
						'section'  => 'section-learndash',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[learndash-title-color-group]',
						'control'  => 'ast-color',
						'title'    => __( '标准', 'adaptive-addon' ),
						'priority' => 20,
					),

					/**
					 * Option: Title Background Color
					 */
					array(
						'name'     => 'learndash-table-title-bg-color',
						'default'  => adaptive_get_option( 'learndash-table-title-bg-color' ),
						'type'     => 'sub-control',
						'section'  => 'section-learndash',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[learndash-title-color-group]',
						'control'  => 'ast-color',
						'title'    => __( '背景', 'adaptive-addon' ),
						'priority' => 25,
					),

					/**
					 * Option: Complete Icon Color
					 */
					array(
						'name'     => 'learndash-complete-icon-color',
						'default'  => adaptive_get_option( 'learndash-complete-icon-color' ),
						'type'     => 'sub-control',
						'section'  => 'section-learndash',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[learndash-icon-color-group]',
						'control'  => 'ast-color',
						'title'    => __( '完成', 'adaptive-addon' ),
						'priority' => 35,
					),

					/**
					 * Option: Incomplete Icon Color
					 */
					array(
						'name'     => 'learndash-incomplete-icon-color',
						'default'  => adaptive_get_option( 'learndash-incomplete-icon-color' ),
						'type'     => 'sub-control',
						'section'  => 'section-learndash',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[learndash-icon-color-group]',
						'control'  => 'ast-color',
						'title'    => __( '未完成', 'adaptive-addon' ),
						'priority' => 40,
					),
				);

			} else {

				$_configs = array(

					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[learndash-overwrite-colors]',
						'type'     => 'control',
						'control'  => Adaptive_Theme_Extension::$switch_control,
						'section'  => 'section-learndash',
						'title'    => __( '如果您希望覆盖LearnDash颜色，请检查此选项', 'adaptive-addon' ),
						'default'  => adaptive_get_option( 'learndash-overwrite-colors' ),
						'priority' => 41,
					),

					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[learndash-profile-link-enabled]',
						'default'  => adaptive_get_option( 'learndash-profile-link-enabled' ),
						'type'     => 'control',
						'section'  => 'section-learndash',
						'title'    => __( '在主标题中显示学生的头像', 'adaptive-addon' ),
						'priority' => 10,
						'control'  => Adaptive_Theme_Extension::$switch_control,
					),

					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[learndash-profile-link]',
						'default'  => adaptive_get_option( 'learndash-profile-link' ),
						'type'     => 'control',
						'control'  => 'text',
						'section'  => 'section-learndash',
						'title'    => __( '头像链接到:', 'adaptive-addon' ),
						'priority' => 15,
						'context'  => array(
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[learndash-profile-link-enabled]',
								'operator' => '==',
								'value'    => true,
							),
						),
					),

					/**
					 * Group: Learndash Colors Group
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[ldv3-color-group]',
						'default'  => adaptive_get_option( 'ldv3-color-group' ),
						'type'     => 'control',
						'control'  => 'ast-settings-group',
						'title'    => __( '颜色', 'adaptive-addon' ),
						'section'  => 'section-learndash',
						'priority' => 41,
						'context'  => array(
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[learndash-overwrite-colors]',
								'operator' => '!=',
								'value'    => 0,
							),
						),
					),

					/**
					 * Option: Heading Color
					 */
					array(
						'name'     => 'learndash-course-link-color',
						'default'  => adaptive_get_option( 'learndash-course-link-color' ),
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[ldv3-color-group]',
						'type'     => 'sub-control',
						'section'  => 'section-learndash',
						'control'  => 'ast-color',
						'title'    => __( '链接颜色', 'adaptive-addon' ),
						'priority' => 10,
					),
					array(
						'name'     => 'learndash-course-highlight-color',
						'default'  => adaptive_get_option( 'learndash-course-highlight-color' ),
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[ldv3-color-group]',
						'type'     => 'sub-control',
						'control'  => 'ast-color',
						'title'    => __( '高亮颜色', 'adaptive-addon' ),
						'section'  => 'section-learndash',
						'priority' => 10,
					),
					array(
						'name'     => 'learndash-course-highlight-text-color',
						'default'  => adaptive_get_option( 'learndash-course-highlight-text-color' ),
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[ldv3-color-group]',
						'type'     => 'sub-control',
						'control'  => 'ast-color',
						'title'    => __( '高亮文本颜色', 'adaptive-addon' ),
						'section'  => 'section-learndash',
						'priority' => 10,
						'context'  => array(
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[learndash-overwrite-colors]',
								'operator' => '!=',
								'value'    => 0,
							),
						),
					),
					array(
						'name'     => 'learndash-course-progress-color',
						'default'  => adaptive_get_option( 'learndash-course-progress-color' ),
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[ldv3-color-group]',
						'type'     => 'sub-control',
						'control'  => 'ast-color',
						'title'    => __( '渐进的颜色', 'adaptive-addon' ),
						'section'  => 'section-learndash',
						'priority' => 10,
						'context'  => array(
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[learndash-overwrite-colors]',
								'operator' => '!=',
								'value'    => 0,
							),
						),
					),
				);
			}

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Learndash_Color_Configs();
