<?php
/**
 * LearnDash General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Learndash_General_Configs' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Learndash_General_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Distraction Free Learning
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[learndash-distraction-free-learning]',
					'default'     => adaptive_get_option( 'learndash-distraction-free-learning' ),
					'type'        => 'control',
					'section'     => 'section-learndash',
					'title'       => __( '让学习不受干扰', 'adaptive-addon' ),
					'description' => __( '删除LearnDash学习页面页眉和页脚中的额外链接', 'adaptive-addon' ),
					'priority'    => 5,
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Header Profile Link
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[learndash-profile-link-enabled]',
					'default'  => adaptive_get_option( 'learndash-profile-link-enabled' ),
					'type'     => 'control',
					'section'  => 'section-learndash',
					'title'    => __( '在主标题中显示学生的头像', 'adaptive-addon' ),
					'priority' => 10,
					'control'  => Adaptive_Theme_Extension::$switch_control,
				),

				/**
				 * Option: Profile Link
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[learndash-profile-link]',
					'default'  => adaptive_get_option( 'learndash-profile-link' ),
					'type'     => 'control',
					'control'  => 'text',
					'section'  => 'section-learndash',
					'title'    => __( '头像链接到:', 'adaptive-addon' ),
					'priority' => 15,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[learndash-profile-link-enabled]',
							'operator' => '==',
							'value'    => true,
						),
					),
				),

				/**
				 * Option: Table Border Radius
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[learndash-table-border-radius]',
					'default'     => adaptive_get_option( 'learndash-table-border-radius' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'title'       => __( '表边框半径', 'adaptive-addon' ),
					'section'     => 'section-learndash',
					'suffix'      => 'px',
					'priority'    => 35,
					'divider'     => array(
						'ast_class' => 'ast-top-divider',
					),
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 50,
					),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Learndash_General_Configs();
