<?php
/**
 * LearnDash General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Learndash_Typo_Configs' ) ) {

	/**
	 * Register Typo Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Learndash_Typo_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Typo Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Group: Learndash Header Typography Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[learndash-header-typography-group]',
					'default'   => adaptive_get_option( 'learndash-header-typography-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '标题字体', 'adaptive-addon' ),
					'section'   => 'section-learndash',
					'transport' => 'postMessage',
					'priority'  => 43,
					'divider'   => array( 'ast_class' => 'ast-top-divider' ),
				),

				/**
				 * Group: Learndash Content Typography Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[learndash-content-typography-group]',
					'default'   => adaptive_get_option( 'learndash-content-typography-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '内容字体', 'adaptive-addon' ),
					'section'   => 'section-learndash',
					'transport' => 'postMessage',
					'priority'  => 43,
					'divider'   => array( 'ast_class' => 'ast-top-divider' ),
				),

				/**
				 * Option: Table Heading Font Family
				 */
				array(
					'name'      => 'font-family-learndash-table-heading',
					'default'   => adaptive_get_option( 'font-family-learndash-table-heading' ),
					'control'   => 'ast-font',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[learndash-header-typography-group]',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-learndash-table-heading]',
					'priority'  => 15,
				),

				/**
				 * Option: Table Heading Font Weight
				 */
				array(
					'name'              => 'font-weight-learndash-table-heading',
					'default'           => adaptive_get_option( 'font-weight-learndash-table-heading' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[learndash-header-typography-group]',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-learndash-table-heading',
					'priority'          => 20,
				),

				/**
				 * Option: Table Heading Text Transform
				 */
				array(
					'name'      => 'text-transform-learndash-table-heading',
					'default'   => adaptive_get_option( 'text-transform-learndash-table-heading' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[learndash-header-typography-group]',
					'transport' => 'postMessage',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'control'   => 'ast-select',
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
					'priority'  => 25,
				),

				/**
				 * Option: Table Heading Font Size
				 */
				array(
					'name'        => 'font-size-learndash-table-heading',
					'default'     => adaptive_get_option( 'font-size-learndash-table-heading' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[learndash-header-typography-group]',
					'control'     => 'ast-responsive',
					'transport'   => 'postMessage',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
					'priority'    => 16,
				),

				/**
				 * Option: Table Heading Font Family
				 */
				array(
					'name'      => 'font-family-learndash-table-content',
					'default'   => adaptive_get_option( 'font-family-learndash-table-content' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[learndash-content-typography-group]',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-learndash-table-content]',
					'priority'  => 40,
				),

				/**
				 * Option: Table Heading Font Weight
				 */
				array(
					'name'              => 'font-weight-learndash-table-content',
					'default'           => adaptive_get_option( 'font-weight-learndash-table-content' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[learndash-content-typography-group]',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-learndash-table-content',
					'priority'          => 45,
				),

				/**
				 * Option: Table Heading Text Transform
				 */
				array(
					'name'      => 'text-transform-learndash-table-content',
					'default'   => adaptive_get_option( 'text-transform-learndash-table-content' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[learndash-content-typography-group]',
					'control'   => 'ast-select',
					'transport' => 'postMessage',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
					'priority'  => 50,
				),

				/**
				 * Option: Table Heading Font Size
				 */
				array(
					'name'        => 'font-size-learndash-table-content',
					'default'     => adaptive_get_option( 'font-size-learndash-table-content' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[learndash-content-typography-group]',
					'transport'   => 'postMessage',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'control'     => 'ast-responsive',
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
					'priority'    => 41,
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Learndash_Typo_Configs();
