<?php
/**
 * LifterLMS Loader
 *
 * @package Adaptive Addon
 */

if ( ! class_exists( 'Adaptive_Ext_LifterLMS_Loader' ) ) {

	/**
	 * Customizer Initialization
	 *
	 * @since 1.0.0
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Ext_LifterLMS_Loader {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Member Variable
		 *
		 * @var instance
		 */
		private static $instance;

		/**
		 * Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {

			add_filter( 'adaptive_theme_defaults', array( $this, 'theme_defaults' ) );
			add_action( 'customize_register', array( $this, 'customize_register' ), 2 );
			add_action( 'customize_preview_init', array( $this, 'preview_scripts' ) );
			add_filter( 'adaptive_theme_lifterlms_settings', array( $this, 'register_builder_fields' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );

		}

		/**
		 * Set Options Default Values
		 *
		 * @param  array $defaults  Adaptive options default value array.
		 * @return array
		 */
		public function theme_defaults( $defaults ) {

			// Student View.
			$defaults['lifterlms-distraction-free-learning'] = true;
			$defaults['lifterlms-enable-featured-image']     = true;
			$defaults['lifterlms-enable-progress-bar']       = true;
			$defaults['lifterlms-enable-course-description'] = true;
			$defaults['lifterlms-enable-course-meta']        = true;
			$defaults['lifterlms-enable-instructor-detail']  = true;

			// Visitor's View.
			$defaults['lifterlms-enable-visitor-featured-image']     = true;
			$defaults['lifterlms-enable-visitor-course-description'] = true;
			$defaults['lifterlms-enable-visitor-course-meta']        = true;
			$defaults['lifterlms-enable-visitor-instructor-detail']  = true;
			$defaults['lifterlms-enable-visitor-syllabus']           = true;

			$defaults['lifterlms-distraction-free-checkout'] = false;

			$defaults['lifterlms-profile-link-enabled'] = false;
			$defaults['lifterlms-my-account-vertical']  = false;

			return $defaults;
		}

		/**
		 * Add postMessage support for site title and description for the Theme Customizer.
		 *
		 * @param GC_Customize_Manager $gc_customize Theme Customizer object.
		 */
		public function customize_register( $gc_customize ) {

			/**
			 * Register Sections & Panels
			 */
			require_once ADAPTIVE_ADDON_EXT_LIFTERLMS_DIR . 'classes/class-adaptive-customizer-lifterlms-panels-and-sections.php';

			/**
			 * Sections
			 */
			require_once ADAPTIVE_ADDON_EXT_LIFTERLMS_DIR . 'classes/sections/class-adaptive-customizer-lifterlms-general-configs.php';
			require_once ADAPTIVE_ADDON_EXT_LIFTERLMS_DIR . 'classes/sections/class-adaptive-customizer-lifterlms-course-lesson-configs.php';

		}

		/**
		 * Customizer Controls
		 *
		 * @see 'adaptive-customizer-preview-js' panel in parent theme
		 */
		public function preview_scripts() {

			if ( SCRIPT_DEBUG ) {
				$js_path = 'assets/js/unminified/customizer-preview.js';
			} else {
				$js_path = 'assets/js/minified/customizer-preview.min.js';
			}

			gc_register_script( 'ast-lifterlms-customizer-preview', ADAPTIVE_ADDON_EXT_LIFTERLMS_URI . $js_path, array( 'customize-preview', 'adaptive-customizer-preview-js' ), ADAPTIVE_EXT_VER, true );
			gc_enqueue_script( 'ast-lifterlms-customizer-preview' );
		}


		/**
		 * Register theme postmeta fields with the LifterLMS Builder
		 *
		 * @since [version]
		 * @param string $default_fields Default custom field definitions.
		 * @return string $default_fields Updated custom field definitions.
		 */
		public function register_builder_fields( $default_fields ) {

			$disable_fields      = array();
			$addon_fields        = array();
			$show_meta_field     = ! Adaptive_Meta_Boxes::is_bb_themer_layout();
			$above_header_layout = adaptive_get_option( 'above-header-layout' );
			$below_header_layout = adaptive_get_option( 'below-header-layout' );

			$header_options = Adaptive_Target_Rules_Fields::get_post_selection( 'adaptive_adv_header' );

			foreach ( $header_options as $key => $value ) {
				$page_headers[ $key ] = $value;
			}

			if ( empty( $header_options ) ) {
				$page_headers = array(
					'' => __( '没有找到页眉', 'adaptive-addon' ),
				);
			}

			if ( Adaptive_Ext_Extension::is_active( 'sticky-header' ) ) {
				if ( $show_meta_field ) {
					$disable_fields[] = array(
						'attribute'  => 'header-main-stick-meta',
						'id'         => 'header-main-stick-meta',
						'label'      => esc_html__( '固定主页眉', 'adaptive-addon' ),
						'switch_on'  => 'on',
						'switch_off' => 'off',
						'type'       => 'switch',
					);
				}
			}

			if ( Adaptive_Ext_Extension::is_active( 'sticky-header' ) ) {
				if ( $show_meta_field ) {
					$disable_fields[] = array(
						'attribute'  => 'header-above-stick-meta',
						'id'         => 'header-above-stick-meta',
						'label'      => esc_html__( '固定上页眉', 'adaptive-addon' ),
						'switch_on'  => 'on',
						'switch_off' => 'off',
						'type'       => 'switch',
					);
				}
			}

			if ( Adaptive_Ext_Extension::is_active( 'sticky-header' ) ) {
				if ( $show_meta_field ) {
					$disable_fields[] = array(
						'attribute'  => 'header-below-stick-meta',
						'id'         => 'header-below-stick-meta',
						'label'      => esc_html__( '固定下页眉', 'adaptive-addon' ),
						'switch_on'  => 'on',
						'switch_off' => 'off',
						'type'       => 'switch',
					);
				}
			}

			if ( 'disabled' !== $above_header_layout ) {
				if ( $show_meta_field ) {
					$disable_fields[] = array(
						'attribute' => 'ast-above-header-display',
						'id'        => 'ast-above-header-display',
						'label'     => esc_html__( '在页眉上方禁用', 'adaptive-addon' ),
						'switch_on' => 'disabled',
						'type'      => 'switch',
					);
				}
			}

			if ( 'disabled' !== $below_header_layout ) {
				if ( $show_meta_field ) {
					$disable_fields[] = array(
						'attribute' => 'ast-below-header-display',
						'id'        => 'ast-below-header-display',
						'label'     => esc_html__( '在页眉下方禁用', 'adaptive-addon' ),
						'switch_on' => 'disabled',
						'type'      => 'switch',
					);
				}
			}

			if ( Adaptive_Ext_Extension::is_active( 'advanced-headers' ) ) {
				$addon_fields[] = array(
					'attribute' => 'adv-header-id-meta',
					'id'        => 'adv-header-id-meta',
					'label'     => esc_html__( '页头 ', 'adaptive-addon' ),
					'type'      => 'ast-select',
					'options'   => $page_headers,
				);
			}

			if ( Adaptive_Ext_Extension::is_active( 'sticky-header' ) ) {
				$addon_fields[] = array(
					'attribute' => 'stick-header-meta',
					'id'        => 'stick-header-meta',
					'label'     => esc_html__( '固定页眉 ', 'adaptive-addon' ),
					'type'      => 'ast-select',
					'options'   => array(
						'default'  => esc_html__( '定制器设置', 'adaptive-addon' ),
						'enabled'  => esc_html__( '已启用', 'adaptive-addon' ),
						'disabled' => esc_html__( '停用', 'adaptive-addon' ),
					),
				);
			}

			if ( Adaptive_Ext_Extension::is_active( 'transparent-header' ) ) {
				$addon_fields[] = array(
					'attribute' => 'theme-transparent-header-meta',
					'id'        => 'theme-transparent-header-meta',
					'label'     => esc_html__( '透明页眉 ', 'adaptive-addon' ),
					'type'      => 'ast-select',
					'options'   => array(
						'default'  => esc_html__( '定制器设置', 'adaptive-addon' ),
						'enabled'  => esc_html__( '已启用', 'adaptive-addon' ),
						'disabled' => esc_html__( '停用', 'adaptive-addon' ),
					),
				);
			}

			$default_fields[] = $addon_fields;
			$default_fields[] = $disable_fields;

			return $default_fields;
		}

		/**
		 * Enqueue admin Scripts and Styles.
		 *
		 * @since  1.3.3
		 */
		public function admin_scripts() {

			if ( class_exists( 'LLMS_Admin_Assets' ) ) {

				$obj = new LLMS_Admin_Assets();

				if ( $obj->is_llms_page() ) {

					if ( SCRIPT_DEBUG ) {
						$js_path = 'assets/js/unminified/lifterlms-builder-settings.js';
					} else {
						$js_path = 'assets/js/minified/lifterlms-builder-settings.min.js';
					}

					gc_enqueue_script( 'ast-lifterlms-builder-settings-', ADAPTIVE_ADDON_EXT_LIFTERLMS_URI . $js_path, array(), ADAPTIVE_EXT_VER, true );
				}
			}
		}
	}
}

/**
* Kicking this off by calling 'get_instance()' method
*/
Adaptive_Ext_LifterLMS_Loader::get_instance();
