<?php
/**
 * LifterLMS General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Lifterlms_Course_Lesson_Configs' ) ) {

	/**
	 * Register Course Lesson Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Lifterlms_Course_Lesson_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Course Lesson Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Distraction Free Learning
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-distraction-free-learning]',
					'default'  => adaptive_get_option( 'lifterlms-distraction-free-learning' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '让学习不受干扰', 'adaptive-addon' ),
					'divider'  => array(
						'ast_class' => 'ast-bottom-divider',
						'ast_title' => __( 'Student视图', 'adaptive-addon' ),
					),
					'priority' => 5,
				),

				/**
				 * Option: Enable Featured Image
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-featured-image]',
					'default'  => adaptive_get_option( 'lifterlms-enable-featured-image' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启特色图像', 'adaptive-addon' ),
					'priority' => 5,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Course Description
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-course-description]',
					'default'  => adaptive_get_option( 'lifterlms-enable-course-description' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启进程描述', 'adaptive-addon' ),
					'priority' => 5,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Course Meta
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-course-meta]',
					'default'  => adaptive_get_option( 'lifterlms-enable-course-meta' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启进程Meta', 'adaptive-addon' ),
					'priority' => 5,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Instructor Detail
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-instructor-detail]',
					'default'  => adaptive_get_option( 'lifterlms-enable-instructor-detail' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启Instructor细节', 'adaptive-addon' ),
					'priority' => 5,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Progress Bar
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-progress-bar]',
					'default'  => adaptive_get_option( 'lifterlms-enable-progress-bar' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启进度条', 'adaptive-addon' ),
					'priority' => 5,
				),

				/**
				 * Option: Enable Featured Image
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-visitor-featured-image]',
					'default'  => adaptive_get_option( 'lifterlms-enable-visitor-featured-image' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启特色图像', 'adaptive-addon' ),
					'priority' => 10,
					'divider'  => array(
						'ast_class' => 'ast-bottom-divider ast-top-divider',
						'ast_title' => __( '访问者视图', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Enable Course Description
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-visitor-course-description]',
					'default'  => adaptive_get_option( 'lifterlms-enable-visitor-course-description' ),
					'type'     => 'control',
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启进程描述', 'adaptive-addon' ),
					'priority' => 10,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Course Meta
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-visitor-course-meta]',
					'default'  => adaptive_get_option( 'lifterlms-enable-visitor-course-meta' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启进程Meta', 'adaptive-addon' ),
					'priority' => 10,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Instructor Detail
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-visitor-instructor-detail]',
					'default'  => adaptive_get_option( 'lifterlms-enable-visitor-instructor-detail' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启Instructor细节', 'adaptive-addon' ),
					'priority' => 10,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Syllabus
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-enable-visitor-syllabus]',
					'default'  => adaptive_get_option( 'lifterlms-enable-visitor-syllabus' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-course-lesson',
					'title'    => __( '开启教学大纲', 'adaptive-addon' ),
					'priority' => 10,
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Lifterlms_Course_Lesson_Configs();
