<?php
/**
 * LifterLMS General Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Lifterlms_General_Configs' ) ) {

	/**
	 * Register General Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Lifterlms_General_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register General Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Shop Columns
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[llms-course-grid]',
					'default'           => adaptive_get_option(
						'llms-course-grid',
						array(
							'desktop' => 3,
							'tablet'  => 2,
							'mobile'  => 1,
						)
					),
					'type'              => 'control',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'section'           => 'section-lifterlms-general',
					'title'             => __( '课程列', 'adaptive-addon' ),
					'priority'          => 5,
					'input_attrs'       => array(
						'step' => 1,
						'min'  => 1,
						'max'  => 6,
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Shop Columns
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[llms-membership-grid]',
					'default'           => adaptive_get_option(
						'llms-membership-grid',
						array(
							'desktop' => 3,
							'tablet'  => 2,
							'mobile'  => 1,
						)
					),
					'type'              => 'control',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'section'           => 'section-lifterlms-general',
					'title'             => __( '会员列', 'adaptive-addon' ),
					'priority'          => 5,
					'input_attrs'       => array(
						'step' => 1,
						'min'  => 1,
						'max'  => 6,
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Header Profile Link
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-profile-link-enabled]',
					'default'  => adaptive_get_option( 'lifterlms-profile-link-enabled' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-general',
					'title'    => __( '启用页眉配置文件链接', 'adaptive-addon' ),
					'priority' => 5,
				),

				/**
				 * Option: Distraction Free Checkout
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-distraction-free-checkout]',
					'default'  => adaptive_get_option( 'lifterlms-distraction-free-checkout' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-general',
					'title'    => __( '免打扰结帐', 'adaptive-addon' ),
					'priority' => 10,
					'divider'  => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '结帐', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Enable Vertical Tab
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[lifterlms-my-account-vertical]',
					'default'  => adaptive_get_option( 'lifterlms-my-account-vertical' ),
					'type'     => 'control',
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'section'  => 'section-lifterlms-general',
					'title'    => __( '显示垂直制表符', 'adaptive-addon' ),
					'priority' => 15,
					'divider'  => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '我的帐户', 'adaptive-addon' ),
					),
				),

			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Lifterlms_General_Configs();
