<?php
/**
 * Adaptive Mobile Header.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}
if ( ! class_exists( 'Adaptive_Customizer_Mobile_Below_Header_Configs' ) ) {

	/**
	 * Customizer Sanitizes Initial setup
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Mobile_Below_Header_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Panels and Sections for Customizer.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$show_deprecated_no_toggle_style = 'no-toggle' == adaptive_get_option( 'mobile-below-header-menu-style' ) ? true : false;

			// Check deprecated flag has been set or not.
			if ( apply_filters( 'adaptive_no_toggle_menu_style_deprecate', $show_deprecated_no_toggle_style ) ) {
				$menu_style_choices     = array(
					'default'    => __( '下拉列表', 'adaptive-addon' ),
					'flyout'     => __( '弹出', 'adaptive-addon' ),
					'fullscreen' => __( '全屏', 'adaptive-addon' ),
					'no-toggle'  => __( '没有切换(弃用)', 'adaptive-addon' ),
				);
				$menu_style_description = __( '不再支持切换样式。我们建议您选择不同的菜单样式。', 'adaptive-addon' );
			} else {
				$menu_style_choices     = array(
					'default'    => __( '下拉列表', 'adaptive-addon' ),
					'flyout'     => __( '弹出', 'adaptive-addon' ),
					'fullscreen' => __( '全屏', 'adaptive-addon' ),
				);
				$menu_style_description = __( '没有切换选项已被弃用。', 'adaptive-addon' );
			}

			$configs = array(

				/**
				 * Option: Mobile Menu Style
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-menu-style]',
					'section'     => 'section-below-header',
					'default'     => adaptive_get_option( 'mobile-below-header-menu-style' ),
					'title'       => __( '菜单样式', 'adaptive-addon' ),
					'type'        => 'control',
					'control'     => 'ast-select',
					'transport'   => 'refresh',
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-on-mobile]',
								'operator' => '==',
								'value'    => true,
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-merge-menu]',
								'operator' => '!=',
								'value'    => true,
							),
						),
					),
					'priority'    => 106,
					'choices'     => $menu_style_choices,
					'description' => $menu_style_description,
				),

				/**
				 * Option: Mobile Menu Style - Flyout alignments
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[flyout-mobile-below-header-menu-alignment]',
					'section'  => 'section-below-header',
					'default'  => adaptive_get_option( 'flyout-mobile-below-header-menu-alignment' ),
					'title'    => __( '浮出菜单对齐', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'priority' => 106,
					'choices'  => array(
						'left'  => __( '左', 'adaptive-addon' ),
						'right' => __( '右', 'adaptive-addon' ),
					),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-menu-style]',
							'operator' => '==',
							'value'    => 'flyout',
						),
					),
				),

				/**
				* Option: Toggle Button Style
				*/
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-toggle-btn-style]',
					'type'      => 'control',
					'control'   => 'ast-select',
					'section'   => 'section-below-header',
					'title'     => __( '切换按钮样式', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'context'   => array(
						adaptive_addon_builder_helper()->general_tab_config,
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-menu-style]',
							'operator' => '!=',
							'value'    => 'no-toggle',
						),
					),
					'default'   => adaptive_get_option( 'mobile-below-header-toggle-btn-style' ),
					'priority'  => 107,
					'choices'   => array(
						'fill'    => __( '填充', 'adaptive-addon' ),
						'outline' => __( '轮廓', 'adaptive-addon' ),
						'minimal' => __( '简化', 'adaptive-addon' ),
					),
				),

				/**
				* Option: Toggle Button Color
				*/
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-toggle-btn-style-color]',
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'           => array(
						adaptive_addon_builder_helper()->general_tab_config,
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-menu-style]',
							'operator' => '!=',
							'value'    => 'no-toggle',
						),
					),
					'default'           => adaptive_get_option( 'mobile-below-header-toggle-btn-style-color' ),
					'title'             => __( '切换按钮颜色', 'adaptive-addon' ),
					'section'           => 'section-below-header',
					'transport'         => 'postMessage',
					'priority'          => 107,
				),

				/**
				* Option: Border Radius
				*/
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-toggle-btn-border-radius]',
					'type'        => 'control',
					'control'     => 'ast-slider',
					'transport'   => 'postMessage',
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-menu-style]',
							'operator' => '!=',
							'value'    => 'no-toggle',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-toggle-btn-style]',
							'operator' => '!=',
							'value'    => 'minimal',
						),
					),
					'default'     => adaptive_get_option( 'mobile-below-header-toggle-btn-border-radius' ),
					'section'     => 'section-below-header',
					'title'       => __( '边界圆角', 'adaptive-addon' ),
					'priority'    => 107,
					'suffix'      => 'px',
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 100,
					),
				),

				/**
				 * Option: Mobile Header Menu Border
				 */
				array(
					'name'           => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-menu-all-border]',
					'type'           => 'control',
					'control'        => 'ast-border',
					'transport'      => 'postMessage',
					'section'        => 'section-below-header',
					'default'        => adaptive_get_option( 'mobile-below-header-menu-all-border' ),
					'title'          => __( '菜单项的边框', 'adaptive-addon' ),
					'linked_choices' => true,
					'context'        => array(
						adaptive_addon_builder_helper()->general_tab_config,
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-on-mobile]',
							'operator' => '==',
							'value'    => true,
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-merge-menu]',
							'operator' => '!=',
							'value'    => true,
						),
					),
					'priority'       => 130,
					'choices'        => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Mobile Header Menu Border Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[mobile-below-header-menu-b-color]',
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'default'           => adaptive_get_option( 'mobile-below-header-menu-b-color', '#dadada' ),
					'transport'         => 'postMessage',
					'title'             => __( '菜单项的边框颜色', 'adaptive-addon' ),
					'context'           => array(
						adaptive_addon_builder_helper()->general_tab_config,
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-on-mobile]',
							'operator' => '==',
							'value'    => true,
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-merge-menu]',
							'operator' => '!=',
							'value'    => true,
						),
					),
					'section'           => 'section-below-header',
					'priority'          => 135,
				),
			);

			return array_merge( $configurations, $configs );
		}
	}
}

new Adaptive_Customizer_Mobile_Below_Header_Configs();
