<?php
/**
 * Adaptive Mobile Header.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Customizer_Mobile_Header_Configs' ) ) {

	/**
	 * Customizer Sanitizes Initial setup
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Mobile_Header_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Panels and Sections for Customizer.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$show_deprecated_no_toggle_style = 'no-toggle' == adaptive_get_option( 'mobile-menu-style' ) ? true : false;

			// Check deprecated flag has been set or not.
			if ( apply_filters( 'adaptive_no_toggle_menu_style_deprecate', $show_deprecated_no_toggle_style ) ) {
				$menu_style_choices     = array(
					'default'    => __( '下拉列表', 'adaptive-addon' ),
					'flyout'     => __( '弹出', 'adaptive-addon' ),
					'fullscreen' => __( '全屏', 'adaptive-addon' ),
					'no-toggle'  => __( '没有切换(弃用)', 'adaptive-addon' ),
				);
				$menu_style_description = __( '不再支持切换样式。我们建议您选择不同的菜单样式。', 'adaptive-addon' );
			} else {
				$menu_style_choices     = array(
					'default'    => __( '下拉列表', 'adaptive-addon' ),
					'flyout'     => __( '弹出', 'adaptive-addon' ),
					'fullscreen' => __( '全屏', 'adaptive-addon' ),
				);
				$menu_style_description = __( '没有切换选项已被弃用。', 'adaptive-addon' );
			}

			$configs = array(

				/**
				 * Option: Mobile Menu Style
				 */

				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[mobile-menu-style]',
					'type'        => 'control',
					'control'     => 'ast-select',
					'section'     => 'section-primary-menu',
					'default'     => adaptive_get_option( 'mobile-menu-style' ),
					'title'       => __( '菜单样式', 'adaptive-addon' ),
					'priority'    => 40,
					'choices'     => $menu_style_choices,
					'description' => $menu_style_description,
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[disable-primary-nav]',
							'operator' => '!=',
							'value'    => '1',
						),
					),
				),

				/**
				 * Option: Mobile Menu Style - Flyout alignments
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[flyout-mobile-menu-alignment]',
					'section'  => 'section-primary-menu',
					'title'    => __( '浮出菜单对齐', 'adaptive-addon' ),
					'default'  => adaptive_get_option( 'flyout-mobile-menu-alignment' ),
					'type'     => 'control',
					'control'  => 'ast-select',

					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-menu-style]',
							'operator' => '==',
							'value'    => 'flyout',
						),
					),

					'priority' => 41,
					'choices'  => array(
						'left'  => __( '左', 'adaptive-addon' ),
						'right' => __( '右', 'adaptive-addon' ),
					),
				),

				/**
				 * Option - Header Menu Border
				 */
				array(
					'name'           => ADAPTIVE_THEME_SETTINGS . '[mobile-header-menu-all-border]',
					'section'        => 'section-primary-menu',
					'type'           => 'control',
					'control'        => 'ast-border',
					'default'        => adaptive_get_option( 'mobile-header-menu-all-border' ),
					'transport'      => 'postMessage',
					'title'          => __( '菜单项的边框', 'adaptive-addon' ),
					'linked_choices' => true,
					'priority'       => 65,
					'choices'        => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Mobile Header Menu Border Color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[mobile-header-menu-b-color]',
					'section'           => 'section-primary-menu',
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '边框颜色', 'adaptive-addon' ),
					'default'           => adaptive_get_option( 'mobile-header-menu-b-color', '#dadada' ),
					'transport'         => 'postMessage',
					'priority'          => 68,
				),
			);

			return array_merge( $configurations, $configs );
		}
	}
}

new Adaptive_Customizer_Mobile_Header_Configs();
