<?php
/**
 * Mega Menu Options configurations.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.6.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Existing_Nav_Menu_Below_Header_Colors' ) ) {

	/**
	 * Register Mega Menu Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Existing_Nav_Menu_Below_Header_Colors extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Mega Menu Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Below Header Menus Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[below-header-megamenu-group]',
					'default'   => adaptive_get_option( 'below-header-megamenu-group' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$group_control,
					'title'     => __( '超级菜单标题', 'adaptive-addon' ),
					'section'   => 'section-below-header',
					'transport' => 'postMessage',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority'  => 136,
					'context'   => array(
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-layout]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
				),

				// Option: Megamenu Heading Color.
				array(
					'type'              => 'sub-control',
					'priority'          => 12,
					'tab'               => __( '标准', 'adaptive-addon' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[below-header-megamenu-group]',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'section'           => 'section-below-header',
					'transport'         => 'postMessage',
					'name'              => 'below-header-megamenu-heading-color',
					'default'           => adaptive_get_option( 'below-header-megamenu-heading-color' ),
					'title'             => __( '标准', 'adaptive-addon' ),
				),

				// Option: Megamenu Heading Hover Color.
				array(
					'type'              => 'sub-control',
					'priority'          => 12,
					'tab'               => __( '悬停', 'adaptive-addon' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[below-header-megamenu-group]',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'section'           => 'section-below-header',
					'transport'         => 'postMessage',
					'name'              => 'below-header-megamenu-heading-h-color',
					'default'           => adaptive_get_option( 'below-header-megamenu-heading-h-color' ),
					'title'             => __( '悬停', 'adaptive-addon' ),
				),

				// Option: Megamenu Heading Color.
				array(
					'type'              => 'sub-control',
					'priority'          => 12,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-mega-menus-colors]',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'section'           => 'section-below-header',
					'transport'         => 'postMessage',
					'name'              => 'sticky-below-header-megamenu-heading-color',
					'default'           => adaptive_get_option( 'sticky-below-header-megamenu-heading-color' ),
					'title'             => __( '标准', 'adaptive-addon' ),
					'context'           => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),

				// Option: Megamenu Heading Hover Color.
				array(
					'type'              => 'sub-control',
					'priority'          => 12,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-mega-menus-colors]',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'section'           => 'section-below-header',
					'transport'         => 'postMessage',
					'name'              => 'sticky-below-header-megamenu-heading-h-color',
					'default'           => adaptive_get_option( 'sticky-below-header-megamenu-heading-h-color' ),
					'title'             => __( '悬停', 'adaptive-addon' ),

					'context'           => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;
		}
	}
}

new Adaptive_Existing_Nav_Menu_Below_Header_Colors();
