<?php
/**
 * Mega Menu Options configurations.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.6.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Nav_Menu_Above_Header_Colors' ) ) {

	/**
	 * Register Mega Menu Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Nav_Menu_Above_Header_Colors extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Mega Menu Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Sticky Above Header Colors
				 */

				// Option: Megamenu Heading Color.
				array(
					'type'              => 'sub-control',
					'priority'          => 12,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-mega-menus-colors]',
					'control'           => 'ast-color',
					'tab'               => __( '标准', 'adaptive-addon' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'section'           => 'section-sticky-header',
					'transport'         => 'postMessage',
					'name'              => 'sticky-above-header-megamenu-heading-color',
					'default'           => adaptive_get_option( 'sticky-above-header-megamenu-heading-color' ),
					'title'             => __( '标准', 'adaptive-addon' ),
					'context'           => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),

				// Option: Megamenu Heading Hover Color.
				array(
					'type'              => 'sub-control',
					'priority'          => 12,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-mega-menus-colors]',
					'control'           => 'ast-color',
					'tab'               => __( '悬停', 'adaptive-addon' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'section'           => 'section-sticky-header',
					'transport'         => 'postMessage',
					'name'              => 'sticky-above-header-megamenu-heading-h-color',
					'default'           => adaptive_get_option( 'sticky-above-header-megamenu-heading-h-color' ),
					'title'             => __( '悬停', 'adaptive-addon' ),
					'context'           => array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
							'operator' => '==',
							'value'    => 'menu',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
				),

			);

			if ( is_callable( 'Adaptive_Sticky_Header_Configs::is_header_section_active' ) && Adaptive_Sticky_Header_Configs::is_header_section_active() && false === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				$_new_config = array(
					/**
					 * Option: Sticky Header Above Menu Color Group
					 */
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-mega-menus-colors]',
						'default'    => adaptive_get_option( 'sticky-header-above-mega-menus-colors' ),
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '超级菜单标题', 'adaptive-addon' ),
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'priority'   => 70,
						'responsive' => false,
						'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
							adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					),
				);

				$_configs = array_merge( $_configs, $_new_config );
			}

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;
		}
	}
}

new Adaptive_Nav_Menu_Above_Header_Colors();
