<?php
/**
 * Mega Menu Options configurations.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.6.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Nav_Menu_Primary_Header_Typography' ) ) {

	/**
	 * Register Mega Menu Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Nav_Menu_Primary_Header_Typography extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Mega Menu Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.6.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[primary-mega-menu-col-typography]',
					'default'   => adaptive_get_option( 'primary-mega-menu-col-typography' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '超级菜单标题字体', 'adaptive-addon' ),
					'section'   => 'section-primary-menu',
					'transport' => 'postMessage',
					'priority'  => 72,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				// Option: Primary Megamenu Header Menu Font Family.
				array(
					'name'      => 'primary-header-megamenu-heading-font-family',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[primary-mega-menu-col-typography]',
					'type'      => 'sub-control',
					'section'   => 'section-primary-menu',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'default'   => adaptive_get_option( 'primary-header-megamenu-heading-font-family' ),
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[primary-header-megamenu-heading-font-weight]',
					'priority'  => 45,
				),

				// Option: Primary Megamenu Header Menu Font Size.
				array(
					'name'        => 'primary-header-megamenu-heading-font-size',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[primary-mega-menu-col-typography]',
					'transport'   => 'postMessage',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'type'        => 'sub-control',
					'section'     => 'section-primary-menu',
					'responsive'  => false,
					'control'     => 'ast-responsive',
					'default'     => adaptive_get_option( 'primary-header-megamenu-heading-font-size' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
					'priority'    => 45,
				),

				// Option: Primary Megamenu Header Menu Font Weight.
				array(
					'name'              => 'primary-header-megamenu-heading-font-weight',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[primary-mega-menu-col-typography]',
					'type'              => 'sub-control',
					'section'           => 'section-primary-menu',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'default'           => adaptive_get_option( 'primary-header-megamenu-heading-font-weight' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'primary-header-megamenu-heading-font-family',
					'priority'          => 45,
				),

				// Option: Primary Megamenu Header Menu Text Transform.
				array(
					'name'      => 'primary-header-megamenu-heading-text-transform',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[primary-mega-menu-col-typography]',
					'type'      => 'sub-control',
					'section'   => 'section-primary-menu',
					'control'   => 'ast-select',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'default'   => adaptive_get_option( 'primary-header-megamenu-heading-text-transform' ),
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
					'priority'  => 45,
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;
		}
	}
}

new Adaptive_Nav_Menu_Primary_Header_Typography();

