<?php
/**
 * Scroll To Top Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Scroll_To_Top_Configs' ) ) {

	/**
	 * Register Scroll To Top Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Scroll_To_Top_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Scroll To Top Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Scroll to Top Display On
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[scroll-to-top-on-devices]',
					'default'    => adaptive_get_option( 'scroll-to-top-on-devices' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => 'section-scroll-to-top',
					'priority'   => 10,
					'title'      => __( '显示在', 'adaptive-addon' ),
					'choices'    => array(
						'desktop' => __( '桌面端', 'adaptive-addon' ),
						'mobile'  => __( '手机号', 'adaptive-addon' ),
						'both'    => __( '桌面端+移动端', 'adaptive-addon' ),
					),
					'renderAs'   => 'text',
					'responsive' => false,
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Scroll to Top Position
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[scroll-to-top-icon-position]',
					'default'    => adaptive_get_option( 'scroll-to-top-icon-position' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'transport'  => 'postMessage',
					'section'    => 'section-scroll-to-top',
					'title'      => __( '位置', 'adaptive-addon' ),
					'choices'    => array(
						'left'  => __( '左', 'adaptive-addon' ),
						'right' => __( '右', 'adaptive-addon' ),
					),
					'priority'   => 11,
					'responsive' => false,
					'renderAs'   => 'text',
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Scroll To Top Icon Size
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[scroll-to-top-icon-size]',
					'default'   => adaptive_get_option( 'scroll-to-top-icon-size' ),
					'type'      => 'control',
					'control'   => 'ast-slider',
					'transport' => 'postMessage',
					'section'   => 'section-scroll-to-top',
					'title'     => __( '图标大小', 'adaptive-addon' ),
					'suffix'    => 'px',
					'priority'  => 12,
				),

				/**
				 * Option: Scroll To Top Radius
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[scroll-to-top-icon-radius]',
					'default'   => adaptive_get_option( 'scroll-to-top-icon-radius' ),
					'type'      => 'control',
					'control'   => 'ast-slider',
					'transport' => 'postMessage',
					'section'   => 'section-scroll-to-top',
					'title'     => __( '边界圆角', 'adaptive-addon' ),
					'suffix'    => 'px',
					'priority'  => 1,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[scroll-on-top-color-group]',
					'default'   => adaptive_get_option( 'scroll-on-top-color-group' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$group_control,
					'title'     => __( '图标颜色', 'adaptive-addon' ),
					'section'   => 'section-scroll-to-top',
					'transport' => 'postMessage',
					'context'   => adaptive_addon_builder_helper()->is_header_footer_builder_active ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					'priority'  => 15,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[scroll-on-top-bg-color-group]',
					'default'   => adaptive_get_option( 'scroll-on-top-bg-color-group' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$group_control,
					'title'     => __( '背景颜色', 'adaptive-addon' ),
					'section'   => 'section-scroll-to-top',
					'transport' => 'postMessage',
					'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					'priority'  => 16,
				),

				/**
				 * Option: Icon Color
				 */
				array(
					'name'              => 'scroll-to-top-icon-color',
					'default'           => adaptive_get_option( 'scroll-to-top-icon-color' ),
					'type'              => 'sub-control',
					'priority'          => 1,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[scroll-on-top-color-group]',
					'section'           => 'section-scroll-to-top',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'title'             => __( '颜色', 'adaptive-addon' ),
				),

				// Check Adaptive_Control_Color is exist in the theme.
				/**
				 * Option: Icon Background Color
				 */
				array(
					'name'              => 'scroll-to-top-icon-bg-color',
					'default'           => adaptive_get_option( 'scroll-to-top-icon-bg-color' ),
					'type'              => 'sub-control',
					'priority'          => 1,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[scroll-on-top-bg-color-group]',
					'section'           => 'section-scroll-to-top',
					'transport'         => 'postMessage',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '颜色', 'adaptive-addon' ),
				),

				/**
				 * Option: Icon Hover Color
				 */
				array(
					'name'              => 'scroll-to-top-icon-h-color',
					'default'           => adaptive_get_option( 'scroll-to-top-icon-h-color' ),
					'type'              => 'sub-control',
					'priority'          => 1,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[scroll-on-top-color-group]',
					'section'           => 'section-scroll-to-top',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'title'             => __( '悬停颜色', 'adaptive-addon' ),
				),

				// Check Adaptive_Control_Color is exist in the theme.
				/**
				 * Option: Link Hover Background Color
				 */

				array(
					'name'              => 'scroll-to-top-icon-h-bg-color',
					'default'           => adaptive_get_option( 'scroll-to-top-icon-h-bg-color' ),
					'type'              => 'sub-control',
					'priority'          => 1,
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[scroll-on-top-bg-color-group]',
					'section'           => 'section-scroll-to-top',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'title'             => __( '悬停颜色', 'adaptive-addon' ),
				),

			);

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				$_configs[] = array(
					'name'        => 'section-scroll-to-top-ast-context-tabs',
					'section'     => 'section-scroll-to-top',
					'type'        => 'control',
					'control'     => 'ast-builder-header-control',
					'priority'    => 0,
					'description' => '',
				);
			}

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;
		}
	}
}

new Adaptive_Scroll_To_Top_Configs();


