<?php
/**
 * Site Layouts - Customizer.
 *
 * @package Adaptive Addon
 * @since 1.0.0
 */

if ( ! class_exists( 'Adaptive_Ext_Site_Layouts_Loader' ) ) {

	/**
	 * Customizer Initialization
	 *
	 * @since 1.0.0
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Ext_Site_Layouts_Loader {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Member Variable
		 *
		 * @var instance
		 */
		private static $instance;

		/**
		 *  Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 *  Constructor
		 */
		public function __construct() {

			add_filter( 'adaptive_theme_defaults', array( $this, 'theme_defaults' ) );
			add_action( 'customize_register', array( $this, 'customize_register' ), 2 );
			add_action( 'customize_preview_init', array( $this, 'preview_scripts' ) );

		}

		/**
		 * Set Options Default Values
		 *
		 * @param  array $defaults  Adaptive options default value array.
		 * @return array
		 */
		public function theme_defaults( $defaults ) {

				$defaults['site-layout-padded-width'] = 1200;
				$defaults['site-layout-padded-pad']   = array(
					'desktop'      => array(
						'top'    => 25,
						'right'  => 50,
						'bottom' => 25,
						'left'   => 50,
					),
					'tablet'       => array(
						'top'    => '',
						'right'  => '',
						'bottom' => '',
						'left'   => '',
					),
					'mobile'       => array(
						'top'    => '',
						'right'  => '',
						'bottom' => '',
						'left'   => '',
					),
					'desktop-unit' => 'px',
					'tablet-unit'  => 'px',
					'mobile-unit'  => 'px',
				);

				$defaults['site-layout-fluid-lr-padding'] = 25;
				$defaults['site-layout-box-width']        = 1200;
				$defaults['site-layout-box-tb-margin']    = 0;
				$defaults['site-layout-box-bg-img']       = '';

				return $defaults;
		}

		/**
		 * Add postMessage support for site title and description for the Theme Customizer.
		 *
		 * @param GC_Customize_Manager $gc_customize Theme Customizer object.
		 */
		public function customize_register( $gc_customize ) {

			/**
			 * Sections
			 */
			require_once ADAPTIVE_ADDON_EXT_SITE_LAYOUTS_DIR . 'classes/sections/class-adaptive-site-layout-configuration.php';
		}

		/**
		 * Customizer Preview
		 */
		public function preview_scripts() {

			if ( SCRIPT_DEBUG ) {
				gc_enqueue_script( 'adaptive-ext-site-layouts-customize-preview-js', ADAPTIVE_ADDON_EXT_SITE_LAYOUTS_URL . 'assets/js/unminified/customizer-preview.js', array( 'customize-preview', 'adaptive-customizer-preview-js' ), ADAPTIVE_EXT_VER, true );
			} else {
				gc_enqueue_script( 'adaptive-ext-site-layouts-customize-preview-js', ADAPTIVE_ADDON_EXT_SITE_LAYOUTS_URL . 'assets/js/minified/customizer-preview.min.js', array( 'customize-preview', 'adaptive-customizer-preview-js' ), ADAPTIVE_EXT_VER, true );
			}
		}

	}
}

/**
 *  Kicking this off by calling 'get_instance()' method
 */
Adaptive_Ext_Site_Layouts_Loader::get_instance();
