<?php
/**
 * Styling Options for Adaptive Theme.
 *
 * @package     Adaptive
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Site_Layout_Configuration' ) ) {

	/**
	 * Register Site Layout Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Site_Layout_Configuration extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Site Layout Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Site Layout
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[site-layout]',
					'default'  => adaptive_get_option( 'site-layout' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'section'  => 'section-container-layout',
					'priority' => 5,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'title'    => __( '站点布局', 'adaptive-addon' ),
					'choices'  => array(
						'ast-full-width-layout'  => __( '全宽度', 'adaptive-addon' ),
						'ast-box-layout'         => __( '最大宽度', 'adaptive-addon' ),
						'ast-padded-layout'      => __( '填补', 'adaptive-addon' ),
						'ast-fluid-width-layout' => __( '流动', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Padded Layout Custom Width
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[site-layout-padded-width]',
					'default'           => adaptive_get_option( 'site-layout-padded-width' ),
					'type'              => 'control',
					'control'           => 'ast-slider',
					'transport'         => 'postMessage',
					'section'           => 'section-container-layout',
					'priority'          => 15,
					'title'             => __( '宽度', 'adaptive-addon' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'suffix'            => 'px',
					'input_attrs'       => array(
						'min'  => 768,
						'step' => 1,
						'max'  => 1920,
					),
					'context'           => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[site-layout]',
							'operator' => '==',
							'value'    => 'ast-padded-layout',
						),
					),
				),

				/**
				 * Option: Box Width
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[site-layout-box-width]',
					'default'     => adaptive_get_option( 'site-layout-box-width' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'section'     => 'section-container-layout',
					'priority'    => 25,
					'title'       => __( '最大宽度', 'adaptive-addon' ),
					'suffix'      => 'px',
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[site-layout]',
							'operator' => '==',
							'value'    => 'ast-box-layout',
						),
					),
					'input_attrs' => array(
						'min'  => 768,
						'step' => 1,
						'max'  => 1920,
					),
				),

				/**
				 * Option: Padded Layout Custom Width
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[site-layout-padded-pad]',
					'default'           => adaptive_get_option( 'site-layout-padded-pad' ),
					'type'              => 'control',
					'transport'         => 'postMessage',
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'section'           => 'section-container-layout',
					'priority'          => 20,
					'title'             => __( '在 Body外的空间', 'adaptive-addon' ),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
					'context'           => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[site-layout]',
							'operator' => '==',
							'value'    => 'ast-padded-layout',
						),
					),
					'linked_choices'    => true,
					'unit_choices'      => array( 'px', 'em', '%' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Box Top & Bottom Margin
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[site-layout-box-tb-margin]',
					'default'     => adaptive_get_option( 'site-layout-box-tb-margin' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'section'     => 'section-container-layout',
					'priority'    => 30,
					'divider'     => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
					'title'       => __( '上下边距', 'adaptive-addon' ),
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[site-layout]',
							'operator' => '==',
							'value'    => 'ast-box-layout',
						),
					),
					'suffix'      => 'px',
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 600,
					),
				),

				/**
				 * Layout: Fluid layout
				 */

				/**
				 * Option: Page Left & Right Padding
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[site-layout-fluid-lr-padding]',
					'default'     => adaptive_get_option( 'site-layout-fluid-lr-padding' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'section'     => 'section-container-layout',
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority'    => 35,
					'title'       => __( '左右边距', 'adaptive-addon' ),
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[site-layout]',
							'operator' => '==',
							'value'    => 'ast-fluid-width-layout',
						),
					),
					'suffix'      => 'px',
					'input_attrs' => array(
						'min'  => 1,
						'step' => 1,
						'max'  => 200,
					),
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;
		}
	}
}

new Adaptive_Site_Layout_Configuration();


