<?php
/**
 * Blog Spacing Options for our theme.
 *
 * @package     Adaptive
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Blog_Spacing_Configs' ) ) {

	/**
	 * Register Blog Spacing Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Blog_Spacing_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Blog Spacing Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Post Outside Spacing
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[blog-post-outside-spacing]',
					'default'           => adaptive_get_option( 'blog-post-outside-spacing' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'transport'         => 'postMessage',
					'section'           => 'section-blog',
					'context'           => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					'priority'          => 165,
					'title'             => __( '文章外间距', 'adaptive-addon' ),
					'linked_choices'    => true,
					'unit_choices'      => array( 'px', 'em', '%' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Post Inside Spacing
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[blog-post-inside-spacing]',
					'default'           => adaptive_get_option( 'blog-post-inside-spacing' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'transport'         => 'postMessage',
					'section'           => 'section-blog',
					'context'           => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					'priority'          => 170,
					'title'             => __( '文章内间距', 'adaptive-addon' ),
					'linked_choices'    => true,
					'unit_choices'      => array( 'px', 'em', '%' ),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Post Pagination Spacing
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[blog-post-pagination-spacing]',
					'default'           => adaptive_get_option( 'blog-post-pagination-spacing' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'transport'         => 'postMessage',
					'section'           => 'section-blog',
					'priority'          => 175,
					'title'             => __( '文章分页间距', 'adaptive-addon' ),
					'context'           => array(
						'context' => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
							adaptive_addon_builder_helper()->design_tab_config : adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[blog-pagination]',
							'operator' => '==',
							'value'    => 'number',
						),
					),
					'linked_choices'    => true,
					'unit_choices'      => array( 'px', 'em', '%' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Blog_Spacing_Configs();
