<?php
/**
 * Content Spacing Options for our theme.
 *
 * @package     Adaptive
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Container_Layout_Spacing_Configs' ) ) {

	/**
	 * Register Content Spacing Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Container_Layout_Spacing_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Content Spacing Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option - Content Space
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[container-outside-spacing]',
					'default'           => adaptive_get_option( 'container-outside-spacing' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'transport'         => 'postMessage',
					'section'           => 'section-container-layout',
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'           => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					'priority'          => 95,
					'title'             => __( '容器外间距', 'adaptive-addon' ),
					'linked_choices'    => true,
					'unit_choices'      => array( 'px', 'em', '%' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),

				/**
				 * Option - Content Space
				 */
				array(
					'name'           => ADAPTIVE_THEME_SETTINGS . '[container-inside-spacing]',
					'default'        => adaptive_get_option( 'container-inside-spacing' ),
					'type'           => 'control',
					'control'        => 'ast-responsive-spacing',
					'context'        => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					'transport'      => 'postMessage',
					'section'        => 'section-container-layout',
					'priority'       => 100,
					'title'          => __( '容器内间距', 'adaptive-addon' ),
					'linked_choices' => true,
					'unit_choices'   => array( 'px', 'em', '%' ),
					'choices'        => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
				),
			);

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				array_push(
					$_configs,
					/**
					 * Option: Container Tabs
					 */
					array(
						'name'        => 'section-container-layout-ast-context-tabs',
						'section'     => 'section-container-layout',
						'type'        => 'control',
						'control'     => 'ast-builder-header-control',
						'priority'    => 0,
						'description' => '',

					)
				);

			} else {

				array_push(
					$_configs,
					/**
					 * Option: Divider
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[content-spacing-divider]',
						'section'  => 'section-container-layout',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'title'    => __( '间距', 'adaptive-addon' ),
						'priority' => 90,
						'settings' => array(),
						'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
							adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					)
				);
			}

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Container_Layout_Spacing_Configs();
