<?php
/**
 * Single Post Spacing Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2021, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 3.5.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 3.5.0
 */
if ( ! class_exists( 'Adaptive_Customizer_Single_Post_Spacing_Configs' ) ) {

	/**
	 * Register Single Post Spacing Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Single_Post_Spacing_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Single Post Spacing Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.5.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Single Post Margin
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[single-post-inside-spacing]',
					'default'           => adaptive_get_option( 'single-post-inside-spacing' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'section'           => 'section-blog-single',
					'title'             => __( '容器内间距', 'adaptive-addon' ),
					'linked_choices'    => true,
					'transport'         => 'postMessage',
					'unit_choices'      => array( 'px', 'em', '%' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
					'priority'          => 30,
					'context'           => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by creating NEW instance.
 */
new Adaptive_Customizer_Single_Post_Spacing_Configs();
