<?php
/**
 * Site Identity Spacing Options for our theme.
 *
 * @package     Adaptive
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Customizer Sanitizes
 *
 * @since 1.4.3
 */
if ( ! class_exists( 'Adaptive_Customizer_Site_Identity_Spacing_Configs' ) ) {

	/**
	 * Register Site Identity Spacing Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Customizer_Site_Identity_Spacing_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Site Identity Spacing Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			if ( adaptive_addon_check_theme_3_5_0_version() ) {

				$_configs = array(

					/**
					 * Option: Divider
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[divider-section-site-identity-spacing]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => 'title_tagline',
						'title'    => __( '间距', 'adaptive-addon' ),
						'context'  => array(
							'relation' => 'AND',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'relation' => 'OR',
								array(
									'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-title]',
									'operator' => '!=',
									'value'    => 0,
								),
								array(
									'setting'  => 'custom_logo',
									'operator' => '!=',
									'value'    => '',
								),
							),
						),
						'priority' => 50,
						'settings' => array(),
					),

					/**
					 * Option - Header Space
					 */
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[site-identity-spacing]',
						'default'           => adaptive_get_option( 'site-identity-spacing' ),
						'type'              => 'control',
						'transport'         => 'postMessage',
						'control'           => 'ast-responsive-spacing',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
						'section'           => 'title_tagline',
						'priority'          => 50,
						'title'             => __( '网站身份空间', 'adaptive-addon' ),
						'context'           => array(
							'relation' => 'AND',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'relation' => 'OR',
								array(
									'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-title]',
									'operator' => '!=',
									'value'    => 0,
								),
								array(
									'setting'  => 'custom_logo',
									'operator' => '!=',
									'value'    => '',
								),
							),
						),
						'linked_choices'    => true,
						'unit_choices'      => array( 'px', 'em', '%' ),
						'choices'           => array(
							'top'    => __( '顶部', 'adaptive-addon' ),
							'right'  => __( '右', 'adaptive-addon' ),
							'bottom' => __( '底部', 'adaptive-addon' ),
							'left'   => __( '左', 'adaptive-addon' ),
						),
					),
				);

			} else {
				$_configs = array(

					/**
					 * Option: Divider
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[divider-section-site-identity-spacing]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => 'title_tagline',
						'title'    => __( '间距', 'adaptive-addon' ),
						'context'  => array(
							'relation' => 'AND',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'relation' => 'OR',
								array(
									'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
									'setting-key' => 'desktop',
									'operator'    => '!=',
									'value'       => 0,
								),
								array(
									'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
									'setting-key' => 'tablet',
									'operator'    => '!=',
									'value'       => 0,
								),
								array(
									'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
									'setting-key' => 'mobile',
									'operator'    => '!=',
									'value'       => 0,
								),
								array(
									'setting'  => 'custom_logo',
									'operator' => '!=',
									'value'    => '',
								),
							),
						),
						'priority' => 50,
						'settings' => array(),
					),

					/**
					 * Option - Header Space
					 */
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[site-identity-spacing]',
						'default'           => adaptive_get_option( 'site-identity-spacing' ),
						'type'              => 'control',
						'transport'         => 'postMessage',
						'control'           => 'ast-responsive-spacing',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
						'section'           => 'title_tagline',
						'priority'          => 50,
						'title'             => __( '网站身份空间', 'adaptive-addon' ),
						'context'           => array(
							'relation' => 'AND',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'relation' => 'OR',
								array(
									'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
									'setting-key' => 'desktop',
									'operator'    => '!=',
									'value'       => 0,
								),
								array(
									'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
									'setting-key' => 'tablet',
									'operator'    => '!=',
									'value'       => 0,
								),
								array(
									'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
									'setting-key' => 'mobile',
									'operator'    => '!=',
									'value'       => 0,
								),
								array(
									'setting'  => 'custom_logo',
									'operator' => '!=',
									'value'    => '',
								),
							),
						),
						'linked_choices'    => true,
						'unit_choices'      => array( 'px', 'em', '%' ),
						'choices'           => array(
							'top'    => __( '顶部', 'adaptive-addon' ),
							'right'  => __( '右', 'adaptive-addon' ),
							'bottom' => __( '底部', 'adaptive-addon' ),
							'left'   => __( '左', 'adaptive-addon' ),
						),
					),
				);
			}

			return array_merge( $configurations, $_configs );
		}
	}
}

/**
 * Kicking this off by calling 'get_instance()' method
 */
new Adaptive_Customizer_Site_Identity_Spacing_Configs();
