<?php
/**
 * Sticky Header Extension
 *
 * @package Adaptive Addon
 */

define( 'ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR', ADAPTIVE_EXT_DIR . 'addons/sticky-header/' );
define( 'ADAPTIVE_ADDON_EXT_STICKY_HEADER_URI', ADAPTIVE_EXT_URI . 'addons/sticky-header/' );

if ( ! class_exists( 'Adaptive_Ext_Sticky_Header' ) ) {

	/**
	 * Sticky Header Initial Setup
	 *
	 * @since 1.0.0
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Ext_Sticky_Header {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Member Variable
		 *
		 * @var instance
		 */
		private static $instance;

		/**
		 *  Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Constructor function that initializes required actions and hooks
		 */
		public function __construct() {

			require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/class-adaptive-ext-sticky-header-loader.php';
			require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/class-adaptive-ext-sticky-header-markup.php';

			// Include front end files.
			if ( ! is_admin() ) {
				require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/dynamic.css.php';
				// Check Header Sections is activated.
				require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/header-sections-dynamic.css.php';

				// Check Site Layouts is activated.
				if ( Adaptive_Ext_Extension::is_active( 'site-layouts' ) ) {
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/site-layouts-dynamic.css.php';
				}

				if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

					// Sticky Header Button CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/button-dynamic.css.php';

					// Sticky Header Social CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/social-dynamic.css.php';

					// Sticky Header Search CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/search-dynamic.css.php';

					// Sticky Header HTML CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/html-dynamic.css.php';

					if ( ! adaptive_addon_remove_widget_design_options() ) {
						// Sticky Header Widget CSS.
						require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/widget-dynamic.css.php';
					}

					// Sticky Header divider CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/divider-dynamic.css.php';

					// Sticky Header language-switcher CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/language-switcher-dynamic.css.php';

					// Sticky Account divider CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/account-dynamic.css.php';

					// Sticky Menu Toggle CSS.
					require_once ADAPTIVE_ADDON_EXT_STICKY_HEADER_DIR . 'classes/dynamic-css/toggle-dynamic.css.php';
				}
			}
		}
	}

	/**
	 *  Kicking this off by calling 'get_instance()' method
	 */
	Adaptive_Ext_Sticky_Header::get_instance();

}
