<?php
/**
 * Transparent Header - Dynamic CSS
 *
 * @package Adaptive Addon
 */

add_filter( 'adaptive_addon_dynamic_css', 'adaptive_ext_sticky_header_dynamic_css', 30 );

/**
 * Dynamic CSS
 *
 * @param  string $dynamic_css          Adaptive Dynamic CSS.
 * @param  string $dynamic_css_filtered Adaptive Dynamic CSS Filters.
 * @return string
 */
function adaptive_ext_sticky_header_dynamic_css( $dynamic_css, $dynamic_css_filtered = '' ) {

	/**
	 * Set colors
	 *
	 * If colors extension is_active then get color from it.
	 * Else set theme default colors.
	 */
	$stick_header            = adaptive_get_option_meta( 'stick-header-meta' );
	$stick_header_main_meta  = adaptive_get_option_meta( 'header-main-stick-meta' );
	$stick_header_above_meta = adaptive_get_option_meta( 'header-above-stick-meta' );
	$stick_header_below_meta = adaptive_get_option_meta( 'header-below-stick-meta' );

	$stick_header_main  = adaptive_get_option( 'header-main-stick' );
	$stick_header_above = adaptive_get_option( 'header-above-stick' );
	$stick_header_below = adaptive_get_option( 'header-below-stick' );

	$sticky_header_style   = adaptive_get_option( 'sticky-header-style' );
	$sticky_hide_on_scroll = adaptive_get_option( 'sticky-hide-on-scroll' );

	$sticky_header_logo_width = adaptive_get_option( 'sticky-header-logo-width' );
	// Old Log Width Option that we are no loginer using it our theme.
	$header_logo_width            = adaptive_get_option( 'ast-header-logo-width' );
	$header_responsive_logo_width = adaptive_get_option( 'ast-header-responsive-logo-width' );

	$site_layout = adaptive_get_option( 'site-layout' );

	$header_color_site_title = '#222';
	$text_color              = adaptive_get_option( 'text-color' );
	$link_color              = adaptive_get_option( 'link-color' );

	$sticky_header_logo_different = adaptive_get_option( 'different-sticky-logo' );
	$sticky_header_logo           = adaptive_get_option( 'sticky-header-logo' );

	// Compatible with header full width.
	$header_break_point = adaptive_header_break_point();
	$adaptive_header_width = adaptive_get_option( 'header-main-layout-width' );

	// Sticky Header Background colors.
	$text_color = adaptive_get_option( 'text-color' );
	$link_color = adaptive_get_option( 'link-color' );

	$desktop_sticky_header_bg_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-bg-color-responsive' ), 'desktop' );
	$tablet_sticky_header_bg_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-bg-color-responsive' ), 'tablet' );
	$mobile_sticky_header_bg_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-bg-color-responsive' ), 'mobile' );

	$sticky_header_menu_bg_color = adaptive_get_option( 'sticky-header-menu-bg-color-responsive' );

	$desktop_sticky_header_color_site_title = adaptive_get_prop( adaptive_get_option( 'sticky-header-color-site-title-responsive' ), 'desktop', '#222' );
	$tablet_sticky_header_color_site_title  = adaptive_get_prop( adaptive_get_option( 'sticky-header-color-site-title-responsive' ), 'tablet' );
	$mobile_sticky_header_color_site_title  = adaptive_get_prop( adaptive_get_option( 'sticky-header-color-site-title-responsive' ), 'mobile' );

	$sticky_header_color_h_site_title = adaptive_get_option( 'sticky-header-color-h-site-title-responsive' );

	$desktop_sticky_header_color_site_tagline = adaptive_get_prop( adaptive_get_option( 'sticky-header-color-site-tagline-responsive' ), 'desktop', $text_color );
	$tablet_sticky_header_color_site_tagline  = adaptive_get_prop( adaptive_get_option( 'sticky-header-color-site-tagline-responsive' ), 'tablet' );
	$mobile_sticky_header_color_site_tagline  = adaptive_get_prop( adaptive_get_option( 'sticky-header-color-site-tagline-responsive' ), 'mobile' );

	$desktop_sticky_primary_menu_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu-color-responsive' ), 'desktop' );
	$tablet_sticky_primary_menu_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu-color-responsive' ), 'tablet' );
	$mobile_sticky_primary_menu_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu-color-responsive' ), 'mobile' );

	$desktop_sticky_primary_menu_h_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu-h-color-responsive' ), 'desktop' );
	$tablet_sticky_primary_menu_h_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu-h-color-responsive' ), 'tablet' );
	$mobile_sticky_primary_menu_h_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu-h-color-responsive' ), 'mobile' );

	$sticky_header_menu_h_a_bg_color = adaptive_get_option( 'sticky-header-menu-h-a-bg-color-responsive' );

	$sticky_header_submenu_bg_color      = adaptive_get_option( 'sticky-header-submenu-bg-color-responsive' );
	$sticky_primary_submenu_color        = adaptive_get_option( 'sticky-header-submenu-color-responsive' );
	$sticky_primary_submenu_h_color      = adaptive_get_option( 'sticky-header-submenu-h-color-responsive' );
	$sticky_primary_submenu_h_a_bg_color = adaptive_get_option( 'sticky-header-submenu-h-a-bg-color-responsive' );

	$sticky_header_content_section_text_color   = adaptive_get_option( 'sticky-header-content-section-text-color-responsive' );
	$sticky_header_content_section_link_color   = adaptive_get_option( 'sticky-header-content-section-link-color-responsive' );
	$sticky_header_content_section_link_h_color = adaptive_get_option( 'sticky-header-content-section-link-h-color-responsive' );

	$header_custom_button_style                 = adaptive_get_option( 'header-main-rt-section-button-style' );
	$header_custom_sticky_button_text_color     = adaptive_get_option( 'header-main-rt-sticky-section-button-text-color' );
	$header_custom_sticky_button_text_h_color   = adaptive_get_option( 'header-main-rt-sticky-section-button-text-h-color' );
	$header_custom_sticky_button_back_color     = adaptive_get_option( 'header-main-rt-sticky-section-button-back-color' );
	$header_custom_sticky_button_back_h_color   = adaptive_get_option( 'header-main-rt-sticky-section-button-back-h-color' );
	$header_custom_sticky_button_spacing        = adaptive_get_option( 'header-main-rt-sticky-section-button-padding' );
	$header_custom_sticky_button_radius         = adaptive_get_option( 'header-main-rt-sticky-section-button-border-radius' );
	$header_custom_sticky_button_border_color   = adaptive_get_option( 'header-main-rt-sticky-section-button-border-color' );
	$header_custom_sticky_button_border_h_color = adaptive_get_option( 'header-main-rt-sticky-section-button-border-h-color' );
	$header_custom_sticky_button_border_size    = adaptive_get_option( 'header-main-rt-sticky-section-button-border-size' );

	$default_header_site_title_color       = adaptive_get_option( 'header-color-site-title' );
	$default_header_site_title_hover_color = adaptive_get_option( 'header-color-h-site-title' );
	$default_header_site_tagline_color     = adaptive_get_option( 'header-color-site-tagline' );

	if ( ! $stick_header_main && ! $stick_header_above && ! $stick_header_below && ( 'disabled' !== $stick_header && empty( $stick_header ) && ( empty( $stick_header_above_meta ) || empty( $stick_header_below_meta ) || empty( $stick_header_main_meta ) ) ) ) {
		return $dynamic_css;
	}

	$parse_css = '';

	/**
	 * Sticky Header
	 *
	 * [1]. Apply default colors from theme for sticky header.
	 * [2]. Hide Sticky Header logo if Sticky Header logo is not enabled.
	 * [3]. Sticky Header Logo responsive widths.
	 * [4]. Compatible with Header Width.
	 * [5]. Stciky Header & Sticky Header Primary menu background color.
	 */

	/**
	 * [1]. Apply default colors from theme for sticky header.
	 */
	if ( ! Adaptive_Ext_Extension::is_active( 'colors-and-background' ) ) {
		$css_output = array(
			'#ast-fixed-header .main-header-bar .site-title a, #ast-fixed-header .main-header-bar .site-title a:focus, #ast-fixed-header .main-header-bar .site-title a:hover, #ast-fixed-header .main-header-bar .site-title a:visited, .main-header-bar.ast-sticky-active .site-title a, .main-header-bar.ast-sticky-active .site-title a:focus, .main-header-bar.ast-sticky-active .site-title a:hover, .main-header-bar.ast-sticky-active .site-title a:visited' => array(
				'color' => esc_attr( $header_color_site_title ),
			),
			'#ast-fixed-header .main-header-bar .site-description, .main-header-bar.ast-sticky-active .site-description' => array(
				'color' => esc_attr( $text_color ),
			),
			'#ast-fixed-header .main-header-menu > .menu-item.current-menu-item > .menu-link, #ast-fixed-header .main-header-menu >.menu-item.current-menu-ancestor > .menu-link, .main-header-bar.ast-sticky-active .main-header-menu > .menu-item.current-menu-item > .menu-link, .main-header-bar.ast-sticky-active .main-header-menu >.menu-item.current-menu-ancestor > .menu-link' => array(
				'color' => esc_attr( $link_color ),
			),
			'#ast-fixed-header .main-header-menu, #ast-fixed-header .main-header-menu > .menu-item > .menu-link, #ast-fixed-header .ast-masthead-custom-menu-items, #ast-fixed-header .ast-masthead-custom-menu-items a, .main-header-bar.ast-sticky-active, .main-header-bar.ast-sticky-active .main-header-menu > .menu-item > .menu-link, .main-header-bar.ast-sticky-active .ast-masthead-custom-menu-items, .main-header-bar.ast-sticky-active .ast-masthead-custom-menu-items a' => array(
				'color' => esc_attr( $text_color ),
			),
			'#ast-fixed-header .main-header-menu .menu-link:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .menu-link, #ast-fixed-header .main-header-menu .menu-item.focus > .menu-link, .main-header-bar.ast-sticky-active .main-header-menu .menu-item:hover > .menu-link, .main-header-bar.ast-sticky-active .main-header-menu .menu-item.focus > .menu-link' => array(
				'color' => esc_attr( $link_color ),
			),
			'#ast-fixed-header .main-header-menu .ast-masthead-custom-menu-items a:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .ast-menu-toggle, #ast-fixed-header .main-header-menu .menu-item.focus > .ast-menu-toggle,.main-header-bar.ast-sticky-active .main-header-menu .menu-item:hover > .ast-menu-toggle,.main-header-bar.ast-sticky-active .main-header-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $link_color ),
			),
		);

		/* Parse CSS from array() */
		$parse_css .= adaptive_parse_css( $css_output );
	}

	/**
	 * [2]. Hide Sticky Header logo if Sticky Header logo is not enabled.
	 */
	if ( '0' === $sticky_header_logo_different && '' != $sticky_header_logo ) {
		$css_output = array(
			'.ast-sticky-active .site-logo-img .custom-logo' => array(
				'display' => 'none',
			),
		);
		$parse_css .= adaptive_parse_css( $css_output );
	}

	/**
	 * [3]. Sticky Header Logo responsive widths
	 */
	// Desktop Sticky Header Logo width.
	$desktop_css_output = array(
		'#masthead .site-logo-img .sticky-custom-logo .adaptive-logo-svg, .site-logo-img .sticky-custom-logo .adaptive-logo-svg, .ast-sticky-main-shrink .ast-sticky-shrunk .site-logo-img .adaptive-logo-svg' => array(
			'width' => adaptive_get_css_value( $sticky_header_logo_width['desktop'], 'px' ),
		),
		'.site-logo-img .sticky-custom-logo img' => array(
			'max-width' => adaptive_get_css_value( $sticky_header_logo_width['desktop'], 'px' ),
		),
	);
	$parse_css         .= adaptive_parse_css( $desktop_css_output );

	// Tablet Sticky Header Logo width.
	$tablet_css_output = array(
		'#masthead .site-logo-img .sticky-custom-logo .adaptive-logo-svg, .site-logo-img .sticky-custom-logo .adaptive-logo-svg, .ast-sticky-main-shrink .ast-sticky-shrunk .site-logo-img .adaptive-logo-svg' => array(
			'width' => adaptive_get_css_value( $sticky_header_logo_width['tablet'], 'px' ),
		),
		'.site-logo-img .sticky-custom-logo img' => array(
			'max-width' => adaptive_get_css_value( $sticky_header_logo_width['tablet'], 'px' ),
		),
	);
	$parse_css        .= adaptive_parse_css( $tablet_css_output, '', adaptive_addon_get_tablet_breakpoint() );

	// Mobile Sticky Header Logo width.
	$mobile_css_output = array(
		'#masthead .site-logo-img .sticky-custom-logo .adaptive-logo-svg, .site-logo-img .sticky-custom-logo .adaptive-logo-svg, .ast-sticky-main-shrink .ast-sticky-shrunk .site-logo-img .adaptive-logo-svg' => array(
			'width' => adaptive_get_css_value( $sticky_header_logo_width['mobile'], 'px' ),
		),
		'.site-logo-img .sticky-custom-logo img' => array(
			'max-width' => adaptive_get_css_value( $sticky_header_logo_width['mobile'], 'px' ),
		),
	);
	$parse_css        .= adaptive_parse_css( $mobile_css_output, '', adaptive_addon_get_mobile_breakpoint( '1' ) );

	// Theme Main Logo width option for responsive devices.
	if ( is_array( $header_responsive_logo_width ) ) {
		/* Responsive main logo width */
		$responsive_logo_output = array(
			'#masthead .site-logo-img .adaptive-logo-svg, .ast-header-break-point #ast-fixed-header .site-logo-img .custom-logo-link img ' => array(
				'max-width' => adaptive_get_css_value( $header_responsive_logo_width['desktop'], 'px' ),
			),
		);
		$parse_css             .= adaptive_parse_css( $responsive_logo_output );

		$responsive_logo_output_tablet = array(
			'#masthead .site-logo-img .adaptive-logo-svg, .ast-header-break-point #ast-fixed-header .site-logo-img .custom-logo-link img ' => array(
				'max-width' => adaptive_get_css_value( $header_responsive_logo_width['tablet'], 'px' ),
			),
		);
		$parse_css                    .= adaptive_parse_css( $responsive_logo_output_tablet, '', adaptive_addon_get_tablet_breakpoint() );

		$responsive_logo_output_mobile = array(
			'#masthead .site-logo-img .adaptive-logo-svg, .ast-header-break-point #ast-fixed-header .site-logo-img .custom-logo-link img ' => array(
				'max-width' => adaptive_get_css_value( $header_responsive_logo_width['mobile'], 'px' ),
			),
		);
		$parse_css                    .= adaptive_parse_css( $responsive_logo_output_mobile, '', adaptive_addon_get_mobile_breakpoint( '1' ) );
	} else {
		/* Old main logo width */
		$logo_output = array(
			'#masthead .site-logo-img .adaptive-logo-svg' => array(
				'width' => adaptive_get_css_value( $header_logo_width, 'px' ),
			),
		);
		/* Parse CSS from array() */
		$parse_css .= adaptive_parse_css( $logo_output );
	}

	/**
	 * [4]. Compatible with Header Width
	 */
	if ( 'content' != $adaptive_header_width ) {

		$general_global_responsive = array(
			'#ast-fixed-header .ast-container' => array(
				'max-width'     => '100%',
				'padding-left'  => '35px',
				'padding-right' => '35px',
			),
		);
		$padding_below_breakpoint  = array(
			'#ast-fixed-header .ast-container' => array(
				'padding-left'  => '20px',
				'padding-right' => '20px',
			),
		);

		/* Parse CSS from array()*/
		$parse_css .= adaptive_parse_css( $general_global_responsive );
		$parse_css .= adaptive_parse_css( $padding_below_breakpoint, '', $header_break_point );
	}

	/**
	 * [5]. Stciky Header & Sticky Header Primary menu colors.
	 */
	if ( 'none' === $sticky_header_style && ! $sticky_hide_on_scroll ) {
		$desktop_css_output = array(

			/**
			 * Header
			 */
			'.ast-transparent-header.ast-primary-sticky-header-active .main-header-bar-wrap .main-header-bar, .ast-primary-sticky-header-active .main-header-bar-wrap .main-header-bar, .ast-primary-sticky-header-active.ast-header-break-point .main-header-bar-wrap .main-header-bar, .ast-transparent-header.ast-primary-sticky-enabled .ast-main-header-wrap .main-header-bar.ast-header-sticked, .ast-primary-sticky-enabled .ast-main-header-wrap .main-header-bar.ast-header-sticked, .ast-primary-sticky-header-ast-primary-sticky-enabled .ast-main-header-wrap .main-header-bar.ast-header-sticked'                      => array(
				'background' => esc_attr( $desktop_sticky_header_bg_color ),
			),

			/**
			 * Primary Header Menu
			 */
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu, .ast-flyout-menu-enable.ast-header-break-point .main-header-bar-navigation .site-navigation, .ast-fullscreen-menu-enable.ast-header-break-point .main-header-bar-navigation .site-navigation' => array(
				'background-color' => esc_attr( $sticky_header_menu_bg_color['desktop'] ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .menu-item:hover > .menu-link, .ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .main-header-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $desktop_sticky_primary_menu_h_color ),
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['desktop'] ),
			),
			'.ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item.current-menu-item > .menu-link:hover, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item.current-menu-item > .menu-link:hover, .ast-header-custom-item a:hover, .ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item > .menu-link:hover, .ast-primary-sticky-header-active .main-header-menu, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item > .menu-link:hover .ast-primary-sticky-header-active .main-header-menu .menu-item.focus > .menu-link, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link:hover, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link:focus' => array(
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['desktop'] ),
				'color'            => esc_attr( $desktop_sticky_primary_menu_h_color ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .ast-masthead-custom-menu-items a:hover, .ast-primary-sticky-header-active .main-header-menu .menu-item:hover > .ast-menu-toggle, .ast-primary-sticky-header-active .main-header-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $desktop_sticky_primary_menu_h_color ),
			),
			'.ast-primary-sticky-header-active .main-header-menu, .ast-primary-sticky-header-active .main-header-menu .menu-link, .ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item > .menu-link, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item > .menu-link, .ast-primary-sticky-header-active .ast-header-custom-item, .ast-header-custom-item a, .ast-primary-sticky-header-active li.ast-masthead-custom-menu-items, .ast-primary-sticky-header-active li.ast-masthead-custom-menu-items a, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link' => array(
				'color' => esc_attr( $desktop_sticky_primary_menu_color ),
			),
			'.ast-primary-sticky-header-active .ast-masthead-custom-menu-items .ast-inline-search form' => array(
				'border-color' => esc_attr( $desktop_sticky_primary_menu_color ),
			),

			/**
			 * Primary Submenu
			 */
			'.ast-primary-sticky-header-active .main-navigation ul .sub-menu, .ast-header-break-point.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu' => array(
				'background-color' => esc_attr( $sticky_header_submenu_bg_color['desktop'] ),
			),
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-link, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_color['desktop'] ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-link:hover, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item:hover > .menu-link, .ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-item.focus > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['desktop'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['desktop'] ),
			),
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item:hover > .ast-menu-toggle, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_h_color['desktop'] ),
			),
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['desktop'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['desktop'] ),
			),

			// Content Section text color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget-title' => array(
				'color' => esc_attr( $sticky_header_content_section_text_color['desktop'] ),
			),
			// Content Section link color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items a, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget a' => array(
				'color' => esc_attr( $sticky_header_content_section_link_color['desktop'] ),
			),
			// Content Section link hover color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items a:hover, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget a:hover' => array(
				'color' => esc_attr( $sticky_header_content_section_link_h_color['desktop'] ),
			),
		);

		$old_sticky_header_desktop_output = array(
			'.ast-primary-sticky-header-active .site-title a, .ast-primary-sticky-header-active .site-title a:focus, .ast-primary-sticky-header-active .site-title a:hover, .ast-primary-sticky-header-active .site-title a:visited' => array(
				'color' => esc_attr( $desktop_sticky_header_color_site_title ),
			),
			'.ast-primary-sticky-header-active .site-header .site-title a:hover'           => array(
				'color' => esc_attr( $sticky_header_color_h_site_title['desktop'] ),
			),
			'.ast-primary-sticky-header-active .site-header .site-description'             => array(
				'color' => esc_attr( $desktop_sticky_header_color_site_tagline ),
			),
		);

		$tablet_css_output = array(

			/**
			 * Header
			 */
			'.ast-transparent-header.ast-primary-sticky-header-active .ast-main-header-wrap .main-header-bar, .ast-primary-sticky-header-active .ast-main-header-wrap .main-header-bar, .ast-primary-sticky-header-active.ast-header-break-point .ast-main-header-wrap .main-header-bar'                      => array(
				'background' => esc_attr( $tablet_sticky_header_bg_color ),
			),
			/**
			 * Primary Header Menu
			 */
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu, .ast-flyout-menu-enable.ast-header-break-point .main-header-bar-navigation .site-navigation, .ast-fullscreen-menu-enable.ast-header-break-point .main-header-bar-navigation .site-navigation' => array(
				'background-color' => esc_attr( $sticky_header_menu_bg_color['tablet'] ),
			),
			'.ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .main-header-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $tablet_sticky_primary_menu_h_color ),
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['tablet'] ),
			),
			'.ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item.current-menu-item > .menu-link:hover, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item.current-menu-item > .menu-link:hover, .ast-header-custom-item a:hover, .ast-primary-sticky-header-active .main-header-menu .menu-item:hover > .menu-link, .ast-primary-sticky-header-active .main-header-menu .menu-item.focus > .menu-link, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link:hover, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link:focus' => array(
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['tablet'] ),
				'color'            => esc_attr( $tablet_sticky_primary_menu_h_color ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .ast-masthead-custom-menu-items a:hover, .ast-primary-sticky-header-active .main-header-menu .menu-item:hover > .ast-menu-toggle, .ast-primary-sticky-header-active .main-header-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $tablet_sticky_primary_menu_h_color ),
			),

			'.ast-primary-sticky-header-active .main-header-menu, .ast-primary-sticky-header-active .main-header-menu .menu-link, .ast-primary-sticky-header-active .ast-header-custom-item, .ast-header-custom-item a, .ast-primary-sticky-header-active li.ast-masthead-custom-menu-items, .ast-primary-sticky-header-active li.ast-masthead-custom-menu-items a, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link' => array(
				'color' => esc_attr( $tablet_sticky_primary_menu_color ),
			),

			'.ast-primary-sticky-header-active .ast-masthead-custom-menu-items .ast-inline-search form' => array(
				'border-color' => esc_attr( $tablet_sticky_primary_menu_color ),
			),
			/**
			 * Primary Submenu
			 */
			'.ast-primary-sticky-header-active .main-navigation ul .sub-menu, .ast-header-break-point.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu' => array(
				'background-color' => esc_attr( $sticky_header_submenu_bg_color['tablet'] ),
			),
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-link, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_color['tablet'] ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-link:hover, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item:hover > .menu-link, .ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-item.focus > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['tablet'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['tablet'] ),
			),
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item:hover > .ast-menu-toggle, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_h_color['tablet'] ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['tablet'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['tablet'] ),
			),

			// Content Section text color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget-title' => array(
				'color' => esc_attr( $sticky_header_content_section_text_color['tablet'] ),
			),
			// Content Section link color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items a, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget a' => array(
				'color' => esc_attr( $sticky_header_content_section_link_color['tablet'] ),
			),
			// Content Section link hover color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items a:hover, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget a:hover' => array(
				'color' => esc_attr( $sticky_header_content_section_link_h_color['tablet'] ),
			),
		);

		$old_sticky_header_tablet_output = array(
			'.ast-primary-sticky-header-active .site-title a, .ast-primary-sticky-header-active .site-title a:focus, .ast-primary-sticky-header-active .site-title a:hover, .ast-primary-sticky-header-active .site-title a:visited' => array(
				'color' => esc_attr( $tablet_sticky_header_color_site_title ),
			),
			'.ast-primary-sticky-header-active .site-header .site-title a:hover'           => array(
				'color' => esc_attr( $sticky_header_color_h_site_title['tablet'] ),
			),
			'.ast-primary-sticky-header-active .site-header .site-description'             => array(
				'color' => esc_attr( $tablet_sticky_header_color_site_tagline ),
			),
		);

		$mobile_css_output = array(

			/**
			 * Header
			 */
			'.ast-transparent-header.ast-primary-sticky-header-active .ast-main-header-wrap .main-header-bar, .ast-primary-sticky-header-active .ast-main-header-wrap .main-header-bar, .ast-primary-sticky-header-active.ast-header-break-point .ast-main-header-wrap .main-header-bar'                      => array(
				'background' => esc_attr( $mobile_sticky_header_bg_color ),
			),
			/**
			 * Primary Header Menu
			 */
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu, .ast-flyout-menu-enable.ast-header-break-point .main-header-bar-navigation .site-navigation, .ast-fullscreen-menu-enable.ast-header-break-point .main-header-bar-navigation .site-navigation' => array(
				'background-color' => esc_attr( $sticky_header_menu_bg_color['mobile'] ),
			),
			'.ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .main-header-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $mobile_sticky_primary_menu_h_color ),
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['mobile'] ),
			),
			'.ast-primary-sticky-header-active .ast-builder-menu-1 .main-header-menu .menu-item.current-menu-item > .menu-link:hover, .ast-primary-sticky-header-active .ast-builder-menu-2 .main-header-menu .menu-item.current-menu-item > .menu-link:hover, .ast-header-custom-item a:hover, .ast-primary-sticky-header-active .main-header-menu .menu-item:hover > .menu-link, .ast-primary-sticky-header-active .main-header-menu .menu-item.focus > .menu-link, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link:hover, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link:focus' => array(
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['mobile'] ),
				'color'            => esc_attr( $mobile_sticky_primary_menu_h_color ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .ast-masthead-custom-menu-items a:hover, .ast-primary-sticky-header-active .main-header-menu .menu-item:hover > .ast-menu-toggle, .ast-primary-sticky-header-active .main-header-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $mobile_sticky_primary_menu_h_color ),
			),

			'.ast-primary-sticky-header-active .main-header-menu, .ast-primary-sticky-header-active .main-header-menu .menu-link, .ast-primary-sticky-header-active .ast-header-custom-item, .ast-header-custom-item a, .ast-primary-sticky-header-active li.ast-masthead-custom-menu-items, .ast-primary-sticky-header-active li.ast-masthead-custom-menu-items a, .ast-primary-sticky-header-active.ast-advanced-headers .main-header-menu > .menu-item > .menu-link' => array(
				'color' => esc_attr( $mobile_sticky_primary_menu_color ),
			),

			'.ast-primary-sticky-header-active .ast-masthead-custom-menu-items .ast-inline-search form' => array(
				'border-color' => esc_attr( $mobile_sticky_primary_menu_color ),
			),
			/**
			 * Primary Submenu
			 */
			'.ast-primary-sticky-header-active .main-navigation ul .sub-menu, .ast-header-break-point.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu' => array(
				'background-color' => esc_attr( $sticky_header_submenu_bg_color['mobile'] ),
			),
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-link, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_color['mobile'] ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-link:hover, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item:hover > .menu-link, .ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-item.focus > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['mobile'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['mobile'] ),
			),
			'.ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item:hover > .ast-menu-toggle, .ast-primary-sticky-header-active .main-header-bar-navigation .main-header-menu .sub-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_h_color['mobile'] ),
			),
			'.ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-item.current-menu-item > .menu-link, .ast-primary-sticky-header-active .main-header-menu .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['mobile'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['mobile'] ),
			),

			// Content Section text color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget-title' => array(
				'color' => esc_attr( $sticky_header_content_section_text_color['mobile'] ),
			),
			// Content Section link color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items a, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget a' => array(
				'color' => esc_attr( $sticky_header_content_section_link_color['mobile'] ),
			),
			// Content Section link hover color.
			'.ast-primary-sticky-header-active div.ast-masthead-custom-menu-items a:hover, .ast-primary-sticky-header-active div.ast-masthead-custom-menu-items .widget a:hover' => array(
				'color' => esc_attr( $sticky_header_content_section_link_h_color['mobile'] ),
			),
		);

		$old_sticky_header_mobile_output = array(
			'.ast-primary-sticky-header-active .site-title a, .ast-primary-sticky-header-active .site-title a:focus, .ast-primary-sticky-header-active .site-title a:hover, .ast-primary-sticky-header-active .site-title a:visited' => array(
				'color' => esc_attr( $mobile_sticky_header_color_site_title ),
			),
			'.ast-primary-sticky-header-active .site-header .site-title a:hover'           => array(
				'color' => esc_attr( $sticky_header_color_h_site_title['mobile'] ),
			),
			'.ast-primary-sticky-header-active .site-header .site-description'             => array(
				'color' => esc_attr( $mobile_sticky_header_color_site_tagline ),
			),
		);

		if ( false === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
			$desktop_css_output = array_merge( $desktop_css_output, $old_sticky_header_desktop_output );
			$tablet_css_output  = array_merge( $tablet_css_output, $old_sticky_header_tablet_output );
			$mobile_css_output  = array_merge( $mobile_css_output, $old_sticky_header_mobile_output );
		}
	} else {
		// Only when Fixed Header Merkup added.
		$desktop_css_output = array(

			/**
			 * Header
			 */
			'#ast-fixed-header .site-title a, #ast-fixed-header .site-title a:focus, #ast-fixed-header .site-title a:hover, #ast-fixed-header .site-title a:visited' => array(
				'color' => esc_attr( $desktop_sticky_header_color_site_title ),
			),
			'#ast-fixed-header.site-header .site-title a:hover' => array(
				'color' => esc_attr( $sticky_header_color_h_site_title['desktop'] ),
			),
			'#ast-fixed-header.site-header .site-description' => array(
				'color' => esc_attr( $desktop_sticky_header_color_site_tagline ),
			),
			'.ast-transparent-header #ast-fixed-header .main-header-bar, .ast-transparent-header.ast-primary-sticky-enabled .ast-main-header-wrap .main-header-bar.ast-header-sticked, .ast-primary-sticky-enabled .ast-main-header-wrap .main-header-bar.ast-header-sticked, .ast-primary-sticky-header-ast-primary-sticky-enabled .ast-main-header-wrap .main-header-bar.ast-header-sticked, #ast-fixed-header .main-header-bar, #ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search .search-field, #ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search .search-field:focus' => array(
				'background' => esc_attr( $desktop_sticky_header_bg_color ),
			),
			/**
			 * Primary Header Menu
			 */
			'#ast-fixed-header .main-header-menu' => array(
				'background' => esc_attr( $sticky_header_menu_bg_color['desktop'] ),
			),
			'#ast-fixed-header .main-header-menu .menu-item.current-menu-item > .menu-link, #ast-fixed-header .main-header-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $desktop_sticky_primary_menu_h_color ),
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['desktop'] ),
			),
			'#ast-fixed-header .main-header-menu .menu-link:hover, .ast-header-custom-item a:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .menu-link, #ast-fixed-header .main-header-menu .menu-item.focus > .menu-link' => array(
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['desktop'] ),
				'color'            => esc_attr( $desktop_sticky_primary_menu_h_color ),
			),
			'#ast-fixed-header .main-header-menu .ast-masthead-custom-menu-items a:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .ast-menu-toggle, #ast-fixed-header .main-header-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $desktop_sticky_primary_menu_h_color ),
			),

			'#ast-fixed-header .main-header-menu, #ast-fixed-header .main-header-menu .menu-link, #ast-fixed-header .ast-header-custom-item, .ast-header-custom-item a, #ast-fixed-header li.ast-masthead-custom-menu-items, #ast-fixed-header li.ast-masthead-custom-menu-items a' => array(
				'color' => esc_attr( $desktop_sticky_primary_menu_color ),
			),

			'#ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search form' => array(
				'border-color' => esc_attr( $desktop_sticky_primary_menu_color ),
			),
			/**
			 * Primary Submenu
			 */
			'#ast-fixed-header .main-navigation ul .sub-menu, .ast-header-break-point#ast-fixed-header .main-header-menu .sub-menu' => array(
				'background-color' => esc_attr( $sticky_header_submenu_bg_color['desktop'] ),
			),
			'#ast-fixed-header .main-header-bar-navigation .main-header-menu .sub-menu, #ast-fixed-header .main-header-bar-navigation .main-header-menu .sub-menu .menu-link, #ast-fixed-header .main-header-bar-navigation .main-header-menu .sub-menu .menu-item > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_color['desktop'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-link:hover, #ast-fixed-header .main-header-menu .sub-menu .menu-item:hover > .menu-link, #ast-fixed-header .main-header-menu .sub-menu .menu-item.focus > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['desktop'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['desktop'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-item:hover > .ast-menu-toggle, #ast-fixed-header .main-header-menu .sub-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_h_color['desktop'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-item.current-menu-item > .menu-link, #ast-fixed-header .main-header-menu .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['desktop'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['desktop'] ),
			),
			// Content Section text color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items, #ast-fixed-header div.ast-masthead-custom-menu-items .widget, #ast-fixed-header div.ast-masthead-custom-menu-items .widget-title' => array(
				'color' => esc_attr( $sticky_header_content_section_text_color['desktop'] ),
			),
			// Content Section link color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items a, #ast-fixed-header div.ast-masthead-custom-menu-items .widget a' => array(
				'color' => esc_attr( $sticky_header_content_section_link_color['desktop'] ),
			),
			// Content Section link hover color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items a:hover, #ast-fixed-header div.ast-masthead-custom-menu-items .widget a:hover' => array(
				'color' => esc_attr( $sticky_header_content_section_link_h_color['desktop'] ),
			),
		);
		$tablet_css_output = array(

			/**
			 * Header
			 */
			'#ast-fixed-header .site-title a, #ast-fixed-header .site-title a:focus, #ast-fixed-header .site-title a:hover, #ast-fixed-header .site-title a:visited' => array(
				'color' => esc_attr( $tablet_sticky_header_color_site_title ),
			),
			'#ast-fixed-header.site-header .site-title a:hover' => array(
				'color' => esc_attr( $sticky_header_color_h_site_title['tablet'] ),
			),
			'#ast-fixed-header.site-header .site-description' => array(
				'color' => esc_attr( $tablet_sticky_header_color_site_tagline ),
			),
			'.ast-transparent-header #ast-fixed-header .main-header-bar, #ast-fixed-header .main-header-bar, #ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search .search-field, #ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search .search-field:focus' => array(
				'background' => esc_attr( $tablet_sticky_header_bg_color ),
			),
			/**
			 * Primary Header Menu
			 */
			'#ast-fixed-header .main-header-menu' => array(
				'background' => esc_attr( $sticky_header_menu_bg_color['tablet'] ),
			),
			'#ast-fixed-header .main-header-menu .menu-item.current-menu-item > .menu-link, #ast-fixed-header .main-header-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $tablet_sticky_primary_menu_h_color ),
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['tablet'] ),
			),
			'#ast-fixed-header .main-header-menu .menu-link:hover, .ast-header-custom-item a:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .menu-link, #ast-fixed-header .main-header-menu .menu-item.focus > .menu-link' => array(
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['tablet'] ),
				'color'            => esc_attr( $tablet_sticky_primary_menu_h_color ),
			),
			'#ast-fixed-header .main-header-menu .ast-masthead-custom-menu-items a:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .ast-menu-toggle, #ast-fixed-header .main-header-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $tablet_sticky_primary_menu_h_color ),
			),

			'#ast-fixed-header .main-header-menu, #ast-fixed-header .main-header-menu .menu-link, #ast-fixed-header .ast-header-custom-item, .ast-header-custom-item a, #ast-fixed-header li.ast-masthead-custom-menu-items, #ast-fixed-header li.ast-masthead-custom-menu-items a' => array(
				'color' => esc_attr( $tablet_sticky_primary_menu_color ),
			),

			'#ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search form' => array(
				'border-color' => esc_attr( $tablet_sticky_primary_menu_color ),
			),
			/**
			 * Primary Submenu
			 */
			'#ast-fixed-header .main-navigation ul .sub-menu, .ast-header-break-point#ast-fixed-header .main-header-menu .sub-menu' => array(
				'background-color' => esc_attr( $sticky_header_submenu_bg_color['tablet'] ),
			),
			'#ast-fixed-header .main-header-bar-navigation .main-header-menu .sub-menu, #ast-fixed-header .main-header-menu .sub-menu .menu-link, #ast-fixed-header .main-header-bar-navigation .main-header-menu .sub-menu .menu-item > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_color['tablet'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-link:hover, #ast-fixed-header .main-header-menu .sub-menu .menu-item:hover > .menu-link, #ast-fixed-header .main-header-menu .sub-menu .menu-item.focus > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['tablet'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['tablet'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-item:hover > .ast-menu-toggle, #ast-fixed-header .main-header-menu .sub-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_h_color['tablet'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-item.current-menu-item > .menu-link, #ast-fixed-header .main-header-menu .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['tablet'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['tablet'] ),
			),
			// Content Section text color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items, #ast-fixed-header div.ast-masthead-custom-menu-items .widget, #ast-fixed-header div.ast-masthead-custom-menu-items .widget-title' => array(
				'color' => esc_attr( $sticky_header_content_section_text_color['tablet'] ),
			),
			// Content Section link color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items a, #ast-fixed-header div.ast-masthead-custom-menu-items .widget a' => array(
				'color' => esc_attr( $sticky_header_content_section_link_color['tablet'] ),
			),
			// Content Section link hover color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items a:hover, #ast-fixed-header div.ast-masthead-custom-menu-items .widget a:hover' => array(
				'color' => esc_attr( $sticky_header_content_section_link_h_color['tablet'] ),
			),
		);
		$mobile_css_output = array(

			/**
			 * Header
			 */
			'#ast-fixed-header .site-title a, #ast-fixed-header .site-title a:focus, #ast-fixed-header .site-title a:hover, #ast-fixed-header .site-title a:visited' => array(
				'color' => esc_attr( $mobile_sticky_header_color_site_title ),
			),
			'#ast-fixed-header.site-header .site-title a:hover' => array(
				'color' => esc_attr( $sticky_header_color_h_site_title['mobile'] ),
			),
			'#ast-fixed-header.site-header .site-description' => array(
				'color' => esc_attr( $mobile_sticky_header_color_site_tagline ),
			),
			'.ast-transparent-header #ast-fixed-header .main-header-bar, #ast-fixed-header .main-header-bar, #ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search .search-field, #ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search .search-field:focus' => array(
				'background' => esc_attr( $mobile_sticky_header_bg_color ),
			),
			/**
			 * Primary Header Menu
			 */
			'#ast-fixed-header .main-header-menu' => array(
				'background' => esc_attr( $sticky_header_menu_bg_color['mobile'] ),
			),
			'#ast-fixed-header .main-header-menu .menu-item.current-menu-item > .menu-link, #ast-fixed-header .main-header-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $mobile_sticky_primary_menu_h_color ),
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['mobile'] ),
			),
			'#ast-fixed-header .main-header-menu .menu-link:hover, .ast-header-custom-item a:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .menu-link, #ast-fixed-header .main-header-menu .menu-item.focus > .menu-link' => array(
				'background-color' => esc_attr( $sticky_header_menu_h_a_bg_color['mobile'] ),
				'color'            => esc_attr( $mobile_sticky_primary_menu_h_color ),
			),
			'#ast-fixed-header .main-header-menu .ast-masthead-custom-menu-items a:hover, #ast-fixed-header .main-header-menu .menu-item:hover > .ast-menu-toggle, #ast-fixed-header .main-header-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $mobile_sticky_primary_menu_h_color ),
			),

			'#ast-fixed-header .main-header-menu, #ast-fixed-header .main-header-menu .menu-link, #ast-fixed-header .ast-header-custom-item, .ast-header-custom-item a, #ast-fixed-header li.ast-masthead-custom-menu-items, #ast-fixed-header li.ast-masthead-custom-menu-items a' => array(
				'color' => esc_attr( $mobile_sticky_primary_menu_color ),
			),

			'#ast-fixed-header .ast-masthead-custom-menu-items .ast-inline-search form' => array(
				'border-color' => esc_attr( $mobile_sticky_primary_menu_color ),
			),
			/**
			 * Primary Submenu
			 */
			'#ast-fixed-header .main-navigation ul .sub-menu, .ast-header-break-point#ast-fixed-header .main-header-menu .sub-menu' => array(
				'background-color' => esc_attr( $sticky_header_submenu_bg_color['mobile'] ),
			),
			'#ast-fixed-header .main-header-bar-navigation .main-header-menu .sub-menu, #ast-fixed-header .main-header-menu .sub-menu .menu-link, #ast-fixed-header .main-header-bar-navigation .main-header-menu .sub-menu .menu-item > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_color['mobile'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-link:hover, #ast-fixed-header .main-header-menu .sub-menu .menu-item:hover > .menu-link, #ast-fixed-header .main-header-menu .sub-menu .menu-item.focus > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['mobile'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['mobile'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-item:hover > .ast-menu-toggle, #ast-fixed-header .main-header-menu .sub-menu .menu-item.focus > .ast-menu-toggle' => array(
				'color' => esc_attr( $sticky_primary_submenu_h_color['mobile'] ),
			),
			'#ast-fixed-header .main-header-menu .sub-menu .menu-item.current-menu-item > .menu-link, #ast-fixed-header .main-header-menu .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
				'color'            => esc_attr( $sticky_primary_submenu_h_color['mobile'] ),
				'background-color' => esc_attr( $sticky_primary_submenu_h_a_bg_color['mobile'] ),
			),
			// Content Section text color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items, #ast-fixed-header div.ast-masthead-custom-menu-items .widget, #ast-fixed-header div.ast-masthead-custom-menu-items .widget-title' => array(
				'color' => esc_attr( $sticky_header_content_section_text_color['mobile'] ),
			),
			// Content Section link color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items a, #ast-fixed-header div.ast-masthead-custom-menu-items .widget a' => array(
				'color' => esc_attr( $sticky_header_content_section_link_color['mobile'] ),
			),
			// Content Section link hover color.
			'#ast-fixed-header div.ast-masthead-custom-menu-items a:hover, #ast-fixed-header div.ast-masthead-custom-menu-items .widget a:hover' => array(
				'color' => esc_attr( $sticky_header_content_section_link_h_color['mobile'] ),
			),
		);
	}

	if ( 'custom-button' === $header_custom_button_style ) {
		$css_output = array(
			// Custom menu item button - Transparent.
			'.ast-primary-sticky-header-active .main-header-bar .button-custom-menu-item .ast-custom-button-link .ast-custom-button' => array(
				'color'               => esc_attr( $header_custom_sticky_button_text_color ),
				'background-color'    => esc_attr( $header_custom_sticky_button_back_color ),
				'padding-top'         => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'top', 'desktop' ),
				'padding-bottom'      => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'bottom', 'desktop' ),
				'padding-left'        => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'left', 'desktop' ),
				'padding-right'       => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'right', 'desktop' ),
				'border-radius'       => adaptive_get_css_value( $header_custom_sticky_button_radius, 'px' ),
				'border-style'        => 'solid',
				'border-color'        => esc_attr( $header_custom_sticky_button_border_color ),
				'border-top-width'    => ( isset( $header_custom_sticky_button_border_size['top'] ) && '' !== $header_custom_sticky_button_border_size['top'] ) ? adaptive_get_css_value( $header_custom_sticky_button_border_size['top'], 'px' ) : '',
				'border-right-width'  => ( isset( $header_custom_sticky_button_border_size['right'] ) && '' !== $header_custom_sticky_button_border_size['right'] ) ? adaptive_get_css_value( $header_custom_sticky_button_border_size['right'], 'px' ) : '',
				'border-left-width'   => ( isset( $header_custom_sticky_button_border_size['left'] ) && '' !== $header_custom_sticky_button_border_size['left'] ) ? adaptive_get_css_value( $header_custom_sticky_button_border_size['left'], 'px' ) : '',
				'border-bottom-width' => ( isset( $header_custom_sticky_button_border_size['bottom'] ) && '' !== $header_custom_sticky_button_border_size['bottom'] ) ? adaptive_get_css_value( $header_custom_sticky_button_border_size['bottom'], 'px' ) : '',
			),
			'.ast-primary-sticky-header-active .main-header-bar .button-custom-menu-item .ast-custom-button-link .ast-custom-button:hover' => array(
				'color'            => esc_attr( $header_custom_sticky_button_text_h_color ),
				'background-color' => esc_attr( $header_custom_sticky_button_back_h_color ),
				'border-color'     => esc_attr( $header_custom_sticky_button_border_h_color ),
			),
		);

		/* Parse CSS from array() */
		$parse_css .= adaptive_parse_css( $css_output );

		$custom_trans_button_css = array(
			'.ast-sticky-active .main-header-bar .button-custom-menu-item .ast-custom-button-link .ast-custom-button' => array(
				'padding-top'    => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'top', 'tablet' ),
				'padding-bottom' => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'bottom', 'tablet' ),
				'padding-left'   => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'left', 'tablet' ),
				'padding-right'  => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'right', 'tablet' ),
			),
		);

		/* Parse CSS from array()*/
		$parse_css .= adaptive_parse_css( $custom_trans_button_css, '', adaptive_addon_get_tablet_breakpoint() );

		$custom_trans_button = array(
			'.ast-sticky-active .main-header-bar .button-custom-menu-item .ast-custom-button-link .ast-custom-button' => array(
				'padding-top'    => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'top', 'mobile' ),
				'padding-bottom' => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'bottom', 'mobile' ),
				'padding-left'   => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'left', 'mobile' ),
				'padding-right'  => adaptive_responsive_spacing( $header_custom_sticky_button_spacing, 'right', 'mobile' ),
			),
		);

		/* Parse CSS from array()*/
		$parse_css .= adaptive_parse_css( $custom_trans_button, '', adaptive_addon_get_mobile_breakpoint() );
	}

	if ( false === adaptive_pro_sticky_header_submenu_below_header_fix() ) :
		$submenu_below_header = array(
			'.ast-sticky-main-shrink .ast-sticky-shrunk .main-header-bar' => array(
				'padding-top'    => '0.5em',
				'padding-bottom' => '0.5em',
			),
			'.ast-sticky-main-shrink .ast-sticky-shrunk .main-header-bar .ast-site-identity' => array(
				'padding-top'    => '0',
				'padding-bottom' => '0',
			),
		);

		$parse_css .= adaptive_parse_css( $submenu_below_header );
	endif;

	/**
	 * Sticky Header with Builder > Site Identity colors.
	 */
	if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

		/* Site Identity Sticky Color Options */
		if ( ! adaptive_addon_sticky_site_title_tagline_css_comp() ) {
			$sticky_site_title_color       = adaptive_get_option( 'sticky-header-builder-site-title-color' );
			$sticky_site_title_hover_color = adaptive_get_option( 'sticky-header-builder-site-title-h-color' );
			$sticky_site_tagline_color     = adaptive_get_option( 'sticky-header-builder-site-tagline-color' );
		} else {
			$sticky_site_title_color       = adaptive_get_option( 'sticky-header-builder-site-title-color', $default_header_site_title_color );
			$sticky_site_title_hover_color = adaptive_get_option( 'sticky-header-builder-site-title-h-color', $default_header_site_title_hover_color );
			$sticky_site_tagline_color     = adaptive_get_option( 'sticky-header-builder-site-tagline-color', $default_header_site_tagline_color );
		}

		$sticky_builder_site_identity_css = array(
			'[CLASS*="-sticky-header-active"] #ast-fixed-header.ast-header-sticked .site-title a, [CLASS*="-sticky-header-active"] .ast-header-sticked .site-title a:focus, [CLASS*="-sticky-header-active"] .ast-header-sticked .site-title a:visited , [CLASS*="-sticky-header-active"] .ast-header-sticked .site-title a' => array(
				'color' => esc_attr( $sticky_site_title_color ),
			),
			'[CLASS*="-sticky-header-active"] #ast-fixed-header.ast-header-sticked .site-title a:hover, [CLASS*="-sticky-header-active"] .ast-header-sticked .site-title a:hover'           => array(
				'color' => esc_attr( $sticky_site_title_hover_color ),
			),
			'[CLASS*="-sticky-header-active"] #ast-fixed-header.ast-header-sticked .ast-site-identity .site-description, [CLASS*="-sticky-header-active"] .ast-header-sticked .ast-site-identity .site-description'             => array(
				'color' => esc_attr( $sticky_site_tagline_color ),
			),
		);

		$parse_css .= adaptive_parse_css( $sticky_builder_site_identity_css );

		$num_of_header_menu = adaptive_addon_builder_helper()->num_of_header_menu;
		for ( $index = 1; $index <= $num_of_header_menu; $index++ ) {

			/**
			 * Sticky Menu Colors.
			 */
			$desktop_sticky_primary_menu_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-color-responsive' ), 'desktop' );
			$tablet_sticky_primary_menu_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-color-responsive' ), 'tablet' );
			$mobile_sticky_primary_menu_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-color-responsive' ), 'mobile' );

			$sticky_header_menu_bg_color = adaptive_get_option( 'sticky-header-menu' . $index . '-bg-obj-responsive' );

			$desktop_sticky_primary_menu_h_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-h-color-responsive' ), 'desktop' );
			$tablet_sticky_primary_menu_h_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-h-color-responsive' ), 'tablet' );
			$mobile_sticky_primary_menu_h_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-h-color-responsive' ), 'mobile' );

			$sticky_header_menu_h_bg_color = adaptive_get_option( 'sticky-header-menu' . $index . '-h-bg-color-responsive' );

			$desktop_sticky_primary_menu_a_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-a-color-responsive' ), 'desktop' );
			$tablet_sticky_primary_menu_a_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-a-color-responsive' ), 'tablet' );
			$mobile_sticky_primary_menu_a_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-a-color-responsive' ), 'mobile' );

			$sticky_header_menu_a_bg_color = adaptive_get_option( 'sticky-header-menu' . $index . '-a-bg-color-responsive' );

			/**
			 * Sticky Submenu Colors.
			 */
			$desktop_sticky_primary_submenu_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-color-responsive' ), 'desktop' );
			$tablet_sticky_primary_submenu_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-color-responsive' ), 'tablet' );
			$mobile_sticky_primary_submenu_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-color-responsive' ), 'mobile' );

			$sticky_header_submenu_bg_color = adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-bg-color-responsive' );

			$desktop_sticky_primary_submenu_h_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-h-color-responsive' ), 'desktop' );
			$tablet_sticky_primary_submenu_h_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-h-color-responsive' ), 'tablet' );
			$mobile_sticky_primary_submenu_h_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-h-color-responsive' ), 'mobile' );

			$sticky_header_submenu_h_bg_color = adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-h-bg-color-responsive' );

			$desktop_sticky_primary_submenu_a_color = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-a-color-responsive' ), 'desktop' );
			$tablet_sticky_primary_submenu_a_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-a-color-responsive' ), 'tablet' );
			$mobile_sticky_primary_submenu_a_color  = adaptive_get_prop( adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-a-color-responsive' ), 'mobile' );

			$sticky_header_submenu_a_bg_color = adaptive_get_option( 'sticky-header-menu' . $index . '-submenu-a-bg-color-responsive' );

			if ( 3 > $index ) {
				/**
				 * Sticky Megamenu Heading Colors.
				 */
				$sticky_megamenu_heading_color   = adaptive_get_option( 'sticky-header-menu' . $index . '-header-megamenu-heading-color' );
				$sticky_megamenu_heading_h_color = adaptive_get_option( 'sticky-header-menu' . $index . '-header-megamenu-heading-h-color' );

				$sticky_builder_megamenu_desktop_css = array(
					// Megamenu Heading CSS Starts.
					'[CLASS*="-sticky-header-active"].ast-desktop .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . '.ast-mega-menu-enabled .sub-menu .menu-item.menu-item-heading > .menu-link' => array(
						'color'      => esc_attr( $sticky_megamenu_heading_color ),
						'background' => 'transparent',
					),
					'[CLASS*="-sticky-header-active"].ast-desktop .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . '.ast-mega-menu-enabled .sub-menu .menu-item.menu-item-heading:hover > .menu-link, [CLASS*="-sticky-header-active"].ast-desktop .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . '.ast-mega-menu-enabled .sub-menu .menu-item.menu-item-heading > .menu-link:hover' => array(
						'color'      => esc_attr( $sticky_megamenu_heading_h_color ),
						'background' => 'transparent',
					),
				);

				$parse_css .= adaptive_parse_css( $sticky_builder_megamenu_desktop_css );
			}

			$sticky_builder_menu_desktop_css = array(
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' > .menu-item > .menu-link' => array(
					'color' => esc_attr( $desktop_sticky_primary_menu_color ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index => array(
					'background-color' => esc_attr( $sticky_header_menu_bg_color['desktop'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item > .menu-link:hover, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item:hover > .menu-link' => array(
					'color'            => esc_attr( $desktop_sticky_primary_menu_h_color ),
					'background-color' => esc_attr( $sticky_header_menu_h_bg_color['desktop'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item.current-menu-item > .menu-link' => array(
					'color'            => esc_attr( $desktop_sticky_primary_menu_a_color ),
					'background-color' => esc_attr( $sticky_header_menu_a_bg_color['desktop'] ),
				),
				// Submenu CSS starts.
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-link' => array(
					'color' => esc_attr( $desktop_sticky_primary_submenu_color ),
				),
				'.ast-header-sticked .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu, .ast-header-sticked .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-link' => array(
					'background-color' => esc_attr( $sticky_header_submenu_bg_color['desktop'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item > .menu-link:hover, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item:hover > .menu-link' => array(
					'color'            => esc_attr( $desktop_sticky_primary_submenu_h_color ),
					'background-color' => esc_attr( $sticky_header_submenu_h_bg_color['desktop'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item.current-menu-item > .menu-link, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
					'color'            => esc_attr( $desktop_sticky_primary_submenu_a_color ),
					'background-color' => esc_attr( $sticky_header_submenu_a_bg_color['desktop'] ),
				),
			);

			$sticky_builder_menu_tablet_css = array(
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' > .menu-item > .menu-link' => array(
					'color' => esc_attr( $tablet_sticky_primary_menu_color ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index => array(
					'background-color' => esc_attr( $sticky_header_menu_bg_color['tablet'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item > .menu-link:hover, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item:hover > .menu-link' => array(
					'color'            => esc_attr( $tablet_sticky_primary_menu_h_color ),
					'background-color' => esc_attr( $sticky_header_menu_h_bg_color['tablet'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item.current-menu-item > .menu-link, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item.current-menu-ancestor > .menu-link' => array(
					'color'            => esc_attr( $tablet_sticky_primary_menu_a_color ),
					'background-color' => esc_attr( $sticky_header_menu_a_bg_color['tablet'] ),
				),
				// Submenu CSS starts.
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-link' => array(
					'color' => esc_attr( $tablet_sticky_primary_submenu_color ),
				),
				'.ast-header-sticked .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu, .ast-header-sticked .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-link' => array(
					'background-color' => esc_attr( $sticky_header_submenu_bg_color['tablet'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item > .menu-link:hover, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item:hover > .menu-link' => array(
					'color'            => esc_attr( $tablet_sticky_primary_submenu_h_color ),
					'background-color' => esc_attr( $sticky_header_submenu_h_bg_color['tablet'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item.current-menu-item > .menu-link, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
					'color'            => esc_attr( $tablet_sticky_primary_submenu_a_color ),
					'background-color' => esc_attr( $sticky_header_submenu_a_bg_color['tablet'] ),
				),
				// Sticky Main Menu Scrolling (Tablet & Mobile).
				'.ast-primary-sticky-header-active.ast-main-header-nav-open nav' => array(
					'overflow-y' => 'auto',
					'max-height' => 'calc(100vh - 100px)',
				),
			);

			$sticky_builder_menu_mobile_css = array(
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' > .menu-item > .menu-link' => array(
					'color' => esc_attr( $mobile_sticky_primary_menu_color ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index => array(
					'background-color' => esc_attr( $sticky_header_menu_bg_color['mobile'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item > .menu-link:hover, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item:hover > .menu-link' => array(
					'color'            => esc_attr( $mobile_sticky_primary_menu_h_color ),
					'background-color' => esc_attr( $sticky_header_menu_h_bg_color['mobile'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item.current-menu-item > .menu-link, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .menu-item.current-menu-ancestor > .menu-link' => array(
					'color'            => esc_attr( $mobile_sticky_primary_menu_a_color ),
					'background-color' => esc_attr( $sticky_header_menu_a_bg_color['mobile'] ),
				),
				// Submenu CSS starts.
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-link' => array(
					'color' => esc_attr( $mobile_sticky_primary_submenu_color ),
				),
				'.ast-header-sticked .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu,.ast-header-sticked .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-link' => array(
					'background-color' => esc_attr( $sticky_header_submenu_bg_color['mobile'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item > .menu-link:hover, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item:hover > .menu-link' => array(
					'color'            => esc_attr( $mobile_sticky_primary_submenu_h_color ),
					'background-color' => esc_attr( $sticky_header_submenu_h_bg_color['mobile'] ),
				),
				'[CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item.current-menu-item > .menu-link, [CLASS*="-sticky-header-active"] .ast-builder-menu-' . $index . ' #ast-hf-menu-' . $index . ' .sub-menu .menu-item.current-menu-ancestor > .menu-link' => array(
					'color'            => esc_attr( $mobile_sticky_primary_submenu_a_color ),
					'background-color' => esc_attr( $sticky_header_submenu_a_bg_color['mobile'] ),
				),
			);

			/* Parse CSS from array() */
			$parse_css .= adaptive_parse_css( $sticky_builder_menu_desktop_css );
			$parse_css .= adaptive_parse_css( $sticky_builder_menu_tablet_css, '', adaptive_addon_get_tablet_breakpoint() );
			$parse_css .= adaptive_parse_css( $sticky_builder_menu_mobile_css, '', adaptive_addon_get_mobile_breakpoint() );
		}
	}

	if ( version_compare( ADAPTIVE_THEME_VERSION, '3.2.0', '<' ) ) {

		$sticky_static_css = '
		.ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content {
			display: none;
		}

		.ast-main-header-nav-open.adaptive-hfb-header .ast-mobile-header-wrap .ast-mobile-header-content {
			display: block;
		}

		.ast-header-stick-slide-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-header-stick-fade-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-header-stick-scroll-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content {
			display: block;
		}

		.ast-header-stick-slide-active .ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-header-stick-fade-active .ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-header-stick-scroll-active .ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content {
			display: none;
		}

		.ast-header-stick-slide-active.ast-off-canvas-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-header-stick-fade-active.ast-off-canvas-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-header-stick-scroll-active.ast-off-canvas-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content {
			display: none;
		}

		.ast-primary-sticky-header-active.ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-above-sticky-header-active.ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
		.ast-below-sticky-header-active.ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content {
			position: fixed;
		}
		';

		if ( is_rtl() ) {

			$sticky_static_css .= '
			.ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content {
				display: none;
			}

			.ast-main-header-nav-open.adaptive-hfb-header .ast-mobile-header-wrap .ast-mobile-header-content {
				display: block;
			}

			.ast-header-stick-slide-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-header-stick-fade-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-header-stick-scroll-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content {
				display: block;
			}

			.ast-header-stick-slide-active .ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-header-stick-fade-active .ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-header-stick-scroll-active .ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content {
				display: none;
			}

			.ast-header-stick-slide-active.ast-off-canvas-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-header-stick-fade-active.ast-off-canvas-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-header-stick-scroll-active.ast-off-canvas-active .ast-main-header-nav-open.adaptive-hfb-header #ast-fixed-header .ast-mobile-header-wrap .ast-mobile-header-content {
				display: none;
			}

			.ast-primary-sticky-header-active.ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-above-sticky-header-active.ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content,
			.ast-below-sticky-header-active.ast-main-header-nav-open.adaptive-hfb-header #masthead > .ast-mobile-header-wrap .ast-mobile-header-content {
				position: fixed;
			}
			';
		}

		$parse_css .= Adaptive_Enqueue_Scripts::trim_css( $sticky_static_css );
	}

	/* Parse CSS from array() */
	$parse_css .= adaptive_parse_css( $desktop_css_output );
	$parse_css .= adaptive_parse_css( $tablet_css_output, '', adaptive_addon_get_tablet_breakpoint() );
	$parse_css .= adaptive_parse_css( $mobile_css_output, '', adaptive_addon_get_mobile_breakpoint() );

	return $dynamic_css . $parse_css;
}


/**
 * Check backwards compatibility CSS for loading submenu below the header needs to be added.
 *
 * @since 1.6.0
 * @return boolean true if CSS should be included, False if not.
 */
function adaptive_pro_sticky_header_submenu_below_header_fix() {

	if ( false == adaptive_get_option( 'submenu-below-header', true ) && false === apply_filters( 'adaptive_submenu_below_header_fix', false ) ) {
		return false;
	} else {
		return true;
	}
}

/**
 * For existing users, do not apply the defaut header site title color by default.
 *
 * @since 3.5.8
 * @return boolean false if it is an existing user , true if not.
 */
function adaptive_addon_sticky_site_title_tagline_css_comp() {
	$adaptive_settings = get_option( ADAPTIVE_THEME_SETTINGS );
	$adaptive_settings['sticky-header-default-site-title-tagline-css'] = isset( $adaptive_settings['sticky-header-default-site-title-tagline-css'] ) ? false : true;
	return apply_filters( 'adaptive_default_site_title_tagline_css_comp', $adaptive_settings['sticky-header-default-site-title-tagline-css'] );
}
