<?php
/**
 * Sticky Header - Above Header Colors Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Above_Header_Colors_Bg_Configs' ) ) {

	/**
	 * Register Sticky Header Above Header ColorsCustomizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Above_Header_Colors_Bg_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$header_above_section        = 'section-sticky-header';
			$header_above_color_priority = 60;
			$context                     = adaptive_addon_builder_helper()->general_tab_config;

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				$header_above_section        = 'section-above-header-builder';
				$header_above_color_priority = 85;
				$context                     = adaptive_addon_builder_helper()->design_tab;

				$_config = array(

					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-above-header-bg-color-responsive]',
						'default'    => adaptive_get_option( 'sticky-above-header-bg-color-responsive' ),
						'type'       => 'control',
						'priority'   => $header_above_color_priority,
						'section'    => $header_above_section,
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '背景颜色', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => $context,
					),
				);
			} else {
				$_config = array(

					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-above-header-bg-color-responsive]',
						'default'    => adaptive_get_option( 'sticky-above-header-bg-color-responsive' ),
						'type'       => 'control',
						'priority'   => $header_above_color_priority,
						'section'    => $header_above_section,
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '背景颜色', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => $context,
					),

					/**
					 * Option: Primary Menu Color
					 */
					array(
						'name'       => 'sticky-above-header-menu-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-menu-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '标准', 'adaptive-addon' ),
						'priority'   => 6,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-menus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
					/**
					 * Option: Menu Background Color
					 */
					array(
						'name'       => 'sticky-above-header-menu-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-menu-bg-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '标准', 'adaptive-addon' ),
						'priority'   => 7,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-menus-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					 * Option: Menu Hover Color
					 */
					array(
						'name'       => 'sticky-above-header-menu-h-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-menu-h-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'priority'   => 6,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-menus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '活动/悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
					/**
					 * Option: Menu Link / Hover Background Color
					 */
					array(
						'name'       => 'sticky-above-header-menu-h-a-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-menu-h-a-bg-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'priority'   => 7,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-menus-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '活动/悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					 * Option: Primary Menu Color
					 */
					array(
						'name'       => 'sticky-above-header-submenu-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-submenu-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '标准', 'adaptive-addon' ),
						'priority'   => 9,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-submenus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
					/**
					 * Option: SubMenu Background Color
					 */
					array(
						'name'       => 'sticky-above-header-submenu-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-submenu-bg-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '标准', 'adaptive-addon' ),
						'priority'   => 10,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-submenus-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					 * Option: Menu Hover Color
					 */
					array(
						'name'       => 'sticky-above-header-submenu-h-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-submenu-h-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'priority'   => 9,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-submenus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '活动/悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					 * Option: SubMenu Link / Hover Background Color
					 */
					array(
						'name'       => 'sticky-above-header-submenu-h-a-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-submenu-h-a-bg-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'priority'   => 10,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-submenus-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '活动/悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					* Option: Content Section Text color.
					*/
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-above-header-content-section-text-color-responsive]',
						'default'    => adaptive_get_option( 'sticky-above-header-content-section-text-color-responsive' ),
						'type'       => 'control',
						'priority'   => 74,
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '文字', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'divider'    => array(
							'ast_class' => 'ast-top-divider',
							'ast_title' => __( '内容', 'adaptive-addon' ),
						),
						'context'    => array(
							'relation' => 'AND',
							adaptive_addon_builder_helper()->is_header_footer_builder_active ? adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							array(
								'relation' => 'OR',
								array(
									'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
									'operator' => 'in',
									'value'    => array( 'search', 'widget', 'text-html', 'edd' ),
								),
								array(
									'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
									'operator' => 'in',
									'value'    => array( 'search', 'widget', 'text-html', 'edd' ),
								),
							),
						),
					),
					/**
					 * Option: Content Section Link color.
					 */
					array(
						'name'       => 'sticky-above-header-content-section-link-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-content-section-link-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '标准', 'adaptive-addon' ),
						'priority'   => 19,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-outside-item-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => array( 'search', 'widget', 'text-html', 'edd' ),
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => array( 'search', 'widget', 'text-html', 'edd' ),
							),
						),
					),

					/**
					 * Option: Content Section Link Hover color.
					 */
					array(
						'name'       => 'sticky-above-header-content-section-link-h-color-responsive',
						'default'    => adaptive_get_option( 'sticky-above-header-content-section-link-h-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'priority'   => 20,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-outside-item-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-1]',
								'operator' => '==',
								'value'    => array( 'search', 'widget', 'text-html', 'edd' ),
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[above-header-section-2]',
								'operator' => '==',
								'value'    => array( 'search', 'widget', 'text-html', 'edd' ),
							),
						),

					),
				);
			}

			return array_merge( $configurations, $_config );
		}

	}
}

new Adaptive_Sticky_Above_Header_Colors_Bg_Configs();
