<?php
/**
 * Sticky Header - Below Header Colors Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Below_Header_Colors_Bg_Configs' ) ) {

	/**
	 * Register Sticky Header Below Header ColorsCustomizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Below_Header_Colors_Bg_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$header_below_section        = 'section-sticky-header';
			$header_below_color_priority = 115;
			$context                     = adaptive_addon_builder_helper()->general_tab_config;

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				$header_below_section        = 'section-below-header-builder';
				$header_below_color_priority = 90;
				$context                     = adaptive_addon_builder_helper()->design_tab;

				$_config = array(

					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-below-header-bg-color-responsive]',
						'default'    => adaptive_get_option( 'sticky-below-header-bg-color-responsive' ),
						'type'       => 'control',
						'priority'   => $header_below_color_priority,
						'section'    => $header_below_section,
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '背景颜色', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => $context,
					),
				);
			} else {

				$_config = array(

					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-below-header-bg-color-responsive]',
						'default'    => adaptive_get_option( 'sticky-below-header-bg-color-responsive' ),
						'type'       => 'control',
						'priority'   => $header_below_color_priority,
						'section'    => $header_below_section,
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '背景颜色', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => $context,
					),

					/**
					 * Option: Primary Menu Color
					 */
					array(
						'name'       => 'sticky-below-header-menu-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-menu-color-responsive' ),
						'type'       => 'sub-control',
						'priority'   => 6,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-menus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
					/**
					 * Option: Menu Background Color
					 */
					array(
						'name'       => 'sticky-below-header-menu-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-menu-bg-color-responsive' ),
						'type'       => 'sub-control',
						'priority'   => 7,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-menus-background-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					// Option: Divider.
					array(
						'name'     => 'divider-sticky-below-h-menu-colors',
						'control'  => 'ast-divider',
						'default'  => '',
						'type'     => 'sub-control',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-menus-colors]',
						'section'  => 'section-sticky-header',
						'title'    => __( '激活/悬停', 'adaptive-addon' ),
						'tab'      => __( '悬停', 'adaptive-addon' ),
						'priority' => 5,
						'settings' => array(),
					),

					/**
					 * Option: Menu Hover Color
					 */
					array(
						'name'       => 'sticky-below-header-menu-h-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-menu-h-color-responsive' ),
						'type'       => 'sub-control',
						'priority'   => 6,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-menus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
					/**
					 * Option: Menu Link / Hover Background Color
					 */
					array(
						'name'       => 'sticky-below-header-menu-h-a-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-menu-h-a-bg-color-responsive' ),
						'type'       => 'sub-control',
						'priority'   => 7,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-menus-background-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					 * Option: Primary Menu Color
					 */
					array(
						'name'       => 'sticky-below-header-submenu-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-submenu-color-responsive' ),
						'type'       => 'sub-control',
						'priority'   => 9,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-submenus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
					/**
					 * Option: SubMenu Background Color
					 */
					array(
						'name'       => 'sticky-below-header-submenu-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-submenu-bg-color-responsive' ),
						'type'       => 'sub-control',
						'priority'   => 10,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-submenus-background-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					// Option: Divider.
					array(
						'name'     => 'divider-sticky-below-submenu-h-menu-colors',
						'control'  => 'ast-divider',
						'default'  => '',
						'type'     => 'sub-control',
						'parent'   => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-submenus-colors]',
						'section'  => 'section-sticky-header',
						'title'    => __( '激活/悬停', 'adaptive-addon' ),
						'tab'      => __( '悬停', 'adaptive-addon' ),
						'priority' => 5,
						'settings' => array(),
					),

					/**
					 * Option: Menu Hover Color
					 */
					array(
						'name'       => 'sticky-below-header-submenu-h-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-submenu-h-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'priority'   => 9,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-submenus-link-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					 * Option: SubMenu Link / Hover Background Color
					 */
					array(
						'name'       => 'sticky-below-header-submenu-h-a-bg-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-submenu-h-a-bg-color-responsive' ),
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'priority'   => 10,
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-submenus-background-colors]',
						'section'    => 'section-sticky-header',
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
						'context'    => array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-1]',
								'operator' => '==',
								'value'    => 'menu',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[below-header-section-2]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),

					/**
					* Option: Content Section Link color.
					*/
					array(
						'name'       => 'sticky-below-header-content-section-link-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-content-section-link-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-header-content-colors]',
						'type'       => 'sub-control',
						'transport'  => 'postMessage',
						'tab'        => __( '标准', 'adaptive-addon' ),
						'control'    => 'ast-responsive-color',
						'title'      => __( '标准', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
					),
					/**
					* Option: Content Section Link Hover color.
					*/
					array(
						'name'       => 'sticky-below-header-content-section-link-h-color-responsive',
						'default'    => adaptive_get_option( 'sticky-below-header-content-section-link-h-color-responsive' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-header-content-colors]',
						'type'       => 'sub-control',
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'transport'  => 'postMessage',
						'control'    => 'ast-responsive-color',
						'title'      => __( '悬停', 'adaptive-addon' ),
						'responsive' => true,
						'rgba'       => true,
					),

				);
			}

			return array_merge( $configurations, $_config );
		}

	}
}

new Adaptive_Sticky_Below_Header_Colors_Bg_Configs();



