<?php
/**
 * Sticky Header - Account options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       3.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Account_Configs' ) ) {

	/**
	 * Register Sticky Header Above Header ColorsCustomizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Account_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.0.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_section = 'section-header-account';

			$_configs = array(

				/**
				 * Option: Sticky Header account Heading.
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-heading]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'section'  => $_section,
					'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
					'settings' => array(),
					'priority' => 120,
					'context'  => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-login-style]',
								'operator' => '==',
								'value'    => 'icon',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-login-style]',
								'operator' => '==',
								'value'    => 'text',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-style]',
								'operator' => '!=',
								'value'    => 'none',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
								'operator' => '==',
								'value'    => 'menu',
							),
						),
					),
				),

				/**
				 * Option: Search Color.
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-icon-color]',
					'default'           => adaptive_get_option( 'sticky-header-account-icon-color' ),
					'type'              => 'control',
					'section'           => $_section,
					'priority'          => 130,
					'transport'         => 'postMessage',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '图标颜色', 'adaptive-addon' ),
					'context'           => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-login-style]',
								'operator' => '==',
								'value'    => 'icon',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-style]',
								'operator' => '==',
								'value'    => 'icon',
							),
						),
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Text Color.
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-type-text-color]',
					'default'           => adaptive_get_option( 'sticky-header-account-type-text-color' ),
					'type'              => 'control',
					'section'           => $_section,
					'priority'          => 131,
					'transport'         => 'postMessage',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '文本颜色', 'adaptive-addon' ),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'           => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'relation' => 'OR',
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-login-style]',
								'operator' => '==',
								'value'    => 'text',
							),
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-style]',
								'operator' => '==',
								'value'    => 'text',
							),
						),
					),
				),

				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-colors]',
					'default'    => adaptive_get_option( 'sticky-header-account-menu-colors' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'divider'    => array(
						'ast_title' => __( '菜单颜色', 'adaptive-addon' ),
					),
					'title'      => __( '链接', 'adaptive-addon' ),
					'section'    => $_section,
					'transport'  => 'postMessage',
					'priority'   => 140,
					'context'    => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'responsive' => false,
				),

				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-bg-colors]',
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$group_control,
					'title'      => __( '背景', 'adaptive-addon' ),
					'section'    => $_section,
					'transport'  => 'postMessage',
					'priority'   => 140,
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'    => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
							'operator' => '==',
							'value'    => 'menu',
						),
					),
					'responsive' => false,
				),

				// Option: Menu Color.
				array(
					'name'      => 'sticky-header-account-menu-color',
					'default'   => adaptive_get_option( 'sticky-header-account-menu-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-colors]',
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'tab'       => __( '标准', 'adaptive-addon' ),
					'section'   => $_section,
					'title'     => __( '标准', 'adaptive-addon' ),
					'priority'  => 7,
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
							'operator' => '==',
							'value'    => 'menu',
						),
						adaptive_addon_builder_helper()->design_tab,
					),
				),

				// Option: Background Color.
				array(
					'name'      => 'sticky-header-account-menu-bg-obj',
					'default'   => adaptive_get_option( 'sticky-header-account-menu-bg-obj' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-bg-colors]',
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'section'   => $_section,
					'title'     => __( '标准', 'adaptive-addon' ),
					'tab'       => __( '标准', 'adaptive-addon' ),
					'priority'  => 8,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),

				// Option: Menu Hover Color.
				array(
					'name'      => 'sticky-header-account-menu-h-color',
					'default'   => adaptive_get_option( 'sticky-header-account-menu-h-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-colors]',
					'tab'       => __( '悬停', 'adaptive-addon' ),
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'title'     => __( '悬停', 'adaptive-addon' ),
					'section'   => $_section,
					'priority'  => 19,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),

				// Option: Menu Hover Background Color.
				array(
					'name'      => 'sticky-header-account-menu-h-bg-color',
					'default'   => adaptive_get_option( 'sticky-header-account-menu-h-bg-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-bg-colors]',
					'type'      => 'sub-control',
					'title'     => __( '悬停', 'adaptive-addon' ),
					'section'   => $_section,
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'tab'       => __( '悬停', 'adaptive-addon' ),
					'priority'  => 21,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),

				// Option: Active Menu Color.
				array(
					'name'      => 'sticky-header-account-menu-a-color',
					'default'   => adaptive_get_option( 'sticky-header-account-menu-a-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-colors]',
					'type'      => 'sub-control',
					'section'   => $_section,
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'tab'       => __( '已启用', 'adaptive-addon' ),
					'title'     => __( '已启用', 'adaptive-addon' ),
					'priority'  => 31,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),

				// Option: Active Menu Background Color.
				array(
					'name'      => 'sticky-header-account-menu-a-bg-color',
					'default'   => adaptive_get_option( 'sticky-header-account-menu-a-bg-color' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-account-menu-bg-colors]',
					'type'      => 'sub-control',
					'control'   => 'ast-color',
					'transport' => 'postMessage',
					'section'   => $_section,
					'title'     => __( '已启用', 'adaptive-addon' ),
					'tab'       => __( '已启用', 'adaptive-addon' ),
					'priority'  => 33,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

new Adaptive_Sticky_Header_Account_Configs();
