<?php
/**
 * Sticky Header - Button Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Button_Configs' ) ) {

	/**
	 * Register Sticky Header Above Header ColorsCustomizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Button_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$html_config = array();

			$main_stick  = adaptive_get_option( 'header-main-stick' );
			$above_stick = adaptive_get_option( 'header-above-stick' );
			$below_stick = adaptive_get_option( 'header-below-stick' );

			$component_limit = adaptive_addon_builder_helper()->component_limit;
			for ( $index = 1; $index <= $component_limit; $index++ ) {

				$_section = 'section-hb-button-' . $index;
				$_prefix  = 'button' . $index;

				$_configs = array(

					/**
					 * Option: Sticky Header Button Heading.
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-heading]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => $_section,
						'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
						'settings' => array(),
						'priority' => 100,
						'context'  => adaptive_addon_builder_helper()->design_tab,
					),
					/**
					 * Group: Primary Header Button Colors Group
					 */
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-text-color-group]',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-color-group' ),
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '文本颜色', 'adaptive-addon' ),
						'section'    => $_section,
						'transport'  => 'postMessage',
						'priority'   => 101,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'responsive' => true,

					),

					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-background-color-group]',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-color-group' ),
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '背景颜色', 'adaptive-addon' ),
						'section'    => $_section,
						'transport'  => 'postMessage',
						'priority'   => 101,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'responsive' => true,
						'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
					),

					/**
					* Option: Button Text Color
					*/
					array(
						'name'       => 'sticky-header-' . $_prefix . '-text-color',
						'transport'  => 'postMessage',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-text-color' ),
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-text-color-group]',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 10,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '标准', 'adaptive-addon' ),
						'tab'        => __( '标准', 'adaptive-addon' ),
					),

					/**
					* Option: Button Text Hover Color
					*/
					array(
						'name'       => 'sticky-header-' . $_prefix . '-text-h-color',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-text-h-color' ),
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-text-color-group]',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 10,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '悬停', 'adaptive-addon' ),
						'tab'        => __( '悬停', 'adaptive-addon' ),
					),

					/**
					* Option: Button Background Color
					*/
					array(
						'name'       => 'sticky-header-' . $_prefix . '-back-color',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-back-color' ),
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-background-color-group]',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 10,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '标准', 'adaptive-addon' ),
						'tab'        => __( '标准', 'adaptive-addon' ),
					),

					/**
					* Option: Button Button Hover Color
					*/
					array(
						'name'       => 'sticky-header-' . $_prefix . '-back-h-color',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-back-h-color' ),
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-background-color-group]',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 10,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '悬停', 'adaptive-addon' ),
						'tab'        => __( '悬停', 'adaptive-addon' ),
					),

					/**
					* Option: Button Border Size
					*/
					array(
						'name'           => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-border-size]',
						'default'        => adaptive_get_option( 'sticky-header-' . $_prefix . '-border-size' ),
						'type'           => 'control',
						'section'        => $_section,
						'control'        => 'ast-border',
						'transport'      => 'postMessage',
						'linked_choices' => true,
						'priority'       => 110,
						'title'          => __( '边框宽度', 'adaptive-addon' ),
						'context'        => adaptive_addon_builder_helper()->design_tab,
						'choices'        => array(
							'top'    => __( '顶部', 'adaptive-addon' ),
							'right'  => __( '右', 'adaptive-addon' ),
							'bottom' => __( '底部', 'adaptive-addon' ),
							'left'   => __( '左', 'adaptive-addon' ),
						),
					),

					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-button-border-colors-group]',
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '边框颜色', 'adaptive-addon' ),
						'section'    => $_section,
						'priority'   => 110,
						'transport'  => 'postMessage',
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'responsive' => true,
					),

					/**
					* Option: Button Border Color
					*/
					array(
						'name'       => 'sticky-header-' . $_prefix . '-border-color',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-border-color' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-button-border-colors-group]',
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 110,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '标准', 'adaptive-addon' ),
					),

					/**
					* Option: Button Border Hover Color
					*/
					array(
						'name'       => 'sticky-header-' . $_prefix . '-border-h-color',
						'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-border-h-color' ),
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-button-border-colors-group]',
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 110,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '悬停', 'adaptive-addon' ),
					),

					/**
					* Option: Button Border Radius
					*/
					array(
						'name'        => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-border-radius]',
						'default'     => adaptive_get_option( 'sticky-header-' . $_prefix . '-border-radius' ),
						'type'        => 'control',
						'section'     => $_section,
						'control'     => 'ast-slider',
						'transport'   => 'postMessage',
						'priority'    => 110,
						'context'     => adaptive_addon_builder_helper()->design_tab,
						'title'       => __( '边界圆角', 'adaptive-addon' ),
						'suffix'      => 'px',
						'input_attrs' => array(
							'min'  => 0,
							'step' => 1,
							'max'  => 100,
						),
						'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
					),

					// Padding.
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-padding]',
						'default'           => adaptive_get_option( 'sticky-header-' . $_prefix . '-padding' ),
						'type'              => 'control',
						'transport'         => 'postMessage',
						'control'           => 'ast-responsive-spacing',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
						'section'           => $_section,
						'priority'          => 120,
						'title'             => __( '粘性页眉内边距', 'adaptive-addon' ),
						'linked_choices'    => true,
						'unit_choices'      => array( 'px', 'em', '%' ),
						'choices'           => array(
							'top'    => __( '顶部', 'adaptive-addon' ),
							'right'  => __( '右', 'adaptive-addon' ),
							'bottom' => __( '底部', 'adaptive-addon' ),
							'left'   => __( '左', 'adaptive-addon' ),
						),
						'context'           => adaptive_addon_builder_helper()->design_tab,
					),
				);

				$html_config[] = $_configs;
			}

			$html_config    = call_user_func_array( 'array_merge', $html_config + array( array() ) );
			$configurations = array_merge( $configurations, $html_config );

			return $configurations;
		}
	}
}

new Adaptive_Sticky_Header_Button_Configs();



