<?php
/**
 * Sticky Header Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Configs' ) ) {

	/**
	 * Register Sticky Header Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$header_above_section          = 'section-sticky-header';
			$header_below_section          = 'section-sticky-header';
			$header_primary_section        = 'section-sticky-header';
			$header_color_label            = __( '表头', 'adaptive-addon' );
			$header_primary_color_priority = 85;

			if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				$header_above_section          = 'section-above-header-builder';
				$header_below_section          = 'section-below-header-builder';
				$header_primary_section        = 'section-primary-header-builder';
				$header_primary_color_priority = 85;
				$header_color_label            = __( '背景颜色', 'adaptive-addon' );
			}

			$_config = array(

				/**
				* Option: Sticky Header Primary Divider
				*/
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[divider-section-sticky-primary-header]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'section'  => 'section-sticky-header',
					'title'    => __( '主标题的颜色', 'adaptive-addon' ),
					'settings' => array(),
					'priority' => 80,
					'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: Stick Primary Header
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[header-main-stick]',
					'default'   => adaptive_get_option( 'header-main-stick' ),
					'type'      => 'control',
					'section'   => 'section-sticky-header',
					'title'     => __( '固定主页眉', 'adaptive-addon' ),
					'priority'  => 10,
					'control'   => Adaptive_Theme_Extension::$switch_control,
					'transport' => 'refresh',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[different-sticky-logo]',
					'default'  => adaptive_get_option( 'different-sticky-logo' ),
					'type'     => 'control',
					'section'  => 'section-sticky-header',
					'title'    => __( '不同页眉采用不同的logo？', 'adaptive-addon' ),
					'priority' => 15,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Sticky header logo selector
				 */
				array(
					'name'           => ADAPTIVE_THEME_SETTINGS . '[sticky-header-logo]',
					'default'        => adaptive_get_option( 'sticky-header-logo' ),
					'type'           => 'control',
					'control'        => 'image',
					'section'        => 'section-sticky-header',
					'priority'       => 16,
					'title'          => __( '固定logo', 'adaptive-addon' ),
					'library_filter' => array( 'gif', 'jpg', 'jpeg', 'png', 'ico' ),
					'context'        => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[different-sticky-logo]',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),

				/**
				 * Option: Different retina logo
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[different-sticky-retina-logo]',
					'default'  => adaptive_get_option( 'different-sticky-retina-logo' ),
					'type'     => 'control',
					'section'  => 'section-sticky-header',
					'title'    => __( '视网膜设备的不同logo?', 'adaptive-addon' ),
					'priority' => 20,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[different-sticky-logo]',
							'operator' => '==',
							'value'    => 1,
						),
					),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
				),

				/**
				 * Option: Sticky header logo selector
				 */
				array(
					'name'           => ADAPTIVE_THEME_SETTINGS . '[sticky-header-retina-logo]',
					'default'        => adaptive_get_option( 'sticky-header-retina-logo' ),
					'type'           => 'control',
					'control'        => 'image',
					'section'        => 'section-sticky-header',
					'priority'       => 21,
					'title'          => __( '固定视网膜屏logo', 'adaptive-addon' ),
					'library_filter' => array( 'gif', 'jpg', 'jpeg', 'png', 'ico' ),
					'context'        => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[different-sticky-logo]',
							'operator' => '==',
							'value'    => 1,
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[different-sticky-retina-logo]',
							'operator' => '==',
							'value'    => 1,
						),
					),
				),

				/**
				 * Option: Sticky header logo width
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-logo-width]',
					'default'           => adaptive_get_option( 'sticky-header-logo-width' ),
					'type'              => 'control',
					'transport'         => 'postMessage',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'section'           => 'section-sticky-header',
					'priority'          => 25,
					'suffix'            => 'px',
					'title'             => __( '固定logo宽度', 'adaptive-addon' ),
					'input_attrs'       => array(
						'min'  => 50,
						'step' => 1,
						'max'  => 600,
					),
					'context'           => array(
						'relation' => 'AND',
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[different-sticky-logo]',
							'operator' => '==',
							'value'    => 1,
						),
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Shrink Primary Header
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[header-main-shrink]',
					'default'     => adaptive_get_option( 'header-main-shrink' ),
					'type'        => 'control',
					'section'     => 'section-sticky-header',
					'title'       => __( '开启收缩效果', 'adaptive-addon' ),
					'priority'    => 13.1,
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
					'description' => __( '它将缩小固定标题的高度，logo和菜单的大小。固定标题将显示在一个压缩的范围大小。', 'adaptive-addon' ),
				),

				/**
				 * Option: Hide on scroll
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-hide-on-scroll]',
					'default'  => adaptive_get_option( 'sticky-hide-on-scroll' ),
					'type'     => 'control',
					'section'  => 'section-sticky-header',
					'title'    => __( '向下滚动时隐藏', 'adaptive-addon' ),
					'priority' => 13.2,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable disable mobile header
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-style]',
					'default'    => adaptive_get_option( 'sticky-header-style' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => 'section-sticky-header',
					'priority'   => 40,
					'title'      => __( '选择动画', 'adaptive-addon' ),
					'choices'    => array(
						'none'  => __( '无', 'adaptive-addon' ),
						'slide' => __( '向上滑', 'adaptive-addon' ),
						'fade'  => __( '渐褪', 'adaptive-addon' ),
					),
					'context'    => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[sticky-hide-on-scroll]',
							'operator' => '!=',
							'value'    => 1,
						),
					),
					'transport'  => 'refresh',
					'responsive' => false,
					'renderAs'   => 'text',
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Sticky Header Display On
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-on-devices]',
					'default'    => adaptive_get_option( 'sticky-header-on-devices' ),
					'type'       => 'control',
					'section'    => 'section-sticky-header',
					'priority'   => 50,
					'title'      => __( '启用', 'adaptive-addon' ),
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'choices'    => array(
						'desktop' => __( '桌面端', 'adaptive-addon' ),
						'mobile'  => __( '手机号', 'adaptive-addon' ),
						'both'    => __( '桌面端+移动端', 'adaptive-addon' ),
					),
					'responsive' => false,
					'renderAs'   => 'text',
				),

				/**
				 * Option: Sticky Header Button Colors Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-color-divider]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'section'  => 'section-sticky-header',
					'title'    => __( '页眉按钮', 'adaptive-addon' ),
					'settings' => array(),
					'priority' => 55,
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section]',
							'operator' => '==',
							'value'    => 'button',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section-button-style]',
							'operator' => '===',
							'value'    => 'custom-button',
						),
					),
				),

				/**
				 * Group: Theme Button Colors Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-color-group]',
					'default'   => adaptive_get_option( 'sticky-header-button-color-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '颜色', 'adaptive-addon' ),
					'section'   => 'section-sticky-header',
					'transport' => 'postMessage',
					'priority'  => 55,
					'context'   => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section]',
							'operator' => '==',
							'value'    => 'button',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section-button-style]',
							'operator' => '===',
							'value'    => 'custom-button',
						),
					),
				),
				/**
				 * Group: Theme Button Border Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-border-group]',
					'default'   => adaptive_get_option( 'sticky-header-button-border-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '边框', 'adaptive-addon' ),
					'section'   => 'section-sticky-header',
					'transport' => 'postMessage',
					'priority'  => 55,
					'context'   => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section]',
							'operator' => '==',
							'value'    => 'button',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section-button-style]',
							'operator' => '===',
							'value'    => 'custom-button',
						),
					),
				),

			);

			if ( self::is_header_section_active() ) {

				$_new_configs = array(
					/**
					 * Option: Sticky Header Above Divider
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[divider-section-sticky-above-header]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => 'section-sticky-header',
						'title'    => __( '标题以上颜色', 'adaptive-addon' ),
						'settings' => array(),
						'priority' => 60,
						'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
							adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					),

					/**
					 * Option: Sticky Header Below Divider
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[divider-section-sticky-below-header]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => 'section-sticky-header',
						'title'    => __( '标题以下颜色', 'adaptive-addon' ),
						'settings' => array(),
						'priority' => 110,
						'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
							adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
					),
				);
				if ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

					$sticky_individual_configs = array(

						/**
						* Option: Sticky Above Header Heading
						*/
						array(
							'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-above-header-options]',
							'type'     => 'control',
							'control'  => 'ast-heading',
							'section'  => $header_above_section,
							'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
							'settings' => array(),
							'priority' => 80,
							'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),

						/**
						* Option: Sticky Below Header Heading
						*/
						array(
							'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-below-header-options]',
							'type'     => 'control',
							'control'  => 'ast-heading',
							'section'  => $header_below_section,
							'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
							'settings' => array(),
							'priority' => 80,
							'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),

						/**
						* Option: Sticky Primary Header Heading
						*/
						array(
							'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-primary-header-options]',
							'type'     => 'control',
							'control'  => 'ast-heading',
							'section'  => $header_primary_section,
							'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
							'settings' => array(),
							'priority' => 80,
							'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),

						// Option: Site Title Color.
						array(
							'name'    => 'sticky-header-builder-site-title-color',
							'parent'  => ADAPTIVE_THEME_SETTINGS . '[sticky-site-identity-title-color-group]',
							'section' => 'title_tagline',
							'type'    => 'sub-control',
							'control' => 'ast-color',
							'default' => adaptive_get_option( 'sticky-header-builder-site-title-color' ),
							'title'   => __( '标准', 'adaptive-addon' ),
						),

						// Option: Site Title Hover Color.
						array(
							'name'    => 'sticky-header-builder-site-title-h-color',
							'parent'  => ADAPTIVE_THEME_SETTINGS . '[sticky-site-identity-title-color-group]',
							'section' => 'title_tagline',
							'type'    => 'sub-control',
							'control' => 'ast-color',
							'default' => adaptive_get_option( 'sticky-header-builder-site-title-h-color' ),
							'title'   => __( '悬停', 'adaptive-addon' ),
						),

						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-bg-color-responsive]',
							'default'    => adaptive_get_option( 'sticky-header-bg-color-responsive' ),
							'type'       => 'control',
							'section'    => $header_primary_section,
							'priority'   => $header_primary_color_priority,
							'control'    => 'ast-responsive-color',
							'transport'  => 'postMessage',
							'title'      => __( '背景颜色', 'adaptive-addon' ),
							'responsive' => true,
							'rgba'       => true,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
							adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
					);

					if ( adaptive_addon_check_theme_3_5_0_version() ) {
						array_push(
							$sticky_individual_configs,
							/**
							* Option: Sticky Site Identity Heading
							*/
							array(
								'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-site-identity-options]',
								'type'     => 'control',
								'control'  => 'ast-heading',
								'section'  => 'title_tagline',
								'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
								'settings' => array(),
								'priority' => 20,
								'context'  => array(
									'relation' => 'AND',
									adaptive_addon_builder_helper()->design_tab_config,
									array(
										'relation' => 'OR',
										array(
											'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-title]',
											'operator' => '==',
											'value'    => true,
										),
										array(
											'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline]',
											'operator' => '==',
											'value'    => true,
										),
									),
								),
							),
							array(
								'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-site-identity-title-color-group]',
								'default'   => adaptive_get_option( 'sticky-site-identity-title-color-group' ),
								'type'      => 'control',
								'control'   => 'ast-color-group',
								'title'     => __( '标题颜色', 'adaptive-addon' ),
								'section'   => 'title_tagline',
								'transport' => 'postMessage',
								'priority'  => 21,
								'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
								'context'   => array(
									adaptive_addon_builder_helper()->design_tab_config,
									array(
										'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-title]',
										'operator' => '==',
										'value'    => true,
									),
								),
							),
							// Option: Site Tagline Color.
							array(
								'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-builder-site-tagline-color]',
								'type'              => 'control',
								'control'           => 'ast-color',
								'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
								'priority'          => 22,
								'transport'         => 'postMessage',
								'default'           => adaptive_get_option( 'sticky-header-builder-site-tagline-color' ),
								'title'             => __( '副标题', 'adaptive-addon' ),
								'section'           => 'title_tagline',
								'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
								'context'           => array(
									adaptive_addon_builder_helper()->design_tab_config,
									array(
										'setting'  => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline]',
										'operator' => '==',
										'value'    => true,
									),
								),
							)
						);
					} else {
						array_push(
							$sticky_individual_configs,
							/**
							* Option: Sticky Site Identity Heading
							*/
							array(
								'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-site-identity-options]',
								'type'     => 'control',
								'control'  => 'ast-heading',
								'section'  => 'title_tagline',
								'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
								'settings' => array(),
								'priority' => 20,
								'context'  => array(
									'relation' => 'AND',
									adaptive_addon_builder_helper()->design_tab_config,
									array(
										'relation' => 'OR',
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
											'setting-key' => 'desktop',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
											'setting-key' => 'tablet',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
											'setting-key' => 'mobile',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline-responsive]',
											'setting-key' => 'desktop',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline-responsive]',
											'setting-key' => 'tablet',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline-responsive]',
											'setting-key' => 'mobile',
											'operator'    => '==',
											'value'       => true,
										),
									),
								),
							),
							array(
								'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-site-identity-title-color-group]',
								'default'   => adaptive_get_option( 'sticky-site-identity-title-color-group' ),
								'type'      => 'control',
								'control'   => 'ast-color-group',
								'title'     => __( '标题颜色', 'adaptive-addon' ),
								'section'   => 'title_tagline',
								'transport' => 'postMessage',
								'priority'  => 21,
								'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
								'context'   => array(
									adaptive_addon_builder_helper()->design_tab_config,
									array(
										'relation' => 'OR',
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
											'setting-key' => 'desktop',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
											'setting-key' => 'tablet',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-title-responsive]',
											'setting-key' => 'mobile',
											'operator'    => '==',
											'value'       => true,
										),
									),
								),
							),
							// Option: Site Tagline Color.
							array(
								'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-builder-site-tagline-color]',
								'type'              => 'control',
								'control'           => 'ast-color',
								'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
								'priority'          => 22,
								'transport'         => 'postMessage',
								'default'           => adaptive_get_option( 'sticky-header-builder-site-tagline-color' ),
								'title'             => __( '副标题', 'adaptive-addon' ),
								'section'           => 'title_tagline',
								'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
								'context'           => array(
									adaptive_addon_builder_helper()->design_tab_config,
									array(
										'relation' => 'OR',
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline-responsive]',
											'setting-key' => 'desktop',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline-responsive]',
											'setting-key' => 'tablet',
											'operator'    => '==',
											'value'       => true,
										),
										array(
											'setting'     => ADAPTIVE_THEME_SETTINGS . '[display-site-tagline-responsive]',
											'setting-key' => 'mobile',
											'operator'    => '==',
											'value'       => true,
										),
									),
								),
							)
						);
					}

					$sticky_menu_configs = array();

					$component_limit = adaptive_addon_builder_helper()->component_limit;
					for ( $index = 1; $index <= $component_limit; $index++ ) {

						$_section = 'section-hb-menu-' . $index;
						$_prefix  = 'menu' . $index;

						$sticky_config = array(

							/**
							 * Option: Sticky Menu 1 Heading
							 */
							array(
								'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-menu-' . $index . '-options]',
								'type'     => 'control',
								'control'  => 'ast-heading',
								'section'  => 'section-hb-menu-' . $index,
								'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
								'settings' => array(),
								'priority' => 100,
								'context'  => adaptive_addon_builder_helper()->design_tab,
							),

							// Option Group: Menu Color.
							array(
								'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-link-colors]',
								'type'       => 'control',
								'control'    => Adaptive_Theme_Extension::$group_control,
								'title'      => __( '文字 / 链接', 'adaptive-addon' ),
								'section'    => $_section,
								'priority'   => 101,
								'context'    => adaptive_addon_builder_helper()->design_tab,
								'responsive' => true,
								'divider'    => array(
									'ast_title' => __( '菜单颜色', 'adaptive-addon' ),
								),
							),

							array(
								'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-background-colors]',
								'type'       => 'control',
								'control'    => Adaptive_Theme_Extension::$group_control,
								'title'      => __( '背景', 'adaptive-addon' ),
								'section'    => $_section,
								'priority'   => 101,
								'context'    => adaptive_addon_builder_helper()->design_tab,
								'responsive' => true,
							),

							// Option: Menu Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-link-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'section'    => $_section,
								'title'      => __( '标准', 'adaptive-addon' ),
								'tab'        => __( '标准', 'adaptive-addon' ),
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 7,
								'context'    => adaptive_addon_builder_helper()->design_tab,
							),

							// Option: Menu Background image, color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-bg-obj-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-bg-obj-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-background-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'responsive' => true,
								'rgba'       => true,
								'section'    => $_section,
								'data_attrs' => array( 'name' => 'sticky-header-' . $_prefix . '-bg-obj-responsive' ),
								'title'      => __( '标准', 'adaptive-addon' ),
								'tab'        => __( '标准', 'adaptive-addon' ),
								'priority'   => 9,
								'context'    => adaptive_addon_builder_helper()->design_tab,
							),

							// Option: Menu Hover Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-h-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-h-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-link-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'title'      => __( '悬停', 'adaptive-addon' ),
								'tab'        => __( '悬停', 'adaptive-addon' ),
								'section'    => $_section,
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 19,
								'context'    => adaptive_addon_builder_helper()->design_tab,
							),

							// Option: Menu Hover Background Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-h-bg-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-h-bg-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-background-colors]',
								'type'       => 'sub-control',
								'title'      => __( '悬停', 'adaptive-addon' ),
								'tab'        => __( '悬停', 'adaptive-addon' ),
								'section'    => $_section,
								'control'    => 'ast-responsive-color',
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 21,
								'context'    => adaptive_addon_builder_helper()->design_tab,
							),

							// Option: Active Menu Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-a-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-a-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-link-colors]',
								'type'       => 'sub-control',
								'section'    => $_section,
								'control'    => 'ast-responsive-color',
								'title'      => __( '已启用', 'adaptive-addon' ),
								'tab'        => __( '已启用', 'adaptive-addon' ),
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 31,
								'context'    => adaptive_addon_builder_helper()->design_tab,
							),

							// Option: Active Menu Background Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-a-bg-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-a-bg-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-background-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'section'    => $_section,
								'title'      => __( '已启用', 'adaptive-addon' ),
								'tab'        => __( '已启用', 'adaptive-addon' ),
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 33,
								'context'    => adaptive_addon_builder_helper()->design_tab,
							),

							// Option Group: Sub Menu Colors.
							array(
								'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-link-colors]',
								'type'       => 'control',
								'control'    => Adaptive_Theme_Extension::$group_control,
								'title'      => __( '文字 / 链接', 'adaptive-addon' ),
								'section'    => $_section,
								'priority'   => 102,
								'context'    => adaptive_addon_builder_helper()->design_tab,
								'responsive' => true,
								'divider'    => array(
									'ast_class' => 'ast-top-divider',
									'ast_title' => __( '子菜单颜色', 'adaptive-addon' ),
								),
							),
							array(
								'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-background-colors]',
								'type'       => 'control',
								'control'    => Adaptive_Theme_Extension::$group_control,
								'title'      => __( '背景', 'adaptive-addon' ),
								'section'    => $_section,
								'priority'   => 102,
								'context'    => adaptive_addon_builder_helper()->design_tab,
								'responsive' => true,
								'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
							),

							// Option: Submenu Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-submenu-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-submenu-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-link-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'title'      => __( '标准', 'adaptive-addon' ),
								'tab'        => __( '标准', 'adaptive-addon' ),
								'section'    => $_section,
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 13,
							),

							// Option: Submenu Background Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-submenu-bg-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-submenu-bg-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-background-colors]',
								'type'       => 'sub-control',
								'title'      => __( '标准', 'adaptive-addon' ),
								'tab'        => __( '标准', 'adaptive-addon' ),
								'section'    => $_section,
								'control'    => 'ast-responsive-color',
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 15,
							),

							// Option: Submenu Hover Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-submenu-h-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-submenu-h-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-link-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'section'    => $_section,
								'title'      => __( '悬停', 'adaptive-addon' ),
								'tab'        => __( '悬停', 'adaptive-addon' ),
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 25,
							),

							// Option: Submenu Hover Background Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-submenu-h-bg-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-submenu-h-bg-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-background-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'section'    => $_section,
								'title'      => __( '悬停', 'adaptive-addon' ),
								'tab'        => __( '悬停', 'adaptive-addon' ),
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 27,
							),

							// Option: Active Submenu Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-submenu-a-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-submenu-a-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-link-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'section'    => $_section,
								'title'      => __( '已启用', 'adaptive-addon' ),
								'tab'        => __( '已启用', 'adaptive-addon' ),
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 37,
							),

							// Option: Active Submenu Background Color.
							array(
								'name'       => 'sticky-header-' . $_prefix . '-submenu-a-bg-color-responsive',
								'default'    => adaptive_get_option( 'sticky-header-' . $_prefix . '-submenu-a-bg-color-responsive' ),
								'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-submenu-background-colors]',
								'type'       => 'sub-control',
								'control'    => 'ast-responsive-color',
								'section'    => $_section,
								'title'      => __( '已启用', 'adaptive-addon' ),
								'tab'        => __( '已启用', 'adaptive-addon' ),
								'responsive' => true,
								'rgba'       => true,
								'priority'   => 39,
							),
						);
						$sticky_menu_configs[] = $sticky_config;

						if ( 3 > $index ) {

							$sticky_config = array(

								// Option Group: Primary Mega Menu Colors.
								array(
									'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-mega-menu-col-color-group]',
									'type'     => 'control',
									'control'  => 'ast-color-group',
									'title'    => __( '超级菜单标题', 'adaptive-addon' ),
									'section'  => $_section,
									'priority' => 103,
									'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
									'context'  => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
									adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
								),

								// Option: Megamenu Heading Color.
								array(
									'name'    => 'sticky-header-' . $_prefix . '-header-megamenu-heading-color',
									'default' => adaptive_get_option( 'sticky-header-' . $_prefix . '-header-megamenu-heading-color' ),
									'parent'  => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-mega-menu-col-color-group]',
									'type'    => 'sub-control',
									'control' => 'ast-color',
									'section' => $_section,
									'title'   => __( '标准', 'adaptive-addon' ),
								),

								// Option: Megamenu Heading Hover Color.
								array(
									'name'    => 'sticky-header-' . $_prefix . '-header-megamenu-heading-h-color',
									'default' => adaptive_get_option( 'sticky-header-' . $_prefix . '-header-megamenu-heading-h-color' ),
									'parent'  => ADAPTIVE_THEME_SETTINGS . '[sticky-header-' . $_prefix . '-mega-menu-col-color-group]',
									'type'    => 'sub-control',
									'control' => 'ast-color',
									'section' => $_section,
									'title'   => __( '悬停', 'adaptive-addon' ),
								),
							);

							$sticky_menu_configs[] = $sticky_config;
						}
					}

					$sticky_menu_configs       = call_user_func_array( 'array_merge', $sticky_menu_configs + array( array() ) );
					$sticky_individual_configs = array_merge( $sticky_individual_configs, $sticky_menu_configs );

				} else {

					$sticky_individual_configs = array(

						/**
						 * Option: Sticky Header primary Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-header-colors]',
							'default'    => adaptive_get_option( 'sticky-header-primary-header-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => '站点标题颜色',
							'section'    => $header_primary_section,
							'transport'  => 'postMessage',
							'priority'   => 86,
							'responsive' => true,
							'divider'    => array( 'ast_class' => 'ast-top-divider' ),
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),

						/**
						 * Option: Sticky Header Above Menu Link Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-menus-link-colors]',
							'default'    => adaptive_get_option( 'sticky-header-above-menus-link-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接 / 文本', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 61,
							'responsive' => true,
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '菜单', 'adaptive-addon' ),
							),
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
						/**
						 * Option: Sticky Header Above Menu Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-menus-colors]',
							'default'    => adaptive_get_option( 'sticky-header-above-menus-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '背景', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 61,
							'responsive' => true,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),

						/**
						 * Option: Sticky Header Above Menu Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-submenus-link-colors]',
							'default'    => adaptive_get_option( 'sticky-header-above-submenus-link-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接 / 文本', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 65,
							'responsive' => true,
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '子菜单', 'adaptive-addon' ),
							),
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
						/**
						 * Option: Sticky Header Above Menu Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-submenus-colors]',
							'default'    => adaptive_get_option( 'sticky-header-above-submenus-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '背景', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 65,
							'responsive' => true,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),

						/**
						 * Option: Sticky Header primary Link Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-menus-link-colors]',
							'default'    => adaptive_get_option( 'sticky-header-primary-menus-link-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接 / 文本', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 90,
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '菜单', 'adaptive-addon' ),
							),
							'responsive' => true,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
						/**
						 * Option: Sticky Header primary Link Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-menus-colors]',
							'default'    => adaptive_get_option( 'sticky-header-primary-menus-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '背景', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 90,
							'responsive' => true,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),

						/**
						 * Option: Sticky Header primary Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-submenu-link-colors]',
							'default'    => adaptive_get_option( 'sticky-header-primary-submenu-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接文本', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 95,
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '子菜单', 'adaptive-addon' ),
							),
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
							adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							'responsive' => true,
						),
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-submenu-background-colors]',
							'default'    => adaptive_get_option( 'sticky-header-primary-submenu-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '背景', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 95,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							'responsive' => true,
						),

						/**
						 * Option: Sticky Header Below Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-menus-link-colors]',
							'default'    => adaptive_get_option( 'sticky-header-below-menus-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接文本', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 120,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							'responsive' => true,
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '菜单', 'adaptive-addon' ),
							),
						),
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-menus-background-colors]',
							'default'    => adaptive_get_option( 'sticky-header-below-menus-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '背景', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 120,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							'responsive' => true,
						),

						/**
						 * Option: Sticky Header Below Submenu Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-submenus-link-colors]',
							'default'    => adaptive_get_option( 'sticky-header-below-submenus-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接 / 文本', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 125,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							'responsive' => true,
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '子菜单', 'adaptive-addon' ),
							),
						),
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-submenus-background-colors]',
							'default'    => adaptive_get_option( 'sticky-header-below-submenus-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '背景', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 125,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							'responsive' => true,
						),

						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-bg-color-responsive]',
							'default'    => adaptive_get_option( 'sticky-header-bg-color-responsive' ),
							'type'       => 'control',
							'tab'        => __( '标准', 'adaptive-addon' ),
							'priority'   => 85,
							'section'    => 'section-sticky-header',
							'control'    => 'ast-responsive-color',
							'transport'  => 'postMessage',
							'title'      => __( '背景颜色', 'adaptive-addon' ),
							'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
							'responsive' => true,
							'rgba'       => true,
						),
						/**
						* Option: Site Title Color
						*/
						array(
							'name'       => 'sticky-header-color-site-title-responsive',
							'default'    => adaptive_get_option( 'sticky-header-color-site-title-responsive' ),
							'type'       => 'sub-control',
							'tab'        => __( '标准', 'adaptive-addon' ),
							'priority'   => 7,
							'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-header-colors]',
							'section'    => 'section-sticky-header',
							'control'    => 'ast-responsive-color',
							'transport'  => 'postMessage',
							'title'      => __( '标准', 'adaptive-addon' ),
							'responsive' => true,
							'rgba'       => true,
						),

						/**
						* Option: Site Title Hover Color
						*/
						array(
							'name'       => 'sticky-header-color-h-site-title-responsive',
							'default'    => adaptive_get_option( 'sticky-header-color-h-site-title-responsive' ),
							'type'       => 'sub-control',
							'tab'        => __( '悬停', 'adaptive-addon' ),
							'priority'   => 8,
							'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-header-colors]',
							'section'    => 'section-sticky-header',
							'control'    => 'ast-responsive-color',
							'transport'  => 'postMessage',
							'title'      => __( '悬停', 'adaptive-addon' ),
							'responsive' => true,
							'rgba'       => true,
						),

						/**
						* Option: Site Tagline Color
						*/
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-color-site-tagline-responsive]',
							'default'    => adaptive_get_option( 'sticky-header-color-site-tagline-responsive' ),
							'type'       => 'control',
							'priority'   => 85,
							'section'    => 'section-sticky-header',
							'control'    => 'ast-responsive-color',
							'transport'  => 'postMessage',
							'title'      => __( '网站标语的颜色', 'adaptive-addon' ),
							'responsive' => true,
							'rgba'       => true,
							'connect'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-color-site-tagline-responsive]',
						),

						/**
						* Option: Content Section Text color.
						*/
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-below-header-content-section-text-color-responsive]',
							'default'    => adaptive_get_option( 'sticky-below-header-content-section-text-color-responsive' ),
							'type'       => 'control',
							'transport'  => 'postMessage',
							'control'    => 'ast-responsive-color',
							'title'      => __( '文字', 'adaptive-addon' ),
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '内容', 'adaptive-addon' ),
							),
							'responsive' => true,
							'rgba'       => true,
							'priority'   => 135,
							'section'    => 'section-sticky-header',
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
						/**
						 * Option: Sticky Header Header Content Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-below-header-content-colors]',
							'default'    => adaptive_get_option( 'sticky-header-below-header-content-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 135,
							'responsive' => true,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
						/**
						 * Option: Content Section Text color.
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-content-section-text-color-responsive]',
							'default'    => adaptive_get_option( 'sticky-header-content-section-text-color-responsive' ),
							'type'       => 'control',
							'priority'   => 105,
							'section'    => 'section-sticky-header',
							'control'    => 'ast-responsive-color',
							'transport'  => 'postMessage',
							'title'      => __( '文字', 'adaptive-addon' ),
							'responsive' => true,
							'rgba'       => true,
							'divider'    => array(
								'ast_class' => 'ast-top-divider',
								'ast_title' => __( '外观', 'adaptive-addon' ),
							),
							'context'    => adaptive_addon_builder_helper()->is_header_footer_builder_active ? adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
						/**
						 * Option: Sticky Header primary Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-primary-outside-item-colors]',
							'default'    => adaptive_get_option( 'sticky-header-primary-outside-item-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 105,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
							'responsive' => true,
						),

						/**
						 * Option: Sticky Header Above Link Color Group
						 */
						array(
							'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-above-outside-item-link-colors]',
							'default'    => adaptive_get_option( 'sticky-header-above-outside-item-link-colors' ),
							'type'       => 'control',
							'control'    => Adaptive_Theme_Extension::$group_control,
							'title'      => __( '链接', 'adaptive-addon' ),
							'section'    => 'section-sticky-header',
							'transport'  => 'postMessage',
							'priority'   => 75,
							'responsive' => true,
							'context'    => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
								adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
						),
					);
				}

				$_new_configs = array_merge( $_new_configs, $sticky_individual_configs );
				$_config      = array_merge( $_config, $_new_configs );
			}

			if ( false === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
				$_new_configs = array(
					/**
					 * Option: Button Text Color
					 */
					array(
						'name'              => 'header-main-rt-sticky-section-button-text-color',
						'transport'         => 'postMessage',
						'default'           => adaptive_get_option( 'header-main-rt-sticky-section-button-text-color' ),
						'type'              => 'sub-control',
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-color-group]',
						'section'           => 'section-sticky-header',
						'tab'               => __( '标准', 'adaptive-addon' ),
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'priority'          => 10,
						'title'             => __( '文本颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Button Text Hover Color
					 */
					array(
						'name'              => 'header-main-rt-sticky-section-button-text-h-color',
						'default'           => adaptive_get_option( 'header-main-rt-sticky-section-button-text-h-color' ),
						'transport'         => 'postMessage',
						'type'              => 'sub-control',
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-color-group]',
						'section'           => 'section-sticky-header',
						'tab'               => __( '悬停', 'adaptive-addon' ),
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'priority'          => 10,
						'title'             => __( '文本颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Button Background Color
					 */
					array(
						'name'              => 'header-main-rt-sticky-section-button-back-color',
						'default'           => adaptive_get_option( 'header-main-rt-sticky-section-button-back-color' ),
						'transport'         => 'postMessage',
						'type'              => 'sub-control',
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-color-group]',
						'section'           => 'section-sticky-header',
						'tab'               => __( '标准', 'adaptive-addon' ),
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'priority'          => 10,
						'title'             => __( '背景颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Button Button Hover Color
					 */
					array(
						'name'              => 'header-main-rt-sticky-section-button-back-h-color',
						'default'           => adaptive_get_option( 'header-main-rt-sticky-section-button-back-h-color' ),
						'transport'         => 'postMessage',
						'type'              => 'sub-control',
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-color-group]',
						'section'           => 'section-sticky-header',
						'tab'               => __( '悬停', 'adaptive-addon' ),
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'priority'          => 10,
						'title'             => __( '背景颜色', 'adaptive-addon' ),
					),

					// Option: Button Custom Menu Button Border.
					array(
						'type'              => 'control',
						'control'           => 'ast-responsive-spacing',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
						'name'              => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-sticky-section-button-padding]',
						'section'           => 'section-sticky-header',
						'transport'         => 'postMessage',
						'linked_choices'    => true,
						'priority'          => 55,
						'default'           => adaptive_get_option( 'header-main-rt-sticky-section-button-padding' ),
						'title'             => __( '内距', 'adaptive-addon' ),
						'choices'           => array(
							'top'    => __( '顶部', 'adaptive-addon' ),
							'right'  => __( '右', 'adaptive-addon' ),
							'bottom' => __( '底部', 'adaptive-addon' ),
							'left'   => __( '左', 'adaptive-addon' ),
						),
						'context'           => array(
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-rt-section-button-style]',
								'operator' => '===',
								'value'    => 'custom-button',
							),
						),
					),

					/**
					 * Option: Button Border Size
					 */
					array(
						'type'           => 'sub-control',
						'parent'         => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-border-group]',
						'section'        => 'section-sticky-header',
						'control'        => 'ast-border',
						'name'           => 'header-main-rt-sticky-section-button-border-size',
						'transport'      => 'postMessage',
						'linked_choices' => true,
						'priority'       => 10,
						'default'        => adaptive_get_option( 'header-main-rt-sticky-section-button-border-size' ),
						'title'          => __( '宽度', 'adaptive-addon' ),
						'choices'        => array(
							'top'    => __( '顶部', 'adaptive-addon' ),
							'right'  => __( '右', 'adaptive-addon' ),
							'bottom' => __( '底部', 'adaptive-addon' ),
							'left'   => __( '左', 'adaptive-addon' ),
						),
					),

					/**
					 * Option: Button Border Color
					 */
					array(
						'name'              => 'header-main-rt-sticky-section-button-border-color',
						'default'           => adaptive_get_option( 'header-main-rt-sticky-section-button-border-color' ),
						'transport'         => 'postMessage',
						'type'              => 'sub-control',
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-border-group]',
						'section'           => 'section-sticky-header',
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'priority'          => 12,
						'title'             => __( '颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Button Border Hover Color
					 */
					array(
						'name'              => 'header-main-rt-sticky-section-button-border-h-color',
						'default'           => adaptive_get_option( 'header-main-rt-sticky-section-button-border-h-color' ),
						'transport'         => 'postMessage',
						'type'              => 'sub-control',
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-border-group]',
						'section'           => 'section-sticky-header',
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'priority'          => 14,
						'title'             => __( '悬停颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Button Border Radius
					 */
					array(
						'name'        => 'header-main-rt-sticky-section-button-border-radius',
						'default'     => adaptive_get_option( 'header-main-rt-sticky-section-button-border-radius' ),
						'type'        => 'sub-control',
						'parent'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-button-border-group]',
						'section'     => 'section-sticky-header',
						'control'     => 'ast-slider',
						'transport'   => 'postMessage',
						'suffix'      => 'px',
						'priority'    => 16,
						'title'       => __( '边界圆角', 'adaptive-addon' ),
						'input_attrs' => array(
							'min'  => 0,
							'step' => 1,
							'max'  => 100,
						),
					),
				);
			} else {
				$_new_configs = array(
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[header-stick-notice]',
						'type'     => 'control',
						'control'  => 'ast-description',
						'section'  => 'section-sticky-header',
						'priority' => 13.5,
						'help'     => __( '注意:你可以在Logo、主菜单、按钮等单独的元素中找到所有粘性页眉相关的设计选项。', 'adaptive-addon' ),
						'context'  => array(
							'relation' => 'AND',
							adaptive_addon_builder_helper()->general_tab_config,
							array(
								'relation' => 'OR',
								array(
									'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-above-stick]',
									'operator' => '==',
									'value'    => true,
								),
								array(
									'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-below-stick]',
									'operator' => '==',
									'value'    => true,
								),
								array(
									'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-main-stick]',
									'operator' => '==',
									'value'    => true,
								),
							),

						),
					),
				);
			}
			$_config = array_merge( $_config, $_new_configs );

			return array_merge( $configurations, $_config );
		}

		/**
		 * Is Header Section addon active.
		 * Decide if the Above & Below option should be visible in Sticky Header depending on Header Section addon.
		 *
		 * @return boolean  True - If the option should be displayed, False - If the option should be hidden.
		 */
		public static function is_header_section_active() {
			$status = false;
			if ( Adaptive_Ext_Extension::is_active( 'header-sections' ) || true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
				$status = true;
			}
			return $status;
		}

	}
}

new Adaptive_Sticky_Header_Configs();



