<?php
/**
 * Sticky Header - Divider Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       3.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Divider_Configs' ) ) {

	/**
	 * Register Sticky Header Above Header Colors Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Divider_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.0.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$divider_config = array();

			$component_limit = adaptive_addon_builder_helper()->component_limit;
			for ( $index = 1; $index <= $component_limit; $index++ ) {

				$_section = 'section-hb-divider-' . $index;

				$_configs = array(

					/**
					 * Option: Sticky Header divider Heading.
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-divider-' . $index . '-heading]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => $_section,
						'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
						'settings' => array(),
						'priority' => 110,
						'context'  => adaptive_addon_builder_helper()->design_tab,
					),
					/**
					 * Option: divider Color.
					 */
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-divider-' . $index . '-color]',
						'default'           => adaptive_get_option( 'sticky-header-divider-' . $index . '-color' ),
						'type'              => 'control',
						'section'           => $_section,
						'priority'          => 120,
						'transport'         => 'postMessage',
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'title'             => __( '颜色', 'adaptive-addon' ),
						'context'           => adaptive_addon_builder_helper()->design_tab,
					),
				);

				$divider_config[] = $_configs;
			}

			$divider_config = call_user_func_array( 'array_merge', $divider_config + array( array() ) );
			$configurations = array_merge( $configurations, $divider_config );

			return $configurations;
		}
	}
}

new Adaptive_Sticky_Header_Divider_Configs();
