<?php
/**
 * Sticky Header - language-switcher Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       3.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Register Sticky Header Above Header Colors Customizer Configurations.
 */
// @codingStandardsIgnoreStart
class Adaptive_Sticky_Header_Language_Switcher_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

	/**
	 * Register Sticky Header Colors Customizer Configurations.
	 *
	 * @param Array                $configurations Adaptive Customizer Configurations.
	 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
	 * @since 3.1.0
	 * @return Array Adaptive Customizer Configurations with updated configurations.
	 */
	public function register_configuration( $configurations, $gc_customize ) {

		$_section = 'section-hb-language-switcher';

		$_configs = array(

			/**
			 * Option: Sticky Header language-switcher Heading.
			 */
			array(
				'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-language-switcher-heading]',
				'type'     => 'control',
				'control'  => 'ast-heading',
				'section'  => $_section,
				'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
				'settings' => array(),
				'priority' => 110,
				'context'  => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-language-switcher-show-name]',
						'operator' => '==',
						'value'    => true,
					),
					adaptive_addon_builder_helper()->design_tab_config,
				),
			),
			/**
			 * Option: language-switcher Color.
			 */
			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-language-switcher-color]',
				'default'   => adaptive_get_option( 'sticky-header-language-switcher-color' ),
				'type'      => 'control',
				'section'   => $_section,
				'priority'  => 120,
				'transport' => 'postMessage',
				'control'   => 'ast-color',
				'title'     => __( '颜色', 'adaptive-addon' ),
				'context'   => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-language-switcher-show-name]',
						'operator' => '==',
						'value'    => true,
					),
					adaptive_addon_builder_helper()->design_tab_config,
				),
				'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
			),
		);

		return array_merge( $configurations, $_configs );
	}
}

new Adaptive_Sticky_Header_Language_Switcher_Configs();
