<?php
/**
 * Sticky Header - Search Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       3.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Search_Configs' ) ) {

	/**
	 * Register Sticky Header Above Header ColorsCustomizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Search_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.0.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_section = 'section-header-search';

			$_configs = array(

				/**
				 * Option: Sticky Header Search Heading.
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-heading]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'section'  => $_section,
					'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
					'settings' => array(),
					'priority' => 10,
					'context'  => adaptive_addon_builder_helper()->design_tab,
				),

				/**
				 * Option: Search text/placeholder Color
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-text-placeholder-color]',
					'default'   => adaptive_get_option( 'sticky-header-search-text-placeholder-color' ),
					'transport' => 'postMessage',
					'type'      => 'control',
					'section'   => $_section,
					'control'   => 'ast-color',
					'priority'  => 20,
					'title'     => __( '文本/占位符颜色', 'adaptive-addon' ),
					'context'   => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
							'operator' => 'in',
							'value'    => array( 'slide-search', 'search-box' ),
						),
					),
				),

				/**
				 * Option: Search icon Color.
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-icon-color-parent]',
					'default'   => adaptive_get_option( 'sticky-header-search-icon-color-parent' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$group_control,
					'title'     => __( '图标颜色', 'adaptive-addon' ),
					'section'   => 'section-header-search',
					'transport' => 'postMessage',
					'priority'  => 20,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),

				/**
				 * Option: Search Color.
				 */
				array(
					'name'              => 'sticky-header-search-icon-color',
					'default'           => adaptive_get_option( 'sticky-header-search-icon-color' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-icon-color-parent]',
					'section'           => $_section,
					'priority'          => 20,
					'transport'         => 'postMessage',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '标准', 'adaptive-addon' ),
					'tab'               => __( '标准', 'adaptive-addon' ),
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),
				/**
				 * Option: Search Color.
				 */
				array(
					'name'      => 'sticky-header-search-icon-h-color',
					'default'   => adaptive_get_option( 'sticky-header-search-icon-h-color' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-icon-color-parent]',
					'section'   => $_section,
					'priority'  => 20,
					'transport' => 'postMessage',
					'control'   => 'ast-color',
					'title'     => __( '悬停', 'adaptive-addon' ),
					'tab'       => __( '悬停', 'adaptive-addon' ),
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: Search bg Color.
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-bg-color-parent]',
					'default'   => adaptive_get_option( 'sticky-header-search-bg-color-parent' ),
					'type'      => 'control',
					'control'   => Adaptive_Theme_Extension::$group_control,
					'title'     => __( '盒子背景', 'adaptive-addon' ),
					'section'   => 'section-header-search',
					'transport' => 'postMessage',
					'priority'  => 20,
					'context'   => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-search-box-type]',
							'operator' => 'in',
							'value'    => array( 'slide-search', 'search-box' ),
						),
					),
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Search Box Background Color
				 */
				array(
					'name'      => 'sticky-header-search-box-background-color',
					'default'   => adaptive_get_option( 'sticky-header-search-box-background-color' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-bg-color-parent]',
					'section'   => $_section,
					'priority'  => 1,
					'transport' => 'postMessage',
					'control'   => 'ast-color',
					'title'     => __( '标准', 'adaptive-addon' ),
					'tab'       => __( '标准', 'adaptive-addon' ),
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),
				/**
				 * Search Box Background hover Color
				 */
				array(
					'name'      => 'sticky-header-search-box-background-h-color',
					'default'   => adaptive_get_option( 'sticky-header-search-box-background-h-color' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sticky-header-search-bg-color-parent]',
					'section'   => $_section,
					'priority'  => 2,
					'transport' => 'postMessage',
					'control'   => 'ast-color',
					'title'     => __( '悬停', 'adaptive-addon' ),
					'tab'       => __( '悬停', 'adaptive-addon' ),
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

new Adaptive_Sticky_Header_Search_Configs();



