<?php
/**
 * Sticky Header - Header Sections Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Sections_Configs' ) ) {

	/**
	 * Register Sticky Header - Header Sections Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Sections_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header - Header Sections Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_config = array(

				/**
				 * Header Button - Sticky
				 */
				array(
					'name'     => 'section-header-button-sticky',
					'type'     => 'section',
					'priority' => 10,
					'title'    => __( '粘性页眉按钮', 'adaptive-addon' ),
					'section'  => 'section-header-button',
				),
			);

			if ( Adaptive_Sticky_Header_Configs::is_header_section_active() ) {
				$_config[] = array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[header-above-stick]',
					'default'   => adaptive_get_option( 'header-above-stick' ),
					'type'      => 'control',
					'section'   => 'section-sticky-header',
					'title'     => __( '固定上页眉', 'adaptive-addon' ),
					'priority'  => 5,
					'control'   => Adaptive_Theme_Extension::$switch_control,
					'context'   => ! adaptive_addon_builder_helper()->is_header_footer_builder_active ? array( ADAPTIVE_THEME_SETTINGS . '[above-header-layout]', '!=', 'disabled' ) : '',
					'transport' => 'refresh',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				);
				$_config[] = array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[header-below-stick]',
					'default'   => adaptive_get_option( 'header-below-stick' ),
					'type'      => 'control',
					'section'   => 'section-sticky-header',
					'title'     => __( '固定下页眉', 'adaptive-addon' ),
					'priority'  => 13,
					'control'   => Adaptive_Theme_Extension::$switch_control,
					'context'   => ! adaptive_addon_builder_helper()->is_header_footer_builder_active ? array( ADAPTIVE_THEME_SETTINGS . '[below-header-layout]', '!=', 'disabled' ) : '',
					'transport' => 'refresh',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				);
			}

			return array_merge( $configurations, $_config );
		}

	}
}

new Adaptive_Sticky_Header_Sections_Configs();



