<?php
/**
 * Sticky Header - Social Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Social_Configs' ) ) {

	/**
	 * Register Sticky Header Above Header ColorsCustomizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Social_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.0.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$section       = 'section-hb-social-icons-';
			$social_config = array();

			$component_limit = adaptive_addon_builder_helper()->component_limit;
			for ( $index = 1; $index <= $component_limit; $index++ ) {

				$_section = $section . $index;

				$_configs = array(

					/**
					 * Option: Sticky Header Button Heading.
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-social-' . $index . '-heading]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => $_section,
						'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
						'settings' => array(),
						'priority' => 50,
						'context'  => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-social-' . $index . '-color-type]',
								'operator' => '==',
								'value'    => 'custom',
							),
						),
					),

					/**
					 * Group: Primary Social Colors Group
					 */
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-social-' . $index . '-color-group]',
						'default'    => adaptive_get_option( 'sticky-header-social-' . $index . '-color-group' ),
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '颜色', 'adaptive-addon' ),
						'section'    => $_section,
						'transport'  => 'postMessage',
						'priority'   => 70,
						'context'    => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-social-' . $index . '-color-type]',
								'operator' => '==',
								'value'    => 'custom',
							),
						),
						'responsive' => true,
					),
					array(
						'name'       => ADAPTIVE_THEME_SETTINGS . '[sticky-header-social-' . $index . '-background-color-group]',
						'default'    => adaptive_get_option( 'sticky-header-social-' . $index . '-color-group' ),
						'type'       => 'control',
						'control'    => Adaptive_Theme_Extension::$group_control,
						'title'      => __( '背景颜色', 'adaptive-addon' ),
						'section'    => $_section,
						'transport'  => 'postMessage',
						'priority'   => 70,
						'context'    => array(
							adaptive_addon_builder_helper()->design_tab_config,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-social-' . $index . '-color-type]',
								'operator' => '==',
								'value'    => 'custom',
							),
						),
						'responsive' => true,
						'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
					),

					/**
					* Option: Social Text Color
					*/
					array(
						'name'       => 'sticky-header-social-' . $index . '-color',
						'transport'  => 'postMessage',
						'default'    => adaptive_get_option( 'sticky-header-social-' . $index . '-color' ),
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-social-' . $index . '-color-group]',
						'section'    => $_section,
						'tab'        => __( '标准', 'adaptive-addon' ),
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 9,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '标准', 'adaptive-addon' ),
					),

					/**
					* Option: Social Text Hover Color
					*/
					array(
						'name'       => 'sticky-header-social-' . $index . '-h-color',
						'default'    => adaptive_get_option( 'sticky-header-social-' . $index . '-h-color' ),
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-social-' . $index . '-color-group]',
						'section'    => $_section,
						'tab'        => __( '悬停', 'adaptive-addon' ),
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 9,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '悬停', 'adaptive-addon' ),
					),

					/**
					* Option: Social Background Color
					*/
					array(
						'name'       => 'sticky-header-social-' . $index . '-bg-color',
						'default'    => adaptive_get_option( 'sticky-header-social-' . $index . '-bg-color' ),
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-social-' . $index . '-background-color-group]',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 9,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '标准', 'adaptive-addon' ),
						'tab'        => __( '标准', 'adaptive-addon' ),
					),

					/**
					* Option: Social Background Hover Color
					*/
					array(
						'name'       => 'sticky-header-social-' . $index . '-bg-h-color',
						'default'    => adaptive_get_option( 'sticky-header-social-' . $index . '-bg-h-color' ),
						'transport'  => 'postMessage',
						'type'       => 'sub-control',
						'parent'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-social-' . $index . '-background-color-group]',
						'section'    => $_section,
						'control'    => 'ast-responsive-color',
						'responsive' => true,
						'rgba'       => true,
						'priority'   => 9,
						'context'    => adaptive_addon_builder_helper()->design_tab,
						'title'      => __( '悬停', 'adaptive-addon' ),
						'tab'        => __( '悬停', 'adaptive-addon' ),
					),

				);

				$social_config[] = $_configs;

			}

			$social_config = call_user_func_array( 'array_merge', $social_config + array( array() ) );

			$configurations = array_merge( $configurations, $social_config );
			return $configurations;
		}

		/**
		 * Get Social color type..
		 *
		 * @since  3.0.0
		 * @return boolean True - If Transparent Header is enabled, False if not.
		 */
		public function is_social_color_custom() {

			$social_color_type = adaptive_get_option( 'header-social-color-type' );

			return ( 'custom' === $social_color_type ? true : false );
		}
	}
}

new Adaptive_Sticky_Header_Social_Configs();



