<?php
/**
 * Sticky Header - Toggle Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       3.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Toggle_Configs' ) ) {

	/**
	 * Register Sticky Header > Toggle component Customizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Toggle_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.0.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_section = 'section-header-mobile-trigger';

			$_configs = array(

				/**
				 * Option: Sticky Header divider Heading.
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-toggle-design-heading]',
					'type'     => 'control',
					'control'  => 'ast-heading',
					'section'  => $_section,
					'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
					'settings' => array(),
					'priority' => 110,
					'context'  => adaptive_addon_builder_helper()->design_tab,
				),

				/**
				 * Option: Toggle Button Color
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-toggle-btn-color]',
					'default'   => adaptive_get_option( 'sticky-header-toggle-btn-color' ),
					'type'      => 'control',
					'control'   => 'ast-color',
					'title'     => __( '颜色', 'adaptive-addon' ),
					'section'   => $_section,
					'transport' => 'postMessage',
					'priority'  => 115,
					'context'   => adaptive_addon_builder_helper()->design_tab,
				),

				/**
				 * Option: Toggle Button Bg Color
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-toggle-btn-bg-color]',
					'default'   => adaptive_get_option( 'sticky-header-toggle-btn-bg-color' ),
					'type'      => 'control',
					'control'   => 'ast-color',
					'title'     => __( '背景颜色', 'adaptive-addon' ),
					'section'   => $_section,
					'transport' => 'postMessage',
					'priority'  => 120,
					'context'   => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-header-toggle-btn-style]',
							'operator' => '==',
							'value'    => 'fill',
						),
					),
				),

				/**
				 * Option: Toggle Button Border Color
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sticky-header-toggle-border-color]',
					'default'   => adaptive_get_option( 'sticky-header-toggle-border-color' ),
					'type'      => 'control',
					'control'   => 'ast-color',
					'title'     => __( '边框颜色', 'adaptive-addon' ),
					'section'   => $_section,
					'transport' => 'postMessage',
					'priority'  => 125,
					'context'   => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[mobile-header-toggle-btn-style]',
							'operator' => '==',
							'value'    => 'outline',
						),
					),
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;
		}
	}
}

new Adaptive_Sticky_Header_Toggle_Configs();
