<?php
/**
 * Sticky Header - Widget Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       3.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sticky_Header_Widget_Configs' ) ) {

	/**
	 * Register Sticky Header Above Header ColorsCustomizer Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sticky_Header_Widget_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Sticky Header Colors Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.0.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$html_config                    = array();
			$adaptive_has_widgets_block_editor = adaptive_addon_has_widgets_block_editor();

			$num_of_header_widgets = adaptive_addon_builder_helper()->num_of_header_widgets;
			for ( $index = 1; $index <= $num_of_header_widgets; $index++ ) {

				$_section = ( ! $adaptive_has_widgets_block_editor ) ? 'sidebar-widgets-header-widget-' . $index : 'adaptive-sidebar-widgets-header-widget-' . $index;

				$_configs = array(

					/**
					 * Option: Sticky Header HTML Heading.
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[sticky-header-widget-' . $index . '-heading]',
						'type'     => 'control',
						'control'  => 'ast-heading',
						'section'  => $_section,
						'title'    => __( '粘性页眉选项', 'adaptive-addon' ),
						'settings' => array(),
						'priority' => 110,
					),

					/**
					 * Option: Widget title color.
					 */
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-widget-' . $index . '-title-color]',
						'default'           => adaptive_get_option( 'sticky-header-widget-' . $index . '-title-color' ),
						'type'              => 'control',
						'section'           => $_section,
						'priority'          => 120,
						'transport'         => 'postMessage',
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'title'             => __( '标题颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Widget Color.
					 */
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-widget-' . $index . '-color]',
						'default'           => adaptive_get_option( 'sticky-header-widget-' . $index . '-color' ),
						'type'              => 'control',
						'section'           => $_section,
						'priority'          => 130,
						'transport'         => 'postMessage',
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'title'             => __( '内容颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Widget link color.
					 */
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-widget-' . $index . '-link-color]',
						'default'           => adaptive_get_option( 'sticky-header-widget-' . $index . '-link-color' ),
						'type'              => 'control',
						'section'           => $_section,
						'priority'          => 140,
						'transport'         => 'postMessage',
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'title'             => __( '链接颜色', 'adaptive-addon' ),
					),

					/**
					 * Option: Widget link hover color.
					 */
					array(
						'name'              => ADAPTIVE_THEME_SETTINGS . '[sticky-header-widget-' . $index . '-link-h-color]',
						'default'           => adaptive_get_option( 'sticky-header-widget-' . $index . '-link-h-color' ),
						'type'              => 'control',
						'section'           => $_section,
						'priority'          => 150,
						'transport'         => 'postMessage',
						'control'           => 'ast-color',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
						'title'             => __( '链接悬停颜色', 'adaptive-addon' ),
						'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					),
				);

				$html_config[] = $_configs;
			}

			$html_config    = call_user_func_array( 'array_merge', $html_config + array( array() ) );
			$configurations = array_merge( $configurations, $html_config );

			return $configurations;
		}
	}
}

new Adaptive_Sticky_Header_Widget_Configs();
