<?php
/**
 * [Primary Menu] options for adaptive theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       3.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Builder_Menu_Configs' ) ) {

	/**
	 * Register below header Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Builder_Menu_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Primary Menu typography Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 3.0.0
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			/**
			 * Header - Menu - Typography
			 */

			$html_config = array();

			$component_limit = adaptive_addon_builder_helper()->component_limit;
			for ( $index = 1; $index <= $component_limit; $index++ ) {

				$_section = 'section-hb-menu-' . $index;
				$_prefix  = 'menu' . $index;

				$_configs = array(
					// Option Group: Primary SubMenu Typography.
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-sub-menu-typography]',
						'type'     => 'control',
						'control'  => 'ast-settings-group',
						'title'    => __( '子菜单的字体', 'adaptive-addon' ),
						'section'  => $_section,
						'priority' => 130,
						'context'  => array(
							array(
								'setting' => 'ast_selected_tab',
								'value'   => 'design',
							),
						),
						'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					),

					// Option: Primary Submenu Font Family.
					array(
						'name'      => 'header-font-family-' . $_prefix . '-sub-menu',
						'default'   => adaptive_get_option( 'header-font-family-' . $_prefix . '-sub-menu' ),
						'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-sub-menu-typography]',
						'type'      => 'sub-control',
						'section'   => $_section,
						'control'   => 'ast-font',
						'transport' => 'postMessage',
						'font_type' => 'ast-font-family',
						'title'     => __( '字体系列', 'adaptive-addon' ),
						'priority'  => 28,
						'connect'   => 'header-font-weight-' . $_prefix . '-sub-menu',
						'context'   => array(
							array(
								'setting' => 'ast_selected_tab',
								'value'   => 'general',
							),
						),
					),

					// Option: Primary Submenu Font Weight.
					array(
						'name'              => 'header-font-weight-' . $_prefix . '-sub-menu',
						'default'           => adaptive_get_option( 'header-font-weight-' . $_prefix . '-sub-menu' ),
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-sub-menu-typography]',
						'type'              => 'sub-control',
						'section'           => $_section,
						'control'           => 'ast-font',
						'transport'         => 'postMessage',
						'font_type'         => 'ast-font-weight',
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
						'title'             => __( '粗细', 'adaptive-addon' ),
						'priority'          => 30,
						'connect'           => 'header-font-family-' . $_prefix . '-sub-menu',
						'context'           => array(
							array(
								'setting' => 'ast_selected_tab',
								'value'   => 'general',
							),
						),
					),

					// Option: Primary Submenu Text Transform.
					array(
						'name'      => 'header-text-transform-' . $_prefix . '-sub-menu',
						'default'   => adaptive_get_option( 'header-text-transform-' . $_prefix . '-sub-menu' ),
						'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-sub-menu-typography]',
						'section'   => $_section,
						'type'      => 'sub-control',
						'title'     => __( '文本转换', 'adaptive-addon' ),
						'transport' => 'postMessage',
						'priority'  => 31,
						'control'   => 'ast-select',
						'choices'   => array(
							''           => __( '继承', 'adaptive-addon' ),
							'none'       => __( '无', 'adaptive-addon' ),
							'capitalize' => __( '首字母大写', 'adaptive-addon' ),
							'uppercase'  => __( '大写字母', 'adaptive-addon' ),
							'lowercase'  => __( '小写字母', 'adaptive-addon' ),
						),
						'context'   => array(
							array(
								'setting' => 'ast_selected_tab',
								'value'   => 'general',
							),
						),
					),

					// Option: Primary Submenu Font Size.
					array(
						'name'        => 'header-font-size-' . $_prefix . '-sub-menu',
						'default'     => adaptive_get_option( 'header-font-size-' . $_prefix . '-sub-menu' ),
						'parent'      => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-sub-menu-typography]',
						'section'     => $_section,
						'title'       => __( '尺寸', 'adaptive-addon' ),
						'type'        => 'sub-control',
						'control'     => 'ast-responsive',
						'transport'   => 'postMessage',
						'priority'    => 29,
						'input_attrs' => array(
							'min' => 0,
						),
						'units'       => array(
							'px' => 'px',
							'em' => 'em',
						),
						'context'     => array(
							array(
								'setting' => 'ast_selected_tab',
								'value'   => 'general',
							),
						),
					),

					// Option: Primary Submenu Line Height.
					array(
						'name'              => 'header-line-height-' . $_prefix . '-sub-menu',
						'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-sub-menu-typography]',
						'section'           => $_section,
						'type'              => 'sub-control',
						'priority'          => 32,
						'title'             => __( '行高', 'adaptive-addon' ),
						'transport'         => 'postMessage',
						'default'           => adaptive_get_option( 'header-line-height-' . $_prefix . '-sub-menu' ),
						'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
						'control'           => 'ast-slider',
						'suffix'            => 'em',
						'input_attrs'       => array(
							'min'  => 1,
							'step' => 0.01,
							'max'  => 5,
						),
						'context'           => array(
							array(
								'setting' => 'ast_selected_tab',
								'value'   => 'general',
							),
						),
					),
				);

				$html_config[] = $_configs;

				if ( 3 > $index ) {
					$_configs = array(
						// Option Group: Primary Mega Menu col Typography.
						array(
							'name'     => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-typography]',
							'type'     => 'control',
							'control'  => 'ast-settings-group',
							'title'    => __( '超级菜单标题', 'adaptive-addon' ),
							'section'  => $_section,
							'priority' => 131,
							'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
							'context'  => array(
								array(
									'setting' => 'ast_selected_tab',
									'value'   => 'design',
								),
							),
						),

						// Option: Primary Megamenu Header Menu Font Family.
						array(
							'name'      => 'header-' . $_prefix . '-megamenu-heading-font-family',
							'default'   => adaptive_get_option( 'header-' . $_prefix . '-megamenu-heading-font-family' ),
							'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-typography]',
							'transport' => 'postMessage',
							'type'      => 'sub-control',
							'section'   => $_section,
							'control'   => 'ast-font',
							'font_type' => 'ast-font-family',
							'title'     => __( '字体系列', 'adaptive-addon' ),
							'connect'   => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-megamenu-heading-font-weight]',
							'priority'  => 10,
							'context'   => array(
								array(
									'setting' => 'ast_selected_tab',
									'value'   => 'general',
								),
							),
						),

						// Option: Primary Megamenu Header Menu Font Size.
						array(
							'name'        => 'header-' . $_prefix . '-megamenu-heading-font-size',
							'default'     => adaptive_get_option( 'header-' . $_prefix . '-megamenu-heading-font-size' ),
							'parent'      => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-typography]',
							'transport'   => 'postMessage',
							'title'       => __( '尺寸', 'adaptive-addon' ),
							'type'        => 'sub-control',
							'section'     => $_section,
							'control'     => 'ast-responsive',
							'input_attrs' => array(
								'min' => 0,
							),
							'units'       => array(
								'px' => 'px',
								'em' => 'em',
							),
							'priority'    => 20,
							'context'     => array(
								array(
									'setting' => 'ast_selected_tab',
									'value'   => 'general',
								),
							),
						),

						// Option: Primary Megamenu Header Menu Font Weight.
						array(
							'name'              => 'header-' . $_prefix . '-megamenu-heading-font-weight',
							'default'           => adaptive_get_option( 'header-' . $_prefix . '-megamenu-heading-font-weight' ),
							'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-typography]',
							'type'              => 'sub-control',
							'section'           => $_section,
							'control'           => 'ast-font',
							'font_type'         => 'ast-font-weight',
							'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
							'title'             => __( '粗细', 'adaptive-addon' ),
							'connect'           => 'header-' . $_prefix . '-megamenu-heading-font-family',
							'priority'          => 30,
							'transport'         => 'postMessage',
							'context'           => array(
								array(
									'setting' => 'ast_selected_tab',
									'value'   => 'general',
								),
							),
						),

						// Option: Primary Megamenu Header Menu Text Transform.
						array(
							'name'      => 'header-' . $_prefix . '-megamenu-heading-text-transform',
							'default'   => adaptive_get_option( 'header-' . $_prefix . '-megamenu-heading-text-transform' ),
							'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-' . $_prefix . '-mega-menu-col-typography]',
							'type'      => 'sub-control',
							'section'   => $_section,
							'control'   => 'ast-select',
							'title'     => __( '文本转换', 'adaptive-addon' ),
							'transport' => 'postMessage',
							'choices'   => array(
								''           => __( '继承', 'adaptive-addon' ),
								'none'       => __( '无', 'adaptive-addon' ),
								'capitalize' => __( '首字母大写', 'adaptive-addon' ),
								'uppercase'  => __( '大写字母', 'adaptive-addon' ),
								'lowercase'  => __( '小写字母', 'adaptive-addon' ),
							),
							'priority'  => 40,
							'context'   => array(
								array(
									'setting' => 'ast_selected_tab',
									'value'   => 'general',
								),
							),
						),
					);

					$html_config[] = $_configs;
				}
			}

			/**
			 * Footer - Menu - Typography
			 */

			$_section = 'section-footer-menu';

			$html_config[] = array(
				// Option: Menu Font Family.
				array(
					'name'      => 'footer-menu-font-family',
					'default'   => adaptive_get_option( 'footer-menu-font-family' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[footer-menu-typography]',
					'type'      => 'sub-control',
					'section'   => $_section,
					'transport' => 'postMessage',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'priority'  => 22,
					'connect'   => 'footer-menu-font-weight',
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Menu Font Weight.
				array(
					'name'              => 'footer-menu-font-weight',
					'default'           => adaptive_get_option( 'footer-menu-font-weight' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-menu-typography]',
					'section'           => $_section,
					'type'              => 'sub-control',
					'control'           => 'ast-font',
					'transport'         => 'postMessage',
					'font_type'         => 'ast-font-weight',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'title'             => __( '粗细', 'adaptive-addon' ),
					'priority'          => 24,
					'connect'           => 'footer-menu-font-family',
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Menu Text Transform.
				array(
					'name'      => 'footer-menu-text-transform',
					'default'   => adaptive_get_option( 'footer-menu-text-transform' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[footer-menu-typography]',
					'section'   => $_section,
					'type'      => 'sub-control',
					'control'   => 'ast-select',
					'transport' => 'postMessage',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'priority'  => 25,
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				// Option: Menu Line Height.
				array(
					'name'              => 'footer-menu-line-height',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[footer-menu-typography]',
					'section'           => $_section,
					'type'              => 'sub-control',
					'priority'          => 26,
					'title'             => __( '行高', 'adaptive-addon' ),
					'suffix'            => 'em',
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'footer-menu-line-height' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'control'           => 'ast-slider',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 10,
					),
					'context'           => adaptive_addon_builder_helper()->general_tab,
				),
			);

			/**
			 * Mobile Menu - Typo.
			 */
			$html_config[] = array(

				// Option Group: Primary SubMenu Typography.
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-sub-menu-typography]',
					'type'     => 'control',
					'control'  => 'ast-settings-group',
					'title'    => __( '子菜单的字体', 'adaptive-addon' ),
					'section'  => 'section-header-mobile-menu',
					'priority' => 130,
					'context'  => array(
						array(
							'setting' => 'ast_selected_tab',
							'value'   => 'design',
						),
					),
				),

				// Option: Primary Submenu Font Family.
				array(
					'name'      => 'header-font-family-mobile-menu-sub-menu',
					'default'   => adaptive_get_option( 'header-font-family-mobile-menu-sub-menu' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-sub-menu-typography]',
					'type'      => 'sub-control',
					'section'   => 'section-header-mobile-menu',
					'control'   => 'ast-font',
					'transport' => 'postMessage',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'priority'  => 28,
					'connect'   => 'header-font-weight-mobile-menu-sub-menu',
					'context'   => array(
						array(
							'setting' => 'ast_selected_tab',
							'value'   => 'general',
						),
					),
				),

				// Option: Primary Submenu Font Weight.
				array(
					'name'              => 'header-font-weight-mobile-menu-sub-menu',
					'default'           => adaptive_get_option( 'header-font-weight-mobile-menu-sub-menu' ),
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-sub-menu-typography]',
					'type'              => 'sub-control',
					'section'           => 'section-header-mobile-menu',
					'control'           => 'ast-font',
					'transport'         => 'postMessage',
					'font_type'         => 'ast-font-weight',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'title'             => __( '粗细', 'adaptive-addon' ),
					'priority'          => 30,
					'connect'           => 'header-font-family-mobile-menu-sub-menu',
					'context'           => array(
						array(
							'setting' => 'ast_selected_tab',
							'value'   => 'general',
						),
					),
				),

				// Option: Primary Submenu Text Transform.
				array(
					'name'      => 'header-text-transform-mobile-menu-sub-menu',
					'default'   => adaptive_get_option( 'header-text-transform-mobile-menu-sub-menu' ),
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-sub-menu-typography]',
					'section'   => 'section-header-mobile-menu',
					'type'      => 'sub-control',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'priority'  => 31,
					'control'   => 'ast-select',
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
					'context'   => array(
						array(
							'setting' => 'ast_selected_tab',
							'value'   => 'general',
						),
					),
				),

				// Option: Primary Submenu Font Size.
				array(
					'name'        => 'header-font-size-mobile-menu-sub-menu',
					'default'     => adaptive_get_option( 'header-font-size-mobile-menu-sub-menu' ),
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-sub-menu-typography]',
					'section'     => 'section-header-mobile-menu',
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'type'        => 'sub-control',
					'control'     => 'ast-responsive',
					'transport'   => 'postMessage',
					'priority'    => 29,
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
					'context'     => array(
						array(
							'setting' => 'ast_selected_tab',
							'value'   => 'general',
						),
					),
				),

				// Option: Primary Submenu Line Height.
				array(
					'name'              => 'header-line-height-mobile-menu-sub-menu',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[header-mobile-menu-sub-menu-typography]',
					'section'           => 'section-header-mobile-menu',
					'type'              => 'sub-control',
					'priority'          => 32,
					'title'             => __( '行高', 'adaptive-addon' ),
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'header-line-height-mobile-menu-sub-menu' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'control'           => 'ast-slider',
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
					'context'           => array(
						array(
							'setting' => 'ast_selected_tab',
							'value'   => 'general',
						),
					),
				),
			);

			$html_config    = call_user_func_array( 'array_merge', $html_config + array( array() ) );
			$configurations = array_merge( $configurations, $html_config );

			return $configurations;
		}
	}
}

new Adaptive_Builder_Menu_Configs();
