<?php
/**
 * Section [Sidebar] options for adaptive theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Sidebar_Typo_Configs' ) ) {

	/**
	 * Register below header Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Sidebar_Typo_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Side bar typography Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: SideBar title typography Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sidebar-title-typography-group]',
					'default'   => adaptive_get_option( 'sidebar-title-typography-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '标题字体', 'adaptive-addon' ),
					'section'   => 'section-sidebars',
					'transport' => 'postMessage',
					'priority'  => 24,
					'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: Widget Title Font Family
				 */
				array(
					'name'      => 'font-family-widget-title',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sidebar-title-typography-group]',
					'section'   => 'section-sidebars',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'default'   => adaptive_get_option( 'font-family-widget-title' ),
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-widget-title]',
				),

				/**
				 * Option: Widget Title Font Size
				 */
				array(
					'name'        => 'font-size-widget-title',
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[sidebar-title-typography-group]',
					'section'     => 'section-sidebars',
					'transport'   => 'postMessage',
					'default'     => adaptive_get_option( 'font-size-widget-title' ),
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'control'     => 'ast-responsive',
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Widget Title Font Weight
				 */
				array(
					'name'              => 'font-weight-widget-title',
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sidebar-title-typography-group]',
					'section'           => 'section-sidebars',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'default'           => adaptive_get_option( 'font-weight-widget-title' ),
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-widget-title',
				),

				/**
				 * Option: Widget Title Text Transform
				 */
				array(
					'name'      => 'text-transform-widget-title',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sidebar-title-typography-group]',
					'section'   => 'section-sidebars',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'default'   => adaptive_get_option( 'text-transform-widget-title' ),
					'control'   => 'ast-select',
					'transport' => 'postMessage',
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Widget Title Line Height
				 */
				array(
					'name'              => 'line-height-widget-title',
					'transport'         => 'postMessage',
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sidebar-title-typography-group]',
					'section'           => 'section-sidebars',
					'default'           => adaptive_get_option( 'line-height-widget-title' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'title'             => __( '行高', 'adaptive-addon' ),
					'control'           => 'ast-slider',
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

				/**
				 * Option: SideBar Content typography Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-typography-group]',
					'default'   => adaptive_get_option( 'sidebar-content-typography-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '内容字体', 'adaptive-addon' ),
					'section'   => 'section-sidebars',
					'transport' => 'postMessage',
					'priority'  => 24,
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ?
						adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: Widget Content Font Family
				 */
				array(
					'name'      => 'font-family-widget-content',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-typography-group]',
					'section'   => 'section-sidebars',
					'default'   => adaptive_get_option( 'font-family-widget-content' ),
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-widget-content]',
				),

				/**
				 * Option: Widget Content Font Size
				 */
				array(
					'name'        => 'font-size-widget-content',
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-typography-group]',
					'section'     => 'section-sidebars',
					'control'     => 'ast-responsive',
					'default'     => adaptive_get_option( 'font-size-widget-content' ),
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'transport'   => 'postMessage',
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Widget Content Font Weight
				 */
				array(
					'name'              => 'font-weight-widget-content',
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-typography-group]',
					'section'           => 'section-sidebars',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'default'           => adaptive_get_option( 'font-weight-widget-content' ),
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-widget-content',
				),

				/**
				 * Option: Widget Content Text Transform
				 */
				array(
					'name'      => 'text-transform-widget-content',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-typography-group]',
					'section'   => 'section-sidebars',
					'default'   => adaptive_get_option( 'text-transform-widget-content' ),
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'control'   => 'ast-select',
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Widget Content Line Height
				 */
				array(
					'name'              => 'line-height-widget-content',
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[sidebar-content-typography-group]',
					'section'           => 'section-sidebars',
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'line-height-widget-content' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'title'             => __( '行高', 'adaptive-addon' ),
					'control'           => 'ast-slider',
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

new Adaptive_Sidebar_Typo_Configs();
