<?php
/**
 * Section [Footer] options for adaptive theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Single_Advanced_Typo_Configs' ) ) {

	/**
	 * Register below header Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Single_Advanced_Typo_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Side bar typography Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Single Post / Page Title Font Family
				 */
				array(
					'name'      => 'font-family-entry-title',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[blog-single-title-typo]',
					'section'   => 'section-blog-single',
					'type'      => 'sub-control',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'default'   => adaptive_get_option( 'font-family-entry-title' ),
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-entry-title]',
					'priority'  => 7,
				),

				/**
				 * Option: Single Post / Page Title Font Weight
				 */
				array(
					'name'              => 'font-weight-entry-title',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-single-title-typo]',
					'section'           => 'section-blog-single',
					'type'              => 'sub-control',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'default'           => adaptive_get_option( 'font-weight-entry-title' ),
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-entry-title',
					'priority'          => 9,
				),

				/**
				 * Option: Single Post / Page Title Line Height
				 */
				array(
					'name'              => 'line-height-entry-title',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[blog-single-title-typo]',
					'section'           => 'section-blog-single',
					'type'              => 'sub-control',
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'line-height-entry-title' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'title'             => __( '行高', 'adaptive-addon' ),
					'control'           => 'ast-slider',
					'priority'          => 15,
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

				/**
				 * Option: Single Post / Page Title Text Transform
				 */
				array(
					'name'      => 'text-transform-entry-title',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[blog-single-title-typo]',
					'section'   => 'section-blog-single',
					'type'      => 'sub-control',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'default'   => adaptive_get_option( 'text-transform-entry-title' ),
					'transport' => 'postMessage',
					'control'   => 'ast-select',
					'priority'  => 10,
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

new Adaptive_Single_Advanced_Typo_Configs();


