<?php
/**
 * [Header] options for adaptive theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       1.0.0
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Site_Header_Typo_Configs' ) ) {

	/**
	 * Register below header Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Site_Header_Typo_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Footer typography Customizer Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Site Title Font Family
				 */
				array(
					'name'      => 'font-family-site-title',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-title-typography]',
					'section'   => 'title_tagline',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'default'   => adaptive_get_option( 'font-family-site-title' ),
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'priority'  => 8,
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-site-title]',
				),

				/**
				 * Option: Site Title Font Weight
				 */
				array(
					'name'      => 'font-weight-site-title',
					'control'   => 'ast-font',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-title-typography]',
					'section'   => 'title_tagline',
					'font_type' => 'ast-font-weight',
					'type'      => 'sub-control',
					'title'     => __( '粗细', 'adaptive-addon' ),
					'default'   => adaptive_get_option( 'font-weight-site-title' ),
					'priority'  => 10,
					'connect'   => 'font-family-site-title',
				),

				/**
				 * Option: Site Title Text Transform
				 */
				array(
					'name'      => 'text-transform-site-title',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-title-typography]',
					'section'   => 'title_tagline',
					'default'   => adaptive_get_option( 'text-transform-site-title' ),
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'control'   => 'ast-select',
					'priority'  => 11,
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Site Title Line Height
				 */
				array(
					'name'              => 'line-height-site-title',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[site-title-typography]',
					'section'           => 'title_tagline',
					'type'              => 'sub-control',
					'title'             => __( '行高', 'adaptive-addon' ),
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'line-height-site-title' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'control'           => 'ast-slider',
					'priority'          => 12,
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

				/**
				 * Option: Site Tagline Font Family
				 */
				array(
					'name'      => 'font-family-site-tagline',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-tagline-typography]',
					'section'   => 'title_tagline',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'default'   => adaptive_get_option( 'font-family-site-tagline' ),
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'priority'  => 13,
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-site-tagline]',
				),

				/**
				 * Option: Site Tagline Font Weight
				 */
				array(
					'name'      => 'font-weight-site-tagline',
					'control'   => 'ast-font',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-tagline-typography]',
					'section'   => 'title_tagline',
					'font_type' => 'ast-font-weight',
					'type'      => 'sub-control',
					'default'   => adaptive_get_option( 'font-weight-site-tagline' ),
					'title'     => __( '粗细', 'adaptive-addon' ),
					'priority'  => 15,
					'connect'   => 'font-family-site-tagline',
				),

				/**
				 * Option: Site Tagline Text Transform
				 */
				array(
					'name'      => 'text-transform-site-tagline',
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[site-tagline-typography]',
					'section'   => 'title_tagline',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'transport' => 'postMessage',
					'default'   => adaptive_get_option( 'text-transform-site-tagline' ),
					'control'   => 'ast-select',
					'priority'  => 16,
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Site Tagline Line Height
				 */

				array(
					'name'              => 'line-height-site-tagline',
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[site-tagline-typography]',
					'section'           => 'title_tagline',
					'default'           => adaptive_get_option( 'line-height-site-tagline' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'title'             => __( '行高', 'adaptive-addon' ),
					'transport'         => 'postMessage',
					'control'           => 'ast-slider',
					'priority'          => 17,
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),
			);

			return array_merge( $configurations, $_configs );
		}
	}
}

new Adaptive_Site_Header_Typo_Configs();
