<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Woocommerce_Checkout_Configs' ) ) {

	/**
	 * Register Woocommerce Checkout Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Woocommerce_Checkout_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Woocommerce Checkout Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Checkout Content Width
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[checkout-content-width]',
					'default'   => adaptive_get_option( 'checkout-content-width' ),
					'type'      => 'control',
					'control'   => 'ast-select',
					'priority'  => 5,
					'section'   => 'woocommerce_checkout',
					'transport' => 'postMessage',
					'title'     => __( '付款形式宽度', 'adaptive-addon' ),
					'choices'   => array(
						'default' => __( '默认', 'adaptive-addon' ),
						'custom'  => __( '自定义', 'adaptive-addon' ),
					),
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enter Width
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[checkout-content-max-width]',
					'default'     => adaptive_get_option( 'checkout-content-max-width' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[checkout-content-width]',
							'operator' => '==',
							'value'    => 'custom',
						),
					),
					'section'     => 'woocommerce_checkout',
					'title'       => __( '自定义宽度', 'adaptive-addon' ),
					'suffix'      => 'px',
					'priority'    => 5,
					'input_attrs' => array(
						'min'  => 768,
						'step' => 1,
						'max'  => 1920,
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Two Step Checkout
				 */
				array(
					'name'    => ADAPTIVE_THEME_SETTINGS . '[two-step-checkout]',
					'default' => adaptive_get_option( 'two-step-checkout' ),
					'type'    => 'control',
					'section' => 'woocommerce_checkout',
					'title'   => __( '两步结账', 'adaptive-addon' ),
					'control' => Adaptive_Theme_Extension::$switch_control,
					'divider' => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
				),

				/**
				 * Option: Display Order Note on Checkout Page
				 */
				array(
					'name'    => ADAPTIVE_THEME_SETTINGS . '[checkout-order-notes-display]',
					'default' => adaptive_get_option( 'checkout-order-notes-display' ),
					'type'    => 'control',
					'section' => 'woocommerce_checkout',
					'title'   => __( '显示订单通知', 'adaptive-addon' ),
					'control' => Adaptive_Theme_Extension::$switch_control,
					'divider' => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Display Coupon on Checkout Page
				 */
				array(
					'name'    => ADAPTIVE_THEME_SETTINGS . '[checkout-coupon-display]',
					'default' => adaptive_get_option( 'checkout-coupon-display' ),
					'type'    => 'control',
					'section' => 'woocommerce_checkout',
					'title'   => __( '显示应用优惠券字段', 'adaptive-addon' ),
					'control' => Adaptive_Theme_Extension::$switch_control,
					'divider' => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/*
				 * Option: Distraction free Checkout.
				 */
				array(
					'name'    => ADAPTIVE_THEME_SETTINGS . '[checkout-distraction-free]',
					'default' => adaptive_get_option( 'checkout-distraction-free' ),
					'type'    => 'control',
					'section' => 'woocommerce_checkout',
					'title'   => __( '免打扰结帐', 'adaptive-addon' ),
					'control' => Adaptive_Theme_Extension::$switch_control,
					'divider' => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/*
				 * Option: Replace Form lable with placeholder
				 */
				array(
					'name'    => ADAPTIVE_THEME_SETTINGS . '[checkout-labels-as-placeholders]',
					'default' => adaptive_get_option( 'checkout-labels-as-placeholders' ),
					'type'    => 'control',
					'section' => 'woocommerce_checkout',
					'title'   => __( '使用标签作为占位符', 'adaptive-addon' ),
					'control' => Adaptive_Theme_Extension::$switch_control,
					'divider' => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/*
				 * Option: Preserve form data.
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[checkout-persistence-form-data]',
					'default'     => adaptive_get_option( 'checkout-persistence-form-data' ),
					'type'        => 'control',
					'section'     => 'woocommerce_checkout',
					'title'       => __( '持久校验表单数据', 'adaptive-addon' ),
					'description' => __( '保留结帐表单字段，即使访问者意外地重新加载了结帐页面。', 'adaptive-addon' ),
					'control'     => Adaptive_Theme_Extension::$switch_control,
				),

			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Woocommerce_Checkout_Configs();





