<?php
/**
 * Woocommerce General Options for our theme.
 *
 * @package     Adaptive
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Woocommerce_General_Configs' ) ) {

	/**
	 * Register Woocommerce General Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Woocommerce_General_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Woocommerce General Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_section = ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? 'section-header-woo-cart' : 'section-woo-general';

			$context = ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? adaptive_addon_builder_helper()->design_tab : adaptive_addon_builder_helper()->general_tab;

			$cart_outline_width_context = ( true === adaptive_addon_builder_helper()->is_header_footer_builder_active ) ? adaptive_addon_builder_helper()->design_tab_config : adaptive_addon_builder_helper()->general_tab_config;

			$_configs = array(

				/**
				 * Option: Sale Notification
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[product-sale-notification]',
					'default'  => adaptive_get_option( 'product-sale-notification' ),
					'type'     => 'control',
					'section'  => 'section-woo-general',
					'title'    => __( '销售通知', 'adaptive-addon' ),
					'control'  => 'ast-select',
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority' => 15,
					'choices'  => array(
						'none'            => __( '无', 'adaptive-addon' ),
						'default'         => __( '默认', 'adaptive-addon' ),
						'sale-percentage' => __( '自定义字符串', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Sale Percentage Input
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[product-sale-percent-value]',
					'default'     => adaptive_get_option( 'product-sale-percent-value' ),
					'type'        => 'control',
					'section'     => 'section-woo-general',
					'title'       => __( '出售%值', 'adaptive-addon' ),
					'description' => __( '销售百分比(%)value = [value]', 'adaptive-addon' ),
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[product-sale-notification]',
							'operator' => '==',
							'value'    => 'sale-percentage',
						),
					),
					'control'     => 'text',
					'priority'    => 20,
					'input_attrs' => array(
						'placeholder' => adaptive_get_option( 'product-sale-percent-value' ),
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Sale Bubble Shape
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[product-sale-style]',
					'default'   => adaptive_get_option( 'product-sale-style' ),
					'type'      => 'control',
					'transport' => 'postMessage',
					'section'   => 'section-woo-general',
					'title'     => __( '销售泡沫风格', 'adaptive-addon' ),
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[product-sale-notification]',
							'operator' => 'in',
							'value'    => array( 'sale-percentage', 'default' ),
						),
					),
					'control'   => 'ast-select',
					'priority'  => 25,
					'choices'   => array(
						'circle'         => __( '圆圈', 'adaptive-addon' ),
						'circle-outline' => __( '圆形', 'adaptive-addon' ),
						'square'         => __( '实心方块', 'adaptive-addon' ),
						'square-outline' => __( '方形', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Header Cart Icon
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon]',
					'default'   => adaptive_get_option( 'woo-header-cart-icon' ),
					'type'      => 'control',
					'section'   => $_section,
					'transport' => 'postMessage',
					'title'     => __( '图标', 'adaptive-addon' ),
					'control'   => 'ast-select',
					'priority'  => 35,
					'choices'   => array(
						'default' => __( '默认', 'adaptive-addon' ),
						'cart'    => __( '购物车', 'adaptive-addon' ),
						'bag'     => __( '包包', 'adaptive-addon' ),
						'basket'  => __( '篮子', 'adaptive-addon' ),
					),
					'context'   => adaptive_addon_builder_helper()->general_tab,
				),

				/**
				 * Option: Cart Count color
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-product-count-color]',
					'default'           => adaptive_get_option( 'woo-header-cart-product-count-color' ),
					'type'              => 'control',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'transport'         => 'postMessage',
					'title'             => __( '计数颜色', 'adaptive-addon' ),
					'context'           => array(
						Adaptive_Builder_Helper::$design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon]',
							'operator' => '!=',
							'value'    => 'default',
						),
					),
					'section'           => $_section,
					'priority'          => 45,
				),

				/**
				 * Option: Border Width
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-border-width]',
					'default'     => adaptive_get_option( 'woo-header-cart-border-width' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'section'     => $_section,
					'context'     => array(
						$cart_outline_width_context,
						'relation' => 'AND',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon-style]',
							'operator' => '==',
							'value'    => 'outline',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon]',
							'operator' => '!=',
							'value'    => 'default',
						),
					),
					'title'       => __( '边框宽度', 'adaptive-addon' ),
					'control'     => 'ast-slider',
					'suffix'      => 'px',
					'priority'    => 46,
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 20,
					),
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			if ( false === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {

				$_configs = array(

					/**
					 * Option: Icon Style
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon-style]',
						'default'   => adaptive_get_option( 'woo-header-cart-icon-style' ),
						'type'      => 'control',
						'transport' => 'postMessage',
						'section'   => $_section,
						'title'     => __( '样式', 'adaptive-addon' ),
						'control'   => 'ast-select',
						'priority'  => 40,
						'choices'   => array(
							'none'    => __( '无', 'adaptive-addon' ),
							'outline' => __( '轮廓', 'adaptive-addon' ),
							'fill'    => __( '填充', 'adaptive-addon' ),
						),
						'context'   => $context,
					),

					/**
					 * Option: Background color
					 */
					array(
						'name'     => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon-color]',
						'default'  => adaptive_get_option( 'woo-header-cart-icon-color' ),
						'type'     => 'control',
						'control'  => 'ast-color',
						'context'  => array(
							$context,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon-style]',
								'operator' => '!=',
								'value'    => 'none',
							),
						),
						'title'    => __( '颜色', 'adaptive-addon' ),
						'section'  => $_section,
						'priority' => 45,
					),

					/**
					 * Option: Border Radius
					 */
					array(
						'name'        => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon-radius]',
						'default'     => adaptive_get_option( 'woo-header-cart-icon-radius' ),
						'type'        => 'control',
						'transport'   => 'postMessage',
						'section'     => $_section,
						'context'     => array(
							$context,
							array(
								'setting'  => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-icon-style]',
								'operator' => '!=',
								'value'    => 'none',
							),
						),
						'title'       => __( '边界圆角', 'adaptive-addon' ),
						'control'     => 'ast-slider',
						'priority'    => 45,
						'suffix'      => 'px',
						'input_attrs' => array(
							'min'  => 0,
							'step' => 1,
							'max'  => 200,
						),
					),

					/**
					 * Option: Header cart total
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-total-display]',
						'default'   => adaptive_get_option( 'woo-header-cart-total-display' ),
						'type'      => 'control',
						'section'   => $_section,
						'transport' => 'postMessage',
						'title'     => __( '显示购物车总数', 'adaptive-addon' ),
						'priority'  => 50,
						'control'   => Adaptive_Theme_Extension::$switch_control,
						'context'   => adaptive_addon_builder_helper()->general_tab,
						'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					),

					/**
					 * Option: Cart Title
					 */
					array(
						'name'      => ADAPTIVE_THEME_SETTINGS . '[woo-header-cart-title-display]',
						'default'   => adaptive_get_option( 'woo-header-cart-title-display' ),
						'type'      => 'control',
						'section'   => $_section,
						'transport' => 'postMessage',
						'title'     => __( '显示购物车标题', 'adaptive-addon' ),
						'priority'  => 55,
						'control'   => Adaptive_Theme_Extension::$switch_control,
						'context'   => adaptive_addon_builder_helper()->general_tab,
						'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					),
				);
			}

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Woocommerce_General_Configs();
