<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Woocommerce_Shop_Configs' ) ) {

	/**
	 * Register Woocommerce Shop Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Woocommerce_Shop_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Woocommerce Shop Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Choose Product Style
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[shop-style]',
					'default'           => adaptive_get_option( 'shop-style' ),
					'type'              => 'control',
					'section'           => 'woocommerce_product_catalog',
					'title'             => __( '样式', 'adaptive-addon' ),
					'control'           => 'ast-radio-image',
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_choices' ),
					'priority'          => 10,
					'choices'           => array(
						'shop-page-grid-style' => array(
							'label' => __( '网格视图', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'shop-page-grid-style', false ) : '',
						),
						'shop-page-list-style' => array(
							'label' => __( '列表视图', 'adaptive-addon' ),
							'path'  => ( class_exists( 'Adaptive_Builder_UI_Controller' ) ) ? Adaptive_Builder_UI_Controller::fetch_svg_icon( 'shop-page-list-style', false ) : '',
						),
					),
				),

				/**
				 * Option: Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-box-styling]',
					'section'  => 'woocommerce_product_catalog',
					'title'    => __( '产品造型', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-heading',
					'priority' => 75,
					'settings' => array(),
				),

				/**
				 * Option: Content Alignment
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[shop-product-align]',
					'default'    => adaptive_get_option( 'shop-product-align' ),
					'type'       => 'control',
					'transport'  => 'postMessage',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => 'woocommerce_product_catalog',
					'priority'   => 80,
					'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
					'title'      => __( '内容对齐', 'adaptive-addon' ),
					'responsive' => false,
					'choices'    => array(
						'align-left'   => 'align-left',
						'align-center' => 'align-center',
						'align-right'  => 'align-right',
					),
				),

				/**
				 * Option: Box shadow
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[shop-product-shadow]',
					'default'     => adaptive_get_option( 'shop-product-shadow' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'title'       => __( '阴影', 'adaptive-addon' ),
					'section'     => 'woocommerce_product_catalog',
					'suffix'      => 'px',
					'priority'    => 85,
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 5,
					),
				),

				/**
				 * Option: Box hover shadow
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[shop-product-shadow-hover]',
					'default'     => adaptive_get_option( 'shop-product-shadow-hover' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'title'       => __( '阴影悬停', 'adaptive-addon' ),
					'section'     => 'woocommerce_product_catalog',
					'suffix'      => 'px',
					'priority'    => 90,
					'input_attrs' => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 5,
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Product Hover Style
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-hover-style]',
					'type'     => 'control',
					'control'  => 'ast-select',
					'section'  => 'woocommerce_product_catalog',
					'default'  => adaptive_get_option( 'shop-hover-style' ),
					'priority' => 90,
					'title'    => __( '产品形象', 'adaptive-addon' ),
					'choices'  => apply_filters(
						'adaptive_woo_shop_hover_style',
						array(
							''     => __( '无', 'adaptive-addon' ),
							'swap' => __( '交换图片', 'adaptive-addon' ),
						)
					),
				),

				/**
				 * Option: Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-button-divider]',
					'section'  => 'woocommerce_product_catalog',
					'title'    => __( '按钮', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-heading',
					'priority' => 110,
					'settings' => array(),
				),

				/**
				 * Option: Vertical Padding
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[shop-button-v-padding]',
					'default'     => adaptive_get_option( 'shop-button-v-padding' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'section'     => 'woocommerce_product_catalog',
					'title'       => __( '垂直填充', 'adaptive-addon' ),
					'control'     => 'ast-slider',
					'suffix'      => 'px',
					'priority'    => 110,
					'input_attrs' => array(
						'min'  => 1,
						'step' => 1,
						'max'  => 200,
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Horizontal Padding
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[shop-button-h-padding]',
					'default'     => adaptive_get_option( 'shop-button-h-padding' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'section'     => 'woocommerce_product_catalog',
					'priority'    => 110,
					'title'       => __( '水平填充', 'adaptive-addon' ),
					'control'     => 'ast-slider',
					'suffix'      => 'px',
					'input_attrs' => array(
						'min'  => 1,
						'step' => 1,
						'max'  => 200,
					),
				),

				/**
				 * Option: Divider
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-pagination-divider]',
					'section'  => 'woocommerce_product_catalog',
					'title'    => __( '分页', 'adaptive-addon' ),
					'type'     => 'control',
					'control'  => 'ast-heading',
					'priority' => 140,
					'settings' => array(),
				),

				/**
				 * Option: Shop Pagination
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-pagination]',
					'default'  => adaptive_get_option( 'shop-pagination' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'section'  => 'woocommerce_product_catalog',
					'priority' => 145,
					'title'    => __( '商店分页', 'adaptive-addon' ),
					'choices'  => array(
						'number'   => __( '显示序列号', 'adaptive-addon' ),
						'infinite' => __( '无限分页', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Shop Pagination Style
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[shop-pagination-style]',
					'default'   => adaptive_get_option( 'shop-pagination-style' ),
					'type'      => 'control',
					'transport' => 'postMessage',
					'control'   => 'ast-select',
					'section'   => 'woocommerce_product_catalog',
					'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-pagination]',
							'operator' => '==',
							'value'    => 'number',
						),
					),
					'priority'  => 150,
					'title'     => __( '商店分页样式', 'adaptive-addon' ),
					'choices'   => array(
						'default' => __( '默认', 'adaptive-addon' ),
						'square'  => __( '实心方块', 'adaptive-addon' ),
						'circle'  => __( '圆圈', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Event to Trigger Infinite Loading
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[shop-infinite-scroll-event]',
					'default'     => adaptive_get_option( 'shop-infinite-scroll-event' ),
					'type'        => 'control',
					'control'     => 'ast-select',
					'section'     => 'woocommerce_product_catalog',
					'description' => __( '无法在定制程序中预览无限分页。', 'adaptive-addon' ),
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-pagination]',
							'operator' => '==',
							'value'    => 'infinite',
						),
					),
					'priority'    => 155,
					'title'       => __( '事件触发无限加载', 'adaptive-addon' ),
					'choices'     => array(
						'scroll' => __( '滚动', 'adaptive-addon' ),
						'click'  => __( '点此查看本设置相关文档', 'adaptive-addon' ),
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
				),

				/**
				 * Option: Read more text
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[shop-load-more-text]',
					'default'   => adaptive_get_option( 'shop-load-more-text' ),
					'type'      => 'control',
					'transport' => 'postMessage',
					'section'   => 'woocommerce_product_catalog',
					'priority'  => 160,
					'title'     => __( '加载更多的文本', 'adaptive-addon' ),
					'context'   => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-pagination]',
							'operator' => '==',
							'value'    => 'infinite',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-infinite-scroll-event]',
							'operator' => '==',
							'value'    => 'click',
						),
					),
					'control'   => 'text',
					'partial'   => array(
						'selector'            => '.ast-shop-pagination-infinite .ast-shop-load-more',
						'container_inclusive' => false,
						'render_callback'     => 'Adaptive_Customizer_Ext_WooCommerce_Partials::_render_shop_load_more',
					),
				),

				/**
				 * Option: Display Page Title
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-page-title-display]',
					'default'  => adaptive_get_option( 'shop-page-title-display' ),
					'type'     => 'control',
					'section'  => 'woocommerce_product_catalog',
					'title'    => __( '显示页面标题', 'adaptive-addon' ),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority' => 29,
					'control'  => Adaptive_Theme_Extension::$switch_control,
				),

				/**
				 * Option: Display Breadcrumb
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-breadcrumb-display]',
					'default'  => adaptive_get_option( 'shop-breadcrumb-display' ),
					'type'     => 'control',
					'section'  => 'woocommerce_product_catalog',
					'title'    => __( '显示导航', 'adaptive-addon' ),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'priority' => 29,
					'control'  => Adaptive_Theme_Extension::$switch_control,
				),

				/**
				 * Option: Display Toolbar
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-toolbar-display]',
					'default'  => adaptive_get_option( 'shop-toolbar-display' ),
					'type'     => 'control',
					'section'  => 'woocommerce_product_catalog',
					'title'    => __( '显示工具栏', 'adaptive-addon' ),
					'priority' => 29,
					'control'  => Adaptive_Theme_Extension::$switch_control,
				),

				/**
				 * Option: Display Off Canvas On Click Of
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-off-canvas-trigger-type]',
					'default'  => adaptive_get_option( 'shop-off-canvas-trigger-type' ),
					'type'     => 'control',
					'control'  => 'ast-select',
					'section'  => 'woocommerce_product_catalog',
					'priority' => 200,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'title'    => __( '引发了Canvas侧边栏', 'adaptive-addon' ),
					'choices'  => array(
						'disable'      => __( '禁用', 'adaptive-addon' ),
						'link'         => __( '链接', 'adaptive-addon' ),
						'button'       => __( '按钮', 'adaptive-addon' ),
						'custom-class' => __( '自定义类', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Filter Button Text
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-filter-trigger-link]',
					'default'  => adaptive_get_option( 'shop-filter-trigger-link' ),
					'type'     => 'control',
					'section'  => 'woocommerce_product_catalog',
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-off-canvas-trigger-type]',
							'operator' => 'in',
							'value'    => array( 'button', 'link' ),
						),
					),
					'priority' => 205,
					'title'    => __( '侧悬浮边栏按钮/链接文本', 'adaptive-addon' ),
					'control'  => 'text',
				),

				/**
				 * Option: Custom Class
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-filter-trigger-custom-class]',
					'default'  => adaptive_get_option( 'shop-filter-trigger-custom-class' ),
					'type'     => 'control',
					'section'  => 'woocommerce_product_catalog',
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-off-canvas-trigger-type]',
							'operator' => '==',
							'value'    => 'custom-class',
						),
					),
					'priority' => 210,
					'title'    => __( '自定义类', 'adaptive-addon' ),
					'control'  => 'text',
				),

				/**
				 * Option: Display Active Filters
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-active-filters-display]',
					'default'  => adaptive_get_option( 'shop-active-filters-display' ),
					'type'     => 'control',
					'section'  => 'woocommerce_product_catalog',
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-off-canvas-trigger-type]',
							'operator' => '!=',
							'value'    => 'disable',
						),
					),
					'title'    => __( '显示活跃的过滤器', 'adaptive-addon' ),
					'priority' => 215,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Quick View
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[shop-quick-view-enable]',
					'default'  => adaptive_get_option( 'shop-quick-view-enable' ),
					'type'     => 'control',
					'section'  => 'woocommerce_product_catalog',
					'title'    => __( '快速查看', 'adaptive-addon' ),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
					'control'  => 'ast-select',
					'priority' => 190,
					'choices'  => array(
						'disabled'       => __( '停用', 'adaptive-addon' ),
						'on-image'       => __( '在图像', 'adaptive-addon' ),
						'on-image-click' => __( '在图像点击', 'adaptive-addon' ),
						'after-summary'  => __( '摘要以后', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Stick Quick View
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[shop-quick-view-stick-cart]',
					'default'     => adaptive_get_option( 'shop-quick-view-stick-cart' ),
					'type'        => 'control',
					'section'     => 'woocommerce_product_catalog',
					'title'       => __( '固定添加购物车按钮', 'adaptive-addon' ),
					'description' => __( '如果弹出窗口的内容较大，那么按钮将固定在弹出窗口的末尾。', 'adaptive-addon' ),
					'control'     => Adaptive_Theme_Extension::$switch_control,
					'priority'    => 190,
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
					'context'     => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[shop-quick-view-enable]',
							'operator' => '!=',
							'value'    => 'disabled',
						),
					),
				),
			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Woocommerce_Shop_Configs();
