<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Woocommerce_Shop_Single_Configs' ) ) {

	/**
	 * Register Woocommerce shop single Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Woocommerce_Shop_Single_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Woocommerce shop single Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Option: Product Gallery Layout
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-gallery-layout]',
					'default'  => adaptive_get_option( 'single-product-gallery-layout' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '画廊的布局', 'adaptive-addon' ),
					'control'  => 'ast-select',
					'priority' => 5,
					'choices'  => array(
						'vertical'   => __( '竖直', 'adaptive-addon' ),
						'horizontal' => __( '水平', 'adaptive-addon' ),
					),
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Product Image Width
				 */
				array(
					'name'        => ADAPTIVE_THEME_SETTINGS . '[single-product-image-width]',
					'default'     => adaptive_get_option( 'single-product-image-width' ),
					'type'        => 'control',
					'transport'   => 'postMessage',
					'control'     => 'ast-slider',
					'section'     => 'section-woo-shop-single',
					'title'       => __( '图像宽度', 'adaptive-addon' ),
					'suffix'      => '%',
					'priority'    => 5,
					'input_attrs' => array(
						'min'  => 20,
						'step' => 1,
						'max'  => 70,
					),
					'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Single Post Meta
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[single-product-structure]',
					'default'           => adaptive_get_option( 'single-product-structure' ),
					'type'              => 'control',
					'control'           => 'ast-sortable',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_multi_choices' ),
					'section'           => 'section-woo-shop-single',
					'title'             => __( '单一产品结构', 'adaptive-addon' ),
					'priority'          => 15,
					'choices'           => array(
						'title'      => __( '标题', 'adaptive-addon' ),
						'price'      => __( '价格', 'adaptive-addon' ),
						'ratings'    => __( '评级', 'adaptive-addon' ),
						'add_cart'   => __( '添加到购物车', 'adaptive-addon' ),
						'short_desc' => __( '简要描述', 'adaptive-addon' ),
						'meta'       => __( '其他', 'adaptive-addon' ),
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable Ajax add to cart.
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-ajax-add-to-cart]',
					'default'  => adaptive_get_option( 'single-product-ajax-add-to-cart' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '启用Ajax添加到购物车', 'adaptive-addon' ),
					'priority' => 18,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Enable product zoom effect.
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-image-zoom-effect]',
					'default'  => adaptive_get_option( 'single-product-image-zoom-effect' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '启用图像缩放效果', 'adaptive-addon' ),
					'priority' => 18,
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Navigation Style
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-nav-style]',
					'default'  => adaptive_get_option( 'single-product-nav-style' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '产品导航', 'adaptive-addon' ),
					'control'  => 'ast-select',
					'priority' => 20,
					'choices'  => array(
						'disable'        => __( '禁用', 'adaptive-addon' ),
						'circle'         => __( '圆圈', 'adaptive-addon' ),
						'circle-outline' => __( '圆形', 'adaptive-addon' ),
						'square'         => __( '实心方块', 'adaptive-addon' ),
						'square-outline' => __( '方形', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Enable Product Tabs Layout
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-tabs-display]',
					'default'  => adaptive_get_option( 'single-product-tabs-display' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '显示产品标签', 'adaptive-addon' ),
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'priority' => 30,
					'divider'  => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '产品说明标签', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Product Tabs Layout
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-tabs-layout]',
					'default'  => adaptive_get_option( 'single-product-tabs-layout' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '样式', 'adaptive-addon' ),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-tabs-display]',
							'operator' => '==',
							'value'    => true,
						),
					),
					'control'  => 'ast-select',
					'priority' => 35,
					'choices'  => array(
						'horizontal' => __( '水平', 'adaptive-addon' ),
						'vertical'   => __( '竖直', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Display related products
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-related-display]',
					'default'  => adaptive_get_option( 'single-product-related-display' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '显示相关产品', 'adaptive-addon' ),
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'priority' => 60,
					'divider'  => array(
						'ast_class' => 'ast-top-divider',
						'ast_title' => __( '相关&追加销售产品', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Display Up Sells
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-up-sells-display]',
					'default'  => adaptive_get_option( 'single-product-up-sells-display' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( '显示追加销售', 'adaptive-addon' ),
					'control'  => Adaptive_Theme_Extension::$switch_control,
					'priority' => 65,
				),

				/**
				 * Option: Related Product Columns
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[single-product-related-upsell-grid]',
					'default'           => adaptive_get_option(
						'single-product-related-upsell-grid',
						array(
							'desktop' => 4,
							'tablet'  => 3,
							'mobile'  => 2,
						)
					),
					'type'              => 'control',
					'transport'         => 'postMessage',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'section'           => 'section-woo-shop-single',
					'context'           => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-related-display]',
							'operator' => '==',
							'value'    => true,
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-up-sells-display]',
							'operator' => '==',
							'value'    => true,
						),
					),
					'priority'          => 70,
					'title'             => __( '栏目', 'adaptive-addon' ),
					'input_attrs'       => array(
						'step' => 1,
						'min'  => 1,
						'max'  => 6,
					),
				),

				/**
				 * Option: No. of Related Product
				 */
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[single-product-related-upsell-per-page]',
					'default'  => adaptive_get_option( 'single-product-related-upsell-per-page' ),
					'type'     => 'control',
					'section'  => 'section-woo-shop-single',
					'title'    => __( 'No. 相关的产品', 'adaptive-addon' ),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-related-display]',
							'operator' => '==',
							'value'    => true,
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-up-sells-display]',
							'operator' => '==',
							'value'    => true,
						),
					),
					'control'  => 'number',
					'priority' => 75,
					'divider'  => array( 'ast_class' => 'ast-bottom-divider' ),
				),

			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Woocommerce_Shop_Single_Configs();





