<?php
/**
 * Shop Options for our theme.
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 1.4.3
 */

// Block direct access to the file.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config base class does not exist.
if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

if ( ! class_exists( 'Adaptive_Woocommerce_Shop_Single_Typo_Configs' ) ) {

	/**
	 * Register Blog Single Layout Configurations.
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Woocommerce_Shop_Single_Typo_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Register Blog Single Layout Configurations.
		 *
		 * @param Array                $configurations Adaptive Customizer Configurations.
		 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
		 * @since 1.4.3
		 * @return Array Adaptive Customizer Configurations with updated configurations.
		 */
		public function register_configuration( $configurations, $gc_customize ) {

			$_configs = array(

				/**
				 * Group: WooCommerce Single product title Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[single-product-title-group]',
					'default'   => adaptive_get_option( 'single-product-title-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '标题字体', 'adaptive-addon' ),
					'section'   => 'section-woo-shop-single',
					'transport' => 'postMessage',
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-structure]',
							'operator' => 'contains',
							'value'    => 'title',
						),
					),

					'priority'  => 82,
				),

				/**
				 * Option: Single Product Title Font Family
				 */
				array(
					'name'      => 'font-family-product-title',
					'default'   => adaptive_get_option( 'font-family-product-title' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[single-product-title-group]',
					'section'   => 'section-woo-shop-single',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => 'font-weight-product-title',
					'priority'  => 4,
				),

				/**
				 * Option: Single Product Title Font Weight
				 */
				array(
					'name'              => 'font-weight-product-title',
					'default'           => adaptive_get_option( 'font-weight-product-title' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[single-product-title-group]',
					'section'           => 'section-woo-shop-single',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-product-title',
					'priority'          => 5,
				),

				/**
					 * Option: Single Product Title Text Transform
					 */
				array(
					'name'      => 'text-transform-product-title',
					'default'   => adaptive_get_option( 'text-transform-product-title' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[single-product-title-group]',
					'section'   => 'section-woo-shop-single',
					'transport' => 'postMessage',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'control'   => 'ast-select',
					'priority'  => 5,
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Single Product Title Font Size
				 */
				array(
					'name'        => 'font-size-product-title',
					'default'     => adaptive_get_option( 'font-size-product-title' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[single-product-title-group]',
					'section'     => 'section-woo-shop-single',
					'transport'   => 'postMessage',
					'control'     => 'ast-responsive',
					'priority'    => 4,
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Single Product Title Line Height
				 */
				array(
					'name'              => 'line-height-product-title',
					'default'           => adaptive_get_option( 'line-height-product-title' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[single-product-title-group]',
					'section'           => 'section-woo-shop-single',
					'transport'         => 'postMessage',
					'title'             => __( '行高', 'adaptive-addon' ),
					'control'           => 'ast-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_number_n_blank' ),
					'priority'          => 5,
					'suffix'            => 'em',
					'input_attrs'       => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

				/**
				 * Group: WooCommerce Single product price Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[single-product-price-group]',
					'default'   => adaptive_get_option( 'single-product-price-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '价格的字体', 'adaptive-addon' ),
					'section'   => 'section-woo-shop-single',
					'transport' => 'postMessage',
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-structure]',
							'operator' => 'contains',
							'value'    => 'title',
						),
					),
					'priority'  => 82,
				),

				/**
				 * Option: Single Product Price Font Family
				 */
				array(
					'name'      => 'font-family-product-price',
					'default'   => adaptive_get_option( 'font-family-product-price' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[single-product-price-group]',
					'section'   => 'section-woo-shop-single',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-product-price]',
					'priority'  => 9,
				),

				/**
				 * Option: Single Product price Font Weight
				 */
				array(
					'name'              => 'font-weight-product-price',
					'default'           => adaptive_get_option( 'font-weight-product-price' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[single-product-price-group]',
					'section'           => 'section-woo-shop-single',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-product-price',
					'priority'          => 10,
				),

				/**
				 * Option: Single Product Price Font Size
				 */
				array(
					'name'        => 'font-size-product-price',
					'default'     => adaptive_get_option( 'font-size-product-price' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[single-product-price-group]',
					'section'     => 'section-woo-shop-single',
					'transport'   => 'postMessage',
					'control'     => 'ast-responsive',
					'priority'    => 9,
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Single Product Price Line Height
				 */
				array(
					'name'        => 'line-height-product-price',
					'default'     => adaptive_get_option( 'line-height-product-price' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[single-product-price-group]',
					'section'     => 'section-woo-shop-single',
					'transport'   => 'postMessage',
					'title'       => __( '行高', 'adaptive-addon' ),
					'control'     => 'ast-slider',
					'priority'    => 10,
					'suffix'      => 'em',
					'input_attrs' => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

				/**
				 * Group: WooCommerce Single product breadcrumb Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[single-product-breadcrumb-group]',
					'default'   => adaptive_get_option( 'single-product-breadcrumb-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '面包屑字体', 'adaptive-addon' ),
					'section'   => 'section-woo-shop-single',
					'transport' => 'postMessage',
					'context'   => array(
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[single-product-breadcrumb-disable]',
							'operator' => '!=',
							'value'    => 1,
						),
					),
					'priority'  => 82,
				),

				/**
				 * Option: Single Product Breadcrumb Font Family
				 */
				array(
					'name'      => 'font-family-product-breadcrumb',
					'default'   => adaptive_get_option( 'font-family-product-breadcrumb' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[single-product-breadcrumb-group]',
					'section'   => 'section-woo-shop-single',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-product-breadcrumb]',
					'priority'  => 14,
				),

				/**
				 * Option: Single Product Breadcrumb Font Weight
				 */
				array(
					'name'              => 'font-weight-product-breadcrumb',
					'default'           => adaptive_get_option( 'font-weight-product-breadcrumb' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[single-product-breadcrumb-group]',
					'section'           => 'section-woo-shop-single',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-product-breadcrumb',
					'priority'          => 15,
				),

				/**
					 * Option: Single Product Breadcrumb Text Transform
					 */
				array(
					'name'      => 'text-transform-product-breadcrumb',
					'default'   => adaptive_get_option( 'text-transform-product-breadcrumb' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[single-product-breadcrumb-group]',
					'section'   => 'section-woo-shop-single',
					'transport' => 'postMessage',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'control'   => 'ast-select',
					'priority'  => 15,
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Single Product Breadcrumb Font Size
				 */
				array(
					'name'        => 'font-size-product-breadcrumb',
					'default'     => adaptive_get_option( 'font-size-product-breadcrumb' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[single-product-breadcrumb-group]',
					'section'     => 'section-woo-shop-single',
					'transport'   => 'postMessage',
					'control'     => 'ast-responsive',
					'priority'    => 14,
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Single Product Breadcrumb Line Height
				 */
				array(
					'name'        => 'line-height-product-breadcrumb',
					'default'     => adaptive_get_option( 'line-height-product-breadcrumb' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[single-product-breadcrumb-group]',
					'section'     => 'section-woo-shop-single',
					'transport'   => 'postMessage',
					'title'       => __( '行高', 'adaptive-addon' ),
					'control'     => 'ast-slider',
					'priority'    => 15,
					'suffix'      => 'em',
					'input_attrs' => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

				/**
				 * Group: WooCommerce Single product content Group
				 */
				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[single-product-content-group]',
					'default'   => adaptive_get_option( 'single-product-content-group' ),
					'type'      => 'control',
					'control'   => 'ast-settings-group',
					'title'     => __( '内容字体', 'adaptive-addon' ),
					'section'   => 'section-woo-shop-single',
					'transport' => 'postMessage',
					'priority'  => 82,
				),

				/**
				 * Option: Single Product Content Font Family
				 */
				array(
					'name'      => 'font-family-product-content',
					'default'   => adaptive_get_option( 'font-family-product-content' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[single-product-content-group]',
					'section'   => 'section-woo-shop-single',
					'control'   => 'ast-font',
					'font_type' => 'ast-font-family',
					'title'     => __( '字体系列', 'adaptive-addon' ),
					'connect'   => ADAPTIVE_THEME_SETTINGS . '[font-weight-product-content]',
					'priority'  => 19,
				),

				/**
				 * Option: Single Product Content Font Weight
				 */
				array(
					'name'              => 'font-weight-product-content',
					'default'           => adaptive_get_option( 'font-weight-product-content' ),
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_font_weight' ),
					'type'              => 'sub-control',
					'parent'            => ADAPTIVE_THEME_SETTINGS . '[single-product-content-group]',
					'section'           => 'section-woo-shop-single',
					'control'           => 'ast-font',
					'font_type'         => 'ast-font-weight',
					'title'             => __( '粗细', 'adaptive-addon' ),
					'connect'           => 'font-family-product-content',
					'priority'          => 20,
				),

				/**
					 * Option: Single Product Content Text Transform
					 */
				array(
					'name'      => 'text-transform-product-content',
					'default'   => adaptive_get_option( 'text-transform-product-content' ),
					'type'      => 'sub-control',
					'parent'    => ADAPTIVE_THEME_SETTINGS . '[single-product-content-group]',
					'section'   => 'section-woo-shop-single',
					'transport' => 'postMessage',
					'title'     => __( '文本转换', 'adaptive-addon' ),
					'control'   => 'ast-select',
					'priority'  => 20,
					'choices'   => array(
						''           => __( '继承', 'adaptive-addon' ),
						'none'       => __( '无', 'adaptive-addon' ),
						'capitalize' => __( '首字母大写', 'adaptive-addon' ),
						'uppercase'  => __( '大写字母', 'adaptive-addon' ),
						'lowercase'  => __( '小写字母', 'adaptive-addon' ),
					),
				),

				/**
				 * Option: Single Product Content Font Size
				 */
				array(
					'name'        => 'font-size-product-content',
					'default'     => adaptive_get_option( 'font-size-product-content' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[single-product-content-group]',
					'section'     => 'section-woo-shop-single',
					'transport'   => 'postMessage',
					'control'     => 'ast-responsive',
					'priority'    => 19,
					'title'       => __( '尺寸', 'adaptive-addon' ),
					'input_attrs' => array(
						'min' => 0,
					),
					'units'       => array(
						'px' => 'px',
						'em' => 'em',
					),
				),

				/**
				 * Option: Single Product Content Line Height
				 */
				array(
					'name'        => 'line-height-product-content',
					'default'     => adaptive_get_option( 'line-height-product-content' ),
					'type'        => 'sub-control',
					'parent'      => ADAPTIVE_THEME_SETTINGS . '[single-product-content-group]',
					'section'     => 'section-woo-shop-single',
					'transport'   => 'postMessage',
					'title'       => __( '行高', 'adaptive-addon' ),
					'control'     => 'ast-slider',
					'priority'    => 20,
					'suffix'      => 'em',
					'input_attrs' => array(
						'min'  => 1,
						'step' => 0.01,
						'max'  => 5,
					),
				),

			);

			$configurations = array_merge( $configurations, $_configs );

			return $configurations;

		}
	}
}


new Adaptive_Woocommerce_Shop_Single_Typo_Configs();





