<?php
/**
 * Adaptive Addon Builder Controller.
 *
 * @package adaptive-builder
 * @since 3.0.0
 */

// No direct access, please.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Adaptive_Addon_Builder_Customizer.
 *
 * Customizer Configuration for Header Footer Builder.
 *
 * @since 3.0.0
 */
final class Adaptive_Addon_Builder_Customizer {

	/**
	 * Constructor
	 *
	 * @since 3.0.0
	 */
	public function __construct() {

		add_action( 'customize_preview_init', array( $this, 'enqueue_customizer_preview_scripts' ) );

		if ( false === adaptive_addon_builder_helper()->is_header_footer_builder_active ) {
			return;
		}

		add_action( 'adaptive_addon_get_css_files', array( $this, 'add_styles' ) );

		$this->load_base_components();

		add_action( 'customize_register', array( $this, 'header_configs' ), 5 );
		add_action( 'customize_register', array( $this, 'footer_configs' ), 5 );

		add_filter( 'adaptive_flags_svgs', array( $this, 'adaptive_addon_flag_svgs' ), 1, 10 );

	}

	/**
	 * Register Base Components for Builder.
	 */
	public function load_base_components() {

		// @codingStandardsIgnoreStart GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound

		// Base Config Files.

		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/configurations/class-adaptive-addon-base-configs.php';
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/dynamic-css/class-adaptive-addon-base-dynamic-css.php';

		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/configurations/class-adaptive-divider-component-configs.php';
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/configurations/class-adaptive-addon-button-component-configs.php';
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/configurations/class-adaptive-social-component-configs.php';
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/configurations/class-adaptive-language-switcher-component-configs.php';

		// Base Dynamic CSS Files.
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/dynamic-css/divider/class-adaptive-divider-component-dynamic-css.php';
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/dynamic-css/language-switcher/class-adaptive-language-switcher-component-dynamic-css.php';
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/dynamic-css/social-icon/class-adaptive-social-icon-component-dynamic-css.php';
		require_once ADAPTIVE_EXT_DIR . 'classes/builder/type/base/dynamic-css/button/class-adaptive-addon-button-component-dynamic-css.php';

		$this->load_header_components();
		$this->load_footer_components();
		// @codingStandardsIgnoreEnd GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	}

	/**
	 * Register controls for Header Builder.
	 *
	 * @param GC_Customize_Manager $gc_customize Theme Customizer object.
	 * @since 3.0.0
	 */
	public function header_configs( $gc_customize ) {
		// @codingStandardsIgnoreStart GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
		$header_config_path = ADAPTIVE_EXT_DIR . 'classes/builder/type/header';
		require_once $header_config_path . '/divider/class-adaptive-header-divider-component-configs.php';
		require_once $header_config_path . '/account/class-adaptive-ext-header-account-component-configs.php';
		require_once $header_config_path . '/menu/class-adaptive-addon-header-menu-component-configs.php';
		require_once $header_config_path . '/button/class-adaptive-addon-header-button-component-configs.php';
		require_once $header_config_path . '/social-icon/class-adaptive-header-social-component-configs.php';
		require_once $header_config_path . '/language-switcher/class-adaptive-header-language-switcher-configs.php';
		require_once $header_config_path . '/off-canvas/class-adaptive-addon-offcanvas-configs.php';
		// @codingStandardsIgnoreEnd GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	}

	/**
	 * Register controls for Footer Builder.
	 *
	 * @param GC_Customize_Manager $gc_customize Theme Customizer object.
	 * @since 3.0.0
	 */
	public function footer_configs( $gc_customize ) {
		// @codingStandardsIgnoreStart GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
		$footer_config_path = ADAPTIVE_EXT_DIR . 'classes/builder/type/footer';
		require_once $footer_config_path . '/divider/class-adaptive-footer-divider-component-configs.php';
		require_once $footer_config_path . '/button/class-adaptive-ext-footer-button-component-configs.php';
		require_once $footer_config_path . '/social-icon/class-adaptive-footer-social-component-configs.php';
		require_once $footer_config_path . '/language-switcher/class-adaptive-footer-language-switcher-configs.php';

		// @codingStandardsIgnoreEnd GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	}

	/**
	 * Register Components for Header Builder.
	 *
	 * @since 3.0.0
	 */
	public function load_header_components() {
		// @codingStandardsIgnoreStart GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
		$header_components_path = ADAPTIVE_EXT_DIR . 'classes/builder/type/header';
		if ( ! class_exists( 'Adaptive_Header_Divider_Component' ) ) {
			require_once $header_components_path . '/divider/class-adaptive-header-divider-component.php';
		}
		require_once $header_components_path . '/button/class-adaptive-addon-header-button-component.php';
		require_once $header_components_path . '/account/class-adaptive-ext-header-account-component.php';
		require_once $header_components_path . '/menu/class-adaptive-addon-header-menu-component.php';
		require_once $header_components_path . '/social-icon/class-adaptive-header-social-component.php';
		require_once $header_components_path . '/language-switcher/class-adaptive-header-language-switcher-component.php';
		require_once $header_components_path . '/off-canvas/class-adaptive-addon-offcanvas-component.php';

		// @codingStandardsIgnoreEnd GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	}

	/**
	 * Register Components for Footer Builder.
	 *
	 * @since 3.0.0
	 */
	public function load_footer_components() {
		// @codingStandardsIgnoreStart GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
		$footer_components_path = ADAPTIVE_EXT_DIR . 'classes/builder/type/footer';
		if ( ! class_exists( 'Adaptive_Footer_Divider_Component' ) ) {
			require_once $footer_components_path . '/divider/class-adaptive-footer-divider-component.php';
		}
		require_once $footer_components_path . '/button/class-adaptive-ext-footer-button-component.php';

		require_once $footer_components_path . '/social-icon/class-adaptive-footer-social-component.php';

		require_once $footer_components_path . '/language-switcher/class-adaptive-footer-language-switcher-component.php';

		// @codingStandardsIgnoreEnd GCThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
	}

	/**
	 * Add Customizer preview script.
	 *
	 * @since 3.0.0
	 */
	public function enqueue_customizer_preview_scripts() {

		// Base Dynamic CSS.
		gc_enqueue_script(
			'ahfb-addon-base-customizer-preview',
			ADAPTIVE_EXT_URI . 'classes/builder/type/base/assets/js/customizer-preview.js',
			array( 'customize-preview' ),
			ADAPTIVE_EXT_VER,
			true
		);

		// Localize variables for Adaptive Breakpoints JS.
		gc_localize_script(
			'ahfb-addon-base-customizer-preview',
			'adaptiveBuilderPreview',
			array(
				'tablet_break_point' => adaptive_addon_get_tablet_breakpoint(),
				'mobile_break_point' => adaptive_addon_get_mobile_breakpoint(),
			)
		);
	}


	/**
	 * Add Styles Callback
	 *
	 * @since 3.1.0
	 */
	public function add_styles() {

		/*** Start Path Logic */

		/* Define Variables */
		$uri  = ADAPTIVE_EXT_URI . 'classes/builder/assets/css/';
		$path = ADAPTIVE_EXT_DIR . 'classes/builder/assets/css/';
		$rtl  = '';

		if ( is_rtl() ) {
			$rtl = '-rtl';
		}

		/* Directory and Extension */
		$file_prefix = $rtl . '.min';
		$dir_name    = 'minified';

		if ( SCRIPT_DEBUG ) {
			$file_prefix = $rtl;
			$dir_name    = 'unminified';
		}

		$css_uri = $uri . $dir_name . '/';
		$css_dir = $path . $dir_name . '/';

		if ( defined( 'ADAPTIVE_THEME_HTTP2' ) && ADAPTIVE_THEME_HTTP2 ) {
			$gen_path = $css_uri;
		} else {
			$gen_path = $css_dir;
		}

		/*** End Path Logic */

		/* Add style.css */
		Adaptive_Minify::add_css( $gen_path . 'style' . $file_prefix . '.css' );
	}

	/**
	 * Load Flags SVG Icon array from the JSON file.
	 *
	 * @param Array $svg_arr Array of svg icons.
	 * @since 3.1.0
	 * @return Array addon svg icons.
	 */
	public function adaptive_addon_flag_svgs( $svg_arr = array() ) {

		ob_start();
		// Include SVGs Json file.
		include_once ADAPTIVE_EXT_DIR . 'assets/flags/svgs.json';
		$svg_icon_arr  = json_decode( ob_get_clean(), true );
		$ast_flag_svgs = array_merge( $svg_arr, $svg_icon_arr );
		return $ast_flag_svgs;
	}
}

/**
 *  Prepare if class 'Adaptive_Addon_Builder_Customizer' exist.
 *  Kicking this off by creating new object of the class.
 */
new Adaptive_Addon_Builder_Customizer();
