<?php
/**
 * Adaptive Addon Base Configuration.
 *
 * @package adaptive-builder
 */

// No direct access, please.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Adaptive_Addon_Base_Configs.
 */
class Adaptive_Addon_Base_Configs {

	/**
	 * Prepare Box Shadow options.
	 *
	 * @param string  $_section section id.
	 * @param string  $_prefix Control Prefix.
	 * @param integer $priority Priority.
	 * @since 3.3.0
	 * @return array
	 */
	public static function prepare_box_shadow_tab( $_section, $_prefix, $priority = 90 ) {

		$configs = array(

			// Option Group: Box shadow Group.
			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $_prefix . '-shadow-group]',
				'type'      => 'control',
				'control'   => 'ast-settings-group',
				'title'     => __( '阴影', 'adaptive-addon' ),
				'section'   => $_section,
				'transport' => 'postMessage',
				'priority'  => $priority,
				'context'   => adaptive_addon_builder_helper()->design_tab,
			),

			/**
			 * Option: box shadow
			 */
			array(
				'name'              => $_prefix . '-box-shadow-control',
				'default'           => adaptive_get_option( $_prefix . '-box-shadow-control' ),
				'parent'            => ADAPTIVE_THEME_SETTINGS . '[' . $_prefix . '-shadow-group]',
				'type'              => 'sub-control',
				'transport'         => 'postMessage',
				'control'           => 'ast-box-shadow',
				'section'           => $_section,
				'sanitize_callback' => array( 'Adaptive_Addon_Customizer', 'sanitize_box_shadow' ),
				'priority'          => 1,
				'title'             => __( '字段值', 'adaptive-addon' ),
				'choices'           => array(
					'x'      => __( 'X', 'adaptive-addon' ),
					'y'      => __( 'Y年', 'adaptive-addon' ),
					'blur'   => __( '模糊', 'adaptive-addon' ),
					'spread' => __( '扩散', 'adaptive-addon' ),
				),
				'context'           => adaptive_addon_builder_helper()->general_tab,
			),

			array(
				'name'      => $_prefix . '-box-shadow-position',
				'default'   => adaptive_get_option( $_prefix . '-box-shadow-position' ),
				'parent'    => ADAPTIVE_THEME_SETTINGS . '[' . $_prefix . '-shadow-group]',
				'type'      => 'sub-control',
				'section'   => $_section,
				'transport' => 'postMessage',
				'control'   => 'ast-select',
				'title'     => __( '位置', 'adaptive-addon' ),
				'choices'   => array(
					'outline' => __( '轮廓', 'adaptive-addon' ),
					'inset'   => __( '插入', 'adaptive-addon' ),
				),
				'priority'  => 2,
				'context'   => adaptive_addon_builder_helper()->general_tab,
			),

			array(
				'name'      => $_prefix . '-box-shadow-color',
				'default'   => adaptive_get_option( $_prefix . '-box-shadow-color' ),
				'parent'    => ADAPTIVE_THEME_SETTINGS . '[' . $_prefix . '-shadow-group]',
				'type'      => 'sub-control',
				'section'   => $_section,
				'transport' => 'postMessage',
				'control'   => 'ast-color',
				'title'     => __( '颜色', 'adaptive-addon' ),
				'rgba'      => true,
				'priority'  => 3,
				'context'   => adaptive_addon_builder_helper()->general_tab,
			),
		);

		return $configs;
	}

}

new Adaptive_Addon_Base_Configs();
