<?php
/**
 * Adaptive Addon Customizer Configuration Button.
 *
 * @package     adaptive-builder
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       3.1.0
 */

// No direct access, please.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Register Button Customizer Configurations.
 *
 * @since 3.1.0
 */
class Adaptive_Addon_Button_Component_Configs {

	/**
	 * Register Button Customizer Configurations.
	 *
	 * @param Array  $configurations Configurations.
	 * @param string $builder_type Builder Type.
	 * @param string $section Section.
	 *
	 * @since 3.1.0
	 * @return Array Adaptive Customizer Configurations with updated configurations.
	 */
	public static function register_configuration( $configurations, $builder_type = 'header', $section = 'section-hb-button-' ) {

		$class_obj = '';

		if ( 'footer' === $builder_type && class_exists( 'Adaptive_Builder_Footer' ) ) {
			$class_obj = Adaptive_Builder_Footer::get_instance();
		} elseif ( 'header' === $builder_type && class_exists( 'Adaptive_Builder_Header' ) ) {
			$class_obj = Adaptive_Builder_Header::get_instance();
		}

		$html_config = array();

		$component_limit = adaptive_addon_builder_helper()->component_limit;
		for ( $index = 1; $index <= $component_limit; $index++ ) {

			$_section = $section . $index;
			$_prefix  = 'button' . $index;

			$_configs = array(

				array(
					'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-' . $_prefix . '-size]',
					'default'   => adaptive_get_option( $builder_type . '-' . $_prefix . '-size' ),
					'type'      => 'control',
					'control'   => 'ast-select',
					'section'   => $_section,
					'priority'  => 30,
					'title'     => __( '尺寸', 'adaptive-addon' ),
					'choices'   => array(
						'xs' => __( '超小', 'adaptive-addon' ),
						'sm' => __( '小', 'adaptive-addon' ),
						'md' => __( '中等', 'adaptive-addon' ),
						'lg' => __( '大', 'adaptive-addon' ),
						'xl' => __( '特大号', 'adaptive-addon' ),
					),
					'transport' => 'postMessage',
					'context'   => adaptive_addon_builder_helper()->general_tab,
					'partial'   => array(
						'selector'            => '.ast-' . $builder_type . '-button-' . $index,
						'container_inclusive' => false,
						'render_callback'     => array( $class_obj, 'button_' . $index ),
						'fallback_refresh'    => false,
					),
				),

			);

			$html_config[] = Adaptive_Addon_Base_Configs::prepare_box_shadow_tab( $_section, $builder_type . '-' . $_prefix );

			$html_config[] = $_configs;
		}

		$html_config = call_user_func_array( 'array_merge', $html_config + array( array() ) );

		return array_merge( $configurations, $html_config );

	}
}

/**
 * Kicking this off by creating object of this class.
 */

new Adaptive_Addon_Button_Component_Configs();
