<?php
/**
 * Adaptive Theme Customizer Configuration Builder.
 *
 * @package     adaptive-builder
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       3.0.0
 */

// No direct access, please.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config divider base class is already present.
if ( class_exists( 'Adaptive_Divider_Component_Configs' ) ) {
	return;
}

/**
 * Register Builder Customizer Configurations.
 *
 * @since 3.0.0
 */
// @codingStandardsIgnoreStart
class Adaptive_Divider_Component_Configs {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
	// @codingStandardsIgnoreEnd

	/**
	 * Register Builder Customizer Configurations.
	 *
	 * @param Array  $configurations Configurations.
	 * @param string $builder_type Builder Type.
	 * @param string $section Section.
	 *
	 * @since 3.0.0
	 * @return Array Adaptive Customizer Configurations with updated configurations.
	 */
	public static function register_configuration( $configurations, $builder_type = 'header', $section = 'section-hb-divider-' ) {

		$divider_config = array();

		if ( 'footer' === $builder_type ) {
			$class_obj           = Adaptive_Addon_Builder_Footer::get_instance();
			$number_of_divider   = adaptive_addon_builder_helper()->num_of_footer_divider;
			$divider_size_layout = 'horizontal';
		} else {
			$class_obj           = Adaptive_Addon_Builder_Header::get_instance();
			$number_of_divider   = adaptive_addon_builder_helper()->num_of_header_divider;
			$divider_size_layout = 'vertical';
		}

		$component_limit = adaptive_addon_builder_helper()->component_limit;
		for ( $index = 1; $index <= $component_limit; $index++ ) {

			$_section = $section . $index;
			$_prefix  = 'divider' . $index;

			/**
			 * These options are related to Header Section - divider.
			 * Prefix hs represents - Header Section.
			 */
			$_configs = array(

				/**
				 * Option: Header Builder Tabs
				 */
				array(
					'name'        => $_section . '-ast-context-tabs',
					'section'     => $_section,
					'type'        => 'control',
					'control'     => 'ast-builder-header-control',
					'priority'    => 0,
					'description' => '',
				),

				/*
				* Header Builder section - divider Component Configs.
				*/
				array(
					'name'        => $_section,
					'type'        => 'section',
					'priority'    => 50,
					/* translators: %s Index */
					'title'       => ( 1 === $number_of_divider ) ? __( 'Divider', 'adaptive-addon' ) : sprintf( __( 'Divider %s', 'adaptive-addon' ), $index ),
					'panel'       => 'panel-' . $builder_type . '-builder-group',
					'clone_index' => $index,
					'clone_type'  => $builder_type . '-divider',
				),

				/**
				 * Option: Position
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-layout]',
					'default'    => adaptive_get_option( $builder_type . '-divider-' . $index . '-layout' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => $_section,
					'priority'   => 30,
					'title'      => __( '样式', 'adaptive-addon' ),
					'choices'    => array(
						'horizontal' => __( '水平', 'adaptive-addon' ),
						'vertical'   => __( '竖直', 'adaptive-addon' ),
					),
					'transport'  => 'postMessage',
					'partial'    => array(
						'selector'        => '.ast-' . $builder_type . '-divider-' . $index,
						'render_callback' => array( $class_obj, $builder_type . '_divider_' . $index ),
					),
					'responsive' => false,
					'renderAs'   => 'text',
				),

				// Vertical divider notice.
				array(
					'name'     => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-description]',
					'type'     => 'control',
					'control'  => 'ast-description',
					'section'  => $_section,
					'priority' => 30,
					'label'    => '',
					/* translators: %1$s builder type param */
					'help'     => sprintf( __( '如果分隔符看起来不可见，请检查元素是否被添加到当前的%1$s行。', 'adaptive-addon' ), $builder_type ),
					'context'  => array(
						adaptive_addon_builder_helper()->general_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-layout]',
							'operator' => '==',
							'value'    => 'vertical',
						),
					),
				),

				/**
				 * Option:  Divider Style
				 */
				array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-style]',
					'default'    => adaptive_get_option( $builder_type . '-divider-' . $index . '-style' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => $_section,
					'priority'   => 30,
					'title'      => __( '样式', 'adaptive-addon' ),
					'choices'    => array(
						'solid'  => __( '固体', 'adaptive-addon' ),
						'dashed' => __( '虚线', 'adaptive-addon' ),
						'dotted' => __( '点线', 'adaptive-addon' ),
						'double' => __( '双实线', 'adaptive-addon' ),
					),
					'transport'  => 'postMessage',
					'responsive' => false,
					'renderAs'   => 'text',
					'divider'    => array( 'ast_class' => 'ast-top-divider' ),
				),

				// Section: Above Footer Border.
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-thickness]',
					'section'           => $_section,
					'priority'          => 40,
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( $builder_type . '-divider-' . $index . '-thickness' ),
					'title'             => __( '厚度', 'adaptive-addon' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'input_attrs'       => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 60,
					),
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
					'suffix'            => 'px',
					'context'           => adaptive_addon_builder_helper()->design_tab,
				),

				// Section: Above Footer Border.
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-size]',
					'section'           => $_section,
					'priority'          => 40,
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( $builder_type . '-divider-' . $index . '-size' ),
					'title'             => __( '尺寸', 'adaptive-addon' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'input_attrs'       => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 100,
					),
					'suffix'            => '%',
					'context'           => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-layout]',
							'operator' => '==',
							'value'    => $divider_size_layout,
						),
					),
				),

				/**
				 * Option: divider Color.
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-color]',
					'default'           => adaptive_get_option( $builder_type . '-divider-' . $index . '-color' ),
					'type'              => 'control',
					'section'           => $_section,
					'priority'          => 8,
					'transport'         => 'postMessage',
					'control'           => 'ast-color',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_alpha_color' ),
					'title'             => __( '颜色', 'adaptive-addon' ),
					'context'           => adaptive_addon_builder_helper()->design_tab,
					'divider'           => array( 'ast_class' => 'ast-bottom-divider' ),
				),

				/**
				 * Option: Margin Space
				 */
				array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[' . $_section . '-margin]',
					'default'           => adaptive_get_option( $_section . '-margin' ),
					'type'              => 'control',
					'transport'         => 'postMessage',
					'control'           => 'ast-responsive-spacing',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_spacing' ),
					'section'           => $_section,
					'priority'          => 220,
					'title'             => __( '外距', 'adaptive-addon' ),
					'divider'           => array( 'ast_class' => 'ast-top-divider' ),
					'linked_choices'    => true,
					'unit_choices'      => array( 'px', 'em', '%' ),
					'choices'           => array(
						'top'    => __( '顶部', 'adaptive-addon' ),
						'right'  => __( '右', 'adaptive-addon' ),
						'bottom' => __( '底部', 'adaptive-addon' ),
						'left'   => __( '左', 'adaptive-addon' ),
					),
					'context'           => adaptive_addon_builder_helper()->design_tab,
				),

			);

			if ( 'footer' === $builder_type ) {
				$_configs[] = array(
					'name'       => ADAPTIVE_THEME_SETTINGS . '[footer-divider-' . $index . '-alignment]',
					'default'    => adaptive_get_option( 'footer-divider-' . $index . '-alignment' ),
					'type'       => 'control',
					'control'    => Adaptive_Theme_Extension::$selector_control,
					'section'    => $_section,
					'priority'   => 35,
					'title'      => __( '对齐方式', 'adaptive-addon' ),
					'choices'    => array(
						'flex-start' => __( '左', 'adaptive-addon' ),
						'center'     => __( '中', 'adaptive-addon' ),
						'flex-end'   => __( '右', 'adaptive-addon' ),
					),
					'transport'  => 'postMessage',
					'responsive' => true,
					'renderAs'   => 'text',
				);

				// Footer vertical divider size.
				$_configs[] = array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[footer-vertical-divider-' . $index . '-size]',
					'section'           => $_section,
					'priority'          => 40,
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'footer-vertical-divider-' . $index . '-size' ),
					'title'             => __( '尺寸', 'adaptive-addon' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'input_attrs'       => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 1000,
					),
					'suffix'            => 'px',
					'context'           => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-layout]',
							'operator' => '==',
							'value'    => 'vertical',
						),
					),
				);
			}

			if ( 'header' === $builder_type ) {

				// Header horizontal divider size.
				$_configs[] = array(
					'name'              => ADAPTIVE_THEME_SETTINGS . '[header-horizontal-divider-' . $index . '-size]',
					'section'           => $_section,
					'priority'          => 40,
					'transport'         => 'postMessage',
					'default'           => adaptive_get_option( 'header-horizontal-divider-' . $index . '-size' ),
					'title'             => __( '尺寸', 'adaptive-addon' ),
					'type'              => 'control',
					'control'           => 'ast-responsive-slider',
					'sanitize_callback' => array( 'Adaptive_Customizer_Sanitizes', 'sanitize_responsive_slider' ),
					'input_attrs'       => array(
						'min'  => 0,
						'step' => 1,
						'max'  => 1000,
					),
					'suffix'            => 'px',
					'context'           => array(
						adaptive_addon_builder_helper()->design_tab_config,
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-divider-' . $index . '-layout]',
							'operator' => '==',
							'value'    => 'horizontal',
						),
					),
				);
			}

			if ( class_exists( 'Adaptive_Builder_Base_Configuration' ) && method_exists( 'Adaptive_Builder_Base_Configuration', 'prepare_visibility_tab' ) ) {
				$divider_config[] = Adaptive_Builder_Base_Configuration::prepare_visibility_tab( $_section, $builder_type );
			}

			$divider_config[] = $_configs;
		}

		$divider_config = call_user_func_array( 'array_merge', $divider_config + array( array() ) );
		$configurations = array_merge( $configurations, $divider_config );

		return $configurations;
	}
}

/**
 * Kicking this off by creating object of this class.
 */

new Adaptive_Divider_Component_Configs();
