<?php
/**
 * Adaptive Theme Customizer Configuration Builder.
 *
 * @package     adaptive-builder
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       3.1.0
 */

// No direct access, please.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Bail if Customizer config language_switcher base class is already present.
if ( class_exists( 'Adaptive_Language_Switcher_Component_Configs' ) ) {
	return;
}

/**
 * Register Builder Customizer Configurations.
 *
 * @since 3.1.0
 */
// @codingStandardsIgnoreStart
class Adaptive_Language_Switcher_Component_Configs {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
	// @codingStandardsIgnoreEnd

	/**
	 * Register Builder Customizer Configurations.
	 *
	 * @param Array  $configurations Configurations.
	 * @param string $builder_type Builder Type.
	 * @param string $_section Section.
	 *
	 * @since 3.1.0
	 * @return Array Adaptive Customizer Configurations with updated configurations.
	 */
	public static function register_configuration( $configurations, $builder_type = 'header', $_section = 'section-hb-language-switcher' ) {

		$lang_config = array();

		if ( 'footer' === $builder_type ) {
			$class_obj = Adaptive_Addon_Builder_Footer::get_instance();
		} else {
			$class_obj = Adaptive_Addon_Builder_Header::get_instance();
		}

		$language_choices = array(
			'custom' => __( '自定义', 'adaptive-addon' ),
		);

		if ( class_exists( 'SitePress' ) ) {
			$language_choices['gcml'] = __( 'GCML', 'adaptive-addon' );
		}

		$type_context = adaptive_addon_builder_helper()->general_tab;

		if ( count( $language_choices ) > 1 ) {
			$type_context = array(
				array(
					'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-type]',
					'operator' => '==',
					'value'    => 'custom',
				),
				adaptive_addon_builder_helper()->general_tab_config,
			);
		}

		/**
		 * These options are related to Header Section - language switcher.
		 */
		$_configs = array(

			/**
			 * Option: Header Builder Tabs
			 */
			array(
				'name'        => $_section . '-ast-context-tabs',
				'section'     => $_section,
				'type'        => 'control',
				'control'     => 'ast-builder-header-control',
				'priority'    => 0,
				'description' => '',
			),
			array(
				'name'     => $_section,
				'type'     => 'section',
				'priority' => 1,
				'title'    => __( '语言切换器', 'adaptive-addon' ),
				'panel'    => 'panel-' . $builder_type . '-builder-group',
			),
			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-options]',
				'section'   => $_section,
				'type'      => 'control',
				'control'   => 'ast-language-selector',
				'title'     => __( '选择语言', 'adaptive-addon' ),
				'transport' => 'postMessage',
				'priority'  => 2,
				'default'   => adaptive_get_option( $builder_type . '-language-switcher-options' ),
				'partial'   => array(
					'selector'        => '.ast-' . $builder_type . '-language-switcher',
					'render_callback' => array( $class_obj, $builder_type . '_language_switcher' ),
				),
				'context'   => $type_context,
			),

			/**
			 * Option: Position
			 */
			array(
				'name'       => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-layout]',
				'default'    => adaptive_get_option( $builder_type . '-language-switcher-layout' ),
				'type'       => 'control',
				'control'    => Adaptive_Theme_Extension::$selector_control,
				'section'    => $_section,
				'priority'   => 3,
				'title'      => __( '样式', 'adaptive-addon' ),
				'choices'    => array(
					'horizontal' => __( '水平', 'adaptive-addon' ),
					'vertical'   => __( '竖直', 'adaptive-addon' ),
				),
				'transport'  => 'postMessage',
				'partial'    => array(
					'selector'        => '.ast-' . $builder_type . '-language-switcher',
					'render_callback' => array( $class_obj, $builder_type . '_language_switcher' ),
				),
				'context'    => adaptive_addon_builder_helper()->general_tab,
				'responsive' => false,
				'renderAs'   => 'text',
				'divider'    => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
			),

			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-show-flag]',
				'default'   => adaptive_get_option( $builder_type . '-language-switcher-show-flag' ),
				'type'      => 'control',
				'control'   => Adaptive_Theme_Extension::$switch_control,
				'section'   => $_section,
				'priority'  => 3,
				'title'     => __( '展示国旗', 'adaptive-addon' ),
				'partial'   => array(
					'selector'        => '.ast-' . $builder_type . '-language-switcher',
					'render_callback' => array( $class_obj, $builder_type . '_language_switcher' ),
				),
				'transport' => 'postMessage',
				'context'   => adaptive_addon_builder_helper()->general_tab,
				'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
			),

			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-show-name]',
				'default'   => adaptive_get_option( $builder_type . '-language-switcher-show-name' ),
				'type'      => 'control',
				'control'   => Adaptive_Theme_Extension::$switch_control,
				'section'   => $_section,
				'priority'  => 3,
				'title'     => __( '显示名称', 'adaptive-addon' ),
				'partial'   => array(
					'selector'        => '.ast-' . $builder_type . '-language-switcher',
					'render_callback' => array( $class_obj, $builder_type . '_language_switcher' ),
				),
				'transport' => 'postMessage',
				'context'   => adaptive_addon_builder_helper()->general_tab,
			),

			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-show-tname]',
				'default'   => adaptive_get_option( $builder_type . '-language-switcher-show-tname' ),
				'type'      => 'control',
				'control'   => Adaptive_Theme_Extension::$switch_control,
				'section'   => $_section,
				'priority'  => 3,
				'title'     => __( '显示翻译的名字', 'adaptive-addon' ),
				'transport' => 'postMessage',
				'partial'   => array(
					'selector'        => '.ast-' . $builder_type . '-language-switcher',
					'render_callback' => array( $class_obj, $builder_type . '_language_switcher' ),
				),
				'context'   => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-type]',
						'operator' => '==',
						'value'    => 'gcml',
					),
					adaptive_addon_builder_helper()->general_tab_config,
				),
			),

			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-show-code]',
				'default'   => adaptive_get_option( $builder_type . '-language-switcher-show-code' ),
				'type'      => 'control',
				'control'   => Adaptive_Theme_Extension::$switch_control,
				'section'   => $_section,
				'priority'  => 3,
				'title'     => __( '显示语言代码', 'adaptive-addon' ),
				'transport' => 'postMessage',
				'partial'   => array(
					'selector'        => '.ast-' . $builder_type . '-language-switcher',
					'render_callback' => array( $class_obj, $builder_type . '_language_switcher' ),
				),
				'context'   => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-type]',
						'operator' => '==',
						'value'    => 'gcml',
					),
					adaptive_addon_builder_helper()->general_tab_config,
				),
			),

			array(
				'name'        => ADAPTIVE_THEME_SETTINGS . '[' . $_section . '-flag-size]',
				'section'     => $_section,
				'priority'    => 2,
				'transport'   => 'postMessage',
				'default'     => adaptive_get_option( $_section . '-flag-size' ),
				'title'       => __( '标志大小', 'adaptive-addon' ),
				'type'        => 'control',
				'control'     => 'ast-responsive-slider',
				'input_attrs' => array(
					'min'  => 0,
					'step' => 1,
					'max'  => 50,
				),
				'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				'suffix'      => 'px',
				'context'     => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-show-flag]',
						'operator' => '==',
						'value'    => true,
					),
					adaptive_addon_builder_helper()->design_tab_config,
				),
			),

			// Section: Above Footer Border.
			array(
				'name'        => ADAPTIVE_THEME_SETTINGS . '[' . $_section . '-flag-spacing]',
				'section'     => $_section,
				'priority'    => 2,
				'transport'   => 'postMessage',
				'default'     => adaptive_get_option( $_section . '-flag-spacing' ),
				'title'       => __( '标签和文本间距', 'adaptive-addon' ),
				'type'        => 'control',
				'suffix'      => 'px',
				'control'     => 'ast-responsive-slider',
				'input_attrs' => array(
					'min'  => 0,
					'step' => 1,
					'max'  => 60,
				),
				'divider'     => array( 'ast_class' => 'ast-bottom-divider' ),
				'context'     => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-show-name]',
						'operator' => '==',
						'value'    => true,
					),
					adaptive_addon_builder_helper()->design_tab_config,
				),
			),

		);

		if ( count( $language_choices ) > 1 ) {
			$_configs[] = array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[' . $builder_type . '-language-switcher-type]',
				'default'   => adaptive_get_option( $builder_type . '-language-switcher-type' ),
				'type'      => 'control',
				'control'   => 'ast-select',
				'section'   => $_section,
				'priority'  => 1,
				'title'     => __( '类型', 'adaptive-addon' ),
				'choices'   => $language_choices,
				'transport' => 'postMessage',
				'partial'   => array(
					'selector'        => '.ast-' . $builder_type . '-language-switcher',
					'render_callback' => array( $class_obj, $builder_type . '_language_switcher' ),
				),
			);
		}

		if ( 'footer' === $builder_type ) {

			$_configs[] = array(
				'name'       => ADAPTIVE_THEME_SETTINGS . '[footer-language-switcher-alignment]',
				'default'    => adaptive_get_option( 'footer-language-switcher-alignment' ),
				'type'       => 'control',
				'control'    => Adaptive_Theme_Extension::$selector_control,
				'section'    => $_section,
				'priority'   => 35,
				'title'      => __( '对齐方式', 'adaptive-addon' ),
				'context'    => adaptive_addon_builder_helper()->general_tab,
				'divider'    => array( 'ast_class' => 'ast-top-divider' ),
				'transport'  => 'postMessage',
				'responsive' => true,
				'choices'    => array(
					'flex-start' => 'align-left',
					'center'     => 'align-center',
					'flex-end'   => 'align-right',
				),
			);
		}

		if ( is_callable( 'Adaptive_Builder_Base_Configuration::prepare_visibility_tab' ) ) {
			$lang_config[] = Adaptive_Builder_Base_Configuration::prepare_visibility_tab( $_section, $builder_type );
		}

		$lang_config[] = $_configs;

		$lang_config    = call_user_func_array( 'array_merge', $lang_config + array( array() ) );
		$configurations = array_merge( $configurations, $lang_config );

		return $configurations;
	}
}

/**
 * Kicking this off by creating object of this class.
 */

new Adaptive_Language_Switcher_Component_Configs();
