<?php
/**
 * Button Styling Loader for Adaptive theme.
 *
 * @package     Adaptive Builder
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 3.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Customizer Initialization
 *
 * @since 3.1.0
 */
// @codingStandardsIgnoreStart
class Adaptive_Ext_Footer_Button_Component_Loader { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
	// @codingStandardsIgnoreEnd

	/**
	 * Constructor
	 *
	 * @since 3.1.0
	 */
	public function __construct() {
		add_filter( 'adaptive_theme_defaults', array( $this, 'theme_defaults' ) );
		add_action( 'customize_preview_init', array( $this, 'preview_scripts' ), 110 );
	}

	/**
	 * Default customizer configs.
	 *
	 * @param  array $defaults  Adaptive options default value array.
	 *
	 * @since 3.1.0
	 */
	public function theme_defaults( $defaults ) {
		// Button footer defaults.
		$component_limit = adaptive_addon_builder_helper()->component_limit;
		for ( $index = 1; $index <= $component_limit; $index++ ) {

			$_prefix = 'button' . $index;

			$defaults[ 'footer-' . $_prefix . '-size' ] = 'sm';

			$defaults[ 'footer-' . $_prefix . '-box-shadow-control' ]  = array(
				'x'      => '0',
				'y'      => '0',
				'blur'   => '0',
				'spread' => '0',
			);
			$defaults[ 'footer-' . $_prefix . '-box-shadow-color' ]    = 'rgba(0,0,0,0.1)';
			$defaults[ 'footer-' . $_prefix . '-box-shadow-position' ] = 'outline';

		}

		return $defaults;
	}

	/**
	 * Customizer Preview
	 *
	 * @since 3.3.0
	 */
	public function preview_scripts() {
		/**
		 * Load unminified if SCRIPT_DEBUG is true.
		 */
		/* Directory and Extension */
		$dir_name    = ( SCRIPT_DEBUG ) ? 'unminified' : 'minified';
		$file_prefix = ( SCRIPT_DEBUG ) ? '' : '.min';
		gc_enqueue_script( 'adaptive-ext-footer-button-customizer-preview-js', ADAPTIVE_ADDON_EXT_FOOTER_BUTTON_URI . '/assets/js/' . $dir_name . '/customizer-preview' . $file_prefix . '.js', array( 'customize-preview', 'ahfb-addon-base-customizer-preview' ), ADAPTIVE_EXT_VER, true );

		// Localize variables for button JS.
		gc_localize_script(
			'adaptive-ext-footer-button-customizer-preview-js',
			'AdaptiveAddonFooterButtonData',
			array(
				'component_limit' => adaptive_addon_builder_helper()->component_limit,
			)
		);
	}

}

/**
*  Kicking this off by creating the object of the class.
*/
new Adaptive_Ext_Footer_Button_Component_Loader();
