<?php
/**
 * Divider control - Dynamic CSS
 *
 * @package Adaptive Builder
 * @since 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Heading Colors
 */
add_filter( 'adaptive_dynamic_theme_css', 'adaptive_addon_footer_divider_dynamic_css' );

/**
 * Dynamic CSS
 *
 * @param  string $dynamic_css          Adaptive Dynamic CSS.
 * @param  string $dynamic_css_filtered Adaptive Dynamic CSS Filters.
 * @return String Generated dynamic CSS for Heading Colors.
 *
 * @since 3.0.0
 */
function adaptive_addon_footer_divider_dynamic_css( $dynamic_css, $dynamic_css_filtered = '' ) {

	$dynamic_css .= Adaptive_Divider_Component_Dynamic_CSS::adaptive_divider_dynamic_css( 'footer' );

	$component_limit = adaptive_addon_builder_helper()->component_limit;
	for ( $index = 1; $index <= $component_limit; $index++ ) {

		if ( ! Adaptive_Addon_Builder_Helper::is_component_loaded( 'divider-' . $index, 'footer' ) ) {
			continue;
		}

		$_section = 'section-fb-divider-' . $index;
		$selector = '.footer-widget-area[data-section="section-fb-divider-' . $index . '"]';

		$alignment = adaptive_get_option( 'footer-divider-' . $index . '-alignment' );

		$desktop_alignment = ( isset( $alignment['desktop'] ) ) ? $alignment['desktop'] : 'center';
		$tablet_alignment  = ( isset( $alignment['tablet'] ) ) ? $alignment['tablet'] : '';
		$mobile_alignment  = ( isset( $alignment['mobile'] ) ) ? $alignment['mobile'] : '';

		$margin = adaptive_get_option( $_section . '-margin' );

		/**
		 * Copyright CSS.
		 */
		$css_output_desktop = array(
			$selector => array(
				'justify-content' => $desktop_alignment,
				'margin-top'      => adaptive_responsive_spacing( $margin, 'top', 'desktop' ),
				'margin-bottom'   => adaptive_responsive_spacing( $margin, 'bottom', 'desktop' ),
				'margin-left'     => adaptive_responsive_spacing( $margin, 'left', 'desktop' ),
				'margin-right'    => adaptive_responsive_spacing( $margin, 'right', 'desktop' ),
			),
		);

		$css_output_tablet = array(
			$selector => array(
				'justify-content' => $tablet_alignment,
				// Margin CSS.
				'margin-top'      => adaptive_responsive_spacing( $margin, 'top', 'tablet' ),
				'margin-bottom'   => adaptive_responsive_spacing( $margin, 'bottom', 'tablet' ),
				'margin-left'     => adaptive_responsive_spacing( $margin, 'left', 'tablet' ),
				'margin-right'    => adaptive_responsive_spacing( $margin, 'right', 'tablet' ),
			),
		);

		$css_output_mobile = array(
			$selector => array(
				'justify-content' => $mobile_alignment,
				// Margin CSS.
				'margin-top'      => adaptive_responsive_spacing( $margin, 'top', 'mobile' ),
				'margin-bottom'   => adaptive_responsive_spacing( $margin, 'bottom', 'mobile' ),
				'margin-left'     => adaptive_responsive_spacing( $margin, 'left', 'mobile' ),
				'margin-right'    => adaptive_responsive_spacing( $margin, 'right', 'mobile' ),
			),
		);

		/* Parse CSS from array() */
		$css_output  = adaptive_parse_css( $css_output_desktop );
		$css_output .= adaptive_parse_css( $css_output_tablet, '', adaptive_addon_get_tablet_breakpoint() );
		$css_output .= adaptive_parse_css( $css_output_mobile, '', adaptive_addon_get_mobile_breakpoint() );

		$dynamic_css .= $css_output;
	}

	return $dynamic_css;
}
