<?php
/**
 * Adaptive Theme Customizer Configuration Builder.
 *
 * @package     adaptive-builder
 * @author      Adaptive
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       3.0.0
 */

// No direct access, please.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Adaptive_Customizer_Config_Base' ) ) {
	return;
}

/**
 * Register Builder Customizer Configurations.
 *
 * @since 3.0.0
 */
// @codingStandardsIgnoreStart
class Adaptive_Ext_Header_Account_Component_Configs extends Adaptive_Customizer_Config_Base {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
	// @codingStandardsIgnoreEnd

	/**
	 * Register Builder Customizer Configurations.
	 *
	 * @param Array                $configurations Adaptive Customizer Configurations.
	 * @param GC_Customize_Manager $gc_customize instance of GC_Customize_Manager.
	 * @since 3.0.0
	 * @return Array Adaptive Customizer Configurations with updated configurations.
	 */
	public function register_configuration( $configurations, $gc_customize ) {

		$_section = 'section-header-account';

		$account_choices = array(
			'default' => __( '默认', 'adaptive-addon' ),
		);

		if ( class_exists( 'LifterLMS' ) && get_permalink( llms_get_page_id( 'myaccount' ) ) ) {
			$account_choices['lifterlms'] = __( 'LifterLMS', 'adaptive-addon' );
		}

		if ( class_exists( 'WooCommerce' ) && get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) {
			$account_choices['woocommerce'] = __( '在线商城', 'adaptive-addon' );
		}

		$register_option = '';

		if ( get_option( 'users_can_register' ) ) {
			$register_option = array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-account-login-register]',
				'default'   => adaptive_get_option( 'header-account-login-register' ),
				'type'      => 'control',
				'control'   => Adaptive_Theme_Extension::$switch_control,
				'section'   => $_section,
				'priority'  => 205,
				'title'     => __( '注册', 'adaptive-addon' ),
				'context'   => array(
					adaptive_addon_builder_helper()->general_tab_config,
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-action]',
						'operator' => '==',
						'value'    => 'login',
					),
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-style]',
						'operator' => '!=',
						'value'    => 'none',
					),
				),
				'partial'   => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
				'transport' => 'postMessage',
			);
		}

		$_configs = array(

			/**
			 * Option: Profile Link type
			 */
			array(
				'name'       => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
				'default'    => adaptive_get_option( 'header-account-action-type' ),
				'type'       => 'control',
				'control'    => Adaptive_Theme_Extension::$selector_control,
				'section'    => $_section,
				'title'      => __( '位置操作', 'adaptive-addon' ),
				'priority'   => 4,
				'choices'    => array(
					'link' => __( '链接', 'adaptive-addon' ),
					'menu' => __( '菜单', 'adaptive-addon' ),
				),
				'transport'  => 'postMessage',
				'partial'    => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
				'responsive' => false,
				'renderAs'   => 'text',
				'divider'    => array( 'ast_class' => 'ast-top-divider' ),
			),

			/**
			 * Option: Profile Link type
			 */
			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-account-link-type]',
				'default'   => adaptive_get_option( 'header-account-link-type' ),
				'type'      => 'control',
				'control'   => 'ast-select',
				'section'   => $_section,
				'priority'  => 5,
				'title'     => __( '链接类型', 'adaptive-addon' ),
				'choices'   => array(
					'default' => __( '默认', 'adaptive-addon' ),
					'custom'  => __( '自定义', 'adaptive-addon' ),
				),
				'transport' => 'postMessage',
				'partial'   => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
				'context'   => array(
					adaptive_addon_builder_helper()->general_tab_config,
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-type]',
						'operator' => '!=',
						'value'    => 'default',
					),
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
						'operator' => '!=',
						'value'    => 'menu',
					),
				),
			),

			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-account-woo-menu]',
				'default'   => adaptive_get_option( 'header-account-woo-menu' ),
				'type'      => 'control',
				'control'   => Adaptive_Theme_Extension::$switch_control,
				'section'   => $_section,
				'priority'  => 7,
				'title'     => __( '使用WooCommerce帐户菜单', 'adaptive-addon' ),
				'context'   => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-type]',
						'operator' => '==',
						'value'    => 'woocommerce',
					),
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
						'operator' => '==',
						'value'    => 'menu',
					),
					adaptive_addon_builder_helper()->general_tab_config,
				),
				'partial'   => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
				'transport' => 'postMessage',
			),

			/**
			* Option: Theme Menu create link
			*/
			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-account-create-menu-link]',
				'default'   => adaptive_get_option( 'header-account-create-menu-link' ),
				'type'      => 'control',
				'control'   => 'ast-customizer-link',
				'section'   => $_section,
				'link_type' => 'section',
				'linked'    => 'menu_locations',
				'link_text' => __( '从这里配置菜单。', 'adaptive-addon' ),
				'priority'  => 7,
				'context'   => array(
					adaptive_addon_builder_helper()->general_tab_config,
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
						'operator' => '==',
						'value'    => 'menu',
					),
				),
			),

			array(
				'name'     => ADAPTIVE_THEME_SETTINGS . '[header-account-menu-link-notice]',
				'type'     => 'control',
				'control'  => 'ast-description',
				'section'  => $_section,
				'priority' => 7,
				'label'    => '',
				'help'     => $this->get_help_text_notice(),
				'context'  => array(
					adaptive_addon_builder_helper()->general_tab_config,
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-action-type]',
						'operator' => '==',
						'value'    => 'menu',
					),
				),
			),

			/**
			 * Option: Click action type
			 */
			array(
				'name'       => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-action]',
				'default'    => adaptive_get_option( 'header-account-logout-action' ),
				'type'       => 'control',
				'control'    => Adaptive_Theme_Extension::$selector_control,
				'section'    => $_section,
				'title'      => __( '点击动作', 'adaptive-addon' ),
				'choices'    => array(
					'link'  => __( '链接', 'adaptive-addon' ),
					'login' => __( '登录弹出窗口', 'adaptive-addon' ),
				),
				'transport'  => 'postMessage',
				'priority'   => 204,
				'context'    => array(
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-style]',
						'operator' => '!=',
						'value'    => 'none',
					),
					adaptive_addon_builder_helper()->general_tab_config,
				),
				'partial'    => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
				'responsive' => false,
				'renderAs'   => 'text',
				'divider'    => array( 'ast_class' => 'ast-bottom-divider ast-top-divider' ),
			),

			$register_option,

			array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-account-login-lostpass]',
				'default'   => adaptive_get_option( 'header-account-login-lostpass' ),
				'type'      => 'control',
				'control'   => Adaptive_Theme_Extension::$switch_control,
				'section'   => $_section,
				'priority'  => 205,
				'title'     => __( '忘记密码？', 'adaptive-addon' ),
				'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				'context'   => array(
					adaptive_addon_builder_helper()->general_tab_config,
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-action]',
						'operator' => '==',
						'value'    => 'login',
					),
					array(
						'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-style]',
						'operator' => '!=',
						'value'    => 'none',
					),
				),
				'partial'   => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
				'transport' => 'postMessage',
			),

			array(
				'name'       => ADAPTIVE_THEME_SETTINGS . '[header-account-icon-type]',
				'default'    => adaptive_get_option( 'header-account-icon-type' ),
				'type'       => 'control',
				'control'    => Adaptive_Theme_Extension::$selector_control,
				'section'    => $_section,
				'priority'   => 3,
				'title'      => __( '选择图标', 'adaptive-addon' ),
				'choices'    => array(
					'account-1' => 'account-1',
					'account-2' => 'account-2',
					'account-3' => 'account-3',
					'account-4' => 'account-4',
				),
				'transport'  => 'postMessage',
				'partial'    => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
				'context'    => array(
					adaptive_addon_builder_helper()->design_tab_config,
					array(
						'relation' => 'OR',
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-login-style]',
							'operator' => '==',
							'value'    => 'icon',
						),
						array(
							'setting'  => ADAPTIVE_THEME_SETTINGS . '[header-account-logout-style]',
							'operator' => '==',
							'value'    => 'icon',
						),
					),
				),
				'responsive' => false,
				'divider'    => array( 'ast_class' => 'ast-bottom-divider' ),
			),
		);

		if ( count( $account_choices ) > 1 ) {
			$_configs[] = array(
				'name'      => ADAPTIVE_THEME_SETTINGS . '[header-account-type]',
				'default'   => adaptive_get_option( 'header-account-type' ),
				'type'      => 'control',
				'control'   => 'ast-select',
				'divider'   => array( 'ast_class' => 'ast-bottom-divider' ),
				'section'   => $_section,
				'priority'  => 1,
				'title'     => __( '选择帐户', 'adaptive-addon' ),
				'choices'   => $account_choices,
				'transport' => 'postMessage',
				'partial'   => array(
					'selector'        => '.ast-header-account',
					'render_callback' => array( 'Adaptive_Builder_UI_Controller', 'render_account' ),
				),
			);
		}

		$configurations = array_merge( $configurations, $_configs );

		return $configurations;
	}

	/**
	 * Help notice message to be displayed when the Link type set as Menu.
	 *
	 * @since  3.5.9
	 * @return String HTML Markup for the help notice.
	 */
	private function get_help_text_notice() {

		if ( class_exists( 'WooCommerce' ) ) {
			$notice = __( '<b>Note:</b> For responsive devices, the menu will be replaced with the WooCommerce "我的帐户" link.', 'adaptive-addon' );
		} elseif ( class_exists( 'LifterLMS' ) ) {
			$notice = __( '<b>Note:</b> For responsive devices, the menu will be replaced with the LifterLMS "我的帐户" link.', 'adaptive-addon' );
		} else {
			$notice = __( '<b>注意：</b> 对于响应式设备，菜单将被链接选项卡中提供的链接替换。', 'adaptive-addon' );
		}

		return $notice;
	}
}

/**
 * Kicking this off by creating object of this class.
 */

new Adaptive_Ext_Header_Account_Component_Configs();
