<?php
/**
 * Divider Styling Loader for Adaptive theme.
 *
 * @package     Adaptive Builder
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Brainstorm Force
 * @link        https://www.brainstormforce.com
 * @since       Adaptive 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Customizer Initialization
 *
 * @since 3.0.0
 */
// @codingStandardsIgnoreStart
class Adaptive_Header_Divider_Component_Loader {
 // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
	// @codingStandardsIgnoreEnd

	/**
	 * Constructor
	 *
	 * @since 3.0.0
	 */
	public function __construct() {
		add_filter( 'adaptive_theme_defaults', array( $this, 'theme_defaults' ) );
		add_action( 'customize_preview_init', array( $this, 'preview_scripts' ), 110 );
	}

	/**
	 * Default customizer configs.
	 *
	 * @param  array $defaults  Adaptive options default value array.
	 *
	 * @since 3.0.0
	 */
	public function theme_defaults( $defaults ) {
		// Divider header defaults.
		$component_limit = adaptive_addon_builder_helper()->component_limit;
		for ( $index = 1; $index <= $component_limit; $index++ ) {

			$defaults[ 'header-divider-' . $index . '-layout' ] = 'vertical';
			$defaults[ 'header-divider-' . $index . '-style' ]  = 'solid';
			$defaults[ 'header-divider-' . $index . '-color' ]  = '#000000';

			$defaults[ 'header-divider-' . $index . '-size' ] = array(
				'desktop' => '50',
				'tablet'  => '50',
				'mobile'  => '50',
			);

			$defaults[ 'header-horizontal-divider-' . $index . '-size' ] = array(
				'desktop' => '50',
				'tablet'  => '50',
				'mobile'  => '50',
			);

			$defaults[ 'header-divider-' . $index . '-thickness' ] = array(
				'desktop' => '1',
				'tablet'  => '1',
				'mobile'  => '1',
			);
		}

		return $defaults;
	}

	/**
	 * Customizer Preview
	 *
	 * @since 3.0.0
	 */
	public function preview_scripts() {
		/**
		 * Load unminified if SCRIPT_DEBUG is true.
		 */
		/* Directory and Extension */
		$dir_name    = ( SCRIPT_DEBUG ) ? 'unminified' : 'minified';
		$file_prefix = ( SCRIPT_DEBUG ) ? '' : '.min';
		gc_enqueue_script( 'adaptive-heading-divider-customizer-preview-js', ADAPTIVE_ADDON_HEADER_DIVIDER_URI . 'assets/js/' . $dir_name . '/customizer-preview' . $file_prefix . '.js', array( 'customize-preview', 'ahfb-addon-base-customizer-preview' ), ADAPTIVE_EXT_VER, true );

		// Localize variables for divider JS.
		gc_localize_script(
			'adaptive-heading-divider-customizer-preview-js',
			'AdaptiveBuilderDividerData',
			array(
				'component_limit' => adaptive_addon_builder_helper()->component_limit,
			)
		);
	}
}

/**
*  Kicking this off by creating the object of the class.
*/
new Adaptive_Header_Divider_Component_Loader();
