<?php
/**
 * Off Canvas control - Dynamic CSS
 *
 * @package Adaptive Addon
 * @since 3.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Off Canvas Colors
 */
add_filter( 'adaptive_dynamic_theme_css', 'adaptive_addon_offcanvas_dynamic_css' );

/**
 * Dynamic CSS
 *
 * @param  string $dynamic_css          Adaptive Dynamic CSS.
 * @param  string $dynamic_css_filtered Adaptive Dynamic CSS Filters.
 * @return String Generated dynamic CSS for Heading Colors.
 *
 * @since 3.3.0
 */
function adaptive_addon_offcanvas_dynamic_css( $dynamic_css, $dynamic_css_filtered = '' ) {

	$selector = '.ast-mobile-popup-drawer.active';

	$popup_width         = adaptive_get_option( 'off-canvas-width' );
	$popup_width_desktop = ( isset( $popup_width['desktop'] ) && ! empty( $popup_width['desktop'] ) ) ? $popup_width['desktop'] : '';
	$popup_width_tablet  = ( isset( $popup_width['tablet'] ) && ! empty( $popup_width['tablet'] ) ) ? $popup_width['tablet'] : '';
	$popup_width_mobile  = ( isset( $popup_width['mobile'] ) && ! empty( $popup_width['mobile'] ) ) ? $popup_width['mobile'] : '';

	$css_output        = array();
	$css_output_tablet = array();
	$css_output_mobile = array();

	if ( ! empty( $popup_width_desktop ) ) {
		$css_output[ '.ast-desktop ' . $selector . ' .ast-mobile-popup-inner' ]['max-width'] = $popup_width_desktop . '%';
	}

	if ( ! empty( $popup_width_tablet ) ) {
		$css_output_tablet[ $selector . ' .ast-mobile-popup-inner' ]['max-width'] = $popup_width_tablet . '%';
	}

	if ( ! empty( $popup_width_mobile ) ) {
		$css_output_mobile[ $selector . ' .ast-mobile-popup-inner' ]['max-width'] = $popup_width_mobile . '%';
	}

	$css_output  = adaptive_parse_css( $css_output );
	$css_output .= adaptive_parse_css( $css_output_tablet, '', adaptive_addon_get_tablet_breakpoint() );
	$css_output .= adaptive_parse_css( $css_output_mobile, '', adaptive_addon_get_mobile_breakpoint() );

	$dynamic_css .= $css_output;

	return $dynamic_css;
}
