<?php
/**
 * Adaptive Theme Extension
 *
 * @package Adaptive Addon
 */

if ( ! class_exists( 'Adaptive_Theme_Extension' ) ) {

	/**
	 * Adaptive_Theme_Extension initial setup
	 *
	 * @since 1.0.0
	 */
	// @codingStandardsIgnoreStart
	class Adaptive_Theme_Extension { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Member Variable
		 *
		 * @var instance
		 */
		private static $instance;

		/**
		 * Member Variable
		 *
		 * @var options
		 */
		public static $options;

		/**
		 * Control Value to use Checkbox | Toggle control in GC_Customize
		 *
		 * @var const control
		 */
		public static $switch_control;

		/**
		 * Control Value to use Setting Group | Color Group in GC_Customize
		 *
		 * @var const control
		 */
		public static $group_control;

		/**
		 * Control Value to use Selector control in GC_Customize
		 *
		 * @var const control
		 */
		public static $selector_control;

		/**
		 *  Initiator
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Constructor
		 */
		public function __construct() {

			// Activation hook.
			register_activation_hook( ADAPTIVE_EXT_FILE, array( $this, 'activation_reset' ) );

			// deActivation hook.
			register_deactivation_hook( ADAPTIVE_EXT_FILE, array( $this, 'deactivation_reset' ) );

			// Includes Required Files.
			$this->includes();

			if ( is_admin() ) {

				add_action( 'admin_init', array( $this, 'min_theme_version__error' ) );

				add_filter( 'adaptive_menu_options', array( $this, 'extension_menu_options' ), 9, 1 );

				// Enqueue Admin Scripts.
				add_action( 'adaptive_admin_settings_scripts', array( $this, 'admin_scripts' ) );

				// Ajax requests.
				add_action( 'gc_ajax_adaptive_addon_activate_module', array( $this, 'activate_module' ) );
				add_action( 'gc_ajax_adaptive_addon_deactivate_module', array( $this, 'deactivate_module' ) );

				add_action( 'gc_ajax_adaptive_addon_bulk_activate_modules', array( $this, 'bulk_activate_modules' ) );
				add_action( 'gc_ajax_adaptive_addon_bulk_deactivate_modules', array( $this, 'bulk_deactivate_modules' ) );

				add_action( 'gc_ajax_adaptive_addon_clear_cache', array( $this, 'clear_cache' ) );

				// Enable/Disable beta updates.
				add_action( 'gc_ajax_adaptive_beta_updates', array( $this, 'enable_disable_beta_updates' ) );

				// Enable/Disable file generation.
				add_action( 'gc_ajax_adaptive_file_generation', array( $this, 'enable_disable_file_generation' ) );

				// Admin enqueue script alpha color picker.
				add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_color_picker_scripts' ) );
			}

			add_action( 'init', array( $this, 'addons_action_hooks' ), 1 );
			add_action( 'after_setup_theme', array( $this, 'setup' ) );

			add_action( 'customize_controls_enqueue_scripts', array( $this, 'controls_scripts' ) );
			add_action( 'customize_register', array( $this, 'customize_register_before_theme' ), 5 );
			add_action( 'customize_register', array( $this, 'addon_customize_register' ), 99 );
			add_action( 'customize_preview_init', array( $this, 'preview_init' ), 1 );

			add_filter( 'body_class', array( $this, 'body_classes' ), 11, 1 );

			// Load textdomain.
			add_action( 'plugins_loaded', array( $this, 'load_textdomain' ) );
			add_action( 'plugins_loaded', array( $this, 'common_plugin_dependent_files' ) );
			add_action( 'gcml_loaded', array( $this, 'gcml_compatibility' ) );

			// add compatibility for custom layouts with polylang plugin.
			add_action( 'pll_init', array( $this, 'gcml_compatibility' ) );

			// Adaptive Addon List filter.
			add_filter( 'adaptive_addon_list', array( $this, 'adaptive_addon_list' ) );
			add_filter( 'adaptive_quick_settings', array( $this, 'adaptive_addon_quick_settings' ) );
			add_action( 'adaptive_addon_bulk_action', array( $this, 'adaptive_addon_bulk_action_markup' ) );

			add_action( 'plugin_action_links_' . ADAPTIVE_EXT_BASE, array( $this, 'action_links' ) );

			if ( Adaptive_Ext_White_Label_Markup::show_branding() ) {
				add_action( 'adaptive_welcome_page_right_sidebar_before', array( $this, 'addon_licence_form' ) );
			} else {
				// if White Lebel settings is selected to Hide setting.
				add_action( 'adaptive_welcome_page_content_after', array( $this, 'addon_licence_form' ) );
			}

			add_action( 'adaptive_welcome_page_right_sidebar_content', array( $this, 'version_rollback_form' ), 30 );

			add_action( 'adaptive_welcome_page_right_sidebar_content', array( $this, 'adaptive_refresh_assets_files' ), 40 );

			add_action( 'adaptive_welcome_page_right_sidebar_content', array( $this, 'adaptive_beta_updates_form' ), 50 );

			// Redirect if old addon screen rendered.
			add_action( 'admin_init', array( $this, 'redirect_addon_listing_page' ) );

			add_action( 'enqueue_block_editor_assets', array( $this, 'addon_gutenberg_assets' ) );

			add_filter( 'adaptive_svg_icons', array( $this, 'adaptive_addon_svg_icons' ), 1, 10 );

			add_filter( 'bsf_show_versions_to_rollback_adaptive-addon', array( $this, 'adaptive_addon_rollback_versions_limit' ), 1, 10 );
		}

		/**
		 * Adaptive Addon action hooks
		 *
		 * @return void
		 */
		public function addons_action_hooks() {

			$activate_transient   = get_transient( 'adaptive_addon_activated_transient' );
			$deactivate_transient = get_transient( 'adaptive_addon_deactivated_transient' );

			if ( false != $activate_transient ) {
				do_action( 'adaptive_addon_activated', $activate_transient );
				delete_transient( 'adaptive_addon_activated_transient' );
			}

			if ( false != $deactivate_transient ) {
				do_action( 'adaptive_addon_deactivated', $deactivate_transient );
				delete_transient( 'adaptive_addon_deactivated_transient' );
			}
		}

		/**
		 * Activate module
		 */
		public function activate_module() {

			check_ajax_referer( 'adaptive-addon-module-nonce', 'nonce' );

			$module_id                = sanitize_text_field( $_POST['module_id'] );
			$extensions               = Adaptive_Ext_Extension::get_enabled_addons();
			$extensions[ $module_id ] = $module_id;
			$extensions               = array_map( 'esc_attr', $extensions );
			Adaptive_Admin_Helper::update_admin_settings_option( '_adaptive_ext_enabled_extensions', $extensions );

			if ( 'http2' == $module_id ) {
				Adaptive_Admin_Helper::update_admin_settings_option( '_adaptive_ext_http2', true );
			}

			set_transient( 'adaptive_addon_activated_transient', $module_id );

			gc_send_json_success();
		}

		/**
		 * Deactivate module
		 */
		public function deactivate_module() {

			check_ajax_referer( 'adaptive-addon-module-nonce', 'nonce' );
			$module_id                = sanitize_text_field( $_POST['module_id'] );
			$extensions               = Adaptive_Ext_Extension::get_enabled_addons();
			$extensions[ $module_id ] = false;
			$extensions               = array_map( 'esc_attr', $extensions );
			Adaptive_Admin_Helper::update_admin_settings_option( '_adaptive_ext_enabled_extensions', $extensions );

			if ( 'http2' == $module_id ) {
				Adaptive_Admin_Helper::delete_admin_settings_option( '_adaptive_ext_http2' );
			}

			set_transient( 'adaptive_addon_deactivated_transient', $module_id );

			gc_send_json_success();
		}

		/**
		 * Activate all module
		 */
		public function bulk_activate_modules() {

			check_ajax_referer( 'adaptive-addon-module-nonce', 'nonce' );

			// Get all extensions.
			$all_extensions = Adaptive_Ext_Extension::get_addons();

			// Sanitize Addon list.
			foreach ( $all_extensions as $key => $value ) {
				$all_extensions[ sanitize_key( $key ) ] = $value;
			}

			$new_extensions = array();

			// Set all extension to enabled.
			foreach ( $all_extensions  as $slug => $value ) {
				$new_extensions[ $slug ] = $slug;
			}

			// Escape attrs.
			$new_extensions = array_map( 'esc_attr', $new_extensions );

			// Update new_extensions.
			Adaptive_Admin_Helper::update_admin_settings_option( '_adaptive_ext_enabled_extensions', $new_extensions );

			Adaptive_Admin_Helper::update_admin_settings_option( '_adaptive_ext_http2', true );

			set_transient( 'adaptive_addon_activated_transient', $new_extensions );

			echo 'success';

			die();
		}

		/**
		 * Deactivate all module
		 */
		public function bulk_deactivate_modules() {

			check_ajax_referer( 'adaptive-addon-module-nonce', 'nonce' );

			// Get all extensions.
			$old_extensions = array_map( 'sanitize_text_field', Adaptive_Ext_Extension::get_enabled_addons() );
			$new_extensions = array();

			// Set all extension to enabled.
			foreach ( $old_extensions  as $slug => $value ) {
				$new_extensions[ $slug ] = false;
			}

			// Escape attrs.
			$new_extensions = array_map( 'esc_attr', $new_extensions );

			// Update new_extensions.
			Adaptive_Admin_Helper::update_admin_settings_option( '_adaptive_ext_enabled_extensions', $new_extensions );

			Adaptive_Admin_Helper::delete_admin_settings_option( '_adaptive_ext_http2' );

			set_transient( 'adaptive_addon_deactivated_transient', $new_extensions );

			echo 'success';

			die();
		}

		/**
		 * Clear assets cache.
		 */
		public function clear_cache() {

			Adaptive_Minify::refresh_assets();

			gc_send_json_success();
		}

		/**
		 * Ajax handler to enable / disable the beta updates for Adaptive Theme and Adaptive Pro.
		 *
		 * @since 1.5.1
		 * @return void
		 */
		public function enable_disable_beta_updates() {
			check_ajax_referer( 'adaptive-addon-module-nonce', 'nonce' );

			$status = isset( $_POST['status'] ) ? sanitize_text_field( $_POST['status'] ) : false;

			if ( false !== $status ) {
				Adaptive_Admin_Helper::update_admin_settings_option( '_adaptive_beta_updates', $status, true );
				gc_send_json_success();
			}

			gc_send_json_error();
		}

		/**
		 * Ajax handler to enable / disable the file generation of scripts/styles for Adaptive Theme and Adaptive Pro.
		 *
		 * @since 1.5.1
		 * @return void
		 */
		public function enable_disable_file_generation() {
			check_ajax_referer( 'adaptive-addon-module-nonce', 'nonce' );

			$status = isset( $_POST['status'] ) ? sanitize_text_field( $_POST['status'] ) : false;

			if ( false !== $status ) {
				update_option( '_adaptive_file_generation', $status );
				gc_send_json_success();
			}

			gc_send_json_error();
		}

		/**
		 * Add Body Classes
		 *
		 * @param  array $classes Body Class Array.
		 * @return array
		 */
		public function body_classes( $classes ) {

			// Current Adaptive Addon version.
			$classes[] = esc_attr( 'adaptive-addon-' . ADAPTIVE_EXT_VER );

			return $classes;
		}


		/**
		 * Load Adaptive Pro Text Domain.
		 * This will load the translation textdomain depending on the file priorities.
		 *      1. Global Languages /gc-content/languages/adaptive-addon/ folder
		 *      2. Local dorectory /gc-content/plugins/adaptive-addon/languages/ folder
		 *
		 * @since  1.0.0
		 * @return void
		 */
		public function load_textdomain() {
			// Default languages directory for Adaptive Pro.
			$lang_dir = ADAPTIVE_EXT_DIR . 'languages/';

			/**
			 * Filters the languages directory path to use for Adaptive Addon.
			 *
			 * @param string $lang_dir The languages directory path.
			 */
			$lang_dir = apply_filters( 'adaptive_addon_languages_directory', $lang_dir );

			// Traditional GeChiUI plugin locale filter.
			global $gc_version;

			$get_locale = get_locale();

			if ( $gc_version >= 4.7 ) {
				$get_locale = get_user_locale();
			}

			/**
			 * Language Locale for Adaptive Pro
			 *
			 * @var $get_locale The locale to use. Uses get_user_locale()` in GeChiUI 4.7 or greater,
			 *                  otherwise uses `get_locale()`.
			 */
			$locale = apply_filters( 'plugin_locale', $get_locale, 'adaptive-addon' ); // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound
			$mofile = sprintf( '%1$s-%2$s.mo', 'adaptive-addon', $locale );

			// Setup paths to current locale file.
			$mofile_local  = $lang_dir . $mofile;
			$mofile_global = GC_LANG_DIR . '/plugins/' . $mofile;

			if ( file_exists( $mofile_global ) ) {
				// Look in global /gc-content/languages/adaptive-addon/ folder.
				load_textdomain( 'adaptive-addon', $mofile_global );
			} elseif ( file_exists( $mofile_local ) ) {
				// Look in local /gc-content/plugins/adaptive-addon/languages/ folder.
				load_textdomain( 'adaptive-addon', $mofile_local );
			} else {
				// Load the default language files.
				load_plugin_textdomain( 'adaptive-addon', false, 'adaptive-addon/languages' );
			}
		}

		/**
		 * Show action links on the plugin screen.
		 *
		 * @param   mixed $links Plugin Action links.
		 * @return  array
		 */
		public function action_links( $links = array() ) {

			$slug                     = 'adaptive';
			$theme_whitelabelled_name = Adaptive_Ext_White_Label_Markup::get_whitelabel_string( 'adaptive', 'name', false );
			if ( false !== $theme_whitelabelled_name && ! empty( $theme_whitelabelled_name ) ) {
				$slug = Adaptive_Ext_White_Label_Markup::get_instance()->adaptive_whitelabelled_slug( 'adaptive' );
			}

			$action_links = array(
				'settings' => '<a href="' . esc_url( admin_url( 'themes.php?page=' . $slug ) ) . '" aria-label="' . esc_attr__( '查看Adaptive Pro设置', 'adaptive-addon' ) . '">' . esc_html__( '设置', 'adaptive-addon' ) . '</a>',
			);

			return array_merge( $action_links, $links );

		}

		/**
		 * Activation Reset
		 */
		public function activation_reset() {

			add_rewrite_endpoint( 'partial', EP_PERMALINK );
			// flush rewrite rules.
			flush_rewrite_rules();

			// Force check graupi bundled products.
			update_site_option( 'bsf_force_check_extensions', true );

			if ( is_multisite() ) {
				$branding = get_site_option( '_adaptive_ext_white_label' );
			} else {
				$branding = get_option( '_adaptive_ext_white_label' );
			}

			if ( isset( $branding['adaptive-agency']['hide_branding'] ) && false != $branding['adaptive-agency']['hide_branding'] ) {

				$branding['adaptive-agency']['hide_branding'] = false;

				if ( is_multisite() ) {
					update_site_option( '_adaptive_ext_white_label', $branding );
				} else {
					update_option( '_adaptive_ext_white_label', $branding );
				}
			}
			do_action( 'adaptive_addon_activate' );
		}

		/**
		 * Deactivation Reset
		 */
		public function deactivation_reset() {
			// flush rewrite rules.
			flush_rewrite_rules();
		}

		/**
		 * Includes
		 */
		public function includes() {
			require_once ADAPTIVE_EXT_DIR . 'classes/helper-functions.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-admin-helper.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/adaptive-theme-compatibility-functions.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/customizer/class-adaptive-addon-customizer.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/modules/target-rule/class-adaptive-target-rules-fields.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/modules/menu-sidebar/class-adaptive-menu-sidebar-animation.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-ext-extension.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-templates.php';

			// White Lebel.
			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-ext-white-label-markup.php';

			// Page Builder compatibility base class.
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-page-builder-compatibility.php';

			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-beaver-builder-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-divi-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-elementor-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-thrive-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-visual-composer-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-brizy-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-nginx-helper-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-run-cloud-helper-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-gutenberg-compatibility.php';

			// AMP Compatibility.
			require_once ADAPTIVE_EXT_DIR . 'classes/compatibility/class-adaptive-addon-amp-compatibility.php';
			require_once ADAPTIVE_EXT_DIR . 'admin/adaptive-rollback/class-adaptive-rollback-version.php';
			require_once ADAPTIVE_EXT_DIR . 'admin/adaptive-rollback/class-adaptive-rollback-version-manager.php';
		}

		/**
		 * Add extension option in menu page
		 *
		 * @param  array $actions   Array of actions.
		 * @return array            Return the actions.
		 */
		public function extension_menu_options( $actions ) {

			$actions['addons'] = array(
				'label' => esc_html__( '扩展库', 'adaptive-addon' ),
				'show'  => ! is_network_admin(),
			);
			return $actions;
		}

		/**
		 * Admin Scripts
		 */
		public function admin_scripts() {
			add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );
		}

		/**
		 * Admin Scripts Callback
		 */
		public function enqueue_admin_scripts() {

			// Styles.
			gc_enqueue_style( 'ast-ext-admin-settings', ADAPTIVE_EXT_URI . 'admin/assets/css/ast-ext-admin-settings.css', array(), ADAPTIVE_EXT_VER );

			// Scripts.
			gc_enqueue_script( 'adaptive-ext-admin-settings', ADAPTIVE_EXT_URI . 'admin/assets/js/ast-ext-admin-settings.js', array( 'jquery-ui-tooltip' ), ADAPTIVE_EXT_VER, false );

			$options = array(
				'ajax_nonce'                 => gc_create_nonce( 'adaptive-addon-module-nonce' ),
				'activate'                   => __( '启用', 'adaptive-addon' ),
				'deactivate'                 => __( '停用', 'adaptive-addon' ),
				'enableBetaUpdates'          => __( '开启测试更新', 'adaptive-addon' ),
				'disableBetaUpdates'         => __( '禁用测试更新', 'adaptive-addon' ),
				'enableFileGeneration'       => __( '开启文件生成', 'adaptive-addon' ),
				'disableFileGeneration'      => __( '关闭文件生成', 'adaptive-addon' ),
				'assetsRefreshingButtonText' => __( '刷新中', 'adaptive-addon' ),
				'assetsRefreshedButtonText'  => __( '已刷新', 'adaptive-addon' ),
				'adminUrl'                   => admin_url( 'post-new.php?post_type=' ),
				'customLayoutText'           => __( '自定义布局', 'adaptive-addon' ),
				'pageHeadersText'            => __( '页面页眉', 'adaptive-addon' ),
			);

			gc_localize_script( 'adaptive-ext-admin-settings', 'adaptiveAddonModules', $options );
		}

		/**
		 * After Setup Theme
		 */
		public function setup() {

			if ( ! defined( 'ADAPTIVE_THEME_VERSION' ) ) {
				return;
			}
			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-icons.php';

			if ( version_compare( ADAPTIVE_THEME_VERSION, '3.1.0', '>=' ) ) {
				self::$switch_control   = 'ast-toggle-control';
				self::$group_control    = 'ast-color-group';
				self::$selector_control = 'ast-selector';
			} else {
				self::$switch_control   = 'checkbox';
				self::$group_control    = 'ast-settings-group';
				self::$selector_control = 'select';
			}

			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-addon-builder-loader.php';

			/**
			 * Load deprecated filters.
			 */
			require_once ADAPTIVE_EXT_DIR . 'classes/deprecated/deprecated-filters.php';

			/**
			 * Load deprecated actions.
			 */
			require_once ADAPTIVE_EXT_DIR . 'classes/deprecated/deprecated-actions.php';

			require_once ADAPTIVE_EXT_DIR . 'classes/adaptive-common-functions.php';
			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-addon-update-filter-function.php';

			require_once ADAPTIVE_EXT_DIR . 'classes/adaptive-common-dynamic-css.php';

			if ( function_exists( 'adaptive_addon_filesystem' ) ) {
				require_once ADAPTIVE_EXT_DIR . 'classes/cache/class-adaptive-cache-base.php';
				require_once ADAPTIVE_EXT_DIR . 'classes/cache/class-adaptive-cache.php';
			}

			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-minify.php';

			if ( function_exists( 'adaptive_addon_filesystem' ) ) {
				require_once ADAPTIVE_EXT_DIR . 'classes/cache/class-adaptive-addon-cache.php';
			}
			require_once ADAPTIVE_EXT_DIR . 'classes/class-adaptive-ext-model.php';

		}
		/**
		 * Load Gutenberg assets
		 */
		public function addon_gutenberg_assets() {

			if ( ! defined( 'ADAPTIVE_THEME_VERSION' ) ) {
				return;
			}
			// Gutenberg dynamic css for Adaptive Addon.
			require_once ADAPTIVE_EXT_DIR . 'classes/class-addon-gutenberg-editor-css.php';
		}

		/**
		 * Enqueues the needed CSS/JS for the customizer.
		 *
		 * @since 1.0
		 * @return void
		 */
		public function controls_scripts() {

			gc_enqueue_script( 'ast-ext-admin-settings', ADAPTIVE_EXT_URI . 'admin/assets/js/customizer-controls.js', array(), ADAPTIVE_EXT_VER, false );

			// Enqueue Customizer React.JS script.
			$custom_controls_react_deps = array(
				'adaptive-custom-control-plain-script',
				'gc-i18n',
				'gc-components',
				'gc-element',
				'gc-media-utils',
				'gc-block-editor',
			);

			gc_enqueue_script( 'adaptive-ext-custom-control-react-script', ADAPTIVE_EXT_URI . 'classes/customizer/extend-controls/build/index.js', $custom_controls_react_deps, ADAPTIVE_EXT_VER, true );

			if ( function_exists( 'adaptive_get_option' ) ) {
				$show_deprecated_no_toggle_style = 'no-toggle' == adaptive_get_option( 'mobile-menu-style' ) ? true : false;

				gc_localize_script(
					'ast-ext-admin-settings',
					'astAdminLacalizeVars',
					array(
						'adaptive_no_toggle_menu_style_deprecate' => apply_filters( 'adaptive_no_toggle_menu_style_deprecate', $show_deprecated_no_toggle_style ), // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound
					)
				);
			}

		}

		/**
		 * Customizer Preview Init
		 *
		 * @since 1.0.0
		 * @return void
		 */
		public function preview_init() {

			if ( SCRIPT_DEBUG ) {
				$js_path = 'assets/js/unminified/ast-addon-customizer-preview.js';
			} else {
				$js_path = 'assets/js/minified/ast-addon-customizer-preview.min.js';
			}

			$addons = Adaptive_Ext_Extension::get_enabled_addons();

			gc_enqueue_script( 'adaptive-addon-customizer-preview-js', ADAPTIVE_EXT_URI . $js_path, array( 'customize-preview', 'adaptive-customizer-preview-js' ), ADAPTIVE_EXT_VER, true );

			gc_localize_script( 'adaptive-addon-customizer-preview-js', 'ast_enabled_addons', $addons );
		}


		/**
		 * Base on addon activation section registered.
		 *
		 * @since 1.0.0
		 * @param object $gc_customize customizer object.
		 * @return void
		 */
		public function customize_register_before_theme( $gc_customize ) {

			if ( ! defined( 'ADAPTIVE_THEME_VERSION' ) ) {
				return;
			}

			if ( ! class_exists( 'Adaptive_GC_Customize_Section' ) ) {
				gc_die( 'You are using an older version of the Adaptive theme. Please update the Adaptive theme to the latest version.' );
			}

			$addons = Adaptive_Ext_Extension::get_enabled_addons();

			// Update the Customizer Sections under Layout.
			if ( false != $addons['header-sections'] ) {
				$gc_customize->add_section(
					new Adaptive_GC_Customize_Section(
						$gc_customize,
						'section-mobile-primary-header-layout',
						array(
							'title'    => __( '主页眉', 'adaptive-addon' ),
							'section'  => 'section-mobile-header',
							'priority' => 10,
						)
					)
				);
			}

			// Update the Customizer Sections under Typography.
			if ( false != $addons['typography'] ) {

				$gc_customize->add_section(
					new Adaptive_GC_Customize_Section(
						$gc_customize,
						'section-header-typo-group',
						array(
							'title'    => __( '表头', 'adaptive-addon' ),
							'panel'    => 'panel-typography',
							'priority' => 20,
						)
					)
				);

				add_filter(
					'adaptive_customizer_primary_header_typo',
					function( $header_arr ) {

						$header_arr['section'] = 'section-header-typo-group';

						return $header_arr;
					}
				);

			}
		}

		/**
		 * Register Customizer Control.
		 *
		 * @since 1.0.2
		 * @param GC_Customize_Manager $gc_customize Theme Customizer object.
		 */
		public function addon_customize_register( $gc_customize ) {

			if ( function_exists( 'GC_Customize_Themes_Panel' ) ) {

				$gc_customize->add_panel(
					new GC_Customize_Themes_Panel(
						$this,
						'themes',
						array(
							'title'       => adaptive_get_theme_name(),
							'description' => (
							'<p>' . __( '要查找某个主题？您可以搜索或浏览dorapress.com主题目录，安装及预览主题，然后在这里激活它们。', 'adaptive-addon' ) . '</p>' .
							'<p>' . __( '在您预览新主题时，您可以继续调整小工具及菜单，也可以探索主题特定的选项。', 'adaptive-addon' ) . '</p>'
							),
							'capability'  => 'switch_themes',
							'priority'    => 0,
						)
					)
				);
			}
		}

		/**
		 * GCML Compatibility.
		 *
		 * @since 1.1.0
		 */
		public function gcml_compatibility() {

			require_once ADAPTIVE_EXT_DIR . 'compatibility/class-adaptive-gcml-compatibility.php';
		}

		/**
		 * Common plugin dependent file which dependd on other plugins.
		 *
		 * @since 1.1.0
		 */
		public function common_plugin_dependent_files() {

			// If plugin - 'Ubermenu' not exist then return.
			if ( class_exists( 'UberMenu' ) ) {
				require_once ADAPTIVE_EXT_DIR . 'compatibility/class-adaptive-ubermenu-pro.php';
			}
		}

		/**
		 * Check compatible theme version.
		 *
		 * @since 1.2.0
		 */
		public function min_theme_version__error() {

			$adaptive_global_options = get_option( 'adaptive-settings' );

			if ( isset( $adaptive_global_options['theme-auto-version'] ) && ( version_compare( $adaptive_global_options['theme-auto-version'], ADAPTIVE_THEME_MIN_VER ) < 0 ) && ( false !== get_theme_update_available( gc_get_theme( get_template() ) ) ) ) {

				$adaptive_theme_name = 'Adaptive';
				if ( function_exists( 'adaptive_get_theme_name' ) ) {
					$adaptive_theme_name = adaptive_get_theme_name();
				}

				$message = sprintf(
					/* translators: %1$1s: Theme Name, %2$2s: Minimum Required version of the Adaptive Theme */
					__( '请将%1$1s 主题更新到版本 %2$2s 或更高。如果已经更新，则忽略。', 'adaptive-addon' ),
					$adaptive_theme_name,
					ADAPTIVE_THEME_MIN_VER
				);

				$min_version = get_user_meta( get_current_user_id(), 'theme-min-version-notice-min-ver', true );

				if ( ! $min_version ) {
					update_user_meta( get_current_user_id(), 'theme-min-version-notice-min-ver', ADAPTIVE_THEME_MIN_VER );
				}

				if ( version_compare( $min_version, ADAPTIVE_THEME_MIN_VER, '!=' ) ) {
					delete_user_meta( get_current_user_id(), 'theme-min-version-notice' );
					update_user_meta( get_current_user_id(), 'theme-min-version-notice-min-ver', ADAPTIVE_THEME_MIN_VER );
				}

				Adaptive_Notices::add_notice(
					array(
						'id'                         => 'theme-min-version-notice',
						'type'                       => 'warning',
						'message'                    => $message,
						'show_if'                    => true,
						'repeat-notice-after'        => false,
						'priority'                   => 20,
						'display-with-other-notices' => true,
					)
				);
			}
		}


		/**
		 * Modified Adaptive Quick settings links update based on the activated plugins
		 *
		 * @since 1.2.1
		 * @param array $quick_settings quick settings list.
		 * @return array $quick_settings Updated quick settings list.
		 */
		public function adaptive_addon_quick_settings( $quick_settings = array() ) {
			$enabled_extensions = Adaptive_Ext_Extension::get_addons();
			// Update the quick setting link for header group.
			$headers_addons = array( 'header-sections', 'transparent-header', 'sticky-header' );

			foreach ( $enabled_extensions as $addon_slug => $value ) {
				if ( ! in_array( $addon_slug, $headers_addons ) || ! Adaptive_Ext_Extension::is_active( $addon_slug ) ) {
					continue;
				}
				$quick_settings['header']['quick_url'] = admin_url( 'customize.php?autofocus[panel]=panel-header-group' );
			}
			return $quick_settings;
		}

		/**
		 * Modified Adaptive Addon List
		 *
		 * @since 1.2.1
		 * @param array $addons Adaptive addon list.
		 * @return array $addons Updated Adaptive addon list.
		 */
		public function adaptive_addon_list( $addons = array() ) {

			$enabled_extensions  = Adaptive_Ext_Extension::get_addons();
			$extension_slugs     = array_keys( $enabled_extensions );
			$extension_slugs[]   = 'white-label';
			$ext_activate_notice = __( '这个插件需要安装才能启用', 'adaptive-addon' );

			foreach ( $addons as $addon_slug => $value ) {
				if ( ! in_array( $addon_slug, $extension_slugs ) ) {
					continue;
				}
				$class = 'deactive';
				$links = array(
					array(
						'link_class' => 'ast-activate-module',
						'link_text'  => __( '启用', 'adaptive-addon' ),
						'link_url'   => '',
					),
				);

				if ( Adaptive_Ext_Extension::is_active( $addon_slug ) ) {
					$class = 'active';
					$links = array(
						array(
							'link_class' => 'ast-deactivate-module',
							'link_text'  => __( '停用', 'adaptive-addon' ),
							'link_url'   => '',
						),
					);
				}

				switch ( $addon_slug ) {
					case 'advanced-hooks':
							$links[] = array(
								'link_class' => 'advanced-module',
								'link_text'  => __( '设置', 'adaptive-addon' ),
								'link_url'   => admin_url( '/edit.php?post_type=adaptive-advanced-hook' ),
							);
						break;
					case 'advanced-headers':
							$links[] = array(
								'link_class' => 'advanced-module',
								'link_text'  => __( '设置', 'adaptive-addon' ),
								'link_url'   => admin_url( '/edit.php?post_type=adaptive_adv_header' ),
							);
						break;

					case 'white-label':
							$class   = 'white-label';
							$links   = false;
							$links[] = array(
								'link_class'   => 'advanced-module',
								'link_text'    => __( '设置', 'adaptive-addon' ),
								'link_url'     => Adaptive_Admin_Settings::get_page_url( $addon_slug ),
								'target_blank' => false,
							);
						break;

					case 'woocommerce':
						$class .= ' woocommerce';
						if ( ! class_exists( 'WooCommerce' ) ) {
							$class .= ' ast-disable ast-modules-not-activated';
							$links  = array(
								array(
									'link_class' => 'ast-deactivate-module',
									'link_text'  => $ext_activate_notice,
									'link_url'   => '',
								),
							);
						}

						break;

					case 'learndash':
						$class .= ' learndash';
						if ( ! class_exists( 'SFWD_LMS' ) ) {
							$class .= ' ast-disable ast-modules-not-activated';
							$links  = array(
								array(
									'link_class' => 'ast-deactivate-module',
									'link_text'  => $ext_activate_notice,
									'link_url'   => '',
								),
							);
						}
						break;

					case 'lifterlms':
						$class .= ' lifterlms';
						if ( ! class_exists( 'LifterLMS' ) ) {
							$class .= ' ast-disable ast-modules-not-activated';
							$links  = array(
								array(
									'link_class' => 'ast-deactivate-module',
									'link_text'  => $ext_activate_notice,
									'link_url'   => '',
								),
							);
						}
						break;

					case 'edd':
						$class .= ' edd';
						if ( ! class_exists( 'Easy_Digital_Downloads' ) ) {
							$class .= ' ast-disable ast-modules-not-activated';
							$links  = array(
								array(
									'link_class' => 'ast-deactivate-module',
									'link_text'  => $ext_activate_notice,
									'link_url'   => '',
								),
							);
						}
						break;
				}

				$addons[ $addon_slug ]['links'] = $links;
				$addons[ $addon_slug ]['class'] = $class;

				// Don't show White Label tab if white label branding is hidden.
				if ( ! Adaptive_Ext_White_Label_Markup::show_branding() ) {
					unset( $addons['white-label'] );
				}
			}

			return $addons;
		}

		/**
		 * Adaptive Addon Bulk action
		 *
		 * @since 1.2.1
		 */
		public function adaptive_addon_bulk_action_markup() {
			?>
				<div class="ast-bulk-actions-wrap">
					<a class="bulk-action ast-activate-all button"> <?php esc_html_e( '激活所有', 'adaptive-addon' ); ?> </a>
					<a class="bulk-action ast-deactivate-all button"> <?php esc_html_e( '禁用所有', 'adaptive-addon' ); ?> </a>
				</div>
			<?php
		}

		/**
		 * Adaptive Header Top Right info
		 *
		 * @since 1.2.1
		 */
		public function adaptive_header_top_right_content() {
			$top_links = apply_filters(
				'adaptive_header_top_links', // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound
				array(
					'adaptive-theme-info' => array(
						'title' => __( '时尚，闪电快速和容易定制!', 'adaptive-addon' ),
					),
				)
			);

		}

		/**
		 * Redirect to adaptive welcome page if visited old Adaptive Addon Listing page
		 *
		 * @since 1.2.1
		 * @return void
		 */
		public function redirect_addon_listing_page() {

			global $pagenow;
			/* Check current admin page. */

			if ( 'themes.php' == $pagenow && isset( $_GET['action'] ) && 'addons' == $_GET['action'] ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
				gc_safe_redirect( admin_url( '/themes.php?page=adaptive' ), 301 );
				exit;
			}
		}

		/**
		 * Addon Activation / Deactivation markup
		 *
		 * @since 1.2.1
		 * @return void
		 */
		public function addon_licence_form() {

			if ( is_multisite() ) {
				$white_label = get_site_option( '_adaptive_ext_white_label' );
			} else {
				$white_label = get_option( '_adaptive_ext_white_label' );
			}

			$pro_name = __( 'Adaptive专业版许可证', 'adaptive-addon' );

			if ( ! empty( $white_label['adaptive-pro']['name'] ) ) {
				/* translators: %s: Adaptive Pro name */
				$pro_name = sprintf( __( '%s许可证', 'adaptive-addon' ), $white_label['adaptive-pro']['name'] );
			}

			$pro_whitelabelled_name = Adaptive_Ext_White_Label_Markup::get_whitelabel_string( 'adaptive-pro', 'name', false );

			if ( false !== $pro_whitelabelled_name ) {
				/* translators: %s: Adaptive Pro name */
				$pro_name = sprintf( __( '%s许可证', 'adaptive-addon' ), $pro_whitelabelled_name );
			}

			/* translators: %s: Adaptive Pro name */
			$not_active_status = sprintf( __( '请输入您的有效的%s许可证密钥来接收更新和支持。', 'adaptive-addon' ), $pro_name );

			?>
			<div class="postbox">
				<h2 class="hndle ast-normal-cusror"><span><?php echo esc_html( $pro_name ); ?></span></h2>
				<div class="inside">
				<?php
					$bsf_product_id = bsf_extract_product_id( ADAPTIVE_EXT_DIR );
					$args           = array(
						'product_id'                       => $bsf_product_id,
						'button_text_activate'             => esc_html__( '激活许可证', 'adaptive-addon' ),
						'button_text_deactivate'           => esc_html__( '禁用许可证', 'adaptive-addon' ),
						'license_form_title'               => '',
						'license_deactivate_status'        => esc_html__( '您的许可证未激活!', 'adaptive-addon' ),
						'license_activate_status'          => esc_html__( '您的许可证已激活!', 'adaptive-addon' ),
						'submit_button_class'              => 'adaptive-product-license button-default',
						'form_class'                       => 'form-wrap bsf-license-register-' . esc_attr( $bsf_product_id ),
						'bsf_license_form_heading_class'   => 'adaptive-license-heading',
						'bsf_license_active_class'         => 'success-message',
						'bsf_license_not_activate_message' => 'license-error',
						'size'                             => 'regular',
						'bsf_license_allow_email'          => false,
						'bsf_license_active_status'        => __( '启用！', 'adaptive-addon' ),
						'bsf_license_not_active_status'    => $not_active_status,
					);
					echo bsf_license_activation_form( $args ); // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
					?>
				</div>
			</div>
			<?php
		}

		/**
		 * Adaptive Theme and Pro rollback version form.
		 *
		 * @since 3.6.1
		 * @return bool
		 */
		public function version_rollback_form() {

			$bsf_product_id = bsf_extract_product_id( ADAPTIVE_EXT_DIR );
			if ( ! bsf_display_rollback_version_form( $bsf_product_id ) ) {
				return false;
			}

			$them_name = Adaptive_Rollback_version::adaptive_get_white_lable_name();
			$pro_name  = bsf_get_white_lable_product_name( $bsf_product_id, 'Adaptive专业版' );
			?>
			<div class="postbox">
				<h2 class="hndle ast-normal-cusror"><span><?php echo esc_html__( '回滚版本', 'adaptive-addon' ); ?></span></h2>
				<div class="inside">
				<h4 class="ast-normal-cusror"><span><?php echo esc_html( $them_name ); ?></span></h4>
				<?php
					// Display Theme Rollback version form.
					render_theme_rollback_form();
				?>
				<div class="hndle rollback-divider"></div>
				<h4 class="ast-normal-cusror"><span><?php echo esc_html( $pro_name ); ?></span></h4>
				<?php
					// Display Addon Rollback version form.
					bsf_get_version_rollback_form( $bsf_product_id );
				?>
				</div>
			</div>

			<?php
		}

		/**
		 * Include Welcome page right side Adaptive community content
		 *
		 * @since 1.2.4
		 */
		public function adaptive_beta_updates_form() {
			$allow_beta = Adaptive_Admin_Helper::get_admin_settings_option( '_adaptive_beta_updates', true, 'disable' );
			?>

			<div class="postbox">
				<h2 class="hndle ast-normal-cusror">
					<span class="dashicons dashicons-update"></span>
					<span>
						<?php
							esc_html_e( '允许测试更新', 'adaptive-addon' );
						?>
				</h2>
				<div class="inside">
					<p>
						<?php esc_html_e( '启用此选项可接收beta版本的更新通知。', 'adaptive-addon' ); ?>
					</p>
					<p>
					<?php
						$a_tag_open  = '<a target="_blank" rel="noopener" href="' . esc_url( 'https://gcadaptive.com/docs/automatic-beta-updates-for-adaptive/?utm_source=welcome_page&utm_medium=sidebar&utm_campaign=adaptive_pro' ) . '">';
						$a_tag_close = '</a>';

						printf(
							/* translators: %1$s: a tag open. */
							__( '请阅读%1$s这篇文章%2$s了解更多。', 'adaptive-addon' ), // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
							$a_tag_open, // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
							$a_tag_close // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
						);
					?>
					</p>

					<label for="adaptive_beta_updates">
						<?php

						if ( 'disable' === $allow_beta ) {
							$beta_string = __( '开启测试更新', 'adaptive-addon' );
						} else {
							$beta_string = __( '禁用测试更新', 'adaptive-addon' );
						}
						?>
						<button class="button adaptive-beta-updates" id="adaptive_beta_updates" data-value="<?php echo esc_attr( $allow_beta ); ?>">
							<?php echo esc_html( $beta_string ); ?>
						</button>
					</label>
				</div>
			</div>
			<?php
		}

		/**
		 * Include the refresh button to delete and regenerate new assets files.
		 *
		 * @since 1.2.4
		 */
		public function adaptive_refresh_assets_files() {

			if ( ! function_exists( 'adaptive_addon_filesystem' ) ) {
				return;
			}

			$allow_file_generation = get_option( '_adaptive_file_generation', 'disable' );

			$file_generation_message  = esc_html__( '启用这个选项来生成CSS文件。', 'adaptive-addon' );
			$file_generation_doc_link = esc_url( 'https://gcadaptive.com/adaptive-2-1/?utm_source=welcome_page&utm_medium=sidebar&utm_campaign=adaptive_pro' );

			if ( adaptive_addon_filesystem()->can_access_filesystem() ) {
				$refresh_assets_button_text = esc_html__( '刷新', 'adaptive-addon' );
				$refresh_assets_message     = esc_html__( '点击“刷新”按钮来重新生成CSS文件。', 'adaptive-addon' );
				$refresh_assets_doc_link    = esc_url( '#' );
			} else {
				$refresh_assets_button_text = esc_html__( '再次检查', 'adaptive-addon' );
				$refresh_assets_message     = esc_html__( '单击“复检”按钮检查uploads文件夹是否有写权限。', 'adaptive-addon' );
				$refresh_assets_doc_link    = esc_url( '#' );
			}
			?>

			<div class="postbox">
				<h2 class="hndle ast-normal-cusror">
					<span class="dashicons dashicons-admin-page"></span>
					<span>
						<?php esc_html_e( 'CSS文件生成', 'adaptive-addon' ); ?>
					</span>
				</h2>
				<div class="inside">
					<p class="warning">
					</p>
						<?php echo esc_html( $file_generation_message ); ?>
					<p>
					<?php
					if ( Adaptive_Ext_White_Label_Markup::show_branding() ) {

						$a_tag_open  = '<a target="_blank" rel="noopener" href="' . $file_generation_doc_link . '">';
						$a_tag_close = '</a>';

						printf(
							/* translators: %1$s: a tag open. */
							__( '请阅读%1$s这篇文章%2$s了解更多。', 'adaptive-addon' ), // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
							$a_tag_open, // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
							$a_tag_close // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
						);
					}
					?>
					</p>
					<label for="adaptive_file_generation">
						<?php

						if ( 'disable' === $allow_file_generation ) {
							$file_generation_string = __( '开启文件生成', 'adaptive-addon' );
						} else {
							$file_generation_string = __( '关闭文件生成', 'adaptive-addon' );
						}
						?>
						<button class="button adaptive-beta-updates" id="adaptive_file_generation" data-value="<?php echo esc_attr( $allow_file_generation ); ?>">
							<?php echo esc_html( $file_generation_string ); ?>
						</button>
					</label>
						<div class="adaptive-refresh-assets-wrapper" style="<?php echo ( 'disable' === $allow_file_generation ) ? 'display: none' : 'display: block'; ?>">
							<p class="warning">
								<?php echo esc_html( $refresh_assets_message ); ?>
							</p>

							<label for="adaptive_refresh_assets">
								<button class="button adaptive-refresh-assets" id="adaptive_refresh_assets">
									<span class="ast-loader"></span>
									<span class="ast-refresh-btn-text"><?php echo esc_html( $refresh_assets_button_text ); ?></span>
								</button>
							</label>
						</div>
				</div>
			</div>
			<?php
		}

		/**
		 * Register Scripts & Styles on admin_enqueue_scripts hook.
		 * As we moved to React customizer so registering the 'adaptive-color-alpha' script in addon as there is no use of that script in theme (apperently it removed from theme).
		 *
		 * @since 2.7.0
		 */
		public function enqueue_color_picker_scripts() {

			gc_register_script( 'adaptive-color-alpha', ADAPTIVE_EXT_URI . 'admin/assets/js/gc-color-picker-alpha.js', array( 'jquery', 'gc-color-picker' ), ADAPTIVE_EXT_VER, true );

			/**
			 * Localize gc-color-picker & gcColorPickerL10n.
			 *
			 * This is only needed in GeChiUI version >= 5.5 because gcColorPickerL10n has been removed.
			 *
			 * @see https://github.com/GeChiUI/GeChiUI/commit/7e7b70cd1ae5772229abb769d0823411112c748b
			 *
			 * This is should be removed once the issue is fixed from gc-color-picker-alpha repo.
			 * @see https://github.com/kallookoo/gc-color-picker-alpha/issues/35
			 *
			 * @since 2.7.0
			 */
			if ( function_exists( 'adaptive_addon_gc_version_compare' ) && adaptive_addon_gc_version_compare( '5.4.99', '>=' ) ) {
				// Localizing variables.
				gc_localize_script(
					'gc-color-picker',
					'gcColorPickerL10n',
					array(
						'clear'            => __( '不排序', 'adaptive-addon' ),
						'clearAriaLabel'   => __( '清除颜色', 'adaptive-addon' ),
						'defaultString'    => __( '默认', 'adaptive-addon' ),
						'defaultAriaLabel' => __( '选择默认的颜色', 'adaptive-addon' ),
						'pick'             => __( '选择颜色', 'adaptive-addon' ),
						'defaultLabel'     => __( '色彩明度', 'adaptive-addon' ),
					)
				);
			}
		}

		/**
		 * Load SVG Icon array from the JSON file.
		 *
		 * @param Array $svg_arr Array of svg icons.
		 * @since 3.0.0
		 * @return Array addon svg icons.
		 */
		public function adaptive_addon_svg_icons( $svg_arr = array() ) {

			ob_start();
			// Include SVGs Json file.
			include_once ADAPTIVE_EXT_DIR . 'assets/svg/svgs.json';
			$svg_icon_arr  = json_decode( ob_get_clean(), true );
			$ast_svg_icons = array_merge( $svg_arr, $svg_icon_arr );
			return $ast_svg_icons;
		}

		/**
		 * Add limit to show number of versions to rollback.
		 *
		 * @param integer $per_page per page count.
		 * @return integer
		 */
		public function adaptive_addon_rollback_versions_limit( $per_page ) {
			return 6;
		}
	}
}

/**
 *  Prepare if class 'Adaptive_Customizer_Loader' exist.
 *  Kicking this off by calling 'get_instance()' method
 */
Adaptive_Theme_Extension::get_instance();
