<?php
/**
 * Adaptive Addon Customizer
 *
 * @package Adaptive Addon
 * @since 1.6.0
 */

if ( ! class_exists( 'Adaptive_Addon_Elementor_Compatibility' ) ) :

	/**
	 * Adaptive Addon Page Builder Compatibility base class
	 *
	 * @since 1.6.0
	 */
	class Adaptive_Addon_Elementor_Compatibility extends Adaptive_Addon_Page_Builder_Compatibility {

		/**
		 * Instance
		 *
		 * @since 1.6.0
		 *
		 * @access private
		 * @var object Class object.
		 */
		private static $instance;

		/**
		 * Initiator
		 *
		 * @since 1.6.0
		 *
		 * @return object initialized object of class.
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		/**
		 * Render content for post.
		 *
		 * @param int $post_id Post id.
		 *
		 * @since 1.6.0
		 */
		public function render_content( $post_id ) {

			// set post to glabal post.
			$elementor_instance = Elementor\Plugin::instance();
			echo $elementor_instance->frontend->get_builder_content_for_display( $post_id ); // phpcs:ignore GeChiUI.Security.EscapeOutput.OutputNotEscaped
		}

		/**
		 * Load styles and scripts.
		 *
		 * @param int $post_id Post id.
		 *
		 * @since 1.6.0
		 */
		public function enqueue_scripts( $post_id ) {

			if ( '' !== $post_id ) {
				if ( class_exists( '\Elementor\Core\Files\CSS\Post' ) ) {
					$css_file = new \Elementor\Core\Files\CSS\Post( $post_id );
				} elseif ( class_exists( '\Elementor\Post_CSS_File' ) ) {
					$css_file = new \Elementor\Post_CSS_File( $post_id );
				}

				$css_file->enqueue();
			}
		}

	}

endif;
