<?php
/**
 * GCML Compatibility
 *
 * @package     Adaptive Addon
 * @author      Brainstorm Force
 * @copyright   Copyright (c) 2020, Adaptive
 * @link        https://gcadaptive.com/
 * @since       Adaptive 1.0
 */

if ( ! class_exists( 'Adaptive_Gcml_Compatibility' ) ) :

	/**
	 * GCML Compatibility
	 */
	// @codingStandardsIgnoreStart
	final class Adaptive_Gcml_Compatibility { // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedClassFound
		// @codingStandardsIgnoreEnd

		/**
		 * Instance of Adaptive_Gcml_Compatibility.
		 *
		 * @since  1.1.0
		 * @var null
		 */
		private static $instance = null;

		/**
		 * Get instance of Adaptive_Gcml_Compatibility
		 *
		 * @since  1.1.0
		 * @return Adaptive_Gcml_Compatibility
		 */
		public static function instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		/**
		 * Setup actions and filters.
		 *
		 * @since  1.1.0
		 */
		private function __construct() {
			add_filter( 'adaptive_addon_get_display_posts_by_conditions', array( $this, 'get_advanced_hook_gcml_object' ), 10, 2 );
		}

		/**
		 * Pass the current page advanced hook display posts to GCML's object filter to allow strings to be translated.
		 *
		 * @since  1.1.0
		 * @param  object $current_posts Posts.
		 * @param  string $post_type Post Type.
		 *
		 * @return object  Posts.
		 */
		public function get_advanced_hook_gcml_object( $current_posts, $post_type ) {

			if ( 'adaptive-advanced-hook' === $post_type ) {

				$gcml_filter_posts = $current_posts;

				foreach ( $current_posts as $post_id => $post_data ) {

					// Get tralated post id here.
					$gcml_filter_id = apply_filters( 'gcml_object_id', $post_id, 'adaptive-advanced-hook', true ); // phpcs:ignore GeChiUI.NamingConventions.PrefixAllGlobals.NonPrefixedHooknameFound

					if ( null !== $gcml_filter_id ) {

						if ( $post_id !== $gcml_filter_id && isset( $gcml_filter_posts[ $post_id ] ) ) {

							$gcml_filter_posts[ $gcml_filter_id ]       = $gcml_filter_posts[ $post_id ];
							$gcml_filter_posts[ $gcml_filter_id ]['id'] = $gcml_filter_id;

							unset( $gcml_filter_posts[ $post_id ] );
						}
					}
				}

				$current_posts = $gcml_filter_posts;
			}

			return $current_posts;
		}
	}
endif;

/**
 * Initiate the class.
 */
Adaptive_Gcml_Compatibility::instance();
